local addonName, bepgp = ...
local moduleName = addonName.."_prices_wrath"
local bepgp_prices_wrath = bepgp:NewModule(moduleName, "AceEvent-3.0")
local ST = LibStub("ScrollingTable")
local name_version = "BastionEPGP_LK-1.0"
local prices = {}
local GetItemInventoryTypeByID = C_Item and C_Item.GetItemInventoryTypeByID or _G.GetItemInventoryTypeByID

local EQUIPSLOT_MULTIPLIER_1 = {
  INVTYPE_HEAD = 1,
  INVTYPE_NECK = 0.5,
  INVTYPE_SHOULDER = 0.75,
  INVTYPE_CHEST = 1,
  INVTYPE_ROBE = 1,
  INVTYPE_WAIST = 0.75,
  INVTYPE_LEGS = 1,
  INVTYPE_FEET = 0.75,
  INVTYPE_WRIST = 0.5,
  INVTYPE_HAND = 0.75,
  INVTYPE_FINGER = 0.5,
  INVTYPE_TRINKET = 0.75,
  INVTYPE_CLOAK = 0.5,
  INVTYPE_WEAPON = 1.5,
  INVTYPE_SHIELD = 1.5,
  INVTYPE_2HWEAPON = 2,
  INVTYPE_WEAPONMAINHAND = 1.5,
  INVTYPE_WEAPONOFFHAND = 0.5,
  INVTYPE_HOLDABLE = 0.5,
  INVTYPE_RANGED = 1.5,
  INVTYPE_RANGEDRIGHT = 1.5,
  INVTYPE_THROWN = 0.5,
  INVTYPE_RELIC = 0.5,
  -- Hack for Tier 9 25M heroic tokens.
  INVTYPE_CUSTOM_MULTISLOT_TIER = 0.9,
}

-- This is the low price equipslot multiplier (off hand weapons, non
-- tanking shields).
local EQUIPSLOT_MULTIPLIER_2 = {
  INVTYPE_WEAPON = 0.5,     -- One-handed subtype for melee Off-hand weapon or Tank Main-hand
  INVTYPE_SHIELD = 0.5,     -- for Non-tank Shield
  INVTYPE_2HWEAPON = 1,     -- Hunter or Titan Grip Off-hand
  INVTYPE_RANGED = 0.5,     -- Non-hunter Ranged Weapon
  INVTYPE_RANGEDRIGHT = 0.5,-- Non-hunter Ranged Weapon or Wands
}



--Used to display GP values directly on tier tokens
local CUSTOM_ITEM_DATA = {
  -- Tier 4
  [29753] = { 4, 120, "INVTYPE_CHEST" },
  [29754] = { 4, 120, "INVTYPE_CHEST" },
  [29755] = { 4, 120, "INVTYPE_CHEST" },
  [29756] = { 4, 120, "INVTYPE_HAND" },
  [29757] = { 4, 120, "INVTYPE_HAND" },
  [29758] = { 4, 120, "INVTYPE_HAND" },
  [29759] = { 4, 120, "INVTYPE_HEAD" },
  [29760] = { 4, 120, "INVTYPE_HEAD" },
  [29761] = { 4, 120, "INVTYPE_HEAD" },
  [29762] = { 4, 120, "INVTYPE_SHOULDER" },
  [29763] = { 4, 120, "INVTYPE_SHOULDER" },
  [29764] = { 4, 120, "INVTYPE_SHOULDER" },
  [29765] = { 4, 120, "INVTYPE_LEGS" },
  [29766] = { 4, 120, "INVTYPE_LEGS" },
  [29767] = { 4, 120, "INVTYPE_LEGS" },

  -- Tier 5
  [30236] = { 4, 133, "INVTYPE_CHEST" },
  [30237] = { 4, 133, "INVTYPE_CHEST" },
  [30238] = { 4, 133, "INVTYPE_CHEST" },
  [30239] = { 4, 133, "INVTYPE_HAND" },
  [30240] = { 4, 133, "INVTYPE_HAND" },
  [30241] = { 4, 133, "INVTYPE_HAND" },
  [30242] = { 4, 133, "INVTYPE_HEAD" },
  [30243] = { 4, 133, "INVTYPE_HEAD" },
  [30244] = { 4, 133, "INVTYPE_HEAD" },
  [30245] = { 4, 133, "INVTYPE_LEGS" },
  [30246] = { 4, 133, "INVTYPE_LEGS" },
  [30247] = { 4, 133, "INVTYPE_LEGS" },
  [30248] = { 4, 133, "INVTYPE_SHOULDER" },
  [30249] = { 4, 133, "INVTYPE_SHOULDER" },
  [30250] = { 4, 133, "INVTYPE_SHOULDER" },

  -- Tier 5 - BoE recipes - BoP crafts
  [30282] = { 4, 128, "INVTYPE_BOOTS" },
  [30283] = { 4, 128, "INVTYPE_BOOTS" },
  [30305] = { 4, 128, "INVTYPE_BOOTS" },
  [30306] = { 4, 128, "INVTYPE_BOOTS" },
  [30307] = { 4, 128, "INVTYPE_BOOTS" },
  [30308] = { 4, 128, "INVTYPE_BOOTS" },
  [30323] = { 4, 128, "INVTYPE_BOOTS" },
  [30324] = { 4, 128, "INVTYPE_BOOTS" },

  -- Tier 6
  [31089] = { 4, 146, "INVTYPE_CHEST" },
  [31090] = { 4, 146, "INVTYPE_CHEST" },
  [31091] = { 4, 146, "INVTYPE_CHEST" },
  [31092] = { 4, 146, "INVTYPE_HAND" },
  [31093] = { 4, 146, "INVTYPE_HAND" },
  [31094] = { 4, 146, "INVTYPE_HAND" },
  [31095] = { 4, 146, "INVTYPE_HEAD" },
  [31096] = { 4, 146, "INVTYPE_HEAD" },
  [31097] = { 4, 146, "INVTYPE_HEAD" },
  [31098] = { 4, 146, "INVTYPE_LEGS" },
  [31099] = { 4, 146, "INVTYPE_LEGS" },
  [31100] = { 4, 146, "INVTYPE_LEGS" },
  [31101] = { 4, 146, "INVTYPE_SHOULDER" },
  [31102] = { 4, 146, "INVTYPE_SHOULDER" },
  [31103] = { 4, 146, "INVTYPE_SHOULDER" },
  [34848] = { 4, 154, "INVTYPE_WRIST" },
  [34851] = { 4, 154, "INVTYPE_WRIST" },
  [34852] = { 4, 154, "INVTYPE_WRIST" },
  [34853] = { 4, 154, "INVTYPE_WAIST" },
  [34854] = { 4, 154, "INVTYPE_WAIST" },
  [34855] = { 4, 154, "INVTYPE_WAIST" },
  [34856] = { 4, 154, "INVTYPE_FEET" },
  [34857] = { 4, 154, "INVTYPE_FEET" },
  [34858] = { 4, 154, "INVTYPE_FEET" },

  -- Tier 6 - BoE recipes - BoP crafts
  [32737] = { 4, 141, "INVTYPE_SHOULDER" },
  [32739] = { 4, 141, "INVTYPE_SHOULDER" },
  [32745] = { 4, 141, "INVTYPE_SHOULDER" },
  [32747] = { 4, 141, "INVTYPE_SHOULDER" },
  [32749] = { 4, 141, "INVTYPE_SHOULDER" },
  [32751] = { 4, 141, "INVTYPE_SHOULDER" },
  [32753] = { 4, 141, "INVTYPE_SHOULDER" },
  [32755] = { 4, 141, "INVTYPE_SHOULDER" },

  -- Magtheridon's Head
  [32385] = { 4, 125, "INVTYPE_FINGER" },
  [32386] = { 4, 125, "INVTYPE_FINGER" },

  -- Kael'thas' Sphere
  [32405] = { 4, 138, "INVTYPE_NECK" },

  -- T7
  [40610] = { 4, 200, "INVTYPE_CHEST" },
  [40611] = { 4, 200, "INVTYPE_CHEST" },
  [40612] = { 4, 200, "INVTYPE_CHEST" },
  [40613] = { 4, 200, "INVTYPE_HAND" },
  [40614] = { 4, 200, "INVTYPE_HAND" },
  [40615] = { 4, 200, "INVTYPE_HAND" },
  [40616] = { 4, 200, "INVTYPE_HEAD" },
  [40617] = { 4, 200, "INVTYPE_HEAD" },
  [40618] = { 4, 200, "INVTYPE_HEAD" },
  [40619] = { 4, 200, "INVTYPE_LEGS" },
  [40620] = { 4, 200, "INVTYPE_LEGS" },
  [40621] = { 4, 200, "INVTYPE_LEGS" },
  [40622] = { 4, 200, "INVTYPE_SHOULDER" },
  [40623] = { 4, 200, "INVTYPE_SHOULDER" },
  [40624] = { 4, 200, "INVTYPE_SHOULDER" },

  -- T7 (heroic)
  [40625] = { 4, 213, "INVTYPE_CHEST" },
  [40626] = { 4, 213, "INVTYPE_CHEST" },
  [40627] = { 4, 213, "INVTYPE_CHEST" },
  [40628] = { 4, 213, "INVTYPE_HAND" },
  [40629] = { 4, 213, "INVTYPE_HAND" },
  [40630] = { 4, 213, "INVTYPE_HAND" },
  [40631] = { 4, 213, "INVTYPE_HEAD" },
  [40632] = { 4, 213, "INVTYPE_HEAD" },
  [40633] = { 4, 213, "INVTYPE_HEAD" },
  [40634] = { 4, 213, "INVTYPE_LEGS" },
  [40635] = { 4, 213, "INVTYPE_LEGS" },
  [40636] = { 4, 213, "INVTYPE_LEGS" },
  [40637] = { 4, 213, "INVTYPE_SHOULDER" },
  [40638] = { 4, 213, "INVTYPE_SHOULDER" },
  [40639] = { 4, 213, "INVTYPE_SHOULDER" },

  -- Key to the Focusing Iris
  [44569] = { 4, 213, "INVTYPE_NECK" },
  [44577] = { 4, 226, "INVTYPE_NECK" },

  -- T8
  [45635] = { 4, 225, "INVTYPE_CHEST" },
  [45636] = { 4, 225, "INVTYPE_CHEST" },
  [45637] = { 4, 225, "INVTYPE_CHEST" },
  [45647] = { 4, 225, "INVTYPE_HEAD" },
  [45648] = { 4, 225, "INVTYPE_HEAD" },
  [45649] = { 4, 225, "INVTYPE_HEAD" },
  [45644] = { 4, 225, "INVTYPE_HAND" },
  [45645] = { 4, 225, "INVTYPE_HAND" },
  [45646] = { 4, 225, "INVTYPE_HAND" },
  [45650] = { 4, 225, "INVTYPE_LEGS" },
  [45651] = { 4, 225, "INVTYPE_LEGS" },
  [45652] = { 4, 225, "INVTYPE_LEGS" },
  [45659] = { 4, 225, "INVTYPE_SHOULDER" },
  [45660] = { 4, 225, "INVTYPE_SHOULDER" },
  [45661] = { 4, 225, "INVTYPE_SHOULDER" },

  -- T8 (heroic)
  [45632] = { 4, 232, "INVTYPE_CHEST" },
  [45633] = { 4, 232, "INVTYPE_CHEST" },
  [45634] = { 4, 232, "INVTYPE_CHEST" },
  [45638] = { 4, 232, "INVTYPE_HEAD" },
  [45639] = { 4, 232, "INVTYPE_HEAD" },
  [45640] = { 4, 232, "INVTYPE_HEAD" },
  [45641] = { 4, 232, "INVTYPE_HAND" },
  [45642] = { 4, 232, "INVTYPE_HAND" },
  [45643] = { 4, 232, "INVTYPE_HAND" },
  [45653] = { 4, 232, "INVTYPE_LEGS" },
  [45654] = { 4, 232, "INVTYPE_LEGS" },
  [45655] = { 4, 232, "INVTYPE_LEGS" },
  [45656] = { 4, 232, "INVTYPE_SHOULDER" },
  [45657] = { 4, 232, "INVTYPE_SHOULDER" },
  [45658] = { 4, 232, "INVTYPE_SHOULDER" },

  -- Reply Code Alpha
  [46052] = { 4, 239, "INVTYPE_FINGER" },
  [46053] = { 4, 252, "INVTYPE_FINGER" },

  -- T9.245 (10M heroic/25M)
  [47242] = { 4, 245, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [49643] = { 4, 245, "INVTYPE_FINGER" }, -- Head of Onyxia (H)
  [49644] = { 4, 245, "INVTYPE_FINGER" }, -- Head of Onyxia (A)

  -- T9.258 (25M heroic)
  [47557] = { 4, 258, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [47558] = { 4, 258, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [47559] = { 4, 258, "INVTYPE_CUSTOM_MULTISLOT_TIER" },

  -- T10.264 (10M heroic/25M)
  [52025] = { 4, 264, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [52026] = { 4, 264, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [52027] = { 4, 264, "INVTYPE_CUSTOM_MULTISLOT_TIER" },

  -- T10.279 (25M heroic)
  [52028] = { 4, 277, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [52029] = { 4, 277, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
  [52030] = { 4, 277, "INVTYPE_CUSTOM_MULTISLOT_TIER" },
}-- hateful, deadly, furious, relentless, wrathful
local CACHED_ITEM_DATA = {
  [37169] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"War Mace of Unrequited Love"
  [37170] = {4,200,"INVTYPE_WRIST"}, --"Interwoven Scale Bracers"
  [37171] = {4,200,"INVTYPE_WAIST"}, --"Flame-Bathed Steel Girdle"
  [37172] = {4,200,"INVTYPE_HAND"}, --"Gloves of Glistening Runes"
  [37191] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Drake-Mounted Crossbow"
  [37192] = {4,200,"INVTYPE_FINGER"}, --"Annhylde's Ring"
  [37193] = {4,200,"INVTYPE_LEGS"}, --"Staggering Legplates"
  [37194] = {4,200,"INVTYPE_WAIST"}, --"Sharp-Barbed Leather Belt"
  [37238] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Rod of the Fallen Monarch"
  [37240] = {4,200,"INVTYPE_WRIST"}, --"Flamebeard's Bracers"
  [37241] = {4,200,"INVTYPE_WAIST"}, --"Ancient Aligned Girdle"
  [37242] = {4,200,"INVTYPE_WAIST"}, --"Sash of the Servant"
  [37254] = {4,200,"INVTYPE_TRINKET"}, --"Super Simian Sphere"
  [37360] = {4,200,"INVTYPE_2HWEAPON"}, --"Staff of Draconic Combat"
  [37361] = {4,200,"INVTYPE_WRIST"}, --"Cuffs of Winged Levitation"
  [37362] = {4,200,"INVTYPE_LEGS"}, --"Leggings of Protective Auras"
  [37363] = {4,200,"INVTYPE_HAND"}, --"Gauntlets of Dragon Wrath"
  [37401] = {4,200,"INVTYPE_WEAPON"}, --"Red Sword of Courage"
  [37407] = {4,200,"INVTYPE_WAIST"}, --"Sovereign's Belt"
  [37408] = {4,200,"INVTYPE_WAIST"}, --"Girdle of Bane"
  [37409] = {4,200,"INVTYPE_HAND"}, --"Gilt-Edged Leather Gauntlets"
  [37619] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Wand of Ahn'kahet"
  [37620] = {4,200,"INVTYPE_WRIST"}, --"Bracers of the Herald"
  [37622] = {4,200,"INVTYPE_LEGS"}, --"Skirt of the Old Kingdom"
  [37623] = {4,200,"INVTYPE_HAND"}, --"Fiery Obelisk Handguards"
  [37642] = {4,200,"INVTYPE_FINGER"}, --"Hemorrhaging Circle"
  [37643] = {4,200,"INVTYPE_WAIST"}, --"Sash of Blood Removal"
  [37644] = {4,200,"INVTYPE_LEGS"}, --"Gored Hide Legguards"
  [37645] = {4,200,"INVTYPE_HAND"}, --"Horn-Tipped Gauntlets"
  [37667] = {4,200,"INVTYPE_WEAPON"}, --"The Fleshshaper"
  [37668] = {4,200,"INVTYPE_WRIST"}, --"Bands of the Stoneforge"
  [37669] = {4,200,"INVTYPE_LEGS"}, --"Leggings of the Stone Halls"
  [37670] = {4,200,"INVTYPE_WAIST"}, --"Sjonnir's Girdle"
  [37693] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Greed"
  [37694] = {4,200,"INVTYPE_FINGER"}, --"Band of Guile"
  [37695] = {4,200,"INVTYPE_LEGS"}, --"Legguards of Nature's Power"
  [37696] = {4,200,"INVTYPE_WRIST"}, --"Plague-Infected Bracers"
  [37784] = {4,200,"INVTYPE_FINGER"}, --"Keystone Great-Ring"
  [37788] = {4,200,"INVTYPE_WRIST"}, --"Limb Regeneration Bracers"
  [37791] = {4,200,"INVTYPE_LEGS"}, --"Leggings of the Winged Serpent"
  [37798] = {4,200,"INVTYPE_HAND"}, --"Overlook Handguards"
  [37835] = {4,200,"INVTYPE_TRINKET"}, --"Je'Tze's Bell"
  [37852] = {4,200,"INVTYPE_2HWEAPON"}, --"Colossal Skull-Clad Cleaver"
  [37853] = {4,200,"INVTYPE_WRIST"}, --"Advanced Tooled-Leather Bands"
  [37854] = {4,200,"INVTYPE_LEGS"}, --"Woven Bracae Leggings"
  [37855] = {4,200,"INVTYPE_WAIST"}, --"Mail Girdle of the Audient Earth"
  [37883] = {4,200,"INVTYPE_2HWEAPON"}, --"Staff of Trickery"
  [37884] = {4,200,"INVTYPE_WRIST"}, --"Azure Cloth Bindings"
  [37886] = {4,200,"INVTYPE_HAND"}, --"Handgrips of the Savage Emissary"
  [38322] = {4,200,"INVTYPE_HOLDABLE"}, --"Iron-bound Tome"
  [39139] = {4,200,"INVTYPE_FEET"}, --"Ravaging Sabatons"
  [39140] = {4,200,"INVTYPE_WEAPON"}, --"Knife of Incision"
  [39141] = {4,200,"INVTYPE_FINGER"}, --"Deflection Band"
  [39146] = {4,200,"INVTYPE_NECK"}, --"Collar of Dissolution"
  [39188] = {4,200,"INVTYPE_CHEST"}, --"Chivalric Chestguard"
  [39189] = {4,200,"INVTYPE_FEET"}, --"Boots of Persistence"
  [39190] = {4,200,"INVTYPE_WAIST"}, --"Agonal Sash"
  [39191] = {4,200,"INVTYPE_LEGS"}, --"Splint-Bound Leggings"
  [39192] = {4,200,"INVTYPE_HAND"}, --"Gloves of Dark Gestures"
  [39193] = {4,200,"INVTYPE_FINGER"}, --"Band of Neglected Pleas"
  [39194] = {4,200,"INVTYPE_HAND"}, --"Rusted-Link Spiked Gauntlets"
  [39195] = {4,200,"INVTYPE_WRIST"}, --"Bracers of Lost Sentiments"
  [39196] = {4,200,"INVTYPE_FEET"}, --"Boots of the Worshiper"
  [39197] = {4,200,"INVTYPE_HAND"}, --"Gauntlets of the Master"
  [39198] = {4,200,"INVTYPE_SHOULDER"}, --"Frostblight Pauldrons"
  [39199] = {4,200,"INVTYPE_HOLDABLE"}, --"Watchful Eye"
  [39200] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Grieving Spellblade"
  [39215] = {4,200,"INVTYPE_FEET"}, --"Boots of the Follower"
  [39216] = {4,200,"INVTYPE_WAIST"}, --"Sash of Mortal Desire"
  [39217] = {4,200,"INVTYPE_LEGS"}, --"Avenging Combat Leggings"
  [39221] = {4,200,"INVTYPE_2HWEAPON"}, --"Wraith Spear"
  [39224] = {4,200,"INVTYPE_LEGS"}, --"Leggings of Discord"
  [39225] = {4,200,"INVTYPE_CLOAK"}, --"Cloak of Armed Strife"
  [39226] = {4,200,"INVTYPE_WEAPON"}, --"Maexxna's Femur"
  [39228] = {4,200,"INVTYPE_HAND"}, --"Web Cocoon Grips"
  [39229] = {4,200,"INVTYPE_TRINKET"}, --"Embrace of the Spider"
  [39230] = {4,200,"INVTYPE_SHOULDER"}, --"Spaulders of the Monstrosity"
  [39231] = {4,200,"INVTYPE_FINGER"}, --"Timeworn Silken Band"
  [39232] = {4,200,"INVTYPE_NECK"}, --"Pendant of Lost Vocations"
  [39233] = {4,200,"INVTYPE_SHIELD"}, --"Aegis of Damnation"
  [39234] = {4,200,"INVTYPE_FEET"}, --"Plague-Impervious Boots"
  [39235] = {4,200,"INVTYPE_WRIST"}, --"Bone-Framed Bracers"
  [39236] = {4,200,"INVTYPE_FEET"}, --"Trespasser's Boots"
  [39237] = {4,200,"INVTYPE_SHOULDER"}, --"Spaulders of Resumed Battle"
  [39239] = {4,200,"INVTYPE_CHEST"}, --"Chestplate of the Risen Soldier"
  [39240] = {4,200,"INVTYPE_HEAD"}, --"Noth's Curse"
  [39241] = {4,200,"INVTYPE_CLOAK"}, --"Dark Shroud of the Scourge"
  [39242] = {4,200,"INVTYPE_ROBE"}, --"Robes of Hoarse Breaths"
  [39243] = {4,200,"INVTYPE_HAND"}, --"Handgrips of the Foredoomed"
  [39244] = {4,200,"INVTYPE_FINGER"}, --"Ring of the Fated"
  [39245] = {4,200,"INVTYPE_2HWEAPON"}, --"Demise"
  [39246] = {4,200,"INVTYPE_NECK"}, --"Amulet of Autopsy"
  [39247] = {4,200,"INVTYPE_WRIST"}, --"Cuffs of Dark Shadows"
  [39248] = {4,200,"INVTYPE_CHEST"}, --"Tunic of the Lost Pack"
  [39249] = {4,200,"INVTYPE_SHOULDER"}, --"Shoulderplates of Bloodshed"
  [39250] = {4,200,"INVTYPE_FINGER"}, --"Ring of Holy Cleansing"
  [39251] = {4,200,"INVTYPE_WAIST"}, --"Necrogenic Belt"
  [39252] = {4,200,"INVTYPE_WRIST"}, --"Preceptor's Bindings"
  [39254] = {4,200,"INVTYPE_FEET"}, --"Saltarello Shoes"
  [39255] = {4,200,"INVTYPE_2HWEAPON"}, --"Staff of the Plague Beast"
  [39256] = {4,200,"INVTYPE_2HWEAPON"}, --"Sulfur Stave"
  [39257] = {4,200,"INVTYPE_TRINKET"}, --"Loatheb's Shadow"
  [39258] = {4,200,"INVTYPE_LEGS"}, --"Legplates of Inescapable Death"
  [39259] = {4,200,"INVTYPE_CHEST"}, --"Fungi-Stained Coverings"
  [39260] = {4,200,"INVTYPE_HEAD"}, --"Helm of the Corrupted Mind"
  [39261] = {4,200,"INVTYPE_WAIST"}, --"Tainted Girdle of Mending"
  [39262] = {4,200,"INVTYPE_HAND"}, --"Gauntlets of Combined Strength"
  [39263] = {4,200,"INVTYPE_LEGS"}, --"Dissevered Leggings"
  [39267] = {4,200,"INVTYPE_SHOULDER"}, --"Abomination Shoulderblades"
  [39270] = {4,200,"INVTYPE_WEAPON"}, --"Hatestrike"
  [39271] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Blade of Dormant Memories"
  [39272] = {4,200,"INVTYPE_CLOAK"}, --"Drape of Surgery"
  [39273] = {4,200,"INVTYPE_FEET"}, --"Sullen Cloth Boots"
  [39274] = {4,200,"INVTYPE_SHOULDER"}, --"Retcher's Shoulderpads"
  [39275] = {4,200,"INVTYPE_HAND"}, --"Contagion Gloves"
  [39276] = {4,200,"INVTYPE_SHIELD"}, --"The Skull of Ruin"
  [39277] = {4,200,"INVTYPE_FINGER"}, --"Sealing Ring of Grobbulus"
  [39278] = {4,200,"INVTYPE_WRIST"}, --"Bands of Anxiety"
  [39279] = {4,200,"INVTYPE_WAIST"}, --"Blistered Belt of Decay"
  [39280] = {4,200,"INVTYPE_LEGS"}, --"Leggings of Innumerable Barbs"
  [39281] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Infection Repulser"
  [39282] = {4,200,"INVTYPE_NECK"}, --"Bone-Linked Amulet"
  [39283] = {4,200,"INVTYPE_WRIST"}, --"Putrescent Bands"
  [39284] = {4,200,"INVTYPE_SHOULDER"}, --"Miasma Mantle"
  [39285] = {4,200,"INVTYPE_HAND"}, --"Handgrips of Turmoil"
  [39291] = {4,200,"INVTYPE_WEAPON"}, --"Torment of the Banished"
  [39292] = {4,200,"INVTYPE_TRINKET"}, --"Repelling Charge"
  [39293] = {4,200,"INVTYPE_LEGS"}, --"Blackened Legplates of Feugen"
  [39294] = {4,200,"INVTYPE_HEAD"}, --"Arc-Scorched Helmet"
  [39295] = {4,200,"INVTYPE_HEAD"}, --"Cowl of Sheet Lightning"
  [39296] = {4,200,"INVTYPE_RANGED"}, --"Accursed Bow of the Elite"
  [39297] = {4,200,"INVTYPE_CLOAK"}, --"Cloak of Darkening"
  [39298] = {4,200,"INVTYPE_WAIST"}, --"Waistguard of the Tutor"
  [39299] = {4,200,"INVTYPE_HAND"}, --"Rapid Attack Gloves"
  [39306] = {4,200,"INVTYPE_HAND"}, --"Plated Gloves of Relief"
  [39307] = {4,200,"INVTYPE_WRIST"}, --"Iron Rings of Endurance"
  [39308] = {4,200,"INVTYPE_WAIST"}, --"Girdle of Lenience"
  [39309] = {4,200,"INVTYPE_LEGS"}, --"Leggings of the Instructor"
  [39310] = {4,200,"INVTYPE_SHOULDER"}, --"Mantle of the Extensive Mind"
  [39311] = {4,200,"INVTYPE_HOLDABLE"}, --"Scepter of Murmuring Spirits"
  [39344] = {4,200,"INVTYPE_WEAPON"}, --"Slayer of the Lifeless"
  [39345] = {4,200,"INVTYPE_WAIST"}, --"Girdle of the Ascended Phantom"
  [39369] = {4,200,"INVTYPE_FEET"}, --"Sabatons of Deathlike Gloom"
  [39379] = {4,200,"INVTYPE_WAIST"}, --"Spectral Rider's Girdle"
  [39386] = {4,200,"INVTYPE_CHEST"}, --"Tunic of Dislocation"
  [39388] = {4,200,"INVTYPE_TRINKET"}, --"Spirit-World Glass"
  [39389] = {4,200,"INVTYPE_FINGER"}, --"Signet of the Malevolent"
  [39390] = {4,200,"INVTYPE_WRIST"}, --"Resurgent Phantom Bindings"
  [39391] = {4,200,"INVTYPE_CHEST"}, --"Heinous Mail Chestguard"
  [39392] = {4,200,"INVTYPE_NECK"}, --"Veiled Amulet of Life"
  [39393] = {4,200,"INVTYPE_2HWEAPON"}, --"Claymore of Ancient Power"
  [39394] = {4,200,"INVTYPE_2HWEAPON"}, --"Charmed Cierge"
  [39395] = {4,200,"INVTYPE_HEAD"}, --"Thane's Tainted Greathelm"
  [39396] = {4,200,"INVTYPE_ROBE"}, --"Gown of Blaumeux"
  [39397] = {4,200,"INVTYPE_SHOULDER"}, --"Pauldrons of Havoc"
  [39398] = {4,200,"INVTYPE_CHEST"}, --"Massive Skeletal Ribcage"
  [39399] = {4,200,"INVTYPE_HEAD"}, --"Helm of the Vast Legions"
  [39401] = {4,200,"INVTYPE_FINGER"}, --"Circle of Death"
  [39403] = {4,200,"INVTYPE_HEAD"}, --"Helm of the Unsubmissive"
  [39404] = {4,200,"INVTYPE_CLOAK"}, --"Cloak of Mastery"
  [39405] = {4,200,"INVTYPE_HEAD"}, --"Helmet of the Inner Sanctum"
  [39407] = {4,200,"INVTYPE_FINGER"}, --"Circle of Life"
  [39408] = {4,200,"INVTYPE_LEGS"}, --"Leggings of Sapphiron"
  [39409] = {4,200,"INVTYPE_HEAD"}, --"Cowl of Winged Fear"
  [39415] = {4,200,"INVTYPE_CLOAK"}, --"Shroud of the Citadel"
  [39416] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"Kel'Thuzad's Reach"
  [39417] = {4,213,"INVTYPE_2HWEAPON"}, --"Death's Bite"
  [39419] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Nerubian Conquerer"
  [39420] = {4,213,"INVTYPE_WEAPON"}, --"Anarchy"
  [39421] = {4,213,"INVTYPE_NECK"}, --"Gem of Imprisoned Vassals"
  [39422] = {4,213,"INVTYPE_2HWEAPON"}, --"Staff of the Plaguehound"
  [39423] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"Hammer of the Astral Plane"
  [39424] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"The Soulblade"
  [39425] = {4,213,"INVTYPE_CLOAK"}, --"Cloak of the Dying"
  [39426] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Wand of the Archlich"
  [39427] = {4,200,"INVTYPE_WEAPON"}, --"Omen of Ruin"
  [39467] = {4,200,"INVTYPE_WRIST"}, --"Minion Bracers"
  [39468] = {4,200,"INVTYPE_WEAPONOFFHAND"}, --"The Stray"
  [39470] = {4,200,"INVTYPE_NECK"}, --"Medallion of the Disgraced"
  [39472] = {4,200,"INVTYPE_NECK"}, --"Chain of Latent Energies"
  [39473] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Contortion"
  [39491] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Frostfire Circlet"
  [39492] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Frostfire Robe"
  [39493] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Frostfire Leggings"
  [39494] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Frostfire Shoulderpads"
  [39495] = {4,200,"INVTYPE_HAND"}, --"Heroes' Frostfire Gloves"
  [39496] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Plagueheart Circlet"
  [39497] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Plagueheart Robe"
  [39498] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Plagueheart Leggings"
  [39499] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Plagueheart Shoulderpads"
  [39500] = {4,200,"INVTYPE_HAND"}, --"Heroes' Plagueheart Gloves"
  [39514] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Crown of Faith"
  [39515] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Robe of Faith"
  [39517] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Leggings of Faith"
  [39518] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Shoulderpads of Faith"
  [39519] = {4,200,"INVTYPE_HAND"}, --"Heroes' Gloves of Faith"
  [39521] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Circlet of Faith"
  [39523] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Raiments of Faith"
  [39528] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Pants of Faith"
  [39529] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Mantle of Faith"
  [39530] = {4,200,"INVTYPE_HAND"}, --"Heroes' Handwraps of Faith"
  [39531] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Dreamwalker Headpiece"
  [39538] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Dreamwalker Robe"
  [39539] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Dreamwalker Leggings"
  [39542] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Dreamwalker Spaulders"
  [39543] = {4,200,"INVTYPE_HAND"}, --"Heroes' Dreamwalker Handguards"
  [39544] = {4,200,"INVTYPE_HAND"}, --"Heroes' Dreamwalker Gloves"
  [39545] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Dreamwalker Cover"
  [39546] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Dreamwalker Trousers"
  [39547] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Dreamwalker Vestments"
  [39548] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Dreamwalker Mantle"
  [39553] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Dreamwalker Headguard"
  [39554] = {4,200,"INVTYPE_ROBE"}, --"Heroes' Dreamwalker Raiments"
  [39555] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Dreamwalker Legguards"
  [39556] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Dreamwalker Shoulderpads"
  [39557] = {4,200,"INVTYPE_HAND"}, --"Heroes' Dreamwalker Handgrips"
  [39558] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Bonescythe Breastplate"
  [39560] = {4,200,"INVTYPE_HAND"}, --"Heroes' Bonescythe Gauntlets"
  [39561] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Bonescythe Helmet"
  [39564] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Bonescythe Legplates"
  [39565] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Bonescythe Pauldrons"
  [39578] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Cryptstalker Headpiece"
  [39579] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Cryptstalker Tunic"
  [39580] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Cryptstalker Legguards"
  [39581] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Cryptstalker Spaulders"
  [39582] = {4,200,"INVTYPE_HAND"}, --"Heroes' Cryptstalker Handguards"
  [39583] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Earthshatter Headpiece"
  [39588] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Earthshatter Tunic"
  [39589] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Earthshatter Legguards"
  [39590] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Earthshatter Spaulders"
  [39591] = {4,200,"INVTYPE_HAND"}, --"Heroes' Earthshatter Handguards"
  [39592] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Earthshatter Hauberk"
  [39593] = {4,200,"INVTYPE_HAND"}, --"Heroes' Earthshatter Gloves"
  [39594] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Earthshatter Helm"
  [39595] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Earthshatter Kilt"
  [39596] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Earthshatter Shoulderpads"
  [39597] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Earthshatter Chestguard"
  [39601] = {4,200,"INVTYPE_HAND"}, --"Heroes' Earthshatter Grips"
  [39602] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Earthshatter Faceguard"
  [39603] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Earthshatter War-Kilt"
  [39604] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Earthshatter Shoulderguards"
  [39605] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Dreadnaught Helmet"
  [39606] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Dreadnaught Battleplate"
  [39607] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Dreadnaught Legplates"
  [39608] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Dreadnaught Shoulderplates"
  [39609] = {4,200,"INVTYPE_HAND"}, --"Heroes' Dreadnaught Gauntlets"
  [39610] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Dreadnaught Greathelm"
  [39611] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Dreadnaught Breastplate"
  [39612] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Dreadnaught Legguards"
  [39613] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Dreadnaught Pauldrons"
  [39617] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Scourgeborne Battleplate"
  [39618] = {4,200,"INVTYPE_HAND"}, --"Heroes' Scourgeborne Gauntlets"
  [39619] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Scourgeborne Helmet"
  [39620] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Scourgeborne Legplates"
  [39621] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Scourgeborne Shoulderplates"
  [39622] = {4,200,"INVTYPE_HAND"}, --"Heroes' Dreadnaught Handguards"
  [39623] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Scourgeborne Chestguard"
  [39624] = {4,200,"INVTYPE_HAND"}, --"Heroes' Scourgeborne Handguards"
  [39625] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Scourgeborne Faceguard"
  [39626] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Scourgeborne Legguards"
  [39627] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Scourgeborne Pauldrons"
  [39628] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Redemption Headpiece"
  [39629] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Redemption Tunic"
  [39630] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Redemption Greaves"
  [39631] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Redemption Spaulders"
  [39632] = {4,200,"INVTYPE_HAND"}, --"Heroes' Redemption Gloves"
  [39633] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Redemption Chestpiece"
  [39634] = {4,200,"INVTYPE_HAND"}, --"Heroes' Redemption Gauntlets"
  [39635] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Redemption Helm"
  [39636] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Redemption Legplates"
  [39637] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Redemption Shoulderplates"
  [39638] = {4,200,"INVTYPE_CHEST"}, --"Heroes' Redemption Breastplate"
  [39639] = {4,200,"INVTYPE_HAND"}, --"Heroes' Redemption Handguards"
  [39640] = {4,200,"INVTYPE_HEAD"}, --"Heroes' Redemption Faceguard"
  [39641] = {4,200,"INVTYPE_LEGS"}, --"Heroes' Redemption Legguards"
  [39642] = {4,200,"INVTYPE_SHOULDER"}, --"Heroes' Redemption Shoulderguards"
  [39701] = {4,213,"INVTYPE_FEET"}, --"Dawnwalkers"
  [39702] = {4,213,"INVTYPE_WRIST"}, --"Arachnoid Gold Band"
  [39703] = {4,213,"INVTYPE_HAND"}, --"Rescinding Grips"
  [39704] = {4,213,"INVTYPE_SHOULDER"}, --"Pauldrons of Unnatural Death"
  [39706] = {4,213,"INVTYPE_FEET"}, --"Sabatons of Sudden Reprisal"
  [39712] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Gemmed Wand of the Nerubians"
  [39714] = {4,213,"INVTYPE_WEAPON"}, --"Webbed Death"
  [39715] = {4,213,"INVTYPE_RELIC"}, --"Sigil of the Remembered Fallen - DO NOT USE"
  [39716] = {4,213,"INVTYPE_SHIELD"}, --"Shield of Assimilation"
  [39717] = {4,213,"INVTYPE_FEET"}, --"Inexorable Sabatons"
  [39718] = {4,213,"INVTYPE_HAND"}, --"Corpse Scarab Handguards"
  [39719] = {4,213,"INVTYPE_SHOULDER"}, --"Mantle of the Locusts"
  [39720] = {4,213,"INVTYPE_LEGS"}, --"Leggings of Atrophy"
  [39721] = {4,213,"INVTYPE_WAIST"}, --"Sash of the Parlor"
  [39722] = {4,213,"INVTYPE_WRIST"}, --"Swarm Bindings"
  [39723] = {4,213,"INVTYPE_HEAD"}, --"Fire-Scorched Greathelm"
  [39724] = {4,213,"INVTYPE_CHEST"}, --"Cult's Chestguard"
  [39725] = {4,213,"INVTYPE_SHOULDER"}, --"Epaulets of the Grieving Servant"
  [39726] = {4,213,"INVTYPE_HAND"}, --"Callous-Hearted Gauntlets"
  [39727] = {4,213,"INVTYPE_HAND"}, --"Dislocating Handguards"
  [39728] = {4,213,"INVTYPE_RELIC"}, --"Totem of Misery"
  [39729] = {4,213,"INVTYPE_WRIST"}, --"Bracers of the Tyrant"
  [39730] = {4,213,"INVTYPE_WEAPON"}, --"Widow's Fury"
  [39731] = {4,213,"INVTYPE_WRIST"}, --"Punctilious Bindings"
  [39732] = {4,213,"INVTYPE_HEAD"}, --"Faerlina's Madness"
  [39733] = {4,213,"INVTYPE_HAND"}, --"Gloves of Token Respect"
  [39734] = {4,213,"INVTYPE_FEET"}, --"Atonement Greaves"
  [39735] = {4,213,"INVTYPE_WAIST"}, --"Belt of False Dignity"
  [39756] = {4,213,"INVTYPE_CHEST"}, --"Tunic of Prejudice"
  [39757] = {4,213,"INVTYPE_RELIC"}, --"Idol of Worship"
  [39758] = {4,213,"INVTYPE_2HWEAPON"}, --"The Jawbone"
  [39759] = {4,213,"INVTYPE_WAIST"}, --"Ablative Chitin Girdle"
  [39760] = {4,213,"INVTYPE_HEAD"}, --"Helm of Diminished Pride"
  [39761] = {4,213,"INVTYPE_LEGS"}, --"Infectious Skitterer Leggings"
  [39762] = {4,213,"INVTYPE_WAIST"}, --"Torn Web Wrapping"
  [39763] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"Wraith Strike"
  [39764] = {4,213,"INVTYPE_WRIST"}, --"Bindings of the Hapless Prey"
  [39765] = {4,213,"INVTYPE_WRIST"}, --"Sinner's Bindings"
  [39766] = {4,213,"INVTYPE_HOLDABLE"}, --"Matriarch's Spawn"
  [39767] = {4,213,"INVTYPE_CHEST"}, --"Undiminished Battleplate"
  [39768] = {4,213,"INVTYPE_HEAD"}, --"Cowl of the Perished"
  [40060] = {4,213,"INVTYPE_LEGS"}, --"Distorted Limbs"
  [40061] = {4,213,"INVTYPE_CHEST"}, --"Quivering Tunic"
  [40062] = {4,213,"INVTYPE_ROBE"}, --"Digested Silken Robes"
  [40063] = {4,213,"INVTYPE_SHOULDER"}, --"Mantle of Shattered Kinship"
  [40064] = {4,213,"INVTYPE_NECK"}, --"Thunderstorm Amulet"
  [40065] = {4,213,"INVTYPE_NECK"}, --"Fool's Trial"
  [40069] = {4,213,"INVTYPE_NECK"}, --"Heritage"
  [40071] = {4,213,"INVTYPE_NECK"}, --"Chains of Adoration"
  [40074] = {4,213,"INVTYPE_FINGER"}, --"Strong-Handed Ring"
  [40075] = {4,213,"INVTYPE_FINGER"}, --"Ruthlessness"
  [40080] = {4,213,"INVTYPE_FINGER"}, --"Lost Jewel"
  [40107] = {4,213,"INVTYPE_FINGER"}, --"Sand-Worn Band"
  [40108] = {4,213,"INVTYPE_FINGER"}, --"Seized Beauty"
  [40184] = {4,213,"INVTYPE_FEET"}, --"Crippled Treads"
  [40185] = {4,213,"INVTYPE_SHOULDER"}, --"Shoulderguards of Opportunity"
  [40186] = {4,213,"INVTYPE_WRIST"}, --"Thrusting Bands"
  [40187] = {4,213,"INVTYPE_FEET"}, --"Poignant Sabatons"
  [40188] = {4,213,"INVTYPE_HAND"}, --"Gauntlets of the Disobedient"
  [40189] = {4,213,"INVTYPE_WEAPON"}, --"Angry Dread"
  [40190] = {4,213,"INVTYPE_THROWN"}, --"Spinning Fate"
  [40191] = {4,213,"INVTYPE_RELIC"}, --"Libram of Radiance"
  [40192] = {4,213,"INVTYPE_HOLDABLE"}, --"Accursed Spine"
  [40193] = {4,213,"INVTYPE_CHEST"}, --"Tunic of Masked Suffering"
  [40194] = {4,226,"INVTYPE_ROBE"}, --"Blanketing Robes of Snow"
  [40196] = {4,213,"INVTYPE_LEGS"}, --"Legguards of the Undisturbed"
  [40197] = {4,213,"INVTYPE_HAND"}, --"Gloves of the Fallen Wizard"
  [40198] = {4,213,"INVTYPE_WRIST"}, --"Bands of Impurity"
  [40200] = {4,213,"INVTYPE_WAIST"}, --"Belt of Potent Chanting"
  [40201] = {4,213,"INVTYPE_LEGS"}, --"Leggings of Colossal Strides"
  [40203] = {4,213,"INVTYPE_CHEST"}, --"Breastplate of Tormented Rage"
  [40204] = {4,213,"INVTYPE_LEGS"}, --"Legguards of the Apostle"
  [40205] = {4,213,"INVTYPE_WAIST"}, --"Stalk-Skin Belt"
  [40206] = {4,213,"INVTYPE_FEET"}, --"Iron-Spring Jumpers"
  [40207] = {4,213,"INVTYPE_RELIC"}, --"Sigil of Awareness"
  [40208] = {4,213,"INVTYPE_2HWEAPON"}, --"Cryptfiend's Bite"
  [40209] = {4,213,"INVTYPE_WRIST"}, --"Bindings of the Decrepit"
  [40210] = {4,213,"INVTYPE_CHEST"}, --"Chestguard of Bitter Charms"
  [40233] = {4,213,"INVTYPE_2HWEAPON"}, --"The Undeath Carrier"
  [40234] = {4,213,"INVTYPE_ROBE"}, --"Heigan's Putrid Vestments"
  [40235] = {4,213,"INVTYPE_HEAD"}, --"Helm of Pilgrimage"
  [40236] = {4,213,"INVTYPE_FEET"}, --"Serene Echoes"
  [40237] = {4,213,"INVTYPE_FEET"}, --"Eruption-Scarred Boots"
  [40238] = {4,213,"INVTYPE_HAND"}, --"Gloves of the Dancing Bear"
  [40239] = {4,213,"INVTYPE_WEAPONOFFHAND"}, --"The Hand of Nerub"
  [40240] = {4,213,"INVTYPE_LEGS"}, --"Greaves of Turbulence"
  [40241] = {4,213,"INVTYPE_WAIST"}, --"Girdle of Unity"
  [40242] = {4,213,"INVTYPE_HAND"}, --"Grotesque Handgrips"
  [40243] = {4,213,"INVTYPE_FEET"}, --"Footwraps of Vile Deceit"
  [40244] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"The Impossible Dream"
  [40245] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Fading Glow"
  [40246] = {4,213,"INVTYPE_FEET"}, --"Boots of Impetuous Ideals"
  [40247] = {4,213,"INVTYPE_HEAD"}, --"Cowl of Innocent Delight"
  [40249] = {4,213,"INVTYPE_CHEST"}, --"Vest of Vitality"
  [40250] = {4,213,"INVTYPE_CLOAK"}, --"Aged Winter Cloak"
  [40251] = {4,213,"INVTYPE_CLOAK"}, --"Shroud of Luminosity"
  [40252] = {4,213,"INVTYPE_CLOAK"}, --"Cloak of the Shadowed Sun"
  [40253] = {4,213,"INVTYPE_CLOAK"}, --"Shawl of the Old Maid"
  [40254] = {4,213,"INVTYPE_CLOAK"}, --"Cloak of Averted Crisis"
  [40255] = {4,213,"INVTYPE_TRINKET"}, --"Dying Curse"
  [40256] = {4,213,"INVTYPE_TRINKET"}, --"Grim Toll"
  [40257] = {4,213,"INVTYPE_TRINKET"}, --"Defender's Code"
  [40258] = {4,213,"INVTYPE_TRINKET"}, --"Forethought Talisman"
  [40259] = {4,213,"INVTYPE_WAIST"}, --"Waistguard of Divine Grace"
  [40260] = {4,213,"INVTYPE_WAIST"}, --"Belt of the Tortured"
  [40261] = {4,213,"INVTYPE_HAND"}, --"Crude Discolored Battlegrips"
  [40262] = {4,213,"INVTYPE_HAND"}, --"Gloves of Calculated Risk"
  [40263] = {4,213,"INVTYPE_WAIST"}, --"Fleshless Girdle"
  [40264] = {4,213,"INVTYPE_WEAPON"}, --"Split Greathammer"
  [40265] = {4,213,"INVTYPE_RANGED"}, --"Arrowsong"
  [40266] = {4,213,"INVTYPE_SHIELD"}, --"Hero's Surrender"
  [40267] = {4,213,"INVTYPE_RELIC"}, --"Totem of Hex"
  [40268] = {4,213,"INVTYPE_RELIC"}, --"Libram of Tolerance"
  [40269] = {4,213,"INVTYPE_FEET"}, --"Boots of Persuasion"
  [40270] = {4,213,"INVTYPE_FEET"}, --"Boots of Septic Wounds"
  [40271] = {4,213,"INVTYPE_WAIST"}, --"Sash of Solitude"
  [40272] = {4,213,"INVTYPE_WAIST"}, --"Girdle of the Gambit"
  [40273] = {4,213,"INVTYPE_HOLDABLE"}, --"Surplus Limb"
  [40274] = {4,213,"INVTYPE_WRIST"}, --"Bracers of Liberation"
  [40275] = {4,213,"INVTYPE_WAIST"}, --"Depraved Linked Belt"
  [40277] = {4,213,"INVTYPE_CHEST"}, --"Tunic of Indulgence"
  [40278] = {4,213,"INVTYPE_WAIST"}, --"Girdle of Chivalry"
  [40279] = {4,213,"INVTYPE_CHEST"}, --"Chestguard of the Exhausted"
  [40280] = {4,213,"INVTYPE_2HWEAPON"}, --"Origin of Nightmares"
  [40281] = {4,213,"INVTYPE_WEAPON"}, --"Twilight Mist"
  [40282] = {4,213,"INVTYPE_WRIST"}, --"Slime Stream Bands"
  [40283] = {4,213,"INVTYPE_CHEST"}, --"Fallout Impervious Tunic"
  [40284] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Plague Igniter"
  [40285] = {4,213,"INVTYPE_LEGS"}, --"Desecrated Past"
  [40286] = {4,213,"INVTYPE_SHOULDER"}, --"Mantle of the Corrupted"
  [40287] = {4,213,"INVTYPE_HEAD"}, --"Cowl of Vanity"
  [40288] = {4,213,"INVTYPE_SHOULDER"}, --"Spaulders of Incoherence"
  [40289] = {4,213,"INVTYPE_SHOULDER"}, --"Sympathetic Amice"
  [40294] = {4,213,"INVTYPE_LEGS"}, --"Riveted Abomination Leggings"
  [40296] = {4,213,"INVTYPE_HEAD"}, --"Cover of Silence"
  [40297] = {4,213,"INVTYPE_FEET"}, --"Sabatons of Endurance"
  [40298] = {4,213,"INVTYPE_HEAD"}, --"Faceguard of the Succumbed"
  [40299] = {4,213,"INVTYPE_SHOULDER"}, --"Pauldrons of the Abandoned"
  [40300] = {4,213,"INVTYPE_2HWEAPON"}, --"Spire of Sunset"
  [40301] = {4,213,"INVTYPE_WAIST"}, --"Cincture of Polarity"
  [40302] = {4,213,"INVTYPE_HAND"}, --"Benefactor's Gauntlets"
  [40303] = {4,213,"INVTYPE_HAND"}, --"Wraps of the Persecuted"
  [40304] = {4,213,"INVTYPE_HEAD"}, --"Headpiece of Fungal Bloom"
  [40305] = {4,213,"INVTYPE_SHOULDER"}, --"Spaulders of Egotism"
  [40306] = {4,213,"INVTYPE_WRIST"}, --"Bracers of the Unholy Knight"
  [40315] = {4,213,"INVTYPE_SHOULDER"}, --"Shoulderpads of Secret Arts"
  [40316] = {4,213,"INVTYPE_HAND"}, --"Gauntlets of Guiding Touch"
  [40317] = {4,213,"INVTYPE_WAIST"}, --"Girdle of Razuvious"
  [40318] = {4,213,"INVTYPE_LEGS"}, --"Legplates of Double Strikes"
  [40319] = {4,213,"INVTYPE_CHEST"}, --"Chestpiece of Suspicion"
  [40320] = {4,213,"INVTYPE_FEET"}, --"Faithful Steel Sabatons"
  [40321] = {4,213,"INVTYPE_RELIC"}, --"Idol of the Shooting Star"
  [40322] = {4,213,"INVTYPE_RELIC"}, --"Totem of Dueling"
  [40323] = {4,213,"INVTYPE_WRIST"}, --"Esteemed Bindings"
  [40324] = {4,213,"INVTYPE_WRIST"}, --"Bands of Mutual Respect"
  [40325] = {4,213,"INVTYPE_WRIST"}, --"Bindings of the Expansive Mind"
  [40326] = {4,213,"INVTYPE_FEET"}, --"Boots of Forlorn Wishes"
  [40327] = {4,213,"INVTYPE_WAIST"}, --"Girdle of Recuperation"
  [40328] = {4,213,"INVTYPE_HEAD"}, --"Helm of Vital Protection"
  [40329] = {4,213,"INVTYPE_HEAD"}, --"Hood of the Exodus"
  [40330] = {4,213,"INVTYPE_WRIST"}, --"Bracers of Unrelenting Attack"
  [40331] = {4,213,"INVTYPE_LEGS"}, --"Leggings of Failed Escape"
  [40332] = {4,213,"INVTYPE_WRIST"}, --"Abetment Bracers"
  [40333] = {4,213,"INVTYPE_LEGS"}, --"Leggings of Fleeting Moments"
  [40334] = {4,213,"INVTYPE_SHOULDER"}, --"Burdened Shoulderplates"
  [40335] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Touch of Horror"
  [40336] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"Life and Death"
  [40337] = {4,213,"INVTYPE_RELIC"}, --"Libram of Resurgence"
  [40338] = {4,213,"INVTYPE_WRIST"}, --"Bindings of Yearning"
  [40339] = {4,213,"INVTYPE_HEAD"}, --"Gothik's Cowl"
  [40340] = {4,213,"INVTYPE_HEAD"}, --"Helm of Unleashed Energy"
  [40341] = {4,213,"INVTYPE_WAIST"}, --"Shackled Cinch"
  [40342] = {4,213,"INVTYPE_RELIC"}, --"Idol of Awakening"
  [40343] = {4,213,"INVTYPE_2HWEAPON"}, --"Armageddon"
  [40344] = {4,213,"INVTYPE_HEAD"}, --"Helm of the Grave"
  [40345] = {4,213,"INVTYPE_WEAPON"}, --"Broken Promise"
  [40346] = {4,213,"INVTYPE_RANGEDRIGHT"}, --"Final Voyage"
  [40347] = {4,213,"INVTYPE_HAND"}, --"Zeliek's Gauntlets"
  [40348] = {4,213,"INVTYPE_2HWEAPON"}, --"Damnation"
  [40349] = {4,213,"INVTYPE_HAND"}, --"Gloves of Peaceful Death"
  [40350] = {4,213,"INVTYPE_HOLDABLE"}, --"Urn of Lost Memories"
  [40351] = {4,213,"INVTYPE_SHOULDER"}, --"Mantle of the Fatigued Sage"
  [40352] = {4,213,"INVTYPE_LEGS"}, --"Leggings of Voracious Shadows"
  [40362] = {4,213,"INVTYPE_HAND"}, --"Gloves of Fast Reactions"
  [40363] = {4,213,"INVTYPE_LEGS"}, --"Bone-Inlaid Legguards"
  [40365] = {4,213,"INVTYPE_CHEST"}, --"Breastplate of Frozen Pain"
  [40366] = {4,213,"INVTYPE_HEAD"}, --"Platehelm of the Great Wyrm"
  [40367] = {4,213,"INVTYPE_FEET"}, --"Boots of the Great Construct"
  [40368] = {4,213,"INVTYPE_WEAPON"}, --"Murder"
  [40369] = {4,213,"INVTYPE_NECK"}, --"Icy Blast Amulet"
  [40370] = {4,213,"INVTYPE_FINGER"}, --"Gatekeeper"
  [40371] = {4,213,"INVTYPE_TRINKET"}, --"Bandit's Insignia"
  [40372] = {4,213,"INVTYPE_TRINKET"}, --"Rune of Repulsion"
  [40373] = {4,213,"INVTYPE_TRINKET"}, --"Extract of Necromantic Power"
  [40374] = {4,213,"INVTYPE_NECK"}, --"Cosmic Lights"
  [40375] = {4,213,"INVTYPE_FINGER"}, --"Ring of Decaying Beauty"
  [40376] = {4,213,"INVTYPE_LEGS"}, --"Legwraps of the Defeated Dragon"
  [40377] = {4,213,"INVTYPE_SHOULDER"}, --"Noble Birthright Pauldrons"
  [40378] = {4,213,"INVTYPE_NECK"}, --"Ceaseless Pity"
  [40379] = {4,213,"INVTYPE_LEGS"}, --"Legguards of the Boneyard"
  [40380] = {4,213,"INVTYPE_HAND"}, --"Gloves of Grandeur"
  [40381] = {4,213,"INVTYPE_ROBE"}, --"Sympathy"
  [40382] = {4,213,"INVTYPE_TRINKET"}, --"Soul of the Dead"
  [40383] = {4,226,"INVTYPE_WEAPONMAINHAND"}, --"Calamity's Grasp"
  [40384] = {4,226,"INVTYPE_2HWEAPON"}, --"Betrayer of Humanity"
  [40385] = {4,226,"INVTYPE_RANGEDRIGHT"}, --"Envoy of Mortality"
  [40386] = {4,226,"INVTYPE_WEAPON"}, --"Sinister Revenge"
  [40387] = {4,226,"INVTYPE_NECK"}, --"Boundless Ambition"
  [40388] = {4,226,"INVTYPE_2HWEAPON"}, --"Journey's End"
  [40395] = {4,226,"INVTYPE_WEAPONMAINHAND"}, --"Torch of Holy Fire"
  [40396] = {4,226,"INVTYPE_WEAPONMAINHAND"}, --"The Turning Tide"
  [40398] = {4,226,"INVTYPE_LEGS"}, --"Leggings of Mortal Arrogance"
  [40399] = {4,226,"INVTYPE_FINGER"}, --"Signet of Manifested Pain"
  [40400] = {4,226,"INVTYPE_SHIELD"}, --"Wall of Terror"
  [40401] = {4,226,"INVTYPE_SHIELD"}, --"Voice of Reason"
  [40402] = {4,226,"INVTYPE_WEAPON"}, --"Last Laugh"
  [40403] = {4,226,"INVTYPE_CLOAK"}, --"Drape of the Deadly Foe"
  [40405] = {4,226,"INVTYPE_CLOAK"}, --"Cape of the Unworthy Wizard"
  [40406] = {4,213,"INVTYPE_2HWEAPON"}, --"Inevitable Defeat"
  [40407] = {4,213,"INVTYPE_WEAPON"}, --"Silent Crusader"
  [40408] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"Haunting Call"
  [40409] = {4,213,"INVTYPE_FEET"}, --"Boots of the Escaped Captive"
  [40410] = {4,213,"INVTYPE_CLOAK"}, --"Shadow of the Ghoul"
  [40412] = {4,213,"INVTYPE_NECK"}, --"Ousted Bead Necklace"
  [40414] = {4,213,"INVTYPE_SHOULDER"}, --"Shoulderguards of the Undaunted"
  [40415] = {4,213,"INVTYPE_HAND"}, --"Valorous Frostfire Gloves"
  [40416] = {4,213,"INVTYPE_HEAD"}, --"Valorous Frostfire Circlet"
  [40417] = {4,213,"INVTYPE_LEGS"}, --"Valorous Frostfire Leggings"
  [40418] = {4,213,"INVTYPE_ROBE"}, --"Valorous Frostfire Robe"
  [40419] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Frostfire Shoulderpads"
  [40420] = {4,213,"INVTYPE_HAND"}, --"Valorous Plagueheart Gloves"
  [40421] = {4,213,"INVTYPE_HEAD"}, --"Valorous Plagueheart Circlet"
  [40422] = {4,213,"INVTYPE_LEGS"}, --"Valorous Plagueheart Leggings"
  [40423] = {4,213,"INVTYPE_ROBE"}, --"Valorous Plagueheart Robe"
  [40424] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Plagueheart Shoulderpads"
  [40426] = {4,200,"INVTYPE_FINGER"}, --"Signet of the Accord"
  [40427] = {4,200,"INVTYPE_NECK"}, --"Circle of Arcane Streams"
  [40428] = {4,200,"INVTYPE_HEAD"}, --"Titan's Outlook"
  [40429] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Crimson Steel"
  [40430] = {4,200,"INVTYPE_TRINKET"}, --"Majestic Dragon Figurine"
  [40431] = {4,213,"INVTYPE_TRINKET"}, --"Fury of the Five Flights"
  [40432] = {4,213,"INVTYPE_TRINKET"}, --"Illustration of the Dragon Soul"
  [40433] = {4,213,"INVTYPE_FINGER"}, --"Wyrmrest Band"
  [40437] = {4,213,"INVTYPE_SHOULDER"}, --"Concealment Shoulderpads"
  [40438] = {4,213,"INVTYPE_SHOULDER"}, --"Council Chamber Epaulets"
  [40439] = {4,213,"INVTYPE_SHOULDER"}, --"Mantle of the Eternal Sentinel"
  [40445] = {4,213,"INVTYPE_HAND"}, --"Valorous Gloves of Faith"
  [40446] = {4,213,"INVTYPE_LEGS"}, --"Dragon Brood Legguards"
  [40447] = {4,213,"INVTYPE_HEAD"}, --"Valorous Crown of Faith"
  [40448] = {4,213,"INVTYPE_LEGS"}, --"Valorous Leggings of Faith"
  [40449] = {4,213,"INVTYPE_ROBE"}, --"Valorous Robe of Faith"
  [40450] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Shoulderpads of Faith"
  [40451] = {4,213,"INVTYPE_HEAD"}, --"Hyaline Helm of the Sniper"
  [40453] = {4,213,"INVTYPE_CHEST"}, --"Chestplate of the Great Aspects"
  [40454] = {4,213,"INVTYPE_HAND"}, --"Valorous Handwraps of Faith"
  [40455] = {4,213,"INVTYPE_2HWEAPON"}, --"Staff of Restraint"
  [40456] = {4,213,"INVTYPE_HEAD"}, --"Valorous Circlet of Faith"
  [40457] = {4,213,"INVTYPE_LEGS"}, --"Valorous Pants of Faith"
  [40458] = {4,213,"INVTYPE_ROBE"}, --"Valorous Raiments of Faith"
  [40459] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Mantle of Faith"
  [40460] = {4,213,"INVTYPE_HAND"}, --"Valorous Dreamwalker Handguards"
  [40461] = {4,213,"INVTYPE_HEAD"}, --"Valorous Dreamwalker Headpiece"
  [40462] = {4,213,"INVTYPE_LEGS"}, --"Valorous Dreamwalker Leggings"
  [40463] = {4,213,"INVTYPE_ROBE"}, --"Valorous Dreamwalker Robe"
  [40465] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Dreamwalker Spaulders"
  [40466] = {4,213,"INVTYPE_HAND"}, --"Valorous Dreamwalker Gloves"
  [40467] = {4,213,"INVTYPE_HEAD"}, --"Valorous Dreamwalker Cover"
  [40468] = {4,213,"INVTYPE_LEGS"}, --"Valorous Dreamwalker Trousers"
  [40469] = {4,213,"INVTYPE_ROBE"}, --"Valorous Dreamwalker Vestments"
  [40470] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Dreamwalker Mantle"
  [40471] = {4,213,"INVTYPE_ROBE"}, --"Valorous Dreamwalker Raiments"
  [40472] = {4,213,"INVTYPE_HAND"}, --"Valorous Dreamwalker Handgrips"
  [40473] = {4,213,"INVTYPE_HEAD"}, --"Valorous Dreamwalker Headguard"
  [40474] = {4,213,"INVTYPE_FINGER"}, --"Surge Needle Ring"
  [40475] = {4,213,"INVTYPE_SHIELD"}, --"Barricade of Eternity"
  [40486] = {4,213,"INVTYPE_NECK"}, --"Necklace of the Glittering Chamber"
  [40488] = {4,213,"INVTYPE_WEAPONMAINHAND"}, --"Ice Spire Scepter"
  [40489] = {4,213,"INVTYPE_2HWEAPON"}, --"Greatstaff of the Nexus"
  [40491] = {4,213,"INVTYPE_WEAPON"}, --"Hailstorm"
  [40493] = {4,213,"INVTYPE_LEGS"}, --"Valorous Dreamwalker Legguards"
  [40494] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Dreamwalker Shoulderpads"
  [40495] = {4,213,"INVTYPE_CHEST"}, --"Valorous Bonescythe Breastplate"
  [40496] = {4,213,"INVTYPE_HAND"}, --"Valorous Bonescythe Gauntlets"
  [40497] = {4,213,"INVTYPE_2HWEAPON"}, --"Black Ice"
  [40499] = {4,213,"INVTYPE_HEAD"}, --"Valorous Bonescythe Helmet"
  [40500] = {4,213,"INVTYPE_LEGS"}, --"Valorous Bonescythe Legplates"
  [40502] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Bonescythe Pauldrons"
  [40503] = {4,213,"INVTYPE_CHEST"}, --"Valorous Cryptstalker Tunic"
  [40504] = {4,213,"INVTYPE_HAND"}, --"Valorous Cryptstalker Handguards"
  [40505] = {4,213,"INVTYPE_HEAD"}, --"Valorous Cryptstalker Headpiece"
  [40506] = {4,213,"INVTYPE_LEGS"}, --"Valorous Cryptstalker Legguards"
  [40507] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Cryptstalker Spaulders"
  [40508] = {4,213,"INVTYPE_CHEST"}, --"Valorous Earthshatter Tunic"
  [40509] = {4,213,"INVTYPE_HAND"}, --"Valorous Earthshatter Handguards"
  [40510] = {4,213,"INVTYPE_HEAD"}, --"Valorous Earthshatter Headpiece"
  [40511] = {4,213,"INVTYPE_SHOULDER"}, --"Focusing Energy Epaulets"
  [40512] = {4,213,"INVTYPE_LEGS"}, --"Valorous Earthshatter Legguards"
  [40513] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Earthshatter Spaulders"
  [40514] = {4,213,"INVTYPE_CHEST"}, --"Valorous Earthshatter Hauberk"
  [40515] = {4,213,"INVTYPE_HAND"}, --"Valorous Earthshatter Gloves"
  [40516] = {4,213,"INVTYPE_HEAD"}, --"Valorous Earthshatter Helm"
  [40517] = {4,213,"INVTYPE_LEGS"}, --"Valorous Earthshatter Kilt"
  [40518] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Earthshatter Shoulderpads"
  [40519] = {4,213,"INVTYPE_FEET"}, --"Footsteps of Malygos"
  [40520] = {4,213,"INVTYPE_HAND"}, --"Valorous Earthshatter Grips"
  [40521] = {4,213,"INVTYPE_HEAD"}, --"Valorous Earthshatter Faceguard"
  [40522] = {4,213,"INVTYPE_LEGS"}, --"Valorous Earthshatter War-Kilt"
  [40523] = {4,213,"INVTYPE_CHEST"}, --"Valorous Earthshatter Chestguard"
  [40524] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Earthshatter Shoulderguards"
  [40525] = {4,213,"INVTYPE_CHEST"}, --"Valorous Dreadnaught Battleplate"
  [40526] = {4,213,"INVTYPE_ROBE"}, --"Gown of the Spell-Weaver"
  [40527] = {4,213,"INVTYPE_HAND"}, --"Valorous Dreadnaught Gauntlets"
  [40528] = {4,213,"INVTYPE_HEAD"}, --"Valorous Dreadnaught Helmet"
  [40529] = {4,213,"INVTYPE_LEGS"}, --"Valorous Dreadnaught Legplates"
  [40530] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Dreadnaught Shoulderplates"
  [40531] = {4,226,"INVTYPE_TRINKET"}, --"Mark of Norgannon"
  [40532] = {4,226,"INVTYPE_TRINKET"}, --"Living Ice Crystals"
  [40539] = {4,226,"INVTYPE_CHEST"}, --"Chestguard of the Recluse"
  [40541] = {4,226,"INVTYPE_HAND"}, --"Frosted Adroit Handguards"
  [40543] = {4,226,"INVTYPE_HEAD"}, --"Blue Aspect Helm"
  [40544] = {4,213,"INVTYPE_CHEST"}, --"Valorous Dreadnaught Breastplate"
  [40545] = {4,213,"INVTYPE_HAND"}, --"Valorous Dreadnaught Handguards"
  [40546] = {4,213,"INVTYPE_HEAD"}, --"Valorous Dreadnaught Greathelm"
  [40547] = {4,213,"INVTYPE_LEGS"}, --"Valorous Dreadnaught Legguards"
  [40548] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Dreadnaught Pauldrons"
  [40549] = {4,226,"INVTYPE_FEET"}, --"Boots of the Renewed Flight"
  [40550] = {4,213,"INVTYPE_CHEST"}, --"Valorous Scourgeborne Battleplate"
  [40552] = {4,213,"INVTYPE_HAND"}, --"Valorous Scourgeborne Gauntlets"
  [40553] = {4,200,"INVTYPE_WEAPON"}, --"Electrified Blade"
  [40554] = {4,213,"INVTYPE_HEAD"}, --"Valorous Scourgeborne Helmet"
  [40555] = {4,226,"INVTYPE_SHOULDER"}, --"Mantle of Dissemination"
  [40556] = {4,213,"INVTYPE_LEGS"}, --"Valorous Scourgeborne Legplates"
  [40557] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Scourgeborne Shoulderplates"
  [40558] = {4,226,"INVTYPE_FEET"}, --"Arcanic Tramplers"
  [40559] = {4,213,"INVTYPE_CHEST"}, --"Valorous Scourgeborne Chestguard"
  [40560] = {4,226,"INVTYPE_LEGS"}, --"Leggings of the Wanton Spellcaster"
  [40561] = {4,226,"INVTYPE_WAIST"}, --"Leash of Heedless Magic"
  [40562] = {4,226,"INVTYPE_HEAD"}, --"Hood of Rationality"
  [40563] = {4,213,"INVTYPE_HAND"}, --"Valorous Scourgeborne Handguards"
  [40564] = {4,226,"INVTYPE_HAND"}, --"Winter Spectacle Gloves"
  [40565] = {4,213,"INVTYPE_HEAD"}, --"Valorous Scourgeborne Faceguard"
  [40566] = {4,226,"INVTYPE_WAIST"}, --"Unravelling Strands of Sanity"
  [40567] = {4,213,"INVTYPE_LEGS"}, --"Valorous Scourgeborne Legguards"
  [40568] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Scourgeborne Pauldrons"
  [40569] = {4,213,"INVTYPE_CHEST"}, --"Valorous Redemption Tunic"
  [40570] = {4,213,"INVTYPE_HAND"}, --"Valorous Redemption Gloves"
  [40571] = {4,213,"INVTYPE_HEAD"}, --"Valorous Redemption Headpiece"
  [40572] = {4,213,"INVTYPE_LEGS"}, --"Valorous Redemption Greaves"
  [40573] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Redemption Spaulders"
  [40574] = {4,213,"INVTYPE_CHEST"}, --"Valorous Redemption Chestpiece"
  [40575] = {4,213,"INVTYPE_HAND"}, --"Valorous Redemption Gauntlets"
  [40576] = {4,213,"INVTYPE_HEAD"}, --"Valorous Redemption Helm"
  [40577] = {4,213,"INVTYPE_LEGS"}, --"Valorous Redemption Legplates"
  [40578] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Redemption Shoulderplates"
  [40579] = {4,213,"INVTYPE_CHEST"}, --"Valorous Redemption Breastplate"
  [40580] = {4,213,"INVTYPE_HAND"}, --"Valorous Redemption Handguards"
  [40581] = {4,213,"INVTYPE_HEAD"}, --"Valorous Redemption Faceguard"
  [40583] = {4,213,"INVTYPE_LEGS"}, --"Valorous Redemption Legguards"
  [40584] = {4,213,"INVTYPE_SHOULDER"}, --"Valorous Redemption Shoulderguards"
  [40585] = {4,200,"INVTYPE_FINGER"}, --"Signet of the Kirin Tor"
  [40586] = {4,200,"INVTYPE_FINGER"}, --"Band of the Kirin Tor"
  [40588] = {4,226,"INVTYPE_CHEST"}, --"Tunic of the Artifact Guardian"
  [40589] = {4,226,"INVTYPE_LEGS"}, --"Legplates of Sovereignty"
  [40590] = {4,226,"INVTYPE_SHOULDER"}, --"Elevated Lair Pauldrons"
  [40591] = {4,226,"INVTYPE_FEET"}, --"Melancholy Sabatons"
  [40592] = {4,226,"INVTYPE_FEET"}, --"Boots of Healing Energies"
  [40594] = {4,226,"INVTYPE_SHOULDER"}, --"Spaulders of Catatonia"
  [40602] = {4,213,"INVTYPE_ROBE"}, --"Robes of Mutation"
  [40678] = {4,200,"INVTYPE_NECK"}, --"Pendant of the Outcast Hero"
  [40679] = {4,200,"INVTYPE_NECK"}, --"Chained Military Gorget"
  [40680] = {4,200,"INVTYPE_NECK"}, --"Encircling Burnished Gold Chains"
  [40681] = {4,200,"INVTYPE_NECK"}, --"Lattice Choker of Light"
  [40682] = {4,200,"INVTYPE_TRINKET"}, --"Sundial of the Exiled"
  [40683] = {4,200,"INVTYPE_TRINKET"}, --"Valor Medal of the First War"
  [40684] = {4,200,"INVTYPE_TRINKET"}, --"Mirror of Truth"
  [40685] = {4,200,"INVTYPE_TRINKET"}, --"The Egg of Mortal Essence"
  [40688] = {4,200,"INVTYPE_WAIST"}, --"Verdungo's Barbarian Cord"
  [40689] = {4,200,"INVTYPE_WAIST"}, --"Waistguard of Living Iron"
  [40691] = {4,200,"INVTYPE_WAIST"}, --"Magroth's Meditative Cincture"
  [40692] = {4,200,"INVTYPE_WAIST"}, --"Vereesa's Silver Chain Belt"
  [40693] = {4,200,"INVTYPE_WAIST"}, --"Beadwork Belt of Shamanic Vision"
  [40694] = {4,200,"INVTYPE_WAIST"}, --"Jorach's Crocolisk Skin Belt"
  [40695] = {4,200,"INVTYPE_WAIST"}, --"Vine Belt of the Woodland Dryad"
  [40696] = {4,200,"INVTYPE_WAIST"}, --"Plush Sash of Guzbah"
  [40697] = {4,200,"INVTYPE_WAIST"}, --"Elegant Temple Gardens' Girdle"
  [40698] = {4,200,"INVTYPE_HOLDABLE"}, --"Ward of the Violet Citadel"
  [40699] = {4,200,"INVTYPE_HOLDABLE"}, --"Handbook of Obscure Remedies"
  [40700] = {4,200,"INVTYPE_SHIELD"}, --"Protective Barricade of the Light"
  [40701] = {4,200,"INVTYPE_SHIELD"}, --"Crygil's Discarded Plate Panel"
  [40702] = {4,200,"INVTYPE_WEAPONOFFHAND"}, --"Rolfsen's Ripper"
  [40703] = {4,200,"INVTYPE_WEAPONOFFHAND"}, --"Grasscutter"
  [40704] = {4,200,"INVTYPE_WEAPONOFFHAND"}, --"Pride"
  [40705] = {4,200,"INVTYPE_RELIC"}, --"Libram of Renewal"
  [40706] = {4,200,"INVTYPE_RELIC"}, --"Libram of Reciprocation"
  [40707] = {4,200,"INVTYPE_RELIC"}, --"Libram of Obstruction"
  [40708] = {4,200,"INVTYPE_RELIC"}, --"Totem of the Elemental Plane"
  [40709] = {4,200,"INVTYPE_RELIC"}, --"Totem of Forest Growth"
  [40710] = {4,200,"INVTYPE_RELIC"}, --"Totem of Splintering"
  [40711] = {4,200,"INVTYPE_RELIC"}, --"Idol of Lush Moss"
  [40712] = {4,200,"INVTYPE_RELIC"}, --"Idol of Steadfast Renewal"
  [40713] = {4,200,"INVTYPE_RELIC"}, --"Idol of the Ravenous Beast"
  [40714] = {4,200,"INVTYPE_RELIC"}, --"Sigil of the Unfaltering Knight"
  [40715] = {4,200,"INVTYPE_RELIC"}, --"Sigil of Haunted Dreams"
  [40716] = {4,200,"INVTYPE_THROWN"}, --"Lillehoff's Winged Blades"
  [40717] = {4,213,"INVTYPE_FINGER"}, --"Ring of Invincibility"
  [40718] = {4,213,"INVTYPE_FINGER"}, --"Signet of the Impregnable Fortress"
  [40719] = {4,213,"INVTYPE_FINGER"}, --"Band of Channeled Magic"
  [40720] = {4,213,"INVTYPE_FINGER"}, --"Renewal of Life"
  [40721] = {4,213,"INVTYPE_CLOAK"}, --"Hammerhead Sharkskin Cloak"
  [40722] = {4,213,"INVTYPE_CLOAK"}, --"Platinum Mesh Cloak"
  [40723] = {4,213,"INVTYPE_CLOAK"}, --"Disguise of the Kumiho"
  [40724] = {4,213,"INVTYPE_CLOAK"}, --"Cloak of Kea Feathers"
  [40733] = {4,213,"INVTYPE_WRIST"}, --"Wristbands of the Sentinel Huntress"
  [40734] = {4,213,"INVTYPE_WRIST"}, --"Bracers of Dalaran's Parapets"
  [40735] = {4,213,"INVTYPE_WRIST"}, --"Zartson's Jungle Vambraces"
  [40736] = {4,213,"INVTYPE_WRIST"}, --"Armguard of the Tower Archer"
  [40737] = {4,213,"INVTYPE_WRIST"}, --"Pigmented Clan Bindings"
  [40738] = {4,213,"INVTYPE_WRIST"}, --"Wristwraps of the Cutthroat"
  [40739] = {4,213,"INVTYPE_WRIST"}, --"Bands of the Great Tree"
  [40740] = {4,213,"INVTYPE_WRIST"}, --"Wraps of the Astral Traveler"
  [40741] = {4,213,"INVTYPE_WRIST"}, --"Cuffs of the Shadow Ascendant"
  [40742] = {4,213,"INVTYPE_FEET"}, --"Bladed Steelboots"
  [40743] = {4,213,"INVTYPE_FEET"}, --"Kyzoc's Ground Stompers"
  [40745] = {4,213,"INVTYPE_FEET"}, --"Sabatons of Rapid Recovery"
  [40746] = {4,213,"INVTYPE_FEET"}, --"Pack-Ice Striders"
  [40747] = {4,213,"INVTYPE_FEET"}, --"Treads of Coastal Wandering"
  [40748] = {4,213,"INVTYPE_FEET"}, --"Boots of Captain Ellis"
  [40749] = {4,213,"INVTYPE_FEET"}, --"Rainey's Chewed Boots"
  [40750] = {4,213,"INVTYPE_FEET"}, --"Xintor's Expeditionary Boots"
  [40751] = {4,213,"INVTYPE_FEET"}, --"Slippers of the Holy Light"
  [41168] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Armor Plated Combat Shotgun"
  [41257] = {4,200,"INVTYPE_2HWEAPON"}, --"Titansteel Destroyer"
  [41383] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Titansteel Bonecrusher"
  [41384] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Titansteel Guardian"
  [41386] = {4,200,"INVTYPE_HEAD"}, --"Spiked Titansteel Helm"
  [41387] = {4,200,"INVTYPE_HEAD"}, --"Tempered Titansteel Helm"
  [41388] = {4,200,"INVTYPE_HEAD"}, --"Brilliant Titansteel Helm"
  [41391] = {4,200,"INVTYPE_FEET"}, --"Spiked Titansteel Treads"
  [41392] = {4,200,"INVTYPE_FEET"}, --"Tempered Titansteel Treads"
  [41394] = {4,200,"INVTYPE_FEET"}, --"Brilliant Titansteel Treads"
  [41609] = {4,200,"INVTYPE_CLOAK"}, --"Wispcloak"
  [41610] = {4,200,"INVTYPE_CLOAK"}, --"Deathchill Cloak"
  [42100] = {4,200,"INVTYPE_ROBE"}, --"Moonshroud Robe"
  [42101] = {4,200,"INVTYPE_ROBE"}, --"Ebonweave Robe"
  [42102] = {4,200,"INVTYPE_ROBE"}, --"Spellweave Robe"
  [42103] = {4,200,"INVTYPE_HAND"}, --"Moonshroud Gloves"
  [42111] = {4,200,"INVTYPE_HAND"}, --"Ebonweave Gloves"
  [42113] = {4,200,"INVTYPE_HAND"}, --"Spellweave Gloves"
  [42128] = {4,213,"INVTYPE_TRINKET"}, --"Battlemaster's Hostility"
  [42129] = {4,213,"INVTYPE_TRINKET"}, --"Battlemaster's Accuracy"
  [42130] = {4,213,"INVTYPE_TRINKET"}, --"Battlemaster's Avidity"
  [42131] = {4,213,"INVTYPE_TRINKET"}, --"Battlemaster's Conviction"
  [42132] = {4,213,"INVTYPE_TRINKET"}, --"Battlemaster's Bravery"
  [42133] = {4,245,"INVTYPE_TRINKET"}, --"Battlemaster's Fury"
  [42134] = {4,245,"INVTYPE_TRINKET"}, --"Battlemaster's Precision"
  [42135] = {4,245,"INVTYPE_TRINKET"}, --"Battlemaster's Vivacity"
  [42136] = {4,245,"INVTYPE_TRINKET"}, --"Battlemaster's Rage"
  [42137] = {4,245,"INVTYPE_TRINKET"}, --"Battlemaster's Ruination"
  [42435] = {4,200,"INVTYPE_WEAPON"}, --"Titansteel Shanker"
  [42508] = {4,200,"INVTYPE_SHIELD"}, --"Titansteel Shield Wall"
  [42549] = {4,200,"INVTYPE_HEAD"}, --"Armored Titanium Goggles"
  [42550] = {4,200,"INVTYPE_HEAD"}, --"Weakness Spectralizers"
  [42551] = {4,200,"INVTYPE_HEAD"}, --"Truesight Ice Blinders"
  [42552] = {4,200,"INVTYPE_HEAD"}, --"Charged Titanium Specs"
  [42553] = {4,200,"INVTYPE_HEAD"}, --"Visage Liquification Goggles"
  [42554] = {4,200,"INVTYPE_HEAD"}, --"Greensight Gogs"
  [42555] = {4,200,"INVTYPE_HEAD"}, --"Electroflux Sight Enhancers"
  [42642] = {4,200,"INVTYPE_FINGER"}, --"Titanium Impact Band"
  [42643] = {4,200,"INVTYPE_FINGER"}, --"Titanium Earthguard Ring"
  [42644] = {4,200,"INVTYPE_FINGER"}, --"Titanium Spellshock Ring"
  [42645] = {4,200,"INVTYPE_NECK"}, --"Titanium Impact Choker"
  [42646] = {4,200,"INVTYPE_NECK"}, --"Titanium Earthguard Chain"
  [42647] = {4,200,"INVTYPE_NECK"}, --"Titanium Spellshock Necklace"
  [42987] = {4,200,"INVTYPE_TRINKET"}, --"Darkmoon Card: Greatness"
  [42988] = {4,200,"INVTYPE_TRINKET"}, --"Darkmoon Card: Illusion"
  [42990] = {4,200,"INVTYPE_TRINKET"}, --"Darkmoon Card: Death"
  [43085] = {4,200,"INVTYPE_SHIELD"}, --"Royal Crest of Lordaeron"
  [43458] = {4,200,"INVTYPE_LEGS"}, --"Giantmaim Legguards"
  [43459] = {4,200,"INVTYPE_WRIST"}, --"Giantmaim Bracers"
  [43460] = {4,200,"INVTYPE_WAIST"}, --"Giantmaim Girdle"
  [43461] = {4,200,"INVTYPE_CHEST"}, --"Revenant's Breastplate"
  [43469] = {4,200,"INVTYPE_FEET"}, --"Revenant's Treads"
  [43481] = {4,200,"INVTYPE_SHOULDER"}, --"Trollwoven Spaulders"
  [43484] = {4,200,"INVTYPE_WAIST"}, --"Trollwoven Girdle"
  [43495] = {4,200,"INVTYPE_LEGS"}, --"Earthgiving Legguards"
  [43500] = {4,200,"INVTYPE_LEGS"}, --"Bolstered Legplates"
  [43502] = {4,200,"INVTYPE_FEET"}, --"Earthgiving Boots"
  [43503] = {4,200,"INVTYPE_WAIST"}, --"Deprecated Earthgiving Belt"
  [43555] = {4,200,"INVTYPE_TRINKET"}, --"Deputy Pa'trolla Badge"
  [43565] = {4,200,"INVTYPE_CLOAK"}, --"Durable Nerubhide Cape"
  [43566] = {4,200,"INVTYPE_CLOAK"}, --"Ice Striker's Cloak"
  [43573] = {4,200,"INVTYPE_TRINKET"}, --"Tears of Bitter Anguish"
  [43582] = {4,213,"INVTYPE_FINGER"}, --"Titanium Frostguard Ring"
  [43583] = {4,213,"INVTYPE_ROBE"}, --"Glacial Robe"
  [43584] = {4,213,"INVTYPE_WAIST"}, --"Glacial Waistband"
  [43585] = {4,213,"INVTYPE_FEET"}, --"Glacial Slippers"
  [43586] = {4,213,"INVTYPE_CHEST"}, --"Icebane Chestguard"
  [43587] = {4,213,"INVTYPE_WAIST"}, --"Icebane Girdle"
  [43588] = {4,213,"INVTYPE_FEET"}, --"Icebane Treads"
  [43590] = {4,213,"INVTYPE_CHEST"}, --"Polar Vest"
  [43591] = {4,213,"INVTYPE_WAIST"}, --"Polar Cord"
  [43592] = {4,213,"INVTYPE_FEET"}, --"Polar Boots"
  [43593] = {4,213,"INVTYPE_CHEST"}, --"Icy Scale Chestguard"
  [43594] = {4,213,"INVTYPE_WAIST"}, --"Icy Scale Belt"
  [43595] = {4,213,"INVTYPE_FEET"}, --"Icy Scale Boots"
  [43611] = {4,200,"INVTYPE_WEAPON"}, --"Krol Cleaver"
  [43612] = {4,200,"INVTYPE_THROWN"}, --"Spineslicer"
  [43613] = {4,200,"INVTYPE_WEAPON"}, --"The Dusk Blade"
  [43727] = {4,200,"INVTYPE_CHEST"}, --"Bonescythe Breastplate"
  [43728] = {4,200,"INVTYPE_HAND"}, --"Bonescythe Gauntlets"
  [43729] = {4,200,"INVTYPE_HEAD"}, --"Bonescythe Helmet"
  [43730] = {4,200,"INVTYPE_LEGS"}, --"Bonescythe Legplates"
  [43731] = {4,200,"INVTYPE_SHOULDER"}, --"Bonescythe Pauldrons"
  [43732] = {4,200,"INVTYPE_HEAD"}, --"Circlet of Faith"
  [43733] = {4,200,"INVTYPE_HEAD"}, --"Crown of Faith"
  [43734] = {4,200,"INVTYPE_HAND"}, --"Cryptstalker Handguards"
  [43735] = {4,200,"INVTYPE_HEAD"}, --"Cryptstalker Headpiece"
  [43736] = {4,200,"INVTYPE_LEGS"}, --"Cryptstalker Legguards"
  [43737] = {4,200,"INVTYPE_SHOULDER"}, --"Cryptstalker Spaulders"
  [43738] = {4,200,"INVTYPE_CHEST"}, --"Cryptstalker Tunic"
  [43739] = {4,200,"INVTYPE_CHEST"}, --"Dreadnaught Battleplate"
  [43740] = {4,200,"INVTYPE_CHEST"}, --"Dreadnaught Breastplate"
  [43741] = {4,200,"INVTYPE_HAND"}, --"Dreadnaught Gauntlets"
  [43742] = {4,200,"INVTYPE_HEAD"}, --"Dreadnaught Greathelm"
  [43743] = {4,200,"INVTYPE_HAND"}, --"Dreadnaught Handguards"
  [43744] = {4,200,"INVTYPE_HEAD"}, --"Dreadnaught Helmet"
  [43745] = {4,200,"INVTYPE_LEGS"}, --"Dreadnaught Legguards"
  [43746] = {4,200,"INVTYPE_LEGS"}, --"Dreadnaught Legplates"
  [43747] = {4,200,"INVTYPE_SHOULDER"}, --"Dreadnaught Pauldrons"
  [43748] = {4,200,"INVTYPE_SHOULDER"}, --"Dreadnaught Shoulderplates"
  [43749] = {4,200,"INVTYPE_HEAD"}, --"Dreamwalker Cover"
  [43750] = {4,200,"INVTYPE_HAND"}, --"Dreamwalker Gloves"
  [43751] = {4,200,"INVTYPE_HAND"}, --"Dreamwalker Handgrips"
  [43752] = {4,200,"INVTYPE_HAND"}, --"Dreamwalker Handguards"
  [43753] = {4,200,"INVTYPE_HEAD"}, --"Dreamwalker Headguard"
  [43754] = {4,200,"INVTYPE_HEAD"}, --"Dreamwalker Headpiece"
  [43755] = {4,200,"INVTYPE_LEGS"}, --"Dreamwalker Leggings"
  [43756] = {4,200,"INVTYPE_LEGS"}, --"Dreamwalker Legguards"
  [43757] = {4,200,"INVTYPE_SHOULDER"}, --"Dreamwalker Mantle"
  [43758] = {4,200,"INVTYPE_SHOULDER"}, --"Dreamwalker Shoulderpads"
  [43759] = {4,200,"INVTYPE_SHOULDER"}, --"Dreamwalker Spaulders"
  [43760] = {4,200,"INVTYPE_LEGS"}, --"Dreamwalker Trousers"
  [43761] = {4,200,"INVTYPE_ROBE"}, --"Dreamwalker Vestments"
  [43762] = {4,200,"INVTYPE_CHEST"}, --"Earthshatter Chestguard"
  [43763] = {4,200,"INVTYPE_HEAD"}, --"Earthshatter Faceguard"
  [43764] = {4,200,"INVTYPE_HAND"}, --"Earthshatter Gloves"
  [43765] = {4,200,"INVTYPE_HAND"}, --"Earthshatter Grips"
  [43766] = {4,200,"INVTYPE_HAND"}, --"Earthshatter Handguards"
  [43767] = {4,200,"INVTYPE_CHEST"}, --"Earthshatter Hauberk"
  [43768] = {4,200,"INVTYPE_HEAD"}, --"Earthshatter Headpiece"
  [43769] = {4,200,"INVTYPE_HEAD"}, --"Earthshatter Helm"
  [43770] = {4,200,"INVTYPE_LEGS"}, --"Earthshatter Kilt"
  [43771] = {4,200,"INVTYPE_LEGS"}, --"Earthshatter Legguards"
  [43772] = {4,200,"INVTYPE_SHOULDER"}, --"Earthshatter Shoulderguards"
  [43773] = {4,200,"INVTYPE_SHOULDER"}, --"Earthshatter Shoulderpads"
  [43774] = {4,200,"INVTYPE_SHOULDER"}, --"Earthshatter Spaulders"
  [43775] = {4,200,"INVTYPE_CHEST"}, --"Earthshatter Tunic"
  [43776] = {4,200,"INVTYPE_LEGS"}, --"Earthshatter War-Kilt"
  [43777] = {4,200,"INVTYPE_HEAD"}, --"Frostfire Circlet"
  [43778] = {4,200,"INVTYPE_HAND"}, --"Frostfire Gloves"
  [43779] = {4,200,"INVTYPE_LEGS"}, --"Frostfire Leggings"
  [43780] = {4,200,"INVTYPE_ROBE"}, --"Frostfire Robe"
  [43781] = {4,200,"INVTYPE_SHOULDER"}, --"Frostfire Shoulderpads"
  [43782] = {4,200,"INVTYPE_HAND"}, --"Gloves of Faith"
  [43783] = {4,200,"INVTYPE_HAND"}, --"Handwraps of Faith"
  [43784] = {4,200,"INVTYPE_LEGS"}, --"Leggings of Faith"
  [43785] = {4,200,"INVTYPE_SHOULDER"}, --"Mantle of Faith"
  [43786] = {4,200,"INVTYPE_LEGS"}, --"Pants of Faith"
  [43787] = {4,200,"INVTYPE_HEAD"}, --"Plagueheart Circlet"
  [43788] = {4,200,"INVTYPE_HAND"}, --"Plagueheart Gloves"
  [43789] = {4,200,"INVTYPE_LEGS"}, --"Plagueheart Leggings"
  [43790] = {4,200,"INVTYPE_ROBE"}, --"Plagueheart Robe"
  [43791] = {4,200,"INVTYPE_SHOULDER"}, --"Plagueheart Shoulderpads"
  [43792] = {4,200,"INVTYPE_ROBE"}, --"Raiments of Faith"
  [43793] = {4,200,"INVTYPE_CHEST"}, --"Redemption Breastplate"
  [43794] = {4,200,"INVTYPE_CHEST"}, --"Redemption Chestpiece"
  [43795] = {4,200,"INVTYPE_HEAD"}, --"Redemption Faceguard"
  [43796] = {4,200,"INVTYPE_HAND"}, --"Redemption Gauntlets"
  [43797] = {4,200,"INVTYPE_HAND"}, --"Redemption Gloves"
  [43798] = {4,200,"INVTYPE_LEGS"}, --"Redemption Greaves"
  [43799] = {4,200,"INVTYPE_HAND"}, --"Redemption Handguards"
  [43800] = {4,200,"INVTYPE_HEAD"}, --"Redemption Headpiece"
  [43801] = {4,200,"INVTYPE_HEAD"}, --"Redemption Helm"
  [43802] = {4,200,"INVTYPE_LEGS"}, --"Redemption Legguards"
  [43803] = {4,200,"INVTYPE_LEGS"}, --"Redemption Legplates"
  [43804] = {4,200,"INVTYPE_SHOULDER"}, --"Redemption Shoulderguards"
  [43805] = {4,200,"INVTYPE_SHOULDER"}, --"Redemption Shoulderplates"
  [43806] = {4,200,"INVTYPE_SHOULDER"}, --"Redemption Spaulders"
  [43807] = {4,200,"INVTYPE_CHEST"}, --"Redemption Tunic"
  [43808] = {4,200,"INVTYPE_ROBE"}, --"Robe of Faith"
  [43809] = {4,200,"INVTYPE_CHEST"}, --"Scourgeborne Battleplate"
  [43810] = {4,200,"INVTYPE_SHOULDER"}, --"Shoulderpads of Faith"
  [43811] = {4,200,"INVTYPE_CHEST"}, --"Scourgeborne Chestguard"
  [43812] = {4,200,"INVTYPE_HEAD"}, --"Scourgeborne Faceguard"
  [43813] = {4,200,"INVTYPE_HAND"}, --"Scourgeborne Gauntlets"
  [43814] = {4,200,"INVTYPE_HAND"}, --"Scourgeborne Handguards"
  [43815] = {4,200,"INVTYPE_HEAD"}, --"Scourgeborne Helmet"
  [43816] = {4,200,"INVTYPE_LEGS"}, --"Scourgeborne Legguards"
  [43817] = {4,200,"INVTYPE_LEGS"}, --"Scourgeborne Legplates"
  [43818] = {4,200,"INVTYPE_SHOULDER"}, --"Scourgeborne Pauldrons"
  [43819] = {4,200,"INVTYPE_SHOULDER"}, --"Scourgeborne Shoulderplates"
  [43820] = {4,200,"INVTYPE_ROBE"}, --"Dreamwalker Robe"
  [43822] = {4,200,"INVTYPE_ROBE"}, --"Dreamwalker Raiments"
  [43988] = {4,200,"INVTYPE_CLOAK"}, --"Gale-Proof Cloak"
  [43989] = {4,200,"INVTYPE_WAIST"}, --"Remembrance Girdle"
  [43990] = {4,200,"INVTYPE_CHEST"}, --"Blade-Scarred Tunic"
  [43991] = {4,200,"INVTYPE_LEGS"}, --"Legguards of Composure"
  [43992] = {4,200,"INVTYPE_NECK"}, --"Volitant Amulet"
  [43993] = {4,213,"INVTYPE_FINGER"}, --"Greatring of Collision"
  [43994] = {4,213,"INVTYPE_LEGS"}, --"Belabored Legplates"
  [43995] = {4,213,"INVTYPE_HEAD"}, --"Enamored Cowl"
  [43996] = {4,213,"INVTYPE_FEET"}, --"Sabatons of Firmament"
  [43998] = {4,213,"INVTYPE_CHEST"}, --"Chestguard of Flagrant Prowess"
  [43999] = {4,213,"INVTYPE_FINGER"}, --"Ring of the Empty Horizon"
  [44000] = {4,213,"INVTYPE_CHEST"}, --"Dragonstorm Breastplate"
  [44002] = {4,213,"INVTYPE_ROBE"}, --"The Sanctum's Flowing Vestments"
  [44003] = {4,213,"INVTYPE_SHOULDER"}, --"Upstanding Spaulders"
  [44004] = {4,213,"INVTYPE_HAND"}, --"Bountiful Gauntlets"
  [44005] = {4,226,"INVTYPE_CLOAK"}, --"Pennant Cloak"
  [44006] = {4,226,"INVTYPE_HEAD"}, --"Obsidian Greathelm"
  [44007] = {4,226,"INVTYPE_HEAD"}, --"Headpiece of Reconciliation"
  [44008] = {4,226,"INVTYPE_WRIST"}, --"Unsullied Cuffs"
  [44011] = {4,226,"INVTYPE_LEGS"}, --"Leggings of the Honored"
  [44050] = {4,200,"INVTYPE_2HWEAPON"}, --"Mastercraft Kalu'ak Fishing Pole"
  [44073] = {4,200,"INVTYPE_TRINKET"}, --"Frenzyheart Insignia of Fury"
  [44074] = {4,200,"INVTYPE_TRINKET"}, --"Oracle Talisman of Ablution"
  [44180] = {4,200,"INVTYPE_ROBE"}, --"Robes of Crackling Flame"
  [44181] = {4,200,"INVTYPE_WAIST"}, --"Ghostflicker Waistband"
  [44182] = {4,200,"INVTYPE_FEET"}, --"Boots of Twinkling Stars"
  [44183] = {4,200,"INVTYPE_HAND"}, --"Fireproven Gauntlets"
  [44202] = {4,200,"INVTYPE_FEET"}, --"Sandals of Crimson Fury"
  [44203] = {4,200,"INVTYPE_WRIST"}, --"Dragonfriend Bracers"
  [44204] = {4,200,"INVTYPE_HAND"}, --"Grips of Fierce Pronouncements"
  [44205] = {4,200,"INVTYPE_LEGS"}, --"Legplates of Bloody Reprisal"
  [44210] = {4,200,"INVTYPE_HOLDABLE"}, --"Faces of Doom"
  [44253] = {4,200,"INVTYPE_TRINKET"}, --"Darkmoon Card: Greatness"
  [44254] = {4,200,"INVTYPE_TRINKET"}, --"Darkmoon Card: Greatness"
  [44255] = {4,200,"INVTYPE_TRINKET"}, --"Darkmoon Card: Greatness"
  [44283] = {4,200,"INVTYPE_FINGER"}, --"Signet of Hopeful Light"
  [44295] = {4,200,"INVTYPE_CHEST"}, --"Polished Regimental Hauberk"
  [44296] = {4,200,"INVTYPE_HEAD"}, --"Helm of Purified Thoughts"
  [44297] = {4,200,"INVTYPE_FEET"}, --"Boots of the Neverending Path"
  [44302] = {4,200,"INVTYPE_WAIST"}, --"Belt of Dark Mending"
  [44303] = {4,200,"INVTYPE_CHEST"}, --"Darkheart Chestguard"
  [44305] = {4,200,"INVTYPE_LEGS"}, --"Kilt of Dark Mercy"
  [44306] = {4,200,"INVTYPE_FEET"}, --"Death-Inured Sabatons"
  [44308] = {4,200,"INVTYPE_FINGER"}, --"Signet of Edward the Odd"
  [44309] = {4,200,"INVTYPE_WAIST"}, --"Sash of Jordan"
  [44310] = {4,200,"INVTYPE_WEAPON"}, --"Namlak's Supernumerary Sticker"
  [44311] = {4,200,"INVTYPE_WEAPON"}, --"Avool's Sword of Jin"
  [44312] = {4,200,"INVTYPE_SHOULDER"}, --"Wapach's Spaulders of Solidarity"
  [44313] = {4,200,"INVTYPE_SHIELD"}, --"Zom's Crackling Bulwark"
  [44333] = {4,200,"INVTYPE_FEET"}, --"Ghostcrawler's Greaves"
  [44504] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Nesingwary 4000"
  [44657] = {4,213,"INVTYPE_NECK"}, --"Torque of the Red Dragonflight"
  [44658] = {4,213,"INVTYPE_NECK"}, --"Chain of the Ancient Wyrm"
  [44659] = {4,213,"INVTYPE_NECK"}, --"Pendant of the Dragonsworn"
  [44660] = {4,213,"INVTYPE_NECK"}, --"Drakescale Collar"
  [44661] = {4,226,"INVTYPE_NECK"}, --"Wyrmrest Necklace of Power"
  [44662] = {4,226,"INVTYPE_NECK"}, --"Life-Binder's Locket"
  [44664] = {4,226,"INVTYPE_NECK"}, --"Favor of the Dragon Queen"
  [44665] = {4,226,"INVTYPE_NECK"}, --"Nexus War Champion Beads"
  [44869] = {4,200,"INVTYPE_TRINKET"}, --"Frenzyheart Insignia of Fury"
  [44870] = {4,200,"INVTYPE_TRINKET"}, --"Oracle Talisman of Ablution"
  [44926] = {4,200,"INVTYPE_2HWEAPON"}, --"Titansteel Deflector"
  [44930] = {4,200,"INVTYPE_FEET"}, --"Windripper Boots"
  [44931] = {4,200,"INVTYPE_LEGS"}, --"Windripper Leggings"
  [44934] = {4,200,"INVTYPE_FINGER"}, --"Loop of the Kirin Tor"
  [44935] = {4,200,"INVTYPE_FINGER"}, --"Ring of the Kirin Tor"
  [44948] = {4,200,"INVTYPE_2HWEAPON"}, --"Titansteel Defender"
  [44949] = {4,200,"INVTYPE_HEAD"}, --"Unbreakable Healing Amplifiers"
  [45074] = {4,200,"INVTYPE_2HWEAPON"}, --"Claymore of the Prophet"
  [45075] = {4,200,"INVTYPE_WEAPON"}, --"Ironforge Smasher"
  [45076] = {4,200,"INVTYPE_WEAPON"}, --"Teldrassil Protector"
  [45077] = {4,200,"INVTYPE_WEAPON"}, --"Dagger of the Rising Moon"
  [45078] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Dagger of Lunar Purity"
  [45085] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Titansteel Spellblade"
  [45086] = {4,238,"INVTYPE_THROWN"}, --"Rising Sun"
  [45106] = {4,232,"INVTYPE_FINGER"}, --"Strength of the Automaton"
  [45107] = {4,232,"INVTYPE_HEAD"}, --"Iron Riveted War Helm"
  [45108] = {4,232,"INVTYPE_WRIST"}, --"Mechanist's Bindings"
  [45109] = {4,232,"INVTYPE_HAND"}, --"Gloves of the Fiery Behemoth"
  [45110] = {4,238,"INVTYPE_WEAPON"}, --"Titanguard"
  [45111] = {4,232,"INVTYPE_WRIST"}, --"Mimiron's Inferno Couplings"
  [45112] = {4,232,"INVTYPE_FINGER"}, --"The Leviathan's Coil"
  [45113] = {4,232,"INVTYPE_FINGER"}, --"Glowing Ring of Reclamation"
  [45114] = {4,232,"INVTYPE_RELIC"}, --"Steamcaller's Totem"
  [45115] = {4,232,"INVTYPE_HOLDABLE"}, --"Leviathan Fueling Manual"
  [45116] = {4,232,"INVTYPE_NECK"}, --"Freya's Choker of Warding"
  [45117] = {4,232,"INVTYPE_HAND"}, --"Constructor's Handwraps"
  [45118] = {4,232,"INVTYPE_HEAD"}, --"Steamworker's Goggles"
  [45119] = {4,232,"INVTYPE_WAIST"}, --"Embrace of the Leviathan"
  [45128] = {4,200,"INVTYPE_2HWEAPON"}, --"Silvery Sylvan Stave"
  [45129] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Gnomeregan Bonechopper"
  [45130] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Blunderbuss of Khaz Modan"
  [45132] = {4,252,"INVTYPE_WEAPONMAINHAND"}, --"Golden Saronite Dragon"
  [45133] = {4,252,"INVTYPE_NECK"}, --"Pendant of Fiery Havoc"
  [45134] = {4,252,"INVTYPE_LEGS"}, --"Plated Leggings of Ruination"
  [45135] = {4,252,"INVTYPE_FEET"}, --"Boots of Fiery Resolution"
  [45136] = {4,252,"INVTYPE_SHOULDER"}, --"Shoulderpads of Dormant Energies"
  [45137] = {4,238,"INVTYPE_RANGEDRIGHT"}, --"Veranus' Bane"
  [45138] = {4,232,"INVTYPE_CLOAK"}, --"Drape of the Drakerider"
  [45139] = {4,232,"INVTYPE_WAIST"}, --"Dragonslayer's Brace"
  [45140] = {4,232,"INVTYPE_SHOULDER"}, --"Razorscale Shoulderguards"
  [45141] = {4,232,"INVTYPE_LEGS"}, --"Proto-hide Leggings"
  [45142] = {4,238,"INVTYPE_WEAPON"}, --"Remorse"
  [45143] = {4,232,"INVTYPE_LEGS"}, --"Saronite Mesh Legguards"
  [45144] = {4,232,"INVTYPE_RELIC"}, --"Sigil of Deflection"
  [45145] = {4,232,"INVTYPE_RELIC"}, --"Libram of the Sacred Shield"
  [45146] = {4,232,"INVTYPE_WRIST"}, --"Shackles of the Odalisque"
  [45147] = {4,238,"INVTYPE_WEAPONMAINHAND"}, --"Guiding Star"
  [45148] = {4,232,"INVTYPE_TRINKET"}, --"Living Flame"
  [45149] = {4,232,"INVTYPE_WRIST"}, --"Bracers of the Broodmother"
  [45150] = {4,232,"INVTYPE_HEAD"}, --"Collar of the Wyrmhunter"
  [45151] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Fallen Wyrm"
  [45157] = {4,232,"INVTYPE_FINGER"}, --"Cindershard Ring"
  [45158] = {4,232,"INVTYPE_TRINKET"}, --"Heart of Iron"
  [45161] = {4,232,"INVTYPE_WAIST"}, --"Girdle of Embers"
  [45162] = {4,232,"INVTYPE_FEET"}, --"Flamestalker Boots"
  [45164] = {4,232,"INVTYPE_HEAD"}, --"Helm of the Furnace Master"
  [45165] = {4,238,"INVTYPE_2HWEAPON"}, --"Worldcarver"
  [45166] = {4,232,"INVTYPE_FEET"}, --"Charred Saronite Greaves"
  [45167] = {4,232,"INVTYPE_CHEST"}, --"Lifeforge Breastplate"
  [45168] = {4,232,"INVTYPE_FINGER"}, --"Pyrelight Circle"
  [45169] = {4,232,"INVTYPE_RELIC"}, --"Totem of the Dancing Flame"
  [45170] = {4,238,"INVTYPE_RANGEDRIGHT"}, --"Scepter of Creation"
  [45171] = {4,238,"INVTYPE_2HWEAPON"}, --"Intensity"
  [45185] = {4,232,"INVTYPE_WAIST"}, --"Flamewrought Cinch"
  [45186] = {4,232,"INVTYPE_SHOULDER"}, --"Soot-Covered Mantle"
  [45187] = {4,232,"INVTYPE_WRIST"}, --"Wristguards of the Firetender"
  [45193] = {4,232,"INVTYPE_NECK"}, --"Insurmountable Fervor"
  [45203] = {4,200,"INVTYPE_WEAPON"}, --"Grimhorn Crusher"
  [45204] = {4,200,"INVTYPE_WEAPON"}, --"Axe of the Sen'jin Protector"
  [45205] = {4,200,"INVTYPE_2HWEAPON"}, --"Greatsword of the Sin'dorei"
  [45208] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Blade of the Keening Banshee"
  [45210] = {4,200,"INVTYPE_RANGEDRIGHT"}, --"Sen'jin Beakblade Longrifle"
  [45212] = {4,200,"INVTYPE_2HWEAPON"}, --"Staff of Feral Furies"
  [45214] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"Scalpel of the Royal Apothecary"
  [45222] = {4,200,"INVTYPE_WEAPON"}, --"Spinal Destroyer"
  [45224] = {4,232,"INVTYPE_CLOAK"}, --"Drape of the Lithe"
  [45225] = {4,232,"INVTYPE_CHEST"}, --"Steelbreaker's Embrace"
  [45226] = {4,232,"INVTYPE_HEAD"}, --"Ancient Iron Heaume"
  [45227] = {4,232,"INVTYPE_SHOULDER"}, --"Iron-studded Mantle"
  [45228] = {4,232,"INVTYPE_HAND"}, --"Handguards of the Enclave"
  [45232] = {4,232,"INVTYPE_FEET"}, --"Runed Ironhide Boots"
  [45233] = {4,238,"INVTYPE_2HWEAPON"}, --"Stormrune Edge"
  [45234] = {4,238,"INVTYPE_2HWEAPON"}, --"Rapture"
  [45235] = {4,232,"INVTYPE_FINGER"}, --"Radiant Seal"
  [45236] = {4,232,"INVTYPE_NECK"}, --"Unblinking Eye"
  [45237] = {4,232,"INVTYPE_ROBE"}, --"Phaelia's Vestments of the Sprouting Seed"
  [45238] = {4,232,"INVTYPE_LEGS"}, --"Overload Legwraps"
  [45239] = {4,232,"INVTYPE_HAND"}, --"Runeshaper's Gloves"
  [45240] = {4,232,"INVTYPE_ROBE"}, --"Raiments of the Iron Council"
  [45241] = {4,252,"INVTYPE_WAIST"}, --"Belt of Colossal Rage"
  [45242] = {4,252,"INVTYPE_CLOAK"}, --"Drape of Mortal Downfall"
  [45243] = {4,252,"INVTYPE_NECK"}, --"Sapphire Amulet of Renewal"
  [45244] = {4,252,"INVTYPE_FEET"}, --"Greaves of Swift Vengeance"
  [45245] = {4,252,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Intruder"
  [45246] = {4,238,"INVTYPE_WEAPON"}, --"Golem-Shard Sticker"
  [45247] = {4,232,"INVTYPE_FINGER"}, --"Signet of the Earthshaker"
  [45248] = {4,232,"INVTYPE_LEGS"}, --"Clockwork Legplates"
  [45249] = {4,232,"INVTYPE_FEET"}, --"Brass-lined Boots"
  [45250] = {4,232,"INVTYPE_FINGER"}, --"Crazed Construct Ring"
  [45251] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderplates of the Deconstructor"
  [45252] = {4,232,"INVTYPE_WRIST"}, --"Horologist's Wristguards"
  [45253] = {4,232,"INVTYPE_SHOULDER"}, --"Mantle of Wavering Calm"
  [45254] = {4,232,"INVTYPE_RELIC"}, --"Sigil of the Vengeful Heart"
  [45255] = {4,232,"INVTYPE_RELIC"}, --"Thunderfall Totem"
  [45256] = {4,238,"INVTYPE_2HWEAPON"}, --"Twisted Visage"
  [45257] = {4,238,"INVTYPE_RANGEDRIGHT"}, --"Quartz Crystal Wand"
  [45258] = {4,232,"INVTYPE_FEET"}, --"Sandals of Rash Temperament"
  [45259] = {4,232,"INVTYPE_CHEST"}, --"Quartz-studded Harness"
  [45260] = {4,232,"INVTYPE_FEET"}, --"Boots of Hasty Revival"
  [45261] = {4,238,"INVTYPE_RANGEDRIGHT"}, --"Giant's Bane"
  [45262] = {4,232,"INVTYPE_NECK"}, --"Necklace of Unerring Mettle"
  [45263] = {4,232,"INVTYPE_TRINKET"}, --"Wrathstone"
  [45264] = {4,239,"INVTYPE_WRIST"}, --"Decimator's Armguards"
  [45265] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Monolith"
  [45266] = {4,238,"INVTYPE_WEAPON"}, --"Malice"
  [45267] = {4,232,"INVTYPE_LEGS"}, --"Saronite Plated Legguards"
  [45268] = {4,232,"INVTYPE_HAND"}, --"Gloves of the Pythonic Guardian"
  [45269] = {4,232,"INVTYPE_WRIST"}, --"Unfaltering Armguards"
  [45270] = {4,232,"INVTYPE_RELIC"}, --"Idol of the Crying Wind"
  [45271] = {4,232,"INVTYPE_HOLDABLE"}, --"Ironmender"
  [45272] = {4,232,"INVTYPE_ROBE"}, --"Robes of the Umbral Brute"
  [45273] = {4,232,"INVTYPE_HAND"}, --"Handwraps of Plentiful Recovery"
  [45274] = {4,232,"INVTYPE_LEGS"}, --"Leggings of the Stoneweaver"
  [45275] = {4,232,"INVTYPE_WRIST"}, --"Bracers of Unleashed Magic"
  [45282] = {4,225,"INVTYPE_2HWEAPON"}, --"Ironsoul"
  [45283] = {4,225,"INVTYPE_WRIST"}, --"Flamewatch Armguards"
  [45284] = {4,225,"INVTYPE_WEAPONOFFHAND"}, --"Kinetic Ripper"
  [45285] = {4,225,"INVTYPE_NECK"}, --"Might of the Leviathan"
  [45286] = {4,225,"INVTYPE_TRINKET"}, --"Pyrite Infuser"
  [45287] = {4,225,"INVTYPE_WEAPONMAINHAND"}, --"Firesoul"
  [45288] = {4,225,"INVTYPE_CHEST"}, --"Firestrider Chestguard"
  [45289] = {4,225,"INVTYPE_HEAD"}, --"Lifespark Visage"
  [45291] = {4,225,"INVTYPE_WRIST"}, --"Combustion Bracers"
  [45292] = {4,225,"INVTYPE_TRINKET"}, --"Energy Siphon"
  [45293] = {4,239,"INVTYPE_HAND"}, --"Handguards of Potent Cures"
  [45294] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Petrified Ivy Sprig"
  [45295] = {4,239,"INVTYPE_LEGS"}, --"Gilded Steel Legplates"
  [45296] = {4,245,"INVTYPE_THROWN"}, --"Twirling Blades"
  [45297] = {4,239,"INVTYPE_FINGER"}, --"Shimmering Seal"
  [45298] = {4,225,"INVTYPE_WEAPON"}, --"Razorscale Talon"
  [45299] = {4,225,"INVTYPE_HEAD"}, --"Dragonsteel Faceplate"
  [45300] = {4,239,"INVTYPE_SHOULDER"}, --"Mantle of Fiery Vengeance"
  [45301] = {4,225,"INVTYPE_WRIST"}, --"Bracers of the Smothering Inferno"
  [45302] = {4,225,"INVTYPE_FEET"}, --"Treads of the Invader"
  [45303] = {4,225,"INVTYPE_FINGER"}, --"Band of Draconic Guile"
  [45304] = {4,225,"INVTYPE_WAIST"}, --"Stormtempered Girdle"
  [45305] = {4,225,"INVTYPE_CHEST"}, --"Breastplate of the Afterlife"
  [45306] = {4,225,"INVTYPE_WAIST"}, --"Binding of the Dragon Matriarch"
  [45307] = {4,225,"INVTYPE_LEGS"}, --"Ironscale Leggings"
  [45308] = {4,225,"INVTYPE_TRINKET"}, --"Eye of the Broodmother"
  [45309] = {4,225,"INVTYPE_RANGEDRIGHT"}, --"Rifle of the Platinum Guard"
  [45310] = {4,225,"INVTYPE_HAND"}, --"Gauntlets of the Iron Furnace"
  [45311] = {4,225,"INVTYPE_2HWEAPON"}, --"Relentless Edge"
  [45312] = {4,225,"INVTYPE_HAND"}, --"Gloves of Smoldering Touch"
  [45313] = {4,225,"INVTYPE_TRINKET"}, --"Furnace Stone"
  [45314] = {4,225,"INVTYPE_HOLDABLE"}, --"Igniter Rod"
  [45315] = {4,238,"INVTYPE_WEAPON"}, --"Stonerender"
  [45316] = {4,225,"INVTYPE_WRIST"}, --"Armbraces of the Vibrant Flame"
  [45317] = {4,225,"INVTYPE_CLOAK"}, --"Shawl of the Caretaker"
  [45318] = {4,225,"INVTYPE_CLOAK"}, --"Drape of Fuming Anger"
  [45319] = {4,232,"INVTYPE_CLOAK"}, --"Cloak of the Makers"
  [45320] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderplates of the Eternal"
  [45321] = {4,225,"INVTYPE_SHOULDER"}, --"Pauldrons of Tempered Will"
  [45322] = {4,225,"INVTYPE_CLOAK"}, --"Cloak of the Iron Council"
  [45324] = {4,225,"INVTYPE_LEGS"}, --"Leggings of Swift Reflexes"
  [45325] = {4,232,"INVTYPE_HAND"}, --"Gloves of the Stonereaper"
  [45326] = {4,232,"INVTYPE_FINGER"}, --"Platinum Band of the Aesir"
  [45327] = {4,238,"INVTYPE_RANGED"}, --"Siren's Cry"
  [45329] = {4,225,"INVTYPE_HEAD"}, --"Circlet of True Sight"
  [45330] = {4,225,"INVTYPE_FEET"}, --"Greaves of Iron Intensity"
  [45331] = {4,225,"INVTYPE_WEAPON"}, --"Rune-Etched Nightblade"
  [45332] = {4,225,"INVTYPE_WEAPONMAINHAND"}, --"Stormtip"
  [45333] = {4,225,"INVTYPE_WAIST"}, --"Belt of the Iron Servant"
  [45334] = {4,232,"INVTYPE_CHEST"}, --"Unbreakable Chestguard"
  [45335] = {4,225,"INVTYPE_CHEST"}, --"Valorous Darkruned Chestguard"
  [45336] = {4,225,"INVTYPE_HEAD"}, --"Valorous Darkruned Faceguard"
  [45337] = {4,225,"INVTYPE_HAND"}, --"Valorous Darkruned Handguards"
  [45338] = {4,225,"INVTYPE_LEGS"}, --"Valorous Darkruned Legguards"
  [45339] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Darkruned Pauldrons"
  [45340] = {4,225,"INVTYPE_CHEST"}, --"Valorous Darkruned Battleplate"
  [45341] = {4,225,"INVTYPE_HAND"}, --"Valorous Darkruned Gauntlets"
  [45342] = {4,225,"INVTYPE_HEAD"}, --"Valorous Darkruned Helmet"
  [45343] = {4,225,"INVTYPE_LEGS"}, --"Valorous Darkruned Legplates"
  [45344] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Darkruned Shoulderplates"
  [45345] = {4,225,"INVTYPE_HAND"}, --"Valorous Nightsong Handguards"
  [45346] = {4,225,"INVTYPE_HEAD"}, --"Valorous Nightsong Headpiece"
  [45347] = {4,225,"INVTYPE_LEGS"}, --"Valorous Nightsong Leggings"
  [45348] = {4,225,"INVTYPE_ROBE"}, --"Valorous Nightsong Robe"
  [45349] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Nightsong Spaulders"
  [45350] = {4,225,"INVTYPE_HEAD"}, --"Nightsong Cover"
  [45351] = {4,225,"INVTYPE_HAND"}, --"Valorous Nightsong Gloves"
  [45352] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Nightsong Mantle"
  [45353] = {4,225,"INVTYPE_LEGS"}, --"Valorous Nightsong Trousers"
  [45354] = {4,225,"INVTYPE_ROBE"}, --"Valorous Nightsong Vestments"
  [45355] = {4,225,"INVTYPE_HAND"}, --"Valorous Nightsong Handgrips"
  [45356] = {4,225,"INVTYPE_HEAD"}, --"Valorous Nightsong Headguard"
  [45357] = {4,225,"INVTYPE_LEGS"}, --"Valorous Nightsong Legguards"
  [45358] = {4,225,"INVTYPE_ROBE"}, --"Valorous Nightsong Raiments"
  [45359] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Nightsong Shoulderpads"
  [45360] = {4,225,"INVTYPE_HAND"}, --"Valorous Scourgestalker Handguards"
  [45361] = {4,225,"INVTYPE_HEAD"}, --"Valorous Scourgestalker Headpiece"
  [45362] = {4,225,"INVTYPE_LEGS"}, --"Valorous Scourgestalker Legguards"
  [45363] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Scourgestalker Spaulders"
  [45364] = {4,225,"INVTYPE_CHEST"}, --"Valorous Scourgestalker Tunic"
  [45365] = {4,225,"INVTYPE_HEAD"}, --"Valorous Kirin Tor Hood"
  [45367] = {4,225,"INVTYPE_LEGS"}, --"Valorous Kirin Tor Leggings"
  [45368] = {4,225,"INVTYPE_CHEST"}, --"Valorous Kirin Tor Tunic"
  [45369] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Kirin Tor Shoulderpads"
  [45370] = {4,225,"INVTYPE_HAND"}, --"Valorous Aegis Gloves"
  [45371] = {4,225,"INVTYPE_LEGS"}, --"Valorous Aegis Greaves"
  [45372] = {4,225,"INVTYPE_HEAD"}, --"Valorous Aegis Headpiece"
  [45373] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Aegis Spaulders"
  [45374] = {4,225,"INVTYPE_CHEST"}, --"Valorous Aegis Tunic"
  [45375] = {4,225,"INVTYPE_CHEST"}, --"Valorous Aegis Battleplate"
  [45376] = {4,225,"INVTYPE_HAND"}, --"Valorous Aegis Gauntlets"
  [45377] = {4,225,"INVTYPE_HEAD"}, --"Valorous Aegis Helm"
  [45378] = {4,225,"INVTYPE_FEET"}, --"Boots of the Petrified Forest"
  [45379] = {4,225,"INVTYPE_LEGS"}, --"Valorous Aegis Legplates"
  [45380] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Aegis Shoulderplates"
  [45381] = {4,225,"INVTYPE_CHEST"}, --"Valorous Aegis Breastplate"
  [45382] = {4,225,"INVTYPE_HEAD"}, --"Valorous Aegis Faceguard"
  [45383] = {4,225,"INVTYPE_HAND"}, --"Valorous Aegis Handguards"
  [45384] = {4,225,"INVTYPE_LEGS"}, --"Valorous Aegis Legguards"
  [45385] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Aegis Shoulderguards"
  [45386] = {4,225,"INVTYPE_HEAD"}, --"Valorous Cowl of Sanctification"
  [45387] = {4,225,"INVTYPE_HAND"}, --"Valorous Gloves of Sanctification"
  [45388] = {4,225,"INVTYPE_LEGS"}, --"Valorous Leggings of Sanctification"
  [45389] = {4,225,"INVTYPE_ROBE"}, --"Valorous Robe of Sanctification"
  [45390] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Shoulderpads of Sanctification"
  [45391] = {4,225,"INVTYPE_HEAD"}, --"Valorous Circlet of Sanctification"
  [45392] = {4,225,"INVTYPE_HAND"}, --"Valorous Handwraps of Sanctification"
  [45393] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Mantle of Sanctification"
  [45394] = {4,225,"INVTYPE_LEGS"}, --"Valorous Pants of Sanctification"
  [45395] = {4,225,"INVTYPE_ROBE"}, --"Valorous Raiments of Sanctification"
  [45396] = {4,225,"INVTYPE_CHEST"}, --"Valorous Terrorblade Breastplate"
  [45397] = {4,225,"INVTYPE_HAND"}, --"Valorous Terrorblade Gauntlets"
  [45398] = {4,225,"INVTYPE_HEAD"}, --"Valorous Terrorblade Helmet"
  [45399] = {4,225,"INVTYPE_LEGS"}, --"Valorous Terrorblade Legplates"
  [45400] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Terrorblade Pauldrons"
  [45401] = {4,225,"INVTYPE_HAND"}, --"Valorous Worldbreaker Handguards"
  [45402] = {4,225,"INVTYPE_HEAD"}, --"Valorous Worldbreaker Headpiece"
  [45403] = {4,225,"INVTYPE_LEGS"}, --"Valorous Worldbreaker Legguards"
  [45404] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Worldbreaker Spaulders"
  [45405] = {4,225,"INVTYPE_ROBE"}, --"Valorous Worldbreaker Tunic"
  [45406] = {4,225,"INVTYPE_HAND"}, --"Valorous Worldbreaker Gloves"
  [45408] = {4,225,"INVTYPE_HEAD"}, --"Valorous Worldbreaker Helm"
  [45409] = {4,225,"INVTYPE_LEGS"}, --"Valorous Worldbreaker Kilt"
  [45410] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Worldbreaker Shoulderpads"
  [45411] = {4,225,"INVTYPE_ROBE"}, --"Valorous Worldbreaker Hauberk"
  [45412] = {4,225,"INVTYPE_HEAD"}, --"Valorous Worldbreaker Faceguard"
  [45413] = {4,225,"INVTYPE_ROBE"}, --"Valorous Worldbreaker Chestguard"
  [45414] = {4,225,"INVTYPE_HAND"}, --"Valorous Worldbreaker Grips"
  [45415] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Worldbreaker Shoulderguards"
  [45416] = {4,225,"INVTYPE_LEGS"}, --"Valorous Worldbreaker War-Kilt"
  [45417] = {4,225,"INVTYPE_HEAD"}, --"Valorous Deathbringer Hood"
  [45418] = {4,225,"INVTYPE_FINGER"}, --"Lady Maye's Sapphire Ring"
  [45419] = {4,225,"INVTYPE_HAND"}, --"Valorous Deathbringer Gloves"
  [45420] = {4,225,"INVTYPE_LEGS"}, --"Valorous Deathbringer Leggings"
  [45421] = {4,225,"INVTYPE_ROBE"}, --"Valorous Deathbringer Robe"
  [45422] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Deathbringer Shoulderpads"
  [45423] = {4,225,"INVTYPE_WRIST"}, --"Runetouch Wristwraps"
  [45424] = {4,225,"INVTYPE_CHEST"}, --"Valorous Siegebreaker Breastplate"
  [45425] = {4,225,"INVTYPE_HEAD"}, --"Valorous Siegebreaker Greathelm"
  [45426] = {4,225,"INVTYPE_HAND"}, --"Valorous Siegebreaker Handguards"
  [45427] = {4,225,"INVTYPE_LEGS"}, --"Valorous Siegebreaker Legguards"
  [45428] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Siegebreaker Pauldrons"
  [45429] = {4,225,"INVTYPE_CHEST"}, --"Valorous Siegebreaker Battleplate"
  [45430] = {4,225,"INVTYPE_HAND"}, --"Valorous Siegebreaker Gauntlets"
  [45431] = {4,225,"INVTYPE_HEAD"}, --"Valorous Siegebreaker Helmet"
  [45432] = {4,225,"INVTYPE_LEGS"}, --"Valorous Siegebreaker Legplates"
  [45433] = {4,225,"INVTYPE_SHOULDER"}, --"Valorous Siegebreaker Shoulderplates"
  [45434] = {4,232,"INVTYPE_FEET"}, --"Greaves of the Rockmender"
  [45435] = {4,232,"INVTYPE_HEAD"}, --"Cowl of the Absolute"
  [45436] = {4,232,"INVTYPE_RELIC"}, --"Libram of the Resolute"
  [45437] = {4,238,"INVTYPE_WEAPONMAINHAND"}, --"Runescribed Blade"
  [45438] = {4,232,"INVTYPE_FINGER"}, --"Ring of the Faithful Servant"
  [45439] = {4,232,"INVTYPE_HEAD"}, --"Unwavering Stare"
  [45440] = {4,232,"INVTYPE_SHOULDER"}, --"Amice of the Stoic Watch"
  [45441] = {4,232,"INVTYPE_FEET"}, --"Sandals of the Ancient Keeper"
  [45442] = {4,252,"INVTYPE_WEAPON"}, --"Sorthalis, Hammer of the Watchers"
  [45443] = {4,252,"INVTYPE_NECK"}, --"Charm of Meticulous Timing"
  [45444] = {4,252,"INVTYPE_HAND"}, --"Gloves of the Steady Hand"
  [45445] = {4,252,"INVTYPE_CHEST"}, --"Breastplate of the Devoted"
  [45446] = {4,252,"INVTYPE_WRIST"}, --"Grasps of Reason"
  [45447] = {4,239,"INVTYPE_NECK"}, --"Watchful Eye of Fate"
  [45448] = {4,245,"INVTYPE_WEAPON"}, --"Perilous Bite"
  [45449] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"The Masticator"
  [45450] = {4,232,"INVTYPE_SHIELD"}, --"Northern Barrier"
  [45451] = {4,232,"INVTYPE_FINGER"}, --"Frozen Loop"
  [45452] = {4,232,"INVTYPE_LEGS"}, --"Frostplate Greaves"
  [45453] = {4,232,"INVTYPE_CHEST"}, --"Winter's Icy Embrace"
  [45454] = {4,232,"INVTYPE_WRIST"}, --"Frost-bound Chain Bracers"
  [45455] = {4,239,"INVTYPE_WAIST"}, --"Belt of the Crystal Tree"
  [45456] = {4,239,"INVTYPE_FINGER"}, --"Loop of the Agile"
  [45457] = {4,252,"INVTYPE_2HWEAPON"}, --"Staff of Endless Winter"
  [45458] = {4,225,"INVTYPE_2HWEAPON"}, --"Stormedge"
  [45459] = {4,252,"INVTYPE_NECK"}, --"Frigid Strength of Hodir"
  [45460] = {4,252,"INVTYPE_WRIST"}, --"Bindings of Winter Gale"
  [45461] = {4,252,"INVTYPE_CLOAK"}, --"Drape of Icy Intent"
  [45462] = {4,252,"INVTYPE_HAND"}, --"Gloves of the Frozen Glade"
  [45463] = {4,238,"INVTYPE_WEAPON"}, --"Vulmir, the Northern Tempest"
  [45464] = {4,225,"INVTYPE_HEAD"}, --"Cowl of Icy Breaths"
  [45466] = {4,232,"INVTYPE_TRINKET"}, --"Scale of Fates"
  [45467] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Betrayed"
  [45468] = {4,232,"INVTYPE_LEGS"}, --"Leggings of Lost Love"
  [45469] = {4,232,"INVTYPE_FINGER"}, --"Sif's Promise"
  [45470] = {4,252,"INVTYPE_SHIELD"}, --"Wisdom's Hold"
  [45471] = {4,252,"INVTYPE_FINGER"}, --"Fate's Clutch"
  [45472] = {4,252,"INVTYPE_HEAD"}, --"Warhelm of the Champion"
  [45473] = {4,252,"INVTYPE_CHEST"}, --"Embrace of the Gladiator"
  [45474] = {4,252,"INVTYPE_SHOULDER"}, --"Pauldrons of the Combatant"
  [45479] = {4,238,"INVTYPE_2HWEAPON"}, --"The Lifebinder"
  [45480] = {4,232,"INVTYPE_NECK"}, --"Nymph Heart Charm"
  [45481] = {4,232,"INVTYPE_HAND"}, --"Gauntlets of Ruthless Reprisal"
  [45482] = {4,232,"INVTYPE_LEGS"}, --"Leggings of the Lifetender"
  [45483] = {4,232,"INVTYPE_FEET"}, --"Boots of the Servant"
  [45484] = {4,252,"INVTYPE_WEAPON"}, --"Bladetwister"
  [45485] = {4,252,"INVTYPE_NECK"}, --"Bronze Pendant of the Vanir"
  [45486] = {4,252,"INVTYPE_CLOAK"}, --"Drape of the Sullen Goddess"
  [45487] = {4,252,"INVTYPE_HAND"}, --"Handguards of Revitalization"
  [45488] = {4,252,"INVTYPE_LEGS"}, --"Leggings of the Enslaved Idol"
  [45489] = {4,238,"INVTYPE_WEAPONMAINHAND"}, --"Insanity's Grip"
  [45490] = {4,232,"INVTYPE_TRINKET"}, --"Pandora's Plea"
  [45491] = {4,232,"INVTYPE_WAIST"}, --"Waistguard of the Creator"
  [45492] = {4,232,"INVTYPE_SHOULDER"}, --"Malleable Steelweave Mantle"
  [45493] = {4,232,"INVTYPE_CLOAK"}, --"Asimov's Drape"
  [45494] = {4,245,"INVTYPE_WEAPONOFFHAND"}, --"Delirium's Touch"
  [45495] = {4,252,"INVTYPE_FINGER"}, --"Conductive Seal"
  [45496] = {4,252,"INVTYPE_CLOAK"}, --"Titanskin Cloak"
  [45497] = {4,252,"INVTYPE_HEAD"}, --"Crown of Luminescence"
  [45498] = {4,238,"INVTYPE_2HWEAPON"}, --"Lotrafen, Spear of the Damned"
  [45501] = {4,232,"INVTYPE_FEET"}, --"Boots of the Underdweller"
  [45502] = {4,232,"INVTYPE_HEAD"}, --"Helm of the Faceless"
  [45503] = {4,232,"INVTYPE_FINGER"}, --"Metallic Loop of the Sufferer"
  [45504] = {4,232,"INVTYPE_LEGS"}, --"Darkcore Leggings"
  [45505] = {4,232,"INVTYPE_WAIST"}, --"Belt of Clinging Hope"
  [45507] = {4,232,"INVTYPE_TRINKET"}, --"The General's Heart"
  [45508] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Darkspeaker"
  [45509] = {4,232,"INVTYPE_RELIC"}, --"Idol of the Corruptor"
  [45510] = {4,232,"INVTYPE_RELIC"}, --"Libram of Discord"
  [45511] = {4,238,"INVTYPE_RANGEDRIGHT"}, --"Scepter of Lost Souls"
  [45512] = {4,232,"INVTYPE_HAND"}, --"Grips of the Unbroken"
  [45513] = {4,232,"INVTYPE_FEET"}, --"Boots of the Forgotten Depths"
  [45514] = {4,232,"INVTYPE_SHOULDER"}, --"Mantle of the Unknowing"
  [45515] = {4,232,"INVTYPE_FINGER"}, --"Ring of the Vacant Eye"
  [45516] = {4,252,"INVTYPE_2HWEAPON"}, --"Voldrethar, Dark Blade of Oblivion"
  [45517] = {4,252,"INVTYPE_NECK"}, --"Pendulum of Infinity"
  [45518] = {4,252,"INVTYPE_TRINKET"}, --"Flare of the Heavens"
  [45519] = {4,252,"INVTYPE_ROBE"}, --"Vestments of the Blind Denizen"
  [45520] = {4,252,"INVTYPE_HAND"}, --"Handwraps of the Vigilant"
  [45521] = {4,238,"INVTYPE_2HWEAPON"}, --"Earthshaper"
  [45522] = {4,232,"INVTYPE_TRINKET"}, --"Blood of the Old God"
  [45523] = {4,232,"INVTYPE_HEAD"}, --"Garona's Guise"
  [45524] = {4,232,"INVTYPE_CHEST"}, --"Chestguard of Insidious Intent"
  [45525] = {4,232,"INVTYPE_FINGER"}, --"Godbane Signet"
  [45527] = {4,238,"INVTYPE_WEAPONMAINHAND"}, --"Soulscribe"
  [45529] = {4,232,"INVTYPE_CLOAK"}, --"Shawl of Haunted Memories"
  [45530] = {4,232,"INVTYPE_FINGER"}, --"Sanity's Bond"
  [45531] = {4,232,"INVTYPE_CHEST"}, --"Chestguard of the Fallen God"
  [45532] = {4,232,"INVTYPE_HEAD"}, --"Cowl of Dark Whispers"
  [45533] = {4,252,"INVTYPE_2HWEAPON"}, --"Dark Edge of Depravity"
  [45534] = {4,252,"INVTYPE_FINGER"}, --"Seal of the Betrayed King"
  [45535] = {4,252,"INVTYPE_TRINKET"}, --"Show of Faith"
  [45536] = {4,252,"INVTYPE_LEGS"}, --"Legguards of Cunning Deception"
  [45537] = {4,252,"INVTYPE_FEET"}, --"Treads of the False Oracle"
  [45538] = {4,232,"INVTYPE_NECK"}, --"Titanstone Pendant"
  [45539] = {4,232,"INVTYPE_NECK"}, --"Pendant of Focused Energies"
  [45540] = {4,232,"INVTYPE_FINGER"}, --"Bladebearer's Signet"
  [45541] = {4,232,"INVTYPE_CLOAK"}, --"Shroud of Alteration"
  [45542] = {4,232,"INVTYPE_FEET"}, --"Greaves of the Stonewarder"
  [45543] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulders of Misfortune"
  [45544] = {4,232,"INVTYPE_LEGS"}, --"Leggings of the Tortured Earth"
  [45547] = {4,232,"INVTYPE_WAIST"}, --"Relic Hunter's Cord"
  [45548] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Sleeper"
  [45549] = {4,232,"INVTYPE_WRIST"}, --"Grips of Chaos"
  [45550] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Titans"
  [45551] = {4,232,"INVTYPE_WAIST"}, --"Indestructible Plate Girdle"
  [45552] = {4,232,"INVTYPE_WAIST"}, --"Plate Girdle of Righteousness"
  [45553] = {4,232,"INVTYPE_WAIST"}, --"Belt of Dragons"
  [45554] = {4,232,"INVTYPE_WAIST"}, --"Blue Belt of Chaos"
  [45555] = {4,232,"INVTYPE_WAIST"}, --"Death-warmed Belt"
  [45556] = {4,232,"INVTYPE_WAIST"}, --"Belt of Arctic Life"
  [45557] = {4,232,"INVTYPE_WAIST"}, --"Sash of Ancient Power"
  [45558] = {4,232,"INVTYPE_WAIST"}, --"Cord of the White Dawn"
  [45559] = {4,232,"INVTYPE_FEET"}, --"Battlelord's Plate Boots"
  [45560] = {4,232,"INVTYPE_FEET"}, --"Spiked Deathdealers"
  [45561] = {4,232,"INVTYPE_FEET"}, --"Treads of Destiny"
  [45562] = {4,232,"INVTYPE_FEET"}, --"Boots of Living Scale"
  [45563] = {4,232,"INVTYPE_FEET"}, --"Lightning Grounded Boots"
  [45564] = {4,232,"INVTYPE_FEET"}, --"Footpads of Silence"
  [45565] = {4,232,"INVTYPE_FEET"}, --"Boots of Wintry Endurance"
  [45566] = {4,232,"INVTYPE_FEET"}, --"Spellslinger's Slippers"
  [45567] = {4,232,"INVTYPE_FEET"}, --"Savior's Slippers"
  [45570] = {4,252,"INVTYPE_RANGEDRIGHT"}, --"Skyforge Crossbow"
  [45587] = {4,252,"INVTYPE_SHIELD"}, --"Bulwark of Algalon"
  [45588] = {4,252,"INVTYPE_CLOAK"}, --"Drape of the Skyborn"
  [45594] = {4,252,"INVTYPE_LEGS"}, --"Legplates of the Endless Void"
  [45599] = {4,252,"INVTYPE_FEET"}, --"Sabatons of Lifeless Night"
  [45605] = {4,238,"INVTYPE_WEAPON"}, --"Daschal's Bite"
  [45607] = {4,252,"INVTYPE_WEAPON"}, --"Fang of Oblivion"
  [45608] = {4,252,"INVTYPE_FINGER"}, --"Brann's Signet Ring"
  [45609] = {4,252,"INVTYPE_TRINKET"}, --"Comet's Trail"
  [45610] = {4,252,"INVTYPE_HEAD"}, --"Boundless Gaze"
  [45611] = {4,252,"INVTYPE_WRIST"}, --"Solar Bindings"
  [45612] = {4,252,"INVTYPE_WEAPONMAINHAND"}, --"Constellus"
  [45613] = {4,252,"INVTYPE_2HWEAPON"}, --"Dreambinder"
  [45614] = {4,252,"INVTYPE_FINGER"}, --"Starshine Circle"
  [45615] = {4,252,"INVTYPE_FEET"}, --"Planewalker Treads"
  [45616] = {4,252,"INVTYPE_WAIST"}, --"Star-beaded Clutch"
  [45617] = {4,252,"INVTYPE_HOLDABLE"}, --"Cosmos"
  [45618] = {4,252,"INVTYPE_CLOAK"}, --"Sunglimmer Cloak"
  [45619] = {4,252,"INVTYPE_WAIST"}, --"Starwatcher's Binding"
  [45620] = {4,252,"INVTYPE_WEAPONMAINHAND"}, --"Starshard Edge"
  [45663] = {4,252,"INVTYPE_WRIST"}, --"Armbands of Bedlam"
  [45665] = {4,252,"INVTYPE_HAND"}, --"Pharos Gloves"
  [45675] = {4,225,"INVTYPE_FINGER"}, --"Power Enhancing Loop"
  [45676] = {4,225,"INVTYPE_CHEST"}, --"Chestplate of Vicious Potency"
  [45677] = {4,225,"INVTYPE_SHOULDER"}, --"Treacherous Shoulderpads"
  [45679] = {4,225,"INVTYPE_HAND"}, --"Gloves of Taut Grip"
  [45680] = {4,225,"INVTYPE_WRIST"}, --"Armbands of the Construct"
  [45682] = {4,225,"INVTYPE_SHIELD"}, --"Pulsing Spellshield"
  [45685] = {4,225,"INVTYPE_WEAPONMAINHAND"}, --"Plasma Foil"
  [45686] = {4,225,"INVTYPE_CHEST"}, --"Vest of the Glowing Crescent"
  [45687] = {4,225,"INVTYPE_HEAD"}, --"Helm of Veiled Energies"
  [45688] = {4,225,"INVTYPE_FINGER"}, --"Inscribed Band of the Kirin Tor"
  [45689] = {4,225,"INVTYPE_FINGER"}, --"Inscribed Loop of the Kirin Tor"
  [45690] = {4,225,"INVTYPE_FINGER"}, --"Inscribed Ring of the Kirin Tor"
  [45691] = {4,225,"INVTYPE_FINGER"}, --"Inscribed Signet of the Kirin Tor"
  [45694] = {4,225,"INVTYPE_WAIST"}, --"Conductive Cord"
  [45695] = {4,225,"INVTYPE_2HWEAPON"}, --"Spire of Withering Dreams"
  [45696] = {4,225,"INVTYPE_NECK"}, --"Mark of the Unyielding"
  [45697] = {4,225,"INVTYPE_SHOULDER"}, --"Shoulderguards of the Solemn Watch"
  [45698] = {4,225,"INVTYPE_FEET"}, --"Sabatons of the Iron Watcher"
  [45699] = {4,225,"INVTYPE_NECK"}, --"Pendant of the Piercing Glare"
  [45700] = {4,225,"INVTYPE_WEAPON"}, --"Stoneguard"
  [45701] = {4,225,"INVTYPE_FEET"}, --"Greaves of the Earthbinder"
  [45702] = {4,225,"INVTYPE_FINGER"}, --"Emerald Signet Ring"
  [45703] = {4,225,"INVTYPE_TRINKET"}, --"Spark of Hope"
  [45704] = {4,225,"INVTYPE_CLOAK"}, --"Shawl of the Shattered Giant"
  [45707] = {4,225,"INVTYPE_SHIELD"}, --"Shieldwall of the Breaker"
  [45708] = {4,225,"INVTYPE_LEGS"}, --"Archaedas' Lost Legplates"
  [45709] = {4,225,"INVTYPE_WAIST"}, --"Nimble Climber's Belt"
  [45711] = {4,225,"INVTYPE_SHOULDER"}, --"Ironaya's Discarded Mantle"
  [45712] = {4,225,"INVTYPE_CHEST"}, --"Chestplate of Titanic Fury"
  [45713] = {4,225,"INVTYPE_RANGEDRIGHT"}, --"Nurturing Touch"
  [45819] = {4,232,"INVTYPE_NECK"}, --"Spiked Battleguard Choker"
  [45820] = {4,232,"INVTYPE_NECK"}, --"Broach of the Wailing Night"
  [45821] = {4,232,"INVTYPE_NECK"}, --"Shard of the Crystal Forest"
  [45822] = {4,232,"INVTYPE_NECK"}, --"Evoker's Charm"
  [45823] = {4,232,"INVTYPE_NECK"}, --"Frozen Tear of Elune"
  [45824] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Singing Blade"
  [45825] = {4,232,"INVTYPE_WAIST"}, --"Shieldwarder Girdle"
  [45826] = {4,232,"INVTYPE_WAIST"}, --"Girdle of Unyielding Trust"
  [45827] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Ardent Marksman"
  [45828] = {4,232,"INVTYPE_WAIST"}, --"Windchill Binding"
  [45829] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Twilight Assassin"
  [45830] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Living Thicket"
  [45831] = {4,232,"INVTYPE_WAIST"}, --"Sash of Potent Incantations"
  [45832] = {4,225,"INVTYPE_SHOULDER"}, --"Mantle of the Preserver"
  [45833] = {4,232,"INVTYPE_HAND"}, --"Bladebreaker Gauntlets"
  [45834] = {4,232,"INVTYPE_HAND"}, --"Gauntlets of the Royal Watch"
  [45835] = {4,232,"INVTYPE_HAND"}, --"Gauntlets of Serene Blessing"
  [45836] = {4,232,"INVTYPE_HAND"}, --"Gloves of Unerring Aim"
  [45837] = {4,232,"INVTYPE_HAND"}, --"Gloves of Augury"
  [45838] = {4,232,"INVTYPE_HAND"}, --"Gloves of the Blind Stalker"
  [45839] = {4,232,"INVTYPE_HAND"}, --"Grips of the Secret Grove"
  [45840] = {4,232,"INVTYPE_HAND"}, --"Touch of the Occult"
  [45841] = {4,232,"INVTYPE_LEGS"}, --"Legplates of the Violet Champion"
  [45842] = {4,232,"INVTYPE_LEGS"}, --"Wyrmguard Legplates"
  [45843] = {4,232,"INVTYPE_LEGS"}, --"Legguards of the Peaceful Covenant"
  [45844] = {4,232,"INVTYPE_LEGS"}, --"Leggings of the Tireless Sentry"
  [45845] = {4,232,"INVTYPE_LEGS"}, --"Leggings of the Weary Mystic"
  [45846] = {4,232,"INVTYPE_LEGS"}, --"Leggings of Wavering Shadow"
  [45847] = {4,232,"INVTYPE_LEGS"}, --"Wildstrider Legguards"
  [45848] = {4,232,"INVTYPE_LEGS"}, --"Legwraps of the Master Conjurer"
  [45859] = {4,206,"INVTYPE_FINGER"}, --"The 5 Ring"
  [45864] = {4,225,"INVTYPE_HEAD"}, --"Cover of the Keepers"
  [45865] = {4,225,"INVTYPE_ROBE"}, --"Raiments of the Corrupted"
  [45866] = {4,225,"INVTYPE_TRINKET"}, --"Elemental Focus Stone"
  [45867] = {4,239,"INVTYPE_CHEST"}, --"Breastplate of the Stoneshaper"
  [45868] = {4,245,"INVTYPE_2HWEAPON"}, --"Aesir's Edge"
  [45869] = {4,239,"INVTYPE_WRIST"}, --"Fluxing Energy Coils"
  [45870] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Magnetized Projectile Emitter"
  [45871] = {4,239,"INVTYPE_FINGER"}, --"Seal of Ulduar"
  [45872] = {4,225,"INVTYPE_RANGED"}, --"Avalanche"
  [45873] = {4,225,"INVTYPE_CLOAK"}, --"Winter's Frigid Embrace"
  [45874] = {4,225,"INVTYPE_FINGER"}, --"Signet of Winter"
  [45876] = {4,245,"INVTYPE_WEAPON"}, --"Shiver"
  [45877] = {4,245,"INVTYPE_SHIELD"}, --"The Boreal Guard"
  [45886] = {4,245,"INVTYPE_2HWEAPON"}, --"Icecore Staff"
  [45887] = {4,245,"INVTYPE_SHIELD"}, --"Ice Layered Barrier"
  [45888] = {4,239,"INVTYPE_WRIST"}, --"Bitter Cold Armguards"
  [45892] = {4,225,"INVTYPE_WEAPON"}, --"Legacy of Thunder"
  [45893] = {4,225,"INVTYPE_HEAD"}, --"Guise of the Midgard Serpent"
  [45894] = {4,225,"INVTYPE_LEGS"}, --"Leggings of Unstable Discharge"
  [45895] = {4,225,"INVTYPE_WAIST"}, --"Belt of the Blood Pit"
  [45927] = {4,225,"INVTYPE_HAND"}, --"Handwraps of Resonance"
  [45928] = {4,239,"INVTYPE_HAND"}, --"Gauntlets of the Thunder God"
  [45929] = {4,239,"INVTYPE_TRINKET"}, --"Sif's Remembrance"
  [45930] = {4,245,"INVTYPE_WEAPON"}, --"Combatant's Bootblade"
  [45931] = {4,239,"INVTYPE_TRINKET"}, --"Mjolnir Runestone"
  [45933] = {4,239,"INVTYPE_NECK"}, --"Pendant of the Shallow Grave"
  [45934] = {4,225,"INVTYPE_2HWEAPON"}, --"Unraveling Reach"
  [45935] = {4,225,"INVTYPE_HEAD"}, --"Ironbark Faceguard"
  [45936] = {4,225,"INVTYPE_LEGS"}, --"Legplates of Flourishing Resolve"
  [45940] = {4,225,"INVTYPE_CHEST"}, --"Tunic of the Limber Stalker"
  [45941] = {4,225,"INVTYPE_CHEST"}, --"Chestguard of the Lasher"
  [45943] = {4,239,"INVTYPE_HAND"}, --"Gloves of Whispering Winds"
  [45945] = {4,239,"INVTYPE_NECK"}, --"Seed of Budding Carnage"
  [45946] = {4,239,"INVTYPE_FINGER"}, --"Fire Orchid Signet"
  [45947] = {4,245,"INVTYPE_WEAPON"}, --"Serilas, Blood Blade of Invar One-Arm"
  [45972] = {4,225,"INVTYPE_WEAPONMAINHAND"}, --"Pulse Baton"
  [45973] = {4,225,"INVTYPE_CLOAK"}, --"Stylish Power Cape"
  [45974] = {4,225,"INVTYPE_SHOULDER"}, --"Shoulderguards of Assimilation"
  [45975] = {4,225,"INVTYPE_WAIST"}, --"Cable of the Metrognome"
  [45976] = {4,225,"INVTYPE_HAND"}, --"Static Charge Handwraps"
  [45982] = {4,239,"INVTYPE_LEGS"}, --"Fused Alloy Legplates"
  [45988] = {4,239,"INVTYPE_FEET"}, --"Greaves of the Iron Army"
  [45989] = {4,239,"INVTYPE_FEET"}, --"Tempered Mercury Greaves"
  [45990] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Fusion Blade"
  [45993] = {4,239,"INVTYPE_HEAD"}, --"Mimiron's Flight Goggles"
  [45996] = {4,225,"INVTYPE_2HWEAPON"}, --"Hoperender"
  [45997] = {4,225,"INVTYPE_HAND"}, --"Gauntlets of the Wretched"
  [46008] = {4,225,"INVTYPE_NECK"}, --"Choker of the Abyss"
  [46009] = {4,225,"INVTYPE_WRIST"}, --"Bindings of the Depths"
  [46010] = {4,225,"INVTYPE_FINGER"}, --"Darkstone Ring"
  [46011] = {4,225,"INVTYPE_WEAPON"}, --"Shadowbite"
  [46012] = {4,225,"INVTYPE_ROBE"}, --"Vestments of the Piercing Light"
  [46013] = {4,225,"INVTYPE_SHOULDER"}, --"Underworld Mantle"
  [46014] = {4,225,"INVTYPE_CLOAK"}, --"Saronite Animus Cloak"
  [46015] = {4,225,"INVTYPE_NECK"}, --"Pendant of Endless Despair"
  [46016] = {4,225,"INVTYPE_2HWEAPON"}, --"Abaddon"
  [46018] = {4,225,"INVTYPE_RANGEDRIGHT"}, --"Deliverance"
  [46019] = {4,225,"INVTYPE_LEGS"}, --"Leggings of the Insatiable"
  [46021] = {4,225,"INVTYPE_TRINKET"}, --"Royal Seal of King Llane"
  [46022] = {4,225,"INVTYPE_NECK"}, --"Pendant of a Thousand Maws"
  [46024] = {4,225,"INVTYPE_WEAPON"}, --"Kingsbane"
  [46025] = {4,225,"INVTYPE_2HWEAPON"}, --"Devotion"
  [46028] = {4,225,"INVTYPE_HEAD"}, --"Faceguard of the Eyeless Horror"
  [46030] = {4,225,"INVTYPE_FEET"}, --"Treads of the Dragon Council"
  [46031] = {4,225,"INVTYPE_WEAPON"}, --"Touch of Madness"
  [46032] = {4,239,"INVTYPE_CLOAK"}, --"Drape of the Faceless General"
  [46033] = {4,245,"INVTYPE_2HWEAPON"}, --"Tortured Earth"
  [46034] = {4,239,"INVTYPE_LEGS"}, --"Leggings of Profound Darkness"
  [46035] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Aesuga, Hand of the Ardent Champion"
  [46036] = {4,245,"INVTYPE_WEAPON"}, --"Void Sabre"
  [46037] = {4,239,"INVTYPE_SHOULDER"}, --"Shoulderplates of the Celestial Watch"
  [46038] = {4,239,"INVTYPE_TRINKET"}, --"Dark Matter"
  [46039] = {4,239,"INVTYPE_CHEST"}, --"Breastplate of the Timeless"
  [46040] = {4,239,"INVTYPE_NECK"}, --"Strength of the Heavens"
  [46041] = {4,239,"INVTYPE_WAIST"}, --"Starfall Girdle"
  [46042] = {4,239,"INVTYPE_CLOAK"}, --"Drape of the Messenger"
  [46043] = {4,239,"INVTYPE_HAND"}, --"Gloves of the Endless Dark"
  [46044] = {4,239,"INVTYPE_SHOULDER"}, --"Observer's Mantle"
  [46045] = {4,239,"INVTYPE_HAND"}, --"Pulsar Gloves"
  [46046] = {4,239,"INVTYPE_FINGER"}, --"Nebula Band"
  [46047] = {4,239,"INVTYPE_NECK"}, --"Pendant of the Somber Witness"
  [46048] = {4,239,"INVTYPE_FINGER"}, --"Band of Lights"
  [46049] = {4,239,"INVTYPE_LEGS"}, --"Zodiac Leggings"
  [46050] = {4,239,"INVTYPE_FEET"}, --"Starlight Treads"
  [46051] = {4,239,"INVTYPE_TRINKET"}, --"Meteorite Crystal"
  [46067] = {4,245,"INVTYPE_2HWEAPON"}, --"Hammer of Crushing Whispers"
  [46068] = {4,239,"INVTYPE_SHOULDER"}, --"Amice of Inconceivable Horror"
  [46081] = {4,213,"INVTYPE_TRINKET"}, --"Titan-Forged Rune of Audacity"
  [46082] = {4,213,"INVTYPE_TRINKET"}, --"Titan-Forged Rune of Determination"
  [46083] = {4,213,"INVTYPE_TRINKET"}, --"Titan-Forged Rune of Accuracy"
  [46084] = {4,213,"INVTYPE_TRINKET"}, --"Titan-Forged Rune of Cruelty"
  [46085] = {4,213,"INVTYPE_TRINKET"}, --"Titan-Forged Rune of Alacrity"
  [46095] = {4,239,"INVTYPE_WAIST"}, --"Soul-Devouring Cinch"
  [46096] = {4,239,"INVTYPE_FINGER"}, --"Signet of Soft Lament"
  [46097] = {4,245,"INVTYPE_WEAPON"}, --"Caress of Insanity"
  [46111] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Darkruned Battleplate"
  [46113] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Darkruned Gauntlets"
  [46115] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Darkruned Helmet"
  [46116] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Darkruned Legplates"
  [46117] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Darkruned Shoulderplates"
  [46118] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Darkruned Chestguard"
  [46119] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Darkruned Handguards"
  [46120] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Darkruned Faceguard"
  [46121] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Darkruned Legguards"
  [46122] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Darkruned Pauldrons"
  [46123] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Terrorblade Breastplate"
  [46124] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Terrorblade Gauntlets"
  [46125] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Terrorblade Helmet"
  [46126] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Terrorblade Legplates"
  [46127] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Terrorblade Pauldrons"
  [46129] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Kirin Tor Hood"
  [46130] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Kirin Tor Tunic"
  [46131] = {4,225,"INVTYPE_HAND"}, --"Valorous Kirin Tor Gauntlets"
  [46132] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Kirin Tor Gauntlets"
  [46133] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Kirin Tor Leggings"
  [46134] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Kirin Tor Shoulderpads"
  [46135] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Deathbringer Gloves"
  [46136] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Deathbringer Shoulderpads"
  [46137] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Deathbringer Robe"
  [46138] = {4,232,"INVTYPE_RELIC"}, --"Idol of the Flourishing Life"
  [46139] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Deathbringer Leggings"
  [46140] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Deathbringer Hood"
  [46141] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Scourgestalker Tunic"
  [46142] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Scourgestalker Handguards"
  [46143] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Scourgestalker Headpiece"
  [46144] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Scourgestalker Legguards"
  [46145] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Scourgestalker Spaulders"
  [46146] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Siegebreaker Battleplate"
  [46148] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Siegebreaker Gauntlets"
  [46149] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Siegebreaker Shoulderplates"
  [46150] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Siegebreaker Legplates"
  [46151] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Siegebreaker Helmet"
  [46152] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Aegis Shoulderplates"
  [46153] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Aegis Legplates"
  [46154] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Aegis Battleplate"
  [46155] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Aegis Gauntlets"
  [46156] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Aegis Helm"
  [46157] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Nightsong Shoulderpads"
  [46158] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Nightsong Handgrips"
  [46159] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Nightsong Raiments"
  [46160] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Nightsong Legguards"
  [46161] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Nightsong Headguard"
  [46162] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Siegebreaker Breastplate"
  [46163] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Handwraps of Sanctification"
  [46164] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Siegebreaker Handguards"
  [46165] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Mantle of Sanctification"
  [46166] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Siegebreaker Greathelm"
  [46167] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Siegebreaker Pauldrons"
  [46168] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Raiments of Sanctification"
  [46169] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Siegebreaker Legguards"
  [46170] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Pants of Sanctification"
  [46172] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Circlet of Sanctification"
  [46173] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Aegis Breastplate"
  [46174] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Aegis Handguards"
  [46175] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Aegis Faceguard"
  [46176] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Aegis Legguards"
  [46177] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Aegis Shoulderguards"
  [46178] = {4,232,"INVTYPE_CHEST"}, --"Conqueror's Aegis Tunic"
  [46179] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Aegis Gloves"
  [46180] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Aegis Headpiece"
  [46181] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Aegis Greaves"
  [46182] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Aegis Spaulders"
  [46183] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Nightsong Handguards"
  [46184] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Nightsong Headpiece"
  [46185] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Nightsong Leggings"
  [46186] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Nightsong Robe"
  [46187] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Nightsong Spaulders"
  [46188] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Gloves of Sanctification"
  [46189] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Nightsong Gloves"
  [46190] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Shoulderpads of Sanctification"
  [46191] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Nightsong Cover"
  [46192] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Nightsong Trousers"
  [46193] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Robe of Sanctification"
  [46194] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Nightsong Vestments"
  [46195] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Leggings of Sanctification"
  [46196] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Nightsong Mantle"
  [46197] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Cowl of Sanctification"
  [46198] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Worldbreaker Tunic"
  [46199] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Worldbreaker Handguards"
  [46200] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Worldbreaker Grips"
  [46201] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Worldbreaker Headpiece"
  [46202] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Worldbreaker Legguards"
  [46203] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Worldbreaker Shoulderguards"
  [46204] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Worldbreaker Spaulders"
  [46205] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Worldbreaker Chestguard"
  [46206] = {4,232,"INVTYPE_ROBE"}, --"Conqueror's Worldbreaker Hauberk"
  [46207] = {4,232,"INVTYPE_HAND"}, --"Conqueror's Worldbreaker Gloves"
  [46208] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Worldbreaker War-Kilt"
  [46209] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Worldbreaker Helm"
  [46210] = {4,232,"INVTYPE_LEGS"}, --"Conqueror's Worldbreaker Kilt"
  [46211] = {4,232,"INVTYPE_SHOULDER"}, --"Conqueror's Worldbreaker Shoulderpads"
  [46212] = {4,232,"INVTYPE_HEAD"}, --"Conqueror's Worldbreaker Faceguard"
  [46213] = {4,225,"INVTYPE_CHEST"}, --"Aegis Battleplate"
  [46214] = {4,225,"INVTYPE_CHEST"}, --"Aegis Breastplate"
  [46215] = {4,225,"INVTYPE_HEAD"}, --"Aegis Faceguard"
  [46216] = {4,225,"INVTYPE_HAND"}, --"Aegis Gauntlets"
  [46217] = {4,225,"INVTYPE_HAND"}, --"Aegis Gloves"
  [46218] = {4,225,"INVTYPE_LEGS"}, --"Aegis Greaves"
  [46219] = {4,225,"INVTYPE_HAND"}, --"Aegis Handguards"
  [46220] = {4,225,"INVTYPE_HEAD"}, --"Aegis Headpiece"
  [46221] = {4,225,"INVTYPE_HEAD"}, --"Aegis Helm"
  [46222] = {4,225,"INVTYPE_LEGS"}, --"Aegis Legguards"
  [46223] = {4,225,"INVTYPE_LEGS"}, --"Aegis Legguards"
  [46224] = {4,225,"INVTYPE_LEGS"}, --"Aegis Legplates"
  [46225] = {4,225,"INVTYPE_SHOULDER"}, --"Aegis Shoulderguards"
  [46226] = {4,225,"INVTYPE_SHOULDER"}, --"Aegis Shoulderplates"
  [46227] = {4,225,"INVTYPE_SHOULDER"}, --"Aegis Spaulders"
  [46228] = {4,225,"INVTYPE_CHEST"}, --"Aegis Tunic"
  [46230] = {4,225,"INVTYPE_HEAD"}, --"Circlet of Sanctification"
  [46231] = {4,225,"INVTYPE_HEAD"}, --"Cowl of Sanctification"
  [46232] = {4,225,"INVTYPE_CHEST"}, --"Darkruned Battleplate"
  [46233] = {4,225,"INVTYPE_CHEST"}, --"Darkruned Chestguard"
  [46234] = {4,225,"INVTYPE_HEAD"}, --"Darkruned Faceguard"
  [46235] = {4,225,"INVTYPE_HAND"}, --"Darkruned Gauntlets"
  [46236] = {4,225,"INVTYPE_HAND"}, --"Darkruned Handguards"
  [46237] = {4,225,"INVTYPE_HEAD"}, --"Darkruned Helmet"
  [46238] = {4,225,"INVTYPE_LEGS"}, --"Darkruned Legguards"
  [46239] = {4,225,"INVTYPE_LEGS"}, --"Darkruned Legplates"
  [46240] = {4,225,"INVTYPE_SHOULDER"}, --"Darkruned Pauldrons"
  [46241] = {4,225,"INVTYPE_SHOULDER"}, --"Darkruned Shoulderplates"
  [46242] = {4,225,"INVTYPE_HAND"}, --"Deathbringer Gloves"
  [46243] = {4,225,"INVTYPE_HEAD"}, --"Deathbringer Hood"
  [46244] = {4,225,"INVTYPE_LEGS"}, --"Deathbringer Leggings"
  [46245] = {4,225,"INVTYPE_ROBE"}, --"Deathbringer Robe"
  [46246] = {4,225,"INVTYPE_SHOULDER"}, --"Deathbringer Shoulderpads"
  [46247] = {4,225,"INVTYPE_HAND"}, --"Gloves of Sanctification"
  [46248] = {4,225,"INVTYPE_HAND"}, --"Handwraps of Sanctification"
  [46249] = {4,225,"INVTYPE_HAND"}, --"Kirin Tor Gauntlets"
  [46250] = {4,225,"INVTYPE_HEAD"}, --"Kirin Tor Hood"
  [46251] = {4,225,"INVTYPE_LEGS"}, --"Kirin Tor Leggings"
  [46252] = {4,225,"INVTYPE_SHOULDER"}, --"Kirin Tor Shoulderpads"
  [46253] = {4,225,"INVTYPE_ROBE"}, --"Kirin Tor Tunic"
  [46254] = {4,225,"INVTYPE_LEGS"}, --"Leggings of Sanctification"
  [46255] = {4,225,"INVTYPE_SHOULDER"}, --"Mantle of Sanctification"
  [46256] = {4,225,"INVTYPE_LEGS"}, --"Pants of Sanctification"
  [46257] = {4,225,"INVTYPE_ROBE"}, --"Raiments of Sanctification"
  [46258] = {4,225,"INVTYPE_ROBE"}, --"Robe of Sanctification"
  [46259] = {4,225,"INVTYPE_SHOULDER"}, --"Shoulderpads of Sanctification"
  [46260] = {4,225,"INVTYPE_HAND"}, --"Nightsong Handgrips"
  [46261] = {4,225,"INVTYPE_HAND"}, --"Nightsong Handguards"
  [46262] = {4,225,"INVTYPE_HEAD"}, --"Nightsong Headguard"
  [46263] = {4,225,"INVTYPE_HEAD"}, --"Nightsong Headpiece"
  [46264] = {4,225,"INVTYPE_LEGS"}, --"Nightsong Leggings"
  [46265] = {4,225,"INVTYPE_LEGS"}, --"Nightsong Legguards"
  [46266] = {4,225,"INVTYPE_SHOULDER"}, --"Nightsong Mantle"
  [46267] = {4,225,"INVTYPE_ROBE"}, --"Nightsong Raiments"
  [46268] = {4,225,"INVTYPE_ROBE"}, --"Nightsong Robe"
  [46269] = {4,225,"INVTYPE_SHOULDER"}, --"Nightsong Shoulderpads"
  [46270] = {4,225,"INVTYPE_SHOULDER"}, --"Nightsong Spaulders"
  [46271] = {4,225,"INVTYPE_LEGS"}, --"Nightsong Trousers"
  [46272] = {4,225,"INVTYPE_ROBE"}, --"Nightsong Vestments"
  [46273] = {4,225,"INVTYPE_HAND"}, --"Scourgestalker Handguards"
  [46274] = {4,225,"INVTYPE_HEAD"}, --"Scourgestalker Headpiece"
  [46275] = {4,225,"INVTYPE_LEGS"}, --"Scourgestalker Legguards"
  [46276] = {4,225,"INVTYPE_SHOULDER"}, --"Scourgestalker Spaulders"
  [46277] = {4,225,"INVTYPE_CHEST"}, --"Scourgestalker Tunic"
  [46278] = {4,225,"INVTYPE_CHEST"}, --"Siegebreaker Battleplate"
  [46279] = {4,225,"INVTYPE_CHEST"}, --"Siegebreaker Breastplate"
  [46280] = {4,225,"INVTYPE_HAND"}, --"Siegebreaker Gauntlets"
  [46281] = {4,225,"INVTYPE_HEAD"}, --"Siegebreaker Greathelm"
  [46282] = {4,225,"INVTYPE_HEAD"}, --"Siegebreaker Helmet"
  [46283] = {4,225,"INVTYPE_HAND"}, --"Siegebreaker Handguards"
  [46284] = {4,225,"INVTYPE_LEGS"}, --"Siegebreaker Legguards"
  [46285] = {4,225,"INVTYPE_LEGS"}, --"Siegebreaker Legplates"
  [46286] = {4,225,"INVTYPE_SHOULDER"}, --"Siegebreaker Pauldrons"
  [46287] = {4,225,"INVTYPE_SHOULDER"}, --"Siegebreaker Shoulderplates"
  [46288] = {4,225,"INVTYPE_CHEST"}, --"Terrorblade Breastplate"
  [46289] = {4,225,"INVTYPE_HAND"}, --"Terrorblade Gauntlets"
  [46290] = {4,225,"INVTYPE_HEAD"}, --"Terrorblade Helmet"
  [46291] = {4,225,"INVTYPE_LEGS"}, --"Terrorblade Legplates"
  [46292] = {4,225,"INVTYPE_SHOULDER"}, --"Terrorblade Pauldrons"
  [46293] = {4,225,"INVTYPE_ROBE"}, --"Worldbreaker Chestguard"
  [46294] = {4,225,"INVTYPE_HEAD"}, --"Worldbreaker Faceguard"
  [46295] = {4,225,"INVTYPE_HAND"}, --"Worldbreaker Gloves"
  [46296] = {4,225,"INVTYPE_HAND"}, --"Worldbreaker Grips"
  [46297] = {4,225,"INVTYPE_HAND"}, --"Worldbreaker Handguards"
  [46298] = {4,225,"INVTYPE_ROBE"}, --"Worldbreaker Hauberk"
  [46299] = {4,225,"INVTYPE_HEAD"}, --"Worldbreaker Headpiece"
  [46300] = {4,225,"INVTYPE_HEAD"}, --"Worldbreaker Helm"
  [46301] = {4,225,"INVTYPE_LEGS"}, --"Worldbreaker Kilt"
  [46302] = {4,225,"INVTYPE_LEGS"}, --"Worldbreaker Legguards"
  [46303] = {4,225,"INVTYPE_SHOULDER"}, --"Worldbreaker Shoulderguards"
  [46304] = {4,225,"INVTYPE_SHOULDER"}, --"Worldbreaker Shoulderpads"
  [46305] = {4,225,"INVTYPE_SHOULDER"}, --"Worldbreaker Spaulders"
  [46306] = {4,225,"INVTYPE_ROBE"}, --"Worldbreaker Tunic"
  [46307] = {4,225,"INVTYPE_LEGS"}, --"Worldbreaker War-Kilt"
  [46309] = {4,225,"INVTYPE_HAND"}, --"Nightsong Gloves"
  [46312] = {4,239,"INVTYPE_TRINKET"}, --"Vanquished Clutches of Yogg-Saron"
  [46313] = {4,225,"INVTYPE_HEAD"}, --"Valorous Nightsong Cover"
  [46320] = {4,239,"INVTYPE_CLOAK"}, --"Drape of the Skyherald"
  [46321] = {4,239,"INVTYPE_CLOAK"}, --"Sunglimmer Drape"
  [46322] = {4,239,"INVTYPE_FINGER"}, --"Brann's Sealing Ring"
  [46323] = {4,239,"INVTYPE_FINGER"}, --"Starshine Signet"
  [46339] = {4,225,"INVTYPE_RANGEDRIGHT"}, --"Mimiron's Repeater"
  [46340] = {4,225,"INVTYPE_HAND"}, --"Adamant Handguards"
  [46341] = {4,225,"INVTYPE_CLOAK"}, --"Drape of the Spellweaver"
  [46342] = {4,225,"INVTYPE_RANGED"}, --"Golemheart Longbow"
  [46343] = {4,225,"INVTYPE_NECK"}, --"Fervor of the Protectorate"
  [46344] = {4,225,"INVTYPE_SHOULDER"}, --"Iceshear Mantle"
  [46345] = {4,225,"INVTYPE_WRIST"}, --"Bracers of Righteous Reformation"
  [46346] = {4,225,"INVTYPE_FEET"}, --"Boots of Unsettled Prey"
  [46347] = {4,225,"INVTYPE_CLOAK"}, --"Cloak of the Dormant Blaze"
  [46350] = {4,225,"INVTYPE_2HWEAPON"}, --"Pillar of Fortitude"
  [46351] = {4,225,"INVTYPE_WEAPON"}, --"Bloodcrush Cudgel"
  [46842] = {4,200,"INVTYPE_FINGER"}, --"Crusader's Band"
  [46958] = {4,245,"INVTYPE_WEAPON"}, --"Steel Bladebreaker"
  [46959] = {4,245,"INVTYPE_FINGER"}, --"Band of the Violent Temperment"
  [46960] = {4,245,"INVTYPE_CHEST"}, --"Breastplate of Cruel Intent"
  [46961] = {4,245,"INVTYPE_WRIST"}, --"Boneshatter Armplates"
  [46962] = {4,245,"INVTYPE_CHEST"}, --"Chestplate of the Towering Monstrosity"
  [46963] = {4,245,"INVTYPE_SHIELD"}, --"Crystal Plated Vanguard"
  [46964] = {4,258,"INVTYPE_SHIELD"}, --"Crystal Plated Vanguard"
  [46965] = {4,258,"INVTYPE_CHEST"}, --"Breastplate of Cruel Intent"
  [46966] = {4,258,"INVTYPE_FINGER"}, --"Band of the Violent Temperment"
  [46967] = {4,258,"INVTYPE_WRIST"}, --"Boneshatter Armplates"
  [46968] = {4,258,"INVTYPE_CHEST"}, --"Chestplate of the Towering Monstrosity"
  [46969] = {4,258,"INVTYPE_WEAPON"}, --"Steel Bladebreaker"
  [46970] = {4,245,"INVTYPE_CLOAK"}, --"Drape of the Untamed Predator"
  [46971] = {4,258,"INVTYPE_CLOAK"}, --"Drape of the Untamed Predator"
  [46972] = {4,245,"INVTYPE_WAIST"}, --"Cord of the Tenebrous Mist"
  [46973] = {4,258,"INVTYPE_WAIST"}, --"Cord of the Tenebrous Mist"
  [46974] = {4,245,"INVTYPE_LEGS"}, --"Leggings of the Broken Beast"
  [46975] = {4,258,"INVTYPE_LEGS"}, --"Leggings of the Broken Beast"
  [46976] = {4,245,"INVTYPE_CLOAK"}, --"Shawl of the Refreshing Winds"
  [46977] = {4,258,"INVTYPE_CLOAK"}, --"Shawl of the Refreshing Winds"
  [46979] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Blade of Tarasque"
  [46980] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Blade of Tarasque"
  [46985] = {4,245,"INVTYPE_FEET"}, --"Boots of the Courageous"
  [46986] = {4,258,"INVTYPE_FEET"}, --"Boots of the Courageous"
  [46988] = {4,245,"INVTYPE_FEET"}, --"Boots of the Unrelenting Storm"
  [46989] = {4,258,"INVTYPE_FEET"}, --"Boots of the Unrelenting Storm"
  [46990] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Ice Burrower"
  [46991] = {4,258,"INVTYPE_WAIST"}, --"Belt of the Ice Burrower"
  [46992] = {4,245,"INVTYPE_ROBE"}, --"Flowing Vestments of Ascent"
  [46993] = {4,258,"INVTYPE_ROBE"}, --"Flowing Vestments of Ascent"
  [46994] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Talonstrike"
  [46995] = {4,258,"INVTYPE_RANGEDRIGHT"}, --"Talonstrike"
  [46996] = {4,245,"INVTYPE_WEAPON"}, --"Lionhead Slasher"
  [46997] = {4,245,"INVTYPE_FEET"}, --"Dawnbreaker Greaves"
  [46999] = {4,245,"INVTYPE_WAIST"}, --"Bloodbath Belt"
  [47000] = {4,245,"INVTYPE_CHEST"}, --"Cuirass of Calamitous Fate"
  [47001] = {4,258,"INVTYPE_WEAPON"}, --"Lionhead Slasher"
  [47002] = {4,258,"INVTYPE_WAIST"}, --"Bloodbath Belt"
  [47003] = {4,258,"INVTYPE_FEET"}, --"Dawnbreaker Greaves"
  [47004] = {4,258,"INVTYPE_CHEST"}, --"Cuirass of Calamitous Fate"
  [47041] = {4,245,"INVTYPE_TRINKET"}, --"Solace of the Defeated"
  [47042] = {4,245,"INVTYPE_CLOAK"}, --"Pride of the Eredar"
  [47043] = {4,245,"INVTYPE_NECK"}, --"Charge of the Demon Lord"
  [47051] = {4,245,"INVTYPE_LEGS"}, --"Leggings of the Soothing Touch"
  [47052] = {4,245,"INVTYPE_LEGS"}, --"Legguards of Feverish Dedication"
  [47053] = {4,245,"INVTYPE_HOLDABLE"}, --"Symbol of Transgression"
  [47054] = {4,245,"INVTYPE_FINGER"}, --"Band of Deplorable Violence"
  [47055] = {4,245,"INVTYPE_WRIST"}, --"Bracers of the Autumn Willow"
  [47056] = {4,245,"INVTYPE_WRIST"}, --"Bracers of Cloudy Omen"
  [47057] = {4,245,"INVTYPE_LEGS"}, --"Legplates of Failing Light"
  [47059] = {4,258,"INVTYPE_TRINKET"}, --"Solace of the Defeated"
  [47060] = {4,258,"INVTYPE_NECK"}, --"Charge of the Demon Lord"
  [47061] = {4,258,"INVTYPE_LEGS"}, --"Legguards of Feverish Dedication"
  [47062] = {4,258,"INVTYPE_LEGS"}, --"Leggings of the Soothing Touch"
  [47063] = {4,258,"INVTYPE_CLOAK"}, --"Pride of the Eredar"
  [47064] = {4,258,"INVTYPE_HOLDABLE"}, --"Symbol of Transgression"
  [47066] = {4,258,"INVTYPE_WRIST"}, --"Bracers of the Autumn Willow"
  [47067] = {4,258,"INVTYPE_LEGS"}, --"Legplates of Failing Light"
  [47068] = {4,258,"INVTYPE_WRIST"}, --"Bracers of Cloudy Omen"
  [47069] = {4,245,"INVTYPE_2HWEAPON"}, --"Justicebringer"
  [47070] = {4,245,"INVTYPE_FINGER"}, --"Ring of Callous Aggression"
  [47071] = {4,245,"INVTYPE_FEET"}, --"Treads of the Icewalker"
  [47072] = {4,245,"INVTYPE_WAIST"}, --"Girdle of Bloodied Scars"
  [47073] = {4,245,"INVTYPE_WRIST"}, --"Bracers of the Untold Massacre"
  [47074] = {4,258,"INVTYPE_WRIST"}, --"Bracers of the Untold Massacre"
  [47075] = {4,258,"INVTYPE_FINGER"}, --"Ring of Callous Aggression"
  [47076] = {4,258,"INVTYPE_WAIST"}, --"Girdle of Bloodied Scars"
  [47077] = {4,258,"INVTYPE_FEET"}, --"Treads of the Icewalker"
  [47078] = {4,258,"INVTYPE_2HWEAPON"}, --"Justicebringer"
  [47079] = {4,245,"INVTYPE_SHIELD"}, --"Bastion of Purity"
  [47080] = {4,245,"INVTYPE_TRINKET"}, --"Satrina's Impeding Scarab"
  [47081] = {4,245,"INVTYPE_WAIST"}, --"Cord of Biting Cold"
  [47082] = {4,245,"INVTYPE_CHEST"}, --"Chestplate of the Frostborn Hero"
  [47083] = {4,245,"INVTYPE_LEGS"}, --"Legguards of Concealed Hatred"
  [47084] = {4,258,"INVTYPE_WAIST"}, --"Cord of Biting Cold"
  [47085] = {4,258,"INVTYPE_SHIELD"}, --"Bastion of Purity"
  [47086] = {4,258,"INVTYPE_CHEST"}, --"Chestplate of the Frostborn Hero"
  [47087] = {4,258,"INVTYPE_LEGS"}, --"Legguards of Concealed Hatred"
  [47088] = {4,258,"INVTYPE_TRINKET"}, --"Satrina's Impeding Scarab"
  [47089] = {4,245,"INVTYPE_CLOAK"}, --"Cloak of Displacement"
  [47090] = {4,245,"INVTYPE_FEET"}, --"Boots of Tremoring Earth"
  [47092] = {4,245,"INVTYPE_FEET"}, --"Boots of the Mourning Widow"
  [47093] = {4,245,"INVTYPE_WRIST"}, --"Vambraces of the Broken Bond"
  [47094] = {4,245,"INVTYPE_ROBE"}, --"Vestments of the Shattered Fellowship"
  [47095] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of Displacement"
  [47096] = {4,258,"INVTYPE_ROBE"}, --"Vestments of the Shattered Fellowship"
  [47097] = {4,258,"INVTYPE_FEET"}, --"Boots of the Mourning Widow"
  [47098] = {4,258,"INVTYPE_WRIST"}, --"Vambraces of the Broken Bond"
  [47099] = {4,258,"INVTYPE_FEET"}, --"Boots of Tremoring Earth"
  [47104] = {4,245,"INVTYPE_WEAPON"}, --"Twin Spike"
  [47105] = {4,245,"INVTYPE_NECK"}, --"The Executioner's Malice"
  [47106] = {4,245,"INVTYPE_FEET"}, --"Sabatons of Ruthless Judgment"
  [47107] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Merciless Killer"
  [47108] = {4,245,"INVTYPE_WRIST"}, --"Bracers of the Shieldmaiden"
  [47109] = {4,258,"INVTYPE_FEET"}, --"Sabatons of Ruthless Judgment"
  [47110] = {4,258,"INVTYPE_NECK"}, --"The Executioner's Malice"
  [47111] = {4,258,"INVTYPE_WRIST"}, --"Bracers of the Shieldmaiden"
  [47112] = {4,258,"INVTYPE_WAIST"}, --"Belt of the Merciless Killer"
  [47113] = {4,258,"INVTYPE_WEAPON"}, --"Twin Spike"
  [47114] = {4,245,"INVTYPE_2HWEAPON"}, --"Lupine Longstaff"
  [47115] = {4,245,"INVTYPE_TRINKET"}, --"Death's Verdict"
  [47116] = {4,245,"INVTYPE_NECK"}, --"The Arbiter's Muse"
  [47121] = {4,245,"INVTYPE_LEGS"}, --"Legguards of Ascension"
  [47126] = {4,245,"INVTYPE_ROBE"}, --"Skyweaver Robes"
  [47129] = {4,258,"INVTYPE_ROBE"}, --"Skyweaver Robes"
  [47130] = {4,258,"INVTYPE_2HWEAPON"}, --"Lupine Longstaff"
  [47131] = {4,258,"INVTYPE_TRINKET"}, --"Death's Verdict"
  [47132] = {4,258,"INVTYPE_LEGS"}, --"Legguards of Ascension"
  [47133] = {4,258,"INVTYPE_NECK"}, --"The Arbiter's Muse"
  [47138] = {4,245,"INVTYPE_HOLDABLE"}, --"Chalice of Searing Light"
  [47139] = {4,245,"INVTYPE_NECK"}, --"Wail of the Val'kyr"
  [47140] = {4,245,"INVTYPE_WAIST"}, --"Cord of Pale Thorns"
  [47141] = {4,245,"INVTYPE_WRIST"}, --"Bindings of Dark Essence"
  [47142] = {4,245,"INVTYPE_CHEST"}, --"Breastplate of the Frozen Lake"
  [47143] = {4,258,"INVTYPE_WRIST"}, --"Bindings of Dark Essence"
  [47144] = {4,258,"INVTYPE_NECK"}, --"Wail of the Val'kyr"
  [47145] = {4,258,"INVTYPE_WAIST"}, --"Cord of Pale Thorns"
  [47146] = {4,258,"INVTYPE_HOLDABLE"}, --"Chalice of Searing Light"
  [47147] = {4,258,"INVTYPE_CHEST"}, --"Breastplate of the Frozen Lake"
  [47148] = {4,245,"INVTYPE_WEAPON"}, --"Stormpike Cleaver"
  [47149] = {4,245,"INVTYPE_FINGER"}, --"Signet of the Traitor King"
  [47150] = {4,245,"INVTYPE_FEET"}, --"Greaves of the 7th Legion"
  [47151] = {4,245,"INVTYPE_WRIST"}, --"Bracers of Dark Determination"
  [47152] = {4,245,"INVTYPE_WAIST"}, --"Belt of Deathly Dominion"
  [47153] = {4,258,"INVTYPE_WAIST"}, --"Belt of Deathly Dominion"
  [47154] = {4,258,"INVTYPE_FEET"}, --"Greaves of the 7th Legion"
  [47155] = {4,258,"INVTYPE_WRIST"}, --"Bracers of Dark Determination"
  [47156] = {4,258,"INVTYPE_WEAPON"}, --"Stormpike Cleaver"
  [47157] = {4,258,"INVTYPE_FINGER"}, --"Signet of the Traitor King"
  [47170] = {4,200,"INVTYPE_WAIST"}, --"Belt of Fierce Competition"
  [47171] = {4,200,"INVTYPE_LEGS"}, --"Legguards of Abandoned Fealty"
  [47172] = {4,200,"INVTYPE_HEAD"}, --"Helm of the Bested Gallant"
  [47173] = {4,200,"INVTYPE_WRIST"}, --"Bindings of the Wicked"
  [47174] = {4,200,"INVTYPE_WAIST"}, --"Binding of the Tranquil Glade"
  [47175] = {4,200,"INVTYPE_FEET"}, --"Scale Boots of the Outlander"
  [47176] = {4,200,"INVTYPE_CHEST"}, --"Breastplate of the Imperial Joust"
  [47177] = {4,200,"INVTYPE_HAND"}, --"Gloves of the Argent Fanatic"
  [47178] = {4,200,"INVTYPE_CHEST"}, --"Carapace of Grim Visions"
  [47181] = {4,200,"INVTYPE_WAIST"}, --"Belt of the Churning Blaze"
  [47182] = {4,245,"INVTYPE_TRINKET"}, --"Reign of the Unliving"
  [47183] = {4,245,"INVTYPE_CLOAK"}, --"Strength of the Nerub"
  [47184] = {4,245,"INVTYPE_LEGS"}, --"Legguards of the Lurking Threat"
  [47185] = {4,200,"INVTYPE_LEGS"}, --"Leggings of the Haggard Apprentice"
  [47186] = {4,245,"INVTYPE_LEGS"}, --"Legwraps of the Awakening"
  [47187] = {4,245,"INVTYPE_LEGS"}, --"Leggings of the Deepening Void"
  [47188] = {4,258,"INVTYPE_TRINKET"}, --"Reign of the Unliving"
  [47189] = {4,258,"INVTYPE_LEGS"}, --"Leggings of the Deepening Void"
  [47190] = {4,258,"INVTYPE_LEGS"}, --"Legwraps of the Awakening"
  [47191] = {4,258,"INVTYPE_LEGS"}, --"Legguards of the Lurking Threat"
  [47192] = {4,258,"INVTYPE_CLOAK"}, --"Strength of the Nerub"
  [47193] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Misery's End"
  [47194] = {4,245,"INVTYPE_FEET"}, --"Footpads of the Icy Floe"
  [47195] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Forgotten Martyr"
  [47197] = {4,200,"INVTYPE_HAND"}, --"Gauntlets of the Stouthearted Crusader"
  [47199] = {4,200,"INVTYPE_FEET"}, --"Greaves of the Grand Paladin"
  [47200] = {4,200,"INVTYPE_FINGER"}, --"Signet of Purity"
  [47201] = {4,200,"INVTYPE_FEET"}, --"Boots of Heartfelt Repentance"
  [47202] = {4,200,"INVTYPE_LEGS"}, --"Leggings of Brazen Trespass"
  [47203] = {4,245,"INVTYPE_WRIST"}, --"Armbands of the Ashen Saint"
  [47204] = {4,245,"INVTYPE_CHEST"}, --"Chestguard of Flowing Elements"
  [47205] = {4,258,"INVTYPE_FEET"}, --"Footpads of the Icy Floe"
  [47206] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Misery's End"
  [47207] = {4,258,"INVTYPE_WAIST"}, --"Belt of the Forgotten Martyr"
  [47208] = {4,258,"INVTYPE_WRIST"}, --"Armbands of the Ashen Saint"
  [47209] = {4,258,"INVTYPE_CHEST"}, --"Chestguard of Flowing Elements"
  [47210] = {4,200,"INVTYPE_SHOULDER"}, --"Mantle of Gnarled Overgrowth"
  [47211] = {4,200,"INVTYPE_WRIST"}, --"Wristguards of Ceaseless Regret"
  [47212] = {4,200,"INVTYPE_HAND"}, --"Mercy's Hold"
  [47213] = {4,200,"INVTYPE_TRINKET"}, --"Abyssal Rune"
  [47214] = {4,200,"INVTYPE_TRINKET"}, --"Banner of Victory"
  [47215] = {4,200,"INVTYPE_TRINKET"}, --"Tears of the Vanquished"
  [47216] = {4,200,"INVTYPE_TRINKET"}, --"The Black Heart"
  [47217] = {4,200,"INVTYPE_HEAD"}, --"Gaze of the Somber Keeper"
  [47218] = {4,200,"INVTYPE_WAIST"}, --"The Confessor's Binding"
  [47219] = {4,200,"INVTYPE_NECK"}, --"Brilliant Hailstone Amulet"
  [47220] = {4,200,"INVTYPE_HEAD"}, --"Helm of the Violent Fray"
  [47221] = {4,200,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Infamous Knave"
  [47222] = {4,200,"INVTYPE_FINGER"}, --"Uruka's Band of Zeal"
  [47223] = {4,245,"INVTYPE_FINGER"}, --"Ring of the Darkmender"
  [47224] = {4,258,"INVTYPE_FINGER"}, --"Ring of the Darkmender"
  [47225] = {4,245,"INVTYPE_CLOAK"}, --"Maiden's Favor"
  [47226] = {4,200,"INVTYPE_SHOULDER"}, --"Mantle of Inconsolable Fear"
  [47227] = {4,200,"INVTYPE_WAIST"}, --"Girdle of the Pallid Knight"
  [47228] = {4,200,"INVTYPE_LEGS"}, --"Leggings of the Bloodless Knight"
  [47229] = {4,200,"INVTYPE_WAIST"}, --"Girdle of Arrogant Downfall"
  [47230] = {4,200,"INVTYPE_HAND"}, --"Handwraps of Surrendered Hope"
  [47231] = {4,200,"INVTYPE_WAIST"}, --"Belt of Merciless Cruelty"
  [47232] = {4,200,"INVTYPE_CLOAK"}, --"Drape of the Undefeated"
  [47233] = {4,245,"INVTYPE_2HWEAPON"}, --"Archon Glaive"
  [47234] = {4,245,"INVTYPE_HAND"}, --"Gloves of Bitter Reprisal"
  [47235] = {4,245,"INVTYPE_HAND"}, --"Gloves of the Lifeless Touch"
  [47236] = {4,258,"INVTYPE_HAND"}, --"Gloves of the Lifeless Touch"
  [47237] = {4,258,"INVTYPE_FINGER"}, --"Band of Deplorable Violence"
  [47238] = {4,258,"INVTYPE_CLOAK"}, --"Maiden's Favor"
  [47239] = {4,258,"INVTYPE_2HWEAPON"}, --"Archon Glaive"
  [47240] = {4,258,"INVTYPE_HAND"}, --"Gloves of Bitter Reprisal"
  [47243] = {4,219,"INVTYPE_FINGER"}, --"Mark of the Relentless"
  [47244] = {4,219,"INVTYPE_CHEST"}, --"Chestguard of the Ravenous Fiend"
  [47245] = {4,219,"INVTYPE_SHOULDER"}, --"Pauldrons of Concealed Loathing"
  [47248] = {4,219,"INVTYPE_FEET"}, --"Treads of Dismal Fortune"
  [47249] = {4,219,"INVTYPE_LEGS"}, --"Leggings of the Snowy Bramble"
  [47250] = {4,219,"INVTYPE_SHOULDER"}, --"Pauldrons of the Deafening Gale"
  [47251] = {4,245,"INVTYPE_CHEST"}, --"Cuirass of Cruel Intent"
  [47252] = {4,245,"INVTYPE_FINGER"}, --"Ring of the Violent Temperament"
  [47253] = {4,245,"INVTYPE_WRIST"}, --"Boneshatter Vambraces"
  [47254] = {4,245,"INVTYPE_CHEST"}, --"Hauberk of the Towering Monstrosity"
  [47255] = {4,245,"INVTYPE_WEAPON"}, --"Stygian Bladebreaker"
  [47256] = {4,245,"INVTYPE_CLOAK"}, --"Drape of the Refreshing Winds"
  [47257] = {4,245,"INVTYPE_CLOAK"}, --"Cloak of the Untamed Predator"
  [47258] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Tenebrous Mist"
  [47259] = {4,245,"INVTYPE_LEGS"}, --"Legwraps of the Broken Beast"
  [47260] = {4,245,"INVTYPE_SHIELD"}, --"Forlorn Barrier"
  [47261] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Barb of Tarasque"
  [47262] = {4,245,"INVTYPE_FEET"}, --"Boots of the Harsh Winter"
  [47263] = {4,245,"INVTYPE_FEET"}, --"Sabatons of the Courageous"
  [47264] = {4,245,"INVTYPE_ROBE"}, --"Flowing Robes of Ascent"
  [47265] = {4,245,"INVTYPE_WAIST"}, --"Binding of the Ice Burrower"
  [47266] = {4,245,"INVTYPE_WEAPON"}, --"Blood Fury"
  [47267] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Death's Head Crossbow"
  [47268] = {4,245,"INVTYPE_WAIST"}, --"Bloodbath Girdle"
  [47269] = {4,245,"INVTYPE_FEET"}, --"Dawnbreaker Sabatons"
  [47270] = {4,245,"INVTYPE_CHEST"}, --"Vest of Calamitous Fate"
  [47271] = {4,245,"INVTYPE_TRINKET"}, --"Solace of the Fallen"
  [47272] = {4,245,"INVTYPE_NECK"}, --"Charge of the Eredar"
  [47273] = {4,245,"INVTYPE_LEGS"}, --"Legplates of Feverish Dedication"
  [47274] = {4,245,"INVTYPE_LEGS"}, --"Pants of the Soothing Touch"
  [47275] = {4,245,"INVTYPE_CLOAK"}, --"Pride of the Demon Lord"
  [47276] = {4,245,"INVTYPE_HOLDABLE"}, --"Talisman of Heedless Sins"
  [47277] = {4,245,"INVTYPE_WRIST"}, --"Bindings of the Autumn Willow"
  [47278] = {4,245,"INVTYPE_FINGER"}, --"Circle of the Darkmender"
  [47279] = {4,245,"INVTYPE_LEGS"}, --"Leggings of Failing Light"
  [47280] = {4,245,"INVTYPE_WRIST"}, --"Wristwraps of Cloudy Omen"
  [47281] = {4,245,"INVTYPE_WRIST"}, --"Bracers of the Silent Massacre"
  [47282] = {4,245,"INVTYPE_FINGER"}, --"Band of Callous Aggression"
  [47283] = {4,245,"INVTYPE_WAIST"}, --"Belt of Bloodied Scars"
  [47284] = {4,245,"INVTYPE_FEET"}, --"Icewalker Treads"
  [47285] = {4,245,"INVTYPE_2HWEAPON"}, --"Dual-blade Butcher"
  [47286] = {4,245,"INVTYPE_WAIST"}, --"Belt of Biting Cold"
  [47287] = {4,245,"INVTYPE_SHIELD"}, --"Bastion of Resolve"
  [47288] = {4,245,"INVTYPE_CHEST"}, --"Chestplate of the Frostwolf Hero"
  [47289] = {4,245,"INVTYPE_LEGS"}, --"Leggings of Concealed Hatred"
  [47290] = {4,245,"INVTYPE_TRINKET"}, --"Juggernaut's Vitality"
  [47291] = {4,245,"INVTYPE_CLOAK"}, --"Shroud of Displacement"
  [47292] = {4,245,"INVTYPE_ROBE"}, --"Robes of the Shattered Fellowship"
  [47293] = {4,245,"INVTYPE_FEET"}, --"Sandals of the Mourning Widow"
  [47294] = {4,245,"INVTYPE_WRIST"}, --"Bracers of the Broken Bond"
  [47295] = {4,245,"INVTYPE_FEET"}, --"Sabatons of Tremoring Earth"
  [47296] = {4,245,"INVTYPE_FEET"}, --"Greaves of Ruthless Judgment"
  [47297] = {4,245,"INVTYPE_NECK"}, --"The Executioner's Vice"
  [47298] = {4,245,"INVTYPE_WRIST"}, --"Armguards of the Shieldmaiden"
  [47299] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Pitiless Killer"
  [47300] = {4,245,"INVTYPE_WEAPON"}, --"Gouge of the Frigid Heart"
  [47301] = {4,245,"INVTYPE_ROBE"}, --"Skyweaver Vestments"
  [47302] = {4,245,"INVTYPE_2HWEAPON"}, --"Twin's Pact"
  [47303] = {4,245,"INVTYPE_TRINKET"}, --"Death's Choice"
  [47304] = {4,245,"INVTYPE_LEGS"}, --"Legplates of Ascension"
  [47305] = {4,245,"INVTYPE_NECK"}, --"Legionnaire's Gorget"
  [47306] = {4,245,"INVTYPE_WRIST"}, --"Dark Essence Bindings"
  [47307] = {4,245,"INVTYPE_NECK"}, --"Cry of the Val'kyr"
  [47308] = {4,245,"INVTYPE_WAIST"}, --"Belt of Pale Thorns"
  [47309] = {4,245,"INVTYPE_HOLDABLE"}, --"Mystifying Charm"
  [47310] = {4,245,"INVTYPE_CHEST"}, --"Chestplate of the Frozen Lake"
  [47311] = {4,245,"INVTYPE_WAIST"}, --"Waistguard of Deathly Dominion"
  [47312] = {4,245,"INVTYPE_FEET"}, --"Greaves of the Saronite Citadel"
  [47313] = {4,245,"INVTYPE_WRIST"}, --"Armbands of Dark Determination"
  [47314] = {4,245,"INVTYPE_WEAPON"}, --"Hellscream Slicer"
  [47315] = {4,245,"INVTYPE_FINGER"}, --"Band of the Traitor King"
  [47316] = {4,245,"INVTYPE_TRINKET"}, --"Reign of the Dead"
  [47317] = {4,245,"INVTYPE_LEGS"}, --"Breeches of the Deepening Void"
  [47318] = {4,245,"INVTYPE_LEGS"}, --"Leggings of the Awakening"
  [47319] = {4,245,"INVTYPE_LEGS"}, --"Leggings of the Lurking Threat"
  [47320] = {4,245,"INVTYPE_CLOAK"}, --"Might of the Nerub"
  [47321] = {4,245,"INVTYPE_FEET"}, --"Boots of the Icy Floe"
  [47322] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Suffering's End"
  [47323] = {4,245,"INVTYPE_WAIST"}, --"Girdle of the Forgotten Martyr"
  [47324] = {4,245,"INVTYPE_WRIST"}, --"Bindings of the Ashen Saint"
  [47325] = {4,245,"INVTYPE_CHEST"}, --"Cuirass of Flowing Elements"
  [47326] = {4,245,"INVTYPE_HAND"}, --"Handwraps of the Lifeless Touch"
  [47327] = {4,245,"INVTYPE_FINGER"}, --"Lurid Manifestation"
  [47328] = {4,245,"INVTYPE_CLOAK"}, --"Maiden's Adoration"
  [47329] = {4,245,"INVTYPE_2HWEAPON"}, --"Hellion Glaive"
  [47330] = {4,245,"INVTYPE_HAND"}, --"Gauntlets of Bitter Reprisal"
  [47412] = {4,258,"INVTYPE_CHEST"}, --"Cuirass of Cruel Intent"
  [47413] = {4,258,"INVTYPE_FINGER"}, --"Ring of the Violent Temperament"
  [47414] = {4,258,"INVTYPE_WRIST"}, --"Boneshatter Vambraces"
  [47415] = {4,258,"INVTYPE_CHEST"}, --"Hauberk of the Towering Monstrosity"
  [47416] = {4,258,"INVTYPE_WEAPON"}, --"Stygian Bladebreaker"
  [47417] = {4,258,"INVTYPE_CLOAK"}, --"Drape of the Refreshing Winds"
  [47418] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of the Untamed Predator"
  [47419] = {4,258,"INVTYPE_WAIST"}, --"Belt of the Tenebrous Mist"
  [47420] = {4,258,"INVTYPE_LEGS"}, --"Legwraps of the Broken Beast"
  [47421] = {4,258,"INVTYPE_SHIELD"}, --"Forlorn Barrier"
  [47422] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Barb of Tarasque"
  [47423] = {4,258,"INVTYPE_FEET"}, --"Boots of the Harsh Winter"
  [47424] = {4,258,"INVTYPE_FEET"}, --"Sabatons of the Courageous"
  [47425] = {4,258,"INVTYPE_ROBE"}, --"Flowing Robes of Ascent"
  [47426] = {4,258,"INVTYPE_WAIST"}, --"Binding of the Ice Burrower"
  [47427] = {4,258,"INVTYPE_WEAPON"}, --"Blood Fury"
  [47428] = {4,258,"INVTYPE_RANGEDRIGHT"}, --"Death's Head Crossbow"
  [47429] = {4,258,"INVTYPE_WAIST"}, --"Bloodbath Girdle"
  [47430] = {4,258,"INVTYPE_FEET"}, --"Dawnbreaker Sabatons"
  [47431] = {4,258,"INVTYPE_CHEST"}, --"Vest of Calamitous Fate"
  [47432] = {4,258,"INVTYPE_TRINKET"}, --"Solace of the Fallen"
  [47433] = {4,258,"INVTYPE_NECK"}, --"Charge of the Eredar"
  [47434] = {4,258,"INVTYPE_LEGS"}, --"Legplates of Feverish Dedication"
  [47435] = {4,258,"INVTYPE_LEGS"}, --"Pants of the Soothing Touch"
  [47436] = {4,258,"INVTYPE_CLOAK"}, --"Pride of the Demon Lord"
  [47437] = {4,258,"INVTYPE_HOLDABLE"}, --"Talisman of Heedless Sins"
  [47438] = {4,258,"INVTYPE_WRIST"}, --"Bindings of the Autumn Willow"
  [47439] = {4,258,"INVTYPE_FINGER"}, --"Circle of the Darkmender"
  [47440] = {4,258,"INVTYPE_LEGS"}, --"Leggings of Failing Light"
  [47441] = {4,258,"INVTYPE_WRIST"}, --"Wristwraps of Cloudy Omen"
  [47442] = {4,258,"INVTYPE_WRIST"}, --"Bracers of the Silent Massacre"
  [47443] = {4,258,"INVTYPE_FINGER"}, --"Band of Callous Aggression"
  [47444] = {4,258,"INVTYPE_WAIST"}, --"Belt of Bloodied Scars"
  [47445] = {4,258,"INVTYPE_FEET"}, --"Icewalker Treads"
  [47446] = {4,258,"INVTYPE_2HWEAPON"}, --"Dual-blade Butcher"
  [47447] = {4,258,"INVTYPE_WAIST"}, --"Belt of Biting Cold"
  [47448] = {4,258,"INVTYPE_SHIELD"}, --"Bastion of Resolve"
  [47449] = {4,258,"INVTYPE_CHEST"}, --"Chestplate of the Frostwolf Hero"
  [47450] = {4,258,"INVTYPE_LEGS"}, --"Leggings of Concealed Hatred"
  [47451] = {4,258,"INVTYPE_TRINKET"}, --"Juggernaut's Vitality"
  [47452] = {4,258,"INVTYPE_CLOAK"}, --"Shroud of Displacement"
  [47453] = {4,258,"INVTYPE_ROBE"}, --"Robes of the Shattered Fellowship"
  [47454] = {4,258,"INVTYPE_FEET"}, --"Sandals of the Mourning Widow"
  [47455] = {4,258,"INVTYPE_WRIST"}, --"Bracers of the Broken Bond"
  [47456] = {4,258,"INVTYPE_FEET"}, --"Sabatons of Tremoring Earth"
  [47457] = {4,258,"INVTYPE_FEET"}, --"Greaves of Ruthless Judgment"
  [47458] = {4,258,"INVTYPE_NECK"}, --"The Executioner's Vice"
  [47459] = {4,258,"INVTYPE_WRIST"}, --"Armguards of the Shieldmaiden"
  [47460] = {4,258,"INVTYPE_WAIST"}, --"Belt of the Pitiless Killer"
  [47461] = {4,258,"INVTYPE_WEAPON"}, --"Gouge of the Frigid Heart"
  [47462] = {4,258,"INVTYPE_ROBE"}, --"Skyweaver Vestments"
  [47463] = {4,258,"INVTYPE_2HWEAPON"}, --"Twin's Pact"
  [47464] = {4,258,"INVTYPE_TRINKET"}, --"Death's Choice"
  [47465] = {4,258,"INVTYPE_LEGS"}, --"Legplates of Ascension"
  [47466] = {4,258,"INVTYPE_NECK"}, --"Legionnaire's Gorget"
  [47467] = {4,258,"INVTYPE_WRIST"}, --"Dark Essence Bindings"
  [47468] = {4,258,"INVTYPE_NECK"}, --"Cry of the Val'kyr"
  [47469] = {4,258,"INVTYPE_WAIST"}, --"Belt of Pale Thorns"
  [47470] = {4,258,"INVTYPE_HOLDABLE"}, --"Mystifying Charm"
  [47471] = {4,258,"INVTYPE_CHEST"}, --"Chestplate of the Frozen Lake"
  [47472] = {4,258,"INVTYPE_WAIST"}, --"Waistguard of Deathly Dominion"
  [47473] = {4,258,"INVTYPE_FEET"}, --"Greaves of the Saronite Citadel"
  [47474] = {4,258,"INVTYPE_WRIST"}, --"Armbands of Dark Determination"
  [47475] = {4,258,"INVTYPE_WEAPON"}, --"Hellscream Slicer"
  [47476] = {4,258,"INVTYPE_FINGER"}, --"Band of the Traitor King"
  [47477] = {4,258,"INVTYPE_TRINKET"}, --"Reign of the Dead"
  [47478] = {4,258,"INVTYPE_LEGS"}, --"Breeches of the Deepening Void"
  [47479] = {4,258,"INVTYPE_LEGS"}, --"Leggings of the Awakening"
  [47480] = {4,258,"INVTYPE_LEGS"}, --"Leggings of the Lurking Threat"
  [47481] = {4,258,"INVTYPE_CLOAK"}, --"Might of the Nerub"
  [47482] = {4,258,"INVTYPE_FEET"}, --"Boots of the Icy Floe"
  [47483] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Suffering's End"
  [47484] = {4,258,"INVTYPE_WAIST"}, --"Girdle of the Forgotten Martyr"
  [47485] = {4,258,"INVTYPE_WRIST"}, --"Bindings of the Ashen Saint"
  [47486] = {4,258,"INVTYPE_CHEST"}, --"Cuirass of Flowing Elements"
  [47487] = {4,258,"INVTYPE_HAND"}, --"Handwraps of the Lifeless Touch"
  [47489] = {4,258,"INVTYPE_FINGER"}, --"Lurid Manifestation"
  [47490] = {4,258,"INVTYPE_CLOAK"}, --"Maiden's Adoration"
  [47491] = {4,258,"INVTYPE_2HWEAPON"}, --"Hellion Glaive"
  [47492] = {4,258,"INVTYPE_HAND"}, --"Gauntlets of Bitter Reprisal"
  [47493] = {4,219,"INVTYPE_2HWEAPON"}, --"Edge of Ruin"
  [47494] = {4,219,"INVTYPE_NECK"}, --"Ancient Pendant of Arathor"
  [47495] = {4,219,"INVTYPE_LEGS"}, --"Legplates of Relentless Onslaught"
  [47496] = {4,219,"INVTYPE_WRIST"}, --"Armbands of the Wary Lookout"
  [47497] = {4,219,"INVTYPE_HEAD"}, --"Helm of the Crestfallen Challenger"
  [47498] = {4,219,"INVTYPE_HAND"}, --"Gloves of Dismal Fortune"
  [47500] = {4,219,"INVTYPE_WEAPON"}, --"Peacekeeper Blade"
  [47501] = {4,219,"INVTYPE_CLOAK"}, --"Kurisu's Indecision"
  [47502] = {4,219,"INVTYPE_SHOULDER"}, --"Majestic Silversmith Shoulderplates"
  [47503] = {4,219,"INVTYPE_LEGS"}, --"Legplates of the Argent Armistice"
  [47504] = {4,219,"INVTYPE_FEET"}, --"Barkhide Treads"
  [47506] = {4,258,"INVTYPE_WEAPON"}, --"Silverwing Defender"
  [47508] = {4,219,"INVTYPE_WEAPON"}, --"Aledar's Battlestar"
  [47509] = {4,219,"INVTYPE_WEAPONMAINHAND"}, --"Mariel's Sorrow"
  [47510] = {4,219,"INVTYPE_WAIST"}, --"Trueheart Girdle"
  [47511] = {4,219,"INVTYPE_FEET"}, --"Plated Greaves of Providence"
  [47512] = {4,219,"INVTYPE_FINGER"}, --"Sinner's Confession"
  [47513] = {4,258,"INVTYPE_WEAPON"}, --"Orgrim's Deflector"
  [47514] = {4,219,"INVTYPE_SHOULDER"}, --"Regal Aurous Shoulderplates"
  [47515] = {4,258,"INVTYPE_2HWEAPON"}, --"Decimation"
  [47516] = {4,258,"INVTYPE_2HWEAPON"}, --"Fleshrender"
  [47517] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Blade of the Unbroken Covenant"
  [47518] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Mortalis"
  [47519] = {4,258,"INVTYPE_2HWEAPON"}, --"Catastrophe"
  [47520] = {4,258,"INVTYPE_2HWEAPON"}, --"Grievance"
  [47521] = {4,258,"INVTYPE_RANGEDRIGHT"}, --"BRK-1000"
  [47522] = {4,219,"INVTYPE_2HWEAPON"}, --"Marrowstrike"
  [47523] = {4,258,"INVTYPE_RANGEDRIGHT"}, --"Fezzik's Autocannon"
  [47524] = {4,258,"INVTYPE_2HWEAPON"}, --"Clemency"
  [47525] = {4,258,"INVTYPE_2HWEAPON"}, --"Sufferance"
  [47526] = {4,258,"INVTYPE_WEAPON"}, --"Remorseless"
  [47527] = {4,219,"INVTYPE_ROBE"}, --"Embrace of Madness"
  [47528] = {4,258,"INVTYPE_WEAPON"}, --"Cudgel of the Damned"
  [47529] = {4,219,"INVTYPE_HEAD"}, --"Mask of Distant Memory"
  [47545] = {4,272,"INVTYPE_CLOAK"}, --"Vereesa's Dexterity"
  [47546] = {4,272,"INVTYPE_CLOAK"}, --"Sylvanas' Cunning"
  [47547] = {4,272,"INVTYPE_CLOAK"}, --"Varian's Furor"
  [47548] = {4,272,"INVTYPE_CLOAK"}, --"Garrosh's Rage"
  [47549] = {4,272,"INVTYPE_CLOAK"}, --"Magni's Resolution"
  [47550] = {4,272,"INVTYPE_CLOAK"}, --"Cairne's Endurance"
  [47551] = {4,272,"INVTYPE_CLOAK"}, --"Aethas' Intensity"
  [47552] = {4,272,"INVTYPE_CLOAK"}, --"Jaina's Radiance"
  [47553] = {4,272,"INVTYPE_CLOAK"}, --"Bolvar's Devotion"
  [47554] = {4,272,"INVTYPE_CLOAK"}, --"Lady Liadrin's Conviction"
  [47560] = {4,219,"INVTYPE_FEET"}, --"Boots of the Crackling Flame"
  [47561] = {4,219,"INVTYPE_HAND"}, --"Gloves of the Dark Exile"
  [47562] = {4,219,"INVTYPE_NECK"}, --"Symbol of Redemption"
  [47563] = {4,219,"INVTYPE_WAIST"}, --"Girdle of the Dauntless Conqueror"
  [47564] = {4,219,"INVTYPE_HEAD"}, --"Gaze of the Unknown"
  [47565] = {4,219,"INVTYPE_WRIST"}, --"Vambraces of Unholy Command"
  [47566] = {4,219,"INVTYPE_NECK"}, --"The Warlord's Depravity"
  [47567] = {4,219,"INVTYPE_HAND"}, --"Gauntlets of Revelation"
  [47568] = {4,219,"INVTYPE_RANGEDRIGHT"}, --"True-aim Long Rifle"
  [47569] = {4,219,"INVTYPE_WEAPONMAINHAND"}, --"Spectral Kris"
  [47570] = {4,245,"INVTYPE_WRIST"}, --"Saronite Swordbreakers"
  [47571] = {4,245,"INVTYPE_WRIST"}, --"Saronite Swordbreakers"
  [47572] = {4,245,"INVTYPE_WRIST"}, --"Titanium Spikeguards"
  [47573] = {4,245,"INVTYPE_WRIST"}, --"Titanium Spikeguards"
  [47574] = {4,245,"INVTYPE_WRIST"}, --"Sunforged Bracers"
  [47575] = {4,245,"INVTYPE_WRIST"}, --"Sunforged Bracers"
  [47576] = {4,245,"INVTYPE_WRIST"}, --"Crusader's Dragonscale Bracers"
  [47577] = {4,245,"INVTYPE_WRIST"}, --"Crusader's Dragonscale Bracers"
  [47578] = {4,232,"INVTYPE_FINGER"}, --"Carnivorous Band"
  [47579] = {4,245,"INVTYPE_WRIST"}, --"Black Chitin Bracers"
  [47580] = {4,245,"INVTYPE_WRIST"}, --"Black Chitin Bracers"
  [47581] = {4,245,"INVTYPE_WRIST"}, --"Bracers of Swift Death"
  [47582] = {4,245,"INVTYPE_WRIST"}, --"Bracers of Swift Death"
  [47583] = {4,245,"INVTYPE_WRIST"}, --"Moonshadow Armguards"
  [47584] = {4,245,"INVTYPE_WRIST"}, --"Moonshadow Armguards"
  [47585] = {4,245,"INVTYPE_WRIST"}, --"Bejeweled Wizard's Bracers"
  [47586] = {4,245,"INVTYPE_WRIST"}, --"Bejeweled Wizard's Bracers"
  [47587] = {4,245,"INVTYPE_WRIST"}, --"Royal Moonshroud Bracers"
  [47588] = {4,245,"INVTYPE_WRIST"}, --"Royal Moonshroud Bracers"
  [47589] = {4,245,"INVTYPE_CHEST"}, --"Titanium Razorplate"
  [47590] = {4,245,"INVTYPE_CHEST"}, --"Titanium Razorplate"
  [47591] = {4,245,"INVTYPE_CHEST"}, --"Breastplate of the White Knight"
  [47592] = {4,245,"INVTYPE_CHEST"}, --"Breastplate of the White Knight"
  [47593] = {4,245,"INVTYPE_CHEST"}, --"Sunforged Breastplate"
  [47594] = {4,245,"INVTYPE_CHEST"}, --"Sunforged Breastplate"
  [47595] = {4,245,"INVTYPE_CHEST"}, --"Crusader's Dragonscale Breastplate"
  [47596] = {4,245,"INVTYPE_CHEST"}, --"Crusader's Dragonscale Breastplate"
  [47597] = {4,245,"INVTYPE_CHEST"}, --"Ensorcelled Nerubian Breastplate"
  [47598] = {4,245,"INVTYPE_CHEST"}, --"Ensorcelled Nerubian Breastplate"
  [47599] = {4,245,"INVTYPE_CHEST"}, --"Knightbane Carapace"
  [47600] = {4,245,"INVTYPE_CHEST"}, --"Knightbane Carapace"
  [47601] = {4,245,"INVTYPE_ROBE"}, --"Lunar Eclipse Robes"
  [47602] = {4,245,"INVTYPE_ROBE"}, --"Lunar Eclipse Robes"
  [47603] = {4,245,"INVTYPE_ROBE"}, --"Merlin's Robe"
  [47604] = {4,245,"INVTYPE_ROBE"}, --"Merlin's Robe"
  [47605] = {4,245,"INVTYPE_ROBE"}, --"Royal Moonshroud Robe"
  [47606] = {4,245,"INVTYPE_ROBE"}, --"Royal Moonshroud Robe"
  [47607] = {4,232,"INVTYPE_NECK"}, --"Collar of Ceaseless Torment"
  [47608] = {4,232,"INVTYPE_FEET"}, --"Acidmaw Boots"
  [47609] = {4,232,"INVTYPE_HAND"}, --"Gauntlets of Rising Anger"
  [47610] = {4,232,"INVTYPE_WRIST"}, --"Armbands of the Northern Stalker"
  [47611] = {4,232,"INVTYPE_WRIST"}, --"Dreadscale Armguards"
  [47612] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Rod of Imprisoned Souls"
  [47613] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Glacial Wilds"
  [47614] = {4,232,"INVTYPE_WAIST"}, --"Girdle of the Impaler"
  [47615] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Frozen Reach"
  [47616] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderguards of the Spirit Walker"
  [47617] = {4,232,"INVTYPE_WAIST"}, --"Icehowl Cinch"
  [47618] = {4,232,"INVTYPE_FINGER"}, --"Firestorm Ring"
  [47619] = {4,232,"INVTYPE_NECK"}, --"Amulet of Binding Elements"
  [47620] = {4,232,"INVTYPE_LEGS"}, --"Leggings of the Demonic Messenger"
  [47621] = {4,232,"INVTYPE_WAIST"}, --"Girdle of the Farseer"
  [47658] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Brimstone Igniter"
  [47659] = {4,245,"INVTYPE_THROWN"}, --"Crimson Star"
  [47660] = {4,245,"INVTYPE_THROWN"}, --"Blades of the Sable Cross"
  [47661] = {4,245,"INVTYPE_RELIC"}, --"Libram of Valiance"
  [47662] = {4,245,"INVTYPE_RELIC"}, --"Libram of Veracity"
  [47663] = {4,232,"INVTYPE_WRIST"}, --"Felspark Bindings"
  [47664] = {4,245,"INVTYPE_RELIC"}, --"Libram of Defiance"
  [47665] = {4,245,"INVTYPE_RELIC"}, --"Totem of Calming Tides"
  [47666] = {4,245,"INVTYPE_RELIC"}, --"Totem of Electrifying Wind"
  [47667] = {4,245,"INVTYPE_RELIC"}, --"Totem of Quaking Earth"
  [47668] = {4,245,"INVTYPE_RELIC"}, --"Idol of Mutilation"
  [47669] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Winter Solstice"
  [47670] = {4,245,"INVTYPE_RELIC"}, --"Idol of Lunar Fury"
  [47671] = {4,245,"INVTYPE_RELIC"}, --"Idol of Flaring Growth"
  [47672] = {4,245,"INVTYPE_RELIC"}, --"Sigil of Insolence"
  [47673] = {4,245,"INVTYPE_RELIC"}, --"Sigil of Virulence"
  [47674] = {4,245,"INVTYPE_HEAD"}, --"Helm of Thunderous Rampage"
  [47675] = {4,245,"INVTYPE_HEAD"}, --"Faceplate of Thunderous Rampage"
  [47676] = {4,232,"INVTYPE_WEAPON"}, --"Dirk of the Night Watch"
  [47677] = {4,245,"INVTYPE_HEAD"}, --"Faceplate of the Honorbound"
  [47678] = {4,245,"INVTYPE_HEAD"}, --"Headplate of the Honorbound"
  [47679] = {4,232,"INVTYPE_NECK"}, --"Endurance of the Infernal"
  [47680] = {4,232,"INVTYPE_WRIST"}, --"Armguards of the Nether Lord"
  [47681] = {4,245,"INVTYPE_HEAD"}, --"Heaume of the Restless Watch"
  [47682] = {4,245,"INVTYPE_HEAD"}, --"Helm of the Restless Watch"
  [47683] = {4,232,"INVTYPE_FEET"}, --"Sentinel Scouting Greaves"
  [47684] = {4,245,"INVTYPE_HEAD"}, --"Coif of the Brooding Dragon"
  [47685] = {4,245,"INVTYPE_HEAD"}, --"Helm of the Brooding Dragon"
  [47686] = {4,245,"INVTYPE_HEAD"}, --"Helm of Inner Warmth"
  [47687] = {4,245,"INVTYPE_HEAD"}, --"Headguard of Inner Warmth"
  [47688] = {4,245,"INVTYPE_HEAD"}, --"Mask of Lethal Intent"
  [47689] = {4,245,"INVTYPE_HEAD"}, --"Hood of Lethal Intent"
  [47690] = {4,245,"INVTYPE_HEAD"}, --"Helm of Abundant Growth"
  [47691] = {4,245,"INVTYPE_HEAD"}, --"Mask of Abundant Growth"
  [47692] = {4,245,"INVTYPE_HEAD"}, --"Hood of Smoldering Aftermath"
  [47693] = {4,245,"INVTYPE_HEAD"}, --"Hood of Fiery Aftermath"
  [47694] = {4,245,"INVTYPE_HEAD"}, --"Helm of Clouded Sight"
  [47695] = {4,245,"INVTYPE_HEAD"}, --"Hood of Clouded Sight"
  [47696] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderplates of Trembling Rage"
  [47697] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of Trembling Rage"
  [47698] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderplates of Enduring Order"
  [47699] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderguards of Enduring Order"
  [47700] = {4,232,"INVTYPE_FINGER"}, --"Loop of the Twin Val'kyr"
  [47701] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderplates of the Cavalier"
  [47702] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Cavalier"
  [47703] = {4,232,"INVTYPE_FINGER"}, --"Planestalker Signet"
  [47704] = {4,245,"INVTYPE_SHOULDER"}, --"Epaulets of the Devourer"
  [47705] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Devourer"
  [47706] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulders of the Groundbreaker"
  [47707] = {4,245,"INVTYPE_SHOULDER"}, --"Mantle of the Groundbreaker"
  [47708] = {4,245,"INVTYPE_SHOULDER"}, --"Duskstalker Shoulderpads"
  [47709] = {4,245,"INVTYPE_SHOULDER"}, --"Duskstalker Pauldrons"
  [47710] = {4,245,"INVTYPE_SHOULDER"}, --"Epaulets of the Fateful Accord"
  [47711] = {4,232,"INVTYPE_WAIST"}, --"Girdle of the Nether Champion"
  [47712] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulders of the Fateful Accord"
  [47713] = {4,245,"INVTYPE_SHOULDER"}, --"Mantle of Catastrophic Emanation"
  [47714] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of Catastrophic Emanation"
  [47715] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of Revered Mortality"
  [47716] = {4,245,"INVTYPE_SHOULDER"}, --"Mantle of Revered Mortality"
  [47717] = {4,232,"INVTYPE_HEAD"}, --"Faceplate of the Silver Champion"
  [47718] = {4,232,"INVTYPE_HEAD"}, --"Helm of the Silver Ranger"
  [47719] = {4,232,"INVTYPE_HAND"}, --"Gloves of the Silver Assassin"
  [47720] = {4,232,"INVTYPE_SHOULDER"}, --"Pauldrons of the Silver Defender"
  [47721] = {4,232,"INVTYPE_FEET"}, --"Sandals of the Silver Magus"
  [47724] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Blade of the Silver Disciple"
  [47725] = {4,232,"INVTYPE_TRINKET"}, --"Victor's Call"
  [47726] = {4,232,"INVTYPE_TRINKET"}, --"Talisman of Volatile Power"
  [47727] = {4,232,"INVTYPE_TRINKET"}, --"Fervor of the Frostborn"
  [47728] = {4,232,"INVTYPE_TRINKET"}, --"Binding Light"
  [47729] = {4,245,"INVTYPE_FINGER"}, --"Bloodshed Band"
  [47730] = {4,245,"INVTYPE_FINGER"}, --"Dexterous Brightstone Ring"
  [47731] = {4,245,"INVTYPE_FINGER"}, --"Clutch of Fortification"
  [47732] = {4,245,"INVTYPE_FINGER"}, --"Band of the Invoker"
  [47733] = {4,245,"INVTYPE_FINGER"}, --"Heartmender Circle"
  [47734] = {4,245,"INVTYPE_TRINKET"}, --"Mark of Supremacy"
  [47735] = {4,245,"INVTYPE_TRINKET"}, --"Glyph of Indomitability"
  [47736] = {4,232,"INVTYPE_WEAPON"}, --"Icefall Blade"
  [47737] = {4,232,"INVTYPE_2HWEAPON"}, --"Reckoning"
  [47738] = {4,232,"INVTYPE_FEET"}, --"Sabatons of the Lingering Vortex"
  [47739] = {4,232,"INVTYPE_CHEST"}, --"Armor of Shifting Shadows"
  [47740] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"The Diplomat"
  [47741] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Baelgun's Heavy Crossbow"
  [47742] = {4,232,"INVTYPE_HOLDABLE"}, --"Chalice of Benedictus"
  [47743] = {4,232,"INVTYPE_2HWEAPON"}, --"Enlightenment"
  [47744] = {4,232,"INVTYPE_HAND"}, --"Gloves of the Azure Prophet"
  [47745] = {4,232,"INVTYPE_HAND"}, --"Gloves of Looming Shadow"
  [47746] = {4,232,"INVTYPE_HEAD"}, --"Helm of the Snowy Grotto"
  [47747] = {4,232,"INVTYPE_NECK"}, --"Darkbane Pendant"
  [47748] = {4,232,"INVTYPE_HEAD"}, --"Khadgar's Hood of Conquest"
  [47749] = {4,232,"INVTYPE_ROBE"}, --"Khadgar's Robe of Conquest"
  [47750] = {4,232,"INVTYPE_LEGS"}, --"Khadgar's Leggings of Conquest"
  [47751] = {4,232,"INVTYPE_SHOULDER"}, --"Khadgar's Shoulderpads of Conquest"
  [47752] = {4,232,"INVTYPE_HAND"}, --"Khadgar's Gauntlets of Conquest"
  [47753] = {4,245,"INVTYPE_HAND"}, --"Khadgar's Gauntlets of Triumph"
  [47754] = {4,245,"INVTYPE_HEAD"}, --"Khadgar's Hood of Triumph"
  [47755] = {4,245,"INVTYPE_LEGS"}, --"Khadgar's Leggings of Triumph"
  [47756] = {4,245,"INVTYPE_ROBE"}, --"Khadgar's Robe of Triumph"
  [47757] = {4,245,"INVTYPE_SHOULDER"}, --"Khadgar's Shoulderpads of Triumph"
  [47758] = {4,258,"INVTYPE_SHOULDER"}, --"Khadgar's Shoulderpads of Triumph"
  [47759] = {4,258,"INVTYPE_ROBE"}, --"Khadgar's Robe of Triumph"
  [47760] = {4,258,"INVTYPE_LEGS"}, --"Khadgar's Leggings of Triumph"
  [47761] = {4,258,"INVTYPE_HEAD"}, --"Khadgar's Hood of Triumph"
  [47762] = {4,258,"INVTYPE_HAND"}, --"Khadgar's Gauntlets of Triumph"
  [47763] = {4,258,"INVTYPE_HAND"}, --"Sunstrider's Gauntlets of Triumph"
  [47764] = {4,258,"INVTYPE_HEAD"}, --"Sunstrider's Hood of Triumph"
  [47765] = {4,258,"INVTYPE_LEGS"}, --"Sunstrider's Leggings of Triumph"
  [47766] = {4,258,"INVTYPE_ROBE"}, --"Sunstrider's Robe of Triumph"
  [47767] = {4,258,"INVTYPE_SHOULDER"}, --"Sunstrider's Shoulderpads of Triumph"
  [47768] = {4,245,"INVTYPE_SHOULDER"}, --"Sunstrider's Shoulderpads of Triumph"
  [47769] = {4,245,"INVTYPE_ROBE"}, --"Sunstrider's Robe of Triumph"
  [47770] = {4,245,"INVTYPE_LEGS"}, --"Sunstrider's Leggings of Triumph"
  [47771] = {4,245,"INVTYPE_HEAD"}, --"Sunstrider's Hood of Triumph"
  [47772] = {4,245,"INVTYPE_HAND"}, --"Sunstrider's Gauntlets of Triumph"
  [47773] = {4,232,"INVTYPE_HAND"}, --"Sunstrider's Gauntlets of Conquest"
  [47774] = {4,232,"INVTYPE_HEAD"}, --"Sunstrider's Hood of Conquest"
  [47775] = {4,232,"INVTYPE_LEGS"}, --"Sunstrider's Leggings of Conquest"
  [47776] = {4,232,"INVTYPE_ROBE"}, --"Sunstrider's Robe of Conquest"
  [47777] = {4,232,"INVTYPE_SHOULDER"}, --"Sunstrider's Shoulderpads of Conquest"
  [47778] = {4,245,"INVTYPE_HEAD"}, --"Kel'Thuzad's Hood of Triumph"
  [47779] = {4,245,"INVTYPE_ROBE"}, --"Kel'Thuzad's Robe of Triumph"
  [47780] = {4,245,"INVTYPE_LEGS"}, --"Kel'Thuzad's Leggings of Triumph"
  [47781] = {4,245,"INVTYPE_SHOULDER"}, --"Kel'Thuzad's Shoulderpads of Triumph"
  [47782] = {4,245,"INVTYPE_HAND"}, --"Kel'Thuzad's Gloves of Triumph"
  [47783] = {4,232,"INVTYPE_HAND"}, --"Kel'Thuzad's Gloves of Conquest"
  [47784] = {4,232,"INVTYPE_HEAD"}, --"Kel'Thuzad's Hood of Conquest"
  [47785] = {4,232,"INVTYPE_LEGS"}, --"Kel'Thuzad's Leggings of Conquest"
  [47786] = {4,232,"INVTYPE_ROBE"}, --"Kel'Thuzad's Robe of Conquest"
  [47787] = {4,232,"INVTYPE_SHOULDER"}, --"Kel'Thuzad's Shoulderpads of Conquest"
  [47788] = {4,258,"INVTYPE_HAND"}, --"Kel'Thuzad's Gloves of Triumph"
  [47789] = {4,258,"INVTYPE_HEAD"}, --"Kel'Thuzad's Hood of Triumph"
  [47790] = {4,258,"INVTYPE_LEGS"}, --"Kel'Thuzad's Leggings of Triumph"
  [47791] = {4,258,"INVTYPE_ROBE"}, --"Kel'Thuzad's Robe of Triumph"
  [47792] = {4,258,"INVTYPE_SHOULDER"}, --"Kel'Thuzad's Shoulderpads of Triumph"
  [47793] = {4,258,"INVTYPE_SHOULDER"}, --"Gul'dan's Shoulderpads of Triumph"
  [47794] = {4,258,"INVTYPE_ROBE"}, --"Gul'dan's Robe of Triumph"
  [47795] = {4,258,"INVTYPE_LEGS"}, --"Gul'dan's Leggings of Triumph"
  [47796] = {4,258,"INVTYPE_HEAD"}, --"Gul'dan's Hood of Triumph"
  [47797] = {4,258,"INVTYPE_HAND"}, --"Gul'dan's Gloves of Triumph"
  [47798] = {4,232,"INVTYPE_SHOULDER"}, --"Gul'dan's Shoulderpads of Conquest"
  [47799] = {4,232,"INVTYPE_ROBE"}, --"Gul'dan's Robe of Conquest"
  [47800] = {4,232,"INVTYPE_LEGS"}, --"Gul'dan's Leggings of Conquest"
  [47801] = {4,232,"INVTYPE_HEAD"}, --"Gul'dan's Hood of Conquest"
  [47802] = {4,232,"INVTYPE_HAND"}, --"Gul'dan's Gloves of Conquest"
  [47803] = {4,245,"INVTYPE_HAND"}, --"Gul'dan's Gloves of Triumph"
  [47804] = {4,245,"INVTYPE_HEAD"}, --"Gul'dan's Hood of Triumph"
  [47805] = {4,245,"INVTYPE_LEGS"}, --"Gul'dan's Leggings of Triumph"
  [47806] = {4,245,"INVTYPE_ROBE"}, --"Gul'dan's Robe of Triumph"
  [47807] = {4,245,"INVTYPE_SHOULDER"}, --"Gul'dan's Shoulderpads of Triumph"
  [47808] = {4,232,"INVTYPE_WEAPON"}, --"The Lion's Maw"
  [47809] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Argent Resolve"
  [47810] = {4,232,"INVTYPE_WEAPON"}, --"Crusader's Glory"
  [47811] = {4,232,"INVTYPE_CHEST"}, --"Chestguard of the Warden"
  [47812] = {4,232,"INVTYPE_SHIELD"}, --"Vigilant Ward"
  [47813] = {4,232,"INVTYPE_HEAD"}, --"Helmet of the Crypt Lord"
  [47814] = {4,232,"INVTYPE_WEAPON"}, --"Westfall Saber"
  [47815] = {4,232,"INVTYPE_2HWEAPON"}, --"Cold Convergence"
  [47816] = {4,232,"INVTYPE_WEAPON"}, --"The Grinder"
  [47829] = {4,232,"INVTYPE_SHOULDER"}, --"Pauldrons of the Timeless Hunter"
  [47830] = {4,232,"INVTYPE_LEGS"}, --"Legplates of the Silver Hand"
  [47832] = {4,232,"INVTYPE_SHOULDER"}, --"Spaulders of the Snow Bandit"
  [47834] = {4,232,"INVTYPE_2HWEAPON"}, --"Fordragon Blades"
  [47835] = {4,232,"INVTYPE_SHIELD"}, --"Bulwark of the Royal Guard"
  [47836] = {4,232,"INVTYPE_LEGS"}, --"Legplates of the Immortal Spider"
  [47837] = {4,232,"INVTYPE_WAIST"}, --"Cinch of the Undying"
  [47838] = {4,232,"INVTYPE_ROBE"}, --"Vestments of the Sleepless"
  [47849] = {4,232,"INVTYPE_NECK"}, --"Collar of Unending Torment"
  [47850] = {4,232,"INVTYPE_WRIST"}, --"Bracers of the Northern Stalker"
  [47851] = {4,232,"INVTYPE_HAND"}, --"Gauntlets of Mounting Anger"
  [47852] = {4,232,"INVTYPE_WRIST"}, --"Dreadscale Bracers"
  [47853] = {4,232,"INVTYPE_FEET"}, --"Acidmaw Treads"
  [47854] = {4,232,"INVTYPE_FINGER"}, --"Gormok's Band"
  [47855] = {4,232,"INVTYPE_WAIST"}, --"Icehowl Binding"
  [47856] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Scepter of Imprisoned Souls"
  [47857] = {4,232,"INVTYPE_SHOULDER"}, --"Pauldrons of the Glacial Wilds"
  [47858] = {4,232,"INVTYPE_WAIST"}, --"Girdle of the Frozen Reach"
  [47859] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Impaler"
  [47860] = {4,232,"INVTYPE_SHOULDER"}, --"Pauldrons of the Spirit Walker"
  [47861] = {4,232,"INVTYPE_WRIST"}, --"Felspark Bracers"
  [47862] = {4,232,"INVTYPE_FINGER"}, --"Firestorm Band"
  [47863] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Bloodhoof Emissary"
  [47864] = {4,232,"INVTYPE_NECK"}, --"Pendant of Binding Elements"
  [47865] = {4,232,"INVTYPE_LEGS"}, --"Legwraps of the Demonic Messenger"
  [47866] = {4,232,"INVTYPE_WAIST"}, --"Darkspear Ritual Binding"
  [47867] = {4,232,"INVTYPE_FEET"}, --"Warsong Poacher's Greaves"
  [47868] = {4,232,"INVTYPE_FINGER"}, --"Planestalker Band"
  [47869] = {4,232,"INVTYPE_WRIST"}, --"Armplates of the Nether Lord"
  [47870] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Nether Champion"
  [47871] = {4,232,"INVTYPE_WEAPON"}, --"Orcish Deathblade"
  [47872] = {4,232,"INVTYPE_NECK"}, --"Fortitude of the Infernal"
  [47873] = {4,232,"INVTYPE_FEET"}, --"Sunreaver Magus' Sandals"
  [47874] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Sunreaver Disciple's Blade"
  [47875] = {4,232,"INVTYPE_HEAD"}, --"Sunreaver Ranger's Helm"
  [47876] = {4,232,"INVTYPE_HEAD"}, --"Sunreaver Champion's Faceplate"
  [47877] = {4,232,"INVTYPE_SHOULDER"}, --"Sunreaver Defender's Pauldrons"
  [47878] = {4,232,"INVTYPE_HAND"}, --"Sunreaver Assassin's Gloves"
  [47879] = {4,232,"INVTYPE_TRINKET"}, --"Fetish of Volatile Power"
  [47880] = {4,232,"INVTYPE_TRINKET"}, --"Binding Stone"
  [47881] = {4,232,"INVTYPE_TRINKET"}, --"Vengeance of the Forsaken"
  [47882] = {4,232,"INVTYPE_TRINKET"}, --"Eitrigg's Oath"
  [47883] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Widebarrel Flintlock"
  [47884] = {4,232,"INVTYPE_2HWEAPON"}, --"Edge of Agony"
  [47885] = {4,232,"INVTYPE_FEET"}, --"Greaves of the Lingering Vortex"
  [47886] = {4,232,"INVTYPE_WEAPON"}, --"Nemesis Blade"
  [47887] = {4,232,"INVTYPE_CHEST"}, --"Vest of Shifting Shadows"
  [47888] = {4,232,"INVTYPE_FINGER"}, --"Band of the Twin Val'kyr"
  [47889] = {4,232,"INVTYPE_HAND"}, --"Looming Shadow Wraps"
  [47890] = {4,232,"INVTYPE_NECK"}, --"Darkbane Amulet"
  [47891] = {4,232,"INVTYPE_HEAD"}, --"Helm of the High Mesa"
  [47892] = {4,232,"INVTYPE_2HWEAPON"}, --"Illumination"
  [47893] = {4,232,"INVTYPE_HAND"}, --"Sen'jin Ritualist Gloves"
  [47894] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Mace of the Earthborn Chieftain"
  [47895] = {4,232,"INVTYPE_SHIELD"}, --"Pride of the Kor'kron"
  [47896] = {4,232,"INVTYPE_CHEST"}, --"Stoneskin Chestplate"
  [47897] = {4,232,"INVTYPE_HEAD"}, --"Helm of the Crypt Lord"
  [47898] = {4,232,"INVTYPE_WEAPON"}, --"Frostblade Hatchet"
  [47899] = {4,232,"INVTYPE_WEAPON"}, --"Ardent Guard"
  [47900] = {4,232,"INVTYPE_2HWEAPON"}, --"Perdition"
  [47901] = {4,232,"INVTYPE_SHOULDER"}, --"Pauldrons of the Shadow Hunter"
  [47902] = {4,232,"INVTYPE_LEGS"}, --"Legplates of Redeemed Blood"
  [47903] = {4,232,"INVTYPE_WEAPON"}, --"Forsaken Bonecarver"
  [47904] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Snow Bandit"
  [47905] = {4,232,"INVTYPE_WEAPON"}, --"Blackhorn Bludgeon"
  [47906] = {4,232,"INVTYPE_ROBE"}, --"Robes of the Sleepless"
  [47907] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Darkmaw Crossbow"
  [47908] = {4,232,"INVTYPE_LEGS"}, --"Sunwalker Legguards"
  [47909] = {4,232,"INVTYPE_WAIST"}, --"Belt of the Eternal"
  [47910] = {4,232,"INVTYPE_SHIELD"}, --"Aegis of the Coliseum"
  [47911] = {4,232,"INVTYPE_2HWEAPON"}, --"Anguish"
  [47913] = {4,232,"INVTYPE_HOLDABLE"}, --"Lightbane Focus"
  [47914] = {4,232,"INVTYPE_HEAD"}, --"Velen's Cowl of Conquest"
  [47915] = {4,245,"INVTYPE_NECK"}, --"Collar of Ceaseless Torment"
  [47916] = {4,245,"INVTYPE_WRIST"}, --"Armbands of the Northern Stalker"
  [47917] = {4,245,"INVTYPE_HAND"}, --"Gauntlets of Rising Anger"
  [47918] = {4,245,"INVTYPE_WRIST"}, --"Dreadscale Armguards"
  [47919] = {4,245,"INVTYPE_FEET"}, --"Acidmaw Boots"
  [47920] = {4,245,"INVTYPE_FINGER"}, --"Carnivorous Band"
  [47921] = {4,245,"INVTYPE_WAIST"}, --"Icehowl Cinch"
  [47922] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Rod of Imprisoned Souls"
  [47923] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Glacial Wilds"
  [47924] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Frozen Reach"
  [47925] = {4,245,"INVTYPE_WAIST"}, --"Girdle of the Impaler"
  [47926] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderguards of the Spirit Walker"
  [47927] = {4,245,"INVTYPE_WRIST"}, --"Felspark Bindings"
  [47928] = {4,245,"INVTYPE_FINGER"}, --"Firestorm Ring"
  [47929] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Winter Solstice"
  [47930] = {4,245,"INVTYPE_NECK"}, --"Amulet of Binding Elements"
  [47931] = {4,245,"INVTYPE_LEGS"}, --"Leggings of the Demonic Messenger"
  [47932] = {4,245,"INVTYPE_WAIST"}, --"Girdle of the Farseer"
  [47933] = {4,245,"INVTYPE_FEET"}, --"Sentinel Scouting Greaves"
  [47934] = {4,245,"INVTYPE_FINGER"}, --"Planestalker Signet"
  [47935] = {4,245,"INVTYPE_WRIST"}, --"Armguards of the Nether Lord"
  [47936] = {4,232,"INVTYPE_ROBE"}, --"Velen's Robe of Conquest"
  [47937] = {4,245,"INVTYPE_WAIST"}, --"Girdle of the Nether Champion"
  [47938] = {4,245,"INVTYPE_WEAPON"}, --"Dirk of the Night Watch"
  [47939] = {4,245,"INVTYPE_NECK"}, --"Endurance of the Infernal"
  [47940] = {4,245,"INVTYPE_FEET"}, --"Sandals of the Silver Magus"
  [47941] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Blade of the Silver Disciple"
  [47942] = {4,245,"INVTYPE_HEAD"}, --"Helm of the Silver Ranger"
  [47943] = {4,245,"INVTYPE_HEAD"}, --"Faceplate of the Silver Champion"
  [47944] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Silver Defender"
  [47945] = {4,245,"INVTYPE_HAND"}, --"Gloves of the Silver Assassin"
  [47946] = {4,245,"INVTYPE_TRINKET"}, --"Talisman of Volatile Power"
  [47947] = {4,245,"INVTYPE_TRINKET"}, --"Binding Light"
  [47948] = {4,245,"INVTYPE_TRINKET"}, --"Victor's Call"
  [47949] = {4,245,"INVTYPE_TRINKET"}, --"Fervor of the Frostborn"
  [47950] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"The Diplomat"
  [47951] = {4,245,"INVTYPE_2HWEAPON"}, --"Reckoning"
  [47952] = {4,245,"INVTYPE_FEET"}, --"Sabatons of the Lingering Vortex"
  [47953] = {4,245,"INVTYPE_WEAPON"}, --"Icefall Blade"
  [47954] = {4,245,"INVTYPE_CHEST"}, --"Armor of Shifting Shadows"
  [47955] = {4,245,"INVTYPE_FINGER"}, --"Loop of the Twin Val'kyr"
  [47956] = {4,245,"INVTYPE_HAND"}, --"Gloves of Looming Shadow"
  [47957] = {4,245,"INVTYPE_NECK"}, --"Darkbane Pendant"
  [47958] = {4,245,"INVTYPE_HOLDABLE"}, --"Chalice of Benedictus"
  [47959] = {4,245,"INVTYPE_HEAD"}, --"Helm of the Snowy Grotto"
  [47960] = {4,245,"INVTYPE_2HWEAPON"}, --"Enlightenment"
  [47961] = {4,245,"INVTYPE_HAND"}, --"Gloves of the Azure Prophet"
  [47962] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Argent Resolve"
  [47963] = {4,245,"INVTYPE_SHIELD"}, --"Vigilant Ward"
  [47964] = {4,245,"INVTYPE_CHEST"}, --"Chestguard of the Warden"
  [47965] = {4,245,"INVTYPE_HEAD"}, --"Helmet of the Crypt Lord"
  [47966] = {4,245,"INVTYPE_WEAPON"}, --"The Lion's Maw"
  [47967] = {4,245,"INVTYPE_WEAPON"}, --"Crusader's Glory"
  [47968] = {4,245,"INVTYPE_2HWEAPON"}, --"Cold Convergence"
  [47969] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Timeless Hunter"
  [47970] = {4,245,"INVTYPE_LEGS"}, --"Legplates of the Silver Hand"
  [47971] = {4,245,"INVTYPE_WEAPON"}, --"Westfall Saber"
  [47972] = {4,245,"INVTYPE_SHOULDER"}, --"Spaulders of the Snow Bandit"
  [47973] = {4,245,"INVTYPE_WEAPON"}, --"The Grinder"
  [47974] = {4,245,"INVTYPE_ROBE"}, --"Vestments of the Sleepless"
  [47975] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Baelgun's Heavy Crossbow"
  [47976] = {4,245,"INVTYPE_LEGS"}, --"Legplates of the Immortal Spider"
  [47977] = {4,245,"INVTYPE_WAIST"}, --"Cinch of the Undying"
  [47978] = {4,245,"INVTYPE_SHIELD"}, --"Bulwark of the Royal Guard"
  [47979] = {4,245,"INVTYPE_2HWEAPON"}, --"Fordragon Blades"
  [47980] = {4,232,"INVTYPE_LEGS"}, --"Velen's Leggings of Conquest"
  [47981] = {4,232,"INVTYPE_SHOULDER"}, --"Velen's Shoulderpads of Conquest"
  [47982] = {4,232,"INVTYPE_HAND"}, --"Velen's Gloves of Conquest"
  [47983] = {4,245,"INVTYPE_HAND"}, --"Velen's Gloves of Triumph"
  [47984] = {4,245,"INVTYPE_HEAD"}, --"Velen's Cowl of Triumph"
  [47985] = {4,245,"INVTYPE_LEGS"}, --"Velen's Leggings of Triumph"
  [47986] = {4,245,"INVTYPE_ROBE"}, --"Velen's Robe of Triumph"
  [47987] = {4,245,"INVTYPE_SHOULDER"}, --"Velen's Shoulderpads of Triumph"
  [47988] = {4,245,"INVTYPE_NECK"}, --"Collar of Unending Torment"
  [47989] = {4,245,"INVTYPE_WRIST"}, --"Bracers of the Northern Stalker"
  [47990] = {4,245,"INVTYPE_HAND"}, --"Gauntlets of Mounting Anger"
  [47991] = {4,245,"INVTYPE_WRIST"}, --"Dreadscale Bracers"
  [47992] = {4,245,"INVTYPE_FEET"}, --"Acidmaw Treads"
  [47993] = {4,245,"INVTYPE_FINGER"}, --"Gormok's Band"
  [47994] = {4,245,"INVTYPE_WAIST"}, --"Icehowl Binding"
  [47995] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Scepter of Imprisoned Souls"
  [47996] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Glacial Wilds"
  [47997] = {4,245,"INVTYPE_WAIST"}, --"Girdle of the Frozen Reach"
  [47998] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Impaler"
  [47999] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Spirit Walker"
  [48000] = {4,245,"INVTYPE_WRIST"}, --"Felspark Bracers"
  [48001] = {4,245,"INVTYPE_FINGER"}, --"Firestorm Band"
  [48002] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Bloodhoof Emissary"
  [48003] = {4,245,"INVTYPE_NECK"}, --"Pendant of Binding Elements"
  [48004] = {4,245,"INVTYPE_LEGS"}, --"Legwraps of the Demonic Messenger"
  [48005] = {4,245,"INVTYPE_WAIST"}, --"Darkspear Ritual Binding"
  [48006] = {4,245,"INVTYPE_FEET"}, --"Warsong Poacher's Greaves"
  [48007] = {4,245,"INVTYPE_FINGER"}, --"Planestalker Band"
  [48008] = {4,245,"INVTYPE_WRIST"}, --"Armplates of the Nether Lord"
  [48009] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Nether Champion"
  [48010] = {4,245,"INVTYPE_WEAPON"}, --"Orcish Deathblade"
  [48011] = {4,245,"INVTYPE_NECK"}, --"Fortitude of the Infernal"
  [48012] = {4,245,"INVTYPE_FEET"}, --"Sunreaver Magus' Sandals"
  [48013] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Sunreaver Disciple's Blade"
  [48014] = {4,245,"INVTYPE_HEAD"}, --"Sunreaver Ranger's Helm"
  [48015] = {4,245,"INVTYPE_HEAD"}, --"Sunreaver Champion's Faceplate"
  [48016] = {4,245,"INVTYPE_SHOULDER"}, --"Sunreaver Defender's Pauldrons"
  [48017] = {4,245,"INVTYPE_HAND"}, --"Sunreaver Assassin's Gloves"
  [48018] = {4,245,"INVTYPE_TRINKET"}, --"Fetish of Volatile Power"
  [48019] = {4,245,"INVTYPE_TRINKET"}, --"Binding Stone"
  [48020] = {4,245,"INVTYPE_TRINKET"}, --"Vengeance of the Forsaken"
  [48021] = {4,245,"INVTYPE_TRINKET"}, --"Eitrigg's Oath"
  [48022] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Widebarrel Flintlock"
  [48023] = {4,245,"INVTYPE_2HWEAPON"}, --"Edge of Agony"
  [48024] = {4,245,"INVTYPE_FEET"}, --"Greaves of the Lingering Vortex"
  [48025] = {4,245,"INVTYPE_WEAPON"}, --"Nemesis Blade"
  [48026] = {4,245,"INVTYPE_CHEST"}, --"Vest of Shifting Shadows"
  [48027] = {4,245,"INVTYPE_FINGER"}, --"Band of the Twin Val'kyr"
  [48028] = {4,245,"INVTYPE_HAND"}, --"Looming Shadow Wraps"
  [48029] = {4,258,"INVTYPE_SHOULDER"}, --"Velen's Shoulderpads of Triumph"
  [48030] = {4,245,"INVTYPE_NECK"}, --"Darkbane Amulet"
  [48031] = {4,258,"INVTYPE_ROBE"}, --"Velen's Robe of Triumph"
  [48032] = {4,245,"INVTYPE_HOLDABLE"}, --"Lightbane Focus"
  [48033] = {4,258,"INVTYPE_LEGS"}, --"Velen's Leggings of Triumph"
  [48034] = {4,245,"INVTYPE_HEAD"}, --"Helm of the High Mesa"
  [48035] = {4,258,"INVTYPE_HEAD"}, --"Velen's Cowl of Triumph"
  [48036] = {4,245,"INVTYPE_2HWEAPON"}, --"Illumination"
  [48037] = {4,258,"INVTYPE_HAND"}, --"Velen's Gloves of Triumph"
  [48038] = {4,245,"INVTYPE_HAND"}, --"Sen'jin Ritualist Gloves"
  [48039] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Mace of the Earthborn Chieftain"
  [48040] = {4,245,"INVTYPE_SHIELD"}, --"Pride of the Kor'kron"
  [48041] = {4,245,"INVTYPE_CHEST"}, --"Stoneskin Chestplate"
  [48042] = {4,245,"INVTYPE_HEAD"}, --"Helm of the Crypt Lord"
  [48043] = {4,245,"INVTYPE_WEAPON"}, --"Frostblade Hatchet"
  [48044] = {4,245,"INVTYPE_WEAPON"}, --"Ardent Guard"
  [48045] = {4,245,"INVTYPE_2HWEAPON"}, --"Perdition"
  [48046] = {4,245,"INVTYPE_SHOULDER"}, --"Pauldrons of the Shadow Hunter"
  [48047] = {4,245,"INVTYPE_LEGS"}, --"Legplates of the Redeemed Blood Knight"
  [48048] = {4,245,"INVTYPE_WEAPON"}, --"Forsaken Bonecarver"
  [48049] = {4,245,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Snow Bandit"
  [48050] = {4,245,"INVTYPE_WEAPON"}, --"Blackhorn Bludgeon"
  [48051] = {4,245,"INVTYPE_ROBE"}, --"Robes of the Sleepless"
  [48052] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Darkmaw Crossbow"
  [48053] = {4,245,"INVTYPE_LEGS"}, --"Sunwalker Legguards"
  [48054] = {4,245,"INVTYPE_WAIST"}, --"Belt of the Eternal"
  [48055] = {4,245,"INVTYPE_SHIELD"}, --"Aegis of the Coliseum"
  [48056] = {4,245,"INVTYPE_2HWEAPON"}, --"Anguish"
  [48057] = {4,258,"INVTYPE_HAND"}, --"Zabra's Gloves of Triumph"
  [48058] = {4,258,"INVTYPE_HEAD"}, --"Zabra's Cowl of Triumph"
  [48059] = {4,258,"INVTYPE_LEGS"}, --"Zabra's Leggings of Triumph"
  [48060] = {4,258,"INVTYPE_ROBE"}, --"Zabra's Robe of Triumph"
  [48061] = {4,258,"INVTYPE_SHOULDER"}, --"Zabra's Shoulderpads of Triumph"
  [48062] = {4,245,"INVTYPE_SHOULDER"}, --"Zabra's Shoulderpads of Triumph"
  [48063] = {4,245,"INVTYPE_ROBE"}, --"Zabra's Robe of Triumph"
  [48064] = {4,245,"INVTYPE_LEGS"}, --"Zabra's Leggings of Triumph"
  [48065] = {4,245,"INVTYPE_HEAD"}, --"Zabra's Cowl of Triumph"
  [48066] = {4,245,"INVTYPE_HAND"}, --"Zabra's Gloves of Triumph"
  [48067] = {4,232,"INVTYPE_HAND"}, --"Zabra's Gloves of Conquest"
  [48068] = {4,232,"INVTYPE_HEAD"}, --"Zabra's Cowl of Conquest"
  [48069] = {4,232,"INVTYPE_LEGS"}, --"Zabra's Leggings of Conquest"
  [48070] = {4,232,"INVTYPE_ROBE"}, --"Zabra's Robe of Conquest"
  [48071] = {4,232,"INVTYPE_SHOULDER"}, --"Zabra's Shoulderpads of Conquest"
  [48072] = {4,232,"INVTYPE_HAND"}, --"Velen's Handwraps of Conquest"
  [48073] = {4,232,"INVTYPE_HEAD"}, --"Velen's Circlet of Conquest"
  [48074] = {4,232,"INVTYPE_LEGS"}, --"Velen's Pants of Conquest"
  [48075] = {4,232,"INVTYPE_ROBE"}, --"Velen's Raiments of Conquest"
  [48076] = {4,232,"INVTYPE_SHOULDER"}, --"Velen's Mantle of Conquest"
  [48077] = {4,245,"INVTYPE_HAND"}, --"Velen's Handwraps of Triumph"
  [48078] = {4,245,"INVTYPE_HEAD"}, --"Velen's Circlet of Triumph"
  [48079] = {4,245,"INVTYPE_LEGS"}, --"Velen's Pants of Triumph"
  [48080] = {4,245,"INVTYPE_ROBE"}, --"Velen's Raiments of Triumph"
  [48081] = {4,245,"INVTYPE_SHOULDER"}, --"Velen's Mantle of Triumph"
  [48082] = {4,258,"INVTYPE_SHOULDER"}, --"Velen's Mantle of Triumph"
  [48083] = {4,258,"INVTYPE_ROBE"}, --"Velen's Raiments of Triumph"
  [48084] = {4,258,"INVTYPE_LEGS"}, --"Velen's Pants of Triumph"
  [48085] = {4,258,"INVTYPE_HEAD"}, --"Velen's Circlet of Triumph"
  [48086] = {4,258,"INVTYPE_HAND"}, --"Velen's Handwraps of Triumph"
  [48087] = {4,258,"INVTYPE_HAND"}, --"Zabra's Handwraps of Triumph"
  [48088] = {4,258,"INVTYPE_HEAD"}, --"Zabra's Circlet of Triumph"
  [48089] = {4,258,"INVTYPE_LEGS"}, --"Zabra's Pants of Triumph"
  [48090] = {4,258,"INVTYPE_ROBE"}, --"Zabra's Raiments of Triumph"
  [48091] = {4,258,"INVTYPE_SHOULDER"}, --"Zabra's Mantle of Triumph"
  [48092] = {4,245,"INVTYPE_SHOULDER"}, --"Zabra's Mantle of Triumph"
  [48093] = {4,245,"INVTYPE_ROBE"}, --"Zabra's Raiments of Triumph"
  [48094] = {4,245,"INVTYPE_LEGS"}, --"Zabra's Pants of Triumph"
  [48095] = {4,245,"INVTYPE_HEAD"}, --"Zabra's Circlet of Triumph"
  [48096] = {4,245,"INVTYPE_HAND"}, --"Zabra's Handwraps of Triumph"
  [48097] = {4,232,"INVTYPE_HAND"}, --"Zabra's Handwraps of Conquest"
  [48098] = {4,232,"INVTYPE_HEAD"}, --"Zabra's Circlet of Conquest"
  [48099] = {4,232,"INVTYPE_LEGS"}, --"Zabra's Pants of Conquest"
  [48100] = {4,232,"INVTYPE_ROBE"}, --"Zabra's Raiments of Conquest"
  [48101] = {4,232,"INVTYPE_SHOULDER"}, --"Zabra's Mantle of Conquest"
  [48102] = {4,232,"INVTYPE_HEAD"}, --"Malfurion's Headpiece of Conquest"
  [48129] = {4,232,"INVTYPE_ROBE"}, --"Malfurion's Robe of Conquest"
  [48130] = {4,232,"INVTYPE_LEGS"}, --"Malfurion's Leggings of Conquest"
  [48131] = {4,232,"INVTYPE_SHOULDER"}, --"Malfurion's Spaulders of Conquest"
  [48132] = {4,232,"INVTYPE_HAND"}, --"Malfurion's Handguards of Conquest"
  [48133] = {4,245,"INVTYPE_HAND"}, --"Malfurion's Handguards of Triumph"
  [48134] = {4,245,"INVTYPE_HEAD"}, --"Malfurion's Headpiece of Triumph"
  [48135] = {4,245,"INVTYPE_LEGS"}, --"Malfurion's Leggings of Triumph"
  [48136] = {4,245,"INVTYPE_ROBE"}, --"Malfurion's Robe of Triumph"
  [48137] = {4,245,"INVTYPE_SHOULDER"}, --"Malfurion's Spaulders of Triumph"
  [48138] = {4,258,"INVTYPE_SHOULDER"}, --"Malfurion's Spaulders of Triumph"
  [48139] = {4,258,"INVTYPE_ROBE"}, --"Malfurion's Robe of Triumph"
  [48140] = {4,258,"INVTYPE_LEGS"}, --"Malfurion's Leggings of Triumph"
  [48141] = {4,258,"INVTYPE_HEAD"}, --"Malfurion's Headpiece of Triumph"
  [48142] = {4,258,"INVTYPE_HAND"}, --"Malfurion's Handguards of Triumph"
  [48143] = {4,258,"INVTYPE_HAND"}, --"Runetotem's Handguards of Triumph"
  [48144] = {4,258,"INVTYPE_HEAD"}, --"Runetotem's Headpiece of Triumph"
  [48145] = {4,258,"INVTYPE_LEGS"}, --"Runetotem's Leggings of Triumph"
  [48146] = {4,258,"INVTYPE_ROBE"}, --"Runetotem's Robe of Triumph"
  [48147] = {4,258,"INVTYPE_SHOULDER"}, --"Runetotem's Spaulders of Triumph"
  [48148] = {4,245,"INVTYPE_SHOULDER"}, --"Runetotem's Spaulders of Triumph"
  [48149] = {4,245,"INVTYPE_ROBE"}, --"Runetotem's Robe of Triumph"
  [48150] = {4,245,"INVTYPE_LEGS"}, --"Runetotem's Leggings of Triumph"
  [48151] = {4,245,"INVTYPE_HEAD"}, --"Runetotem's Headpiece of Triumph"
  [48152] = {4,245,"INVTYPE_HAND"}, --"Runetotem's Handguards of Triumph"
  [48153] = {4,232,"INVTYPE_HAND"}, --"Runetotem's Handguards of Conquest"
  [48154] = {4,232,"INVTYPE_HEAD"}, --"Runetotem's Headpiece of Conquest"
  [48155] = {4,232,"INVTYPE_LEGS"}, --"Runetotem's Leggings of Conquest"
  [48156] = {4,232,"INVTYPE_ROBE"}, --"Runetotem's Robe of Conquest"
  [48157] = {4,232,"INVTYPE_SHOULDER"}, --"Runetotem's Spaulders of Conquest"
  [48158] = {4,232,"INVTYPE_HEAD"}, --"Malfurion's Cover of Conquest"
  [48159] = {4,232,"INVTYPE_ROBE"}, --"Malfurion's Vestments of Conquest"
  [48160] = {4,232,"INVTYPE_LEGS"}, --"Malfurion's Trousers of Conquest"
  [48161] = {4,232,"INVTYPE_SHOULDER"}, --"Malfurion's Mantle of Conquest"
  [48162] = {4,232,"INVTYPE_HAND"}, --"Malfurion's Gloves of Conquest"
  [48163] = {4,245,"INVTYPE_HAND"}, --"Malfurion's Gloves of Triumph"
  [48164] = {4,245,"INVTYPE_HEAD"}, --"Malfurion's Cover of Triumph"
  [48165] = {4,245,"INVTYPE_LEGS"}, --"Malfurion's Trousers of Triumph"
  [48166] = {4,245,"INVTYPE_ROBE"}, --"Malfurion's Vestments of Triumph"
  [48167] = {4,245,"INVTYPE_SHOULDER"}, --"Malfurion's Mantle of Triumph"
  [48168] = {4,258,"INVTYPE_SHOULDER"}, --"Malfurion's Mantle of Triumph"
  [48169] = {4,258,"INVTYPE_ROBE"}, --"Malfurion's Vestments of Triumph"
  [48170] = {4,258,"INVTYPE_LEGS"}, --"Malfurion's Trousers of Triumph"
  [48171] = {4,258,"INVTYPE_HEAD"}, --"Malfurion's Cover of Triumph"
  [48172] = {4,258,"INVTYPE_HAND"}, --"Malfurion's Gloves of Triumph"
  [48173] = {4,258,"INVTYPE_HAND"}, --"Runetotem's Gloves of Triumph"
  [48174] = {4,258,"INVTYPE_HEAD"}, --"Runetotem's Cover of Triumph"
  [48175] = {4,258,"INVTYPE_LEGS"}, --"Runetotem's Trousers of Triumph"
  [48176] = {4,258,"INVTYPE_ROBE"}, --"Runetotem's Vestments of Triumph"
  [48177] = {4,258,"INVTYPE_SHOULDER"}, --"Runetotem's Mantle of Triumph"
  [48178] = {4,245,"INVTYPE_SHOULDER"}, --"Runetotem's Mantle of Triumph"
  [48179] = {4,245,"INVTYPE_ROBE"}, --"Runetotem's Vestments of Triumph"
  [48180] = {4,245,"INVTYPE_LEGS"}, --"Runetotem's Trousers of Triumph"
  [48181] = {4,245,"INVTYPE_HEAD"}, --"Runetotem's Cover of Triumph"
  [48182] = {4,245,"INVTYPE_HAND"}, --"Runetotem's Gloves of Triumph"
  [48183] = {4,232,"INVTYPE_HAND"}, --"Runetotem's Gloves of Conquest"
  [48184] = {4,232,"INVTYPE_HEAD"}, --"Runetotem's Cover of Conquest"
  [48185] = {4,232,"INVTYPE_LEGS"}, --"Runetotem's Trousers of Conquest"
  [48186] = {4,232,"INVTYPE_ROBE"}, --"Runetotem's Vestments of Conquest"
  [48187] = {4,232,"INVTYPE_SHOULDER"}, --"Runetotem's Mantle of Conquest"
  [48188] = {4,232,"INVTYPE_HEAD"}, --"Runetotem's Headguard of Conquest"
  [48189] = {4,232,"INVTYPE_ROBE"}, --"Runetotem's Raiments of Conquest"
  [48190] = {4,232,"INVTYPE_LEGS"}, --"Runetotem's Legguards of Conquest"
  [48191] = {4,232,"INVTYPE_SHOULDER"}, --"Runetotem's Shoulderpads of Conquest"
  [48192] = {4,232,"INVTYPE_HAND"}, --"Runetotem's Handgrips of Conquest"
  [48193] = {4,245,"INVTYPE_HAND"}, --"Runetotem's Handgrips of Triumph"
  [48194] = {4,245,"INVTYPE_HEAD"}, --"Runetotem's Headguard of Triumph"
  [48195] = {4,245,"INVTYPE_LEGS"}, --"Runetotem's Legguards of Triumph"
  [48196] = {4,245,"INVTYPE_ROBE"}, --"Runetotem's Raiments of Triumph"
  [48197] = {4,245,"INVTYPE_SHOULDER"}, --"Runetotem's Shoulderpads of Triumph"
  [48198] = {4,258,"INVTYPE_SHOULDER"}, --"Runetotem's Shoulderpads of Triumph"
  [48199] = {4,258,"INVTYPE_ROBE"}, --"Runetotem's Raiments of Triumph"
  [48200] = {4,258,"INVTYPE_LEGS"}, --"Runetotem's Legguards of Triumph"
  [48201] = {4,258,"INVTYPE_HEAD"}, --"Runetotem's Headguard of Triumph"
  [48202] = {4,258,"INVTYPE_HAND"}, --"Runetotem's Handgrips of Triumph"
  [48203] = {4,258,"INVTYPE_HAND"}, --"Malfurion's Handgrips of Triumph"
  [48204] = {4,258,"INVTYPE_HEAD"}, --"Malfurion's Headguard of Triumph"
  [48205] = {4,258,"INVTYPE_LEGS"}, --"Malfurion's Legguards of Triumph"
  [48206] = {4,258,"INVTYPE_ROBE"}, --"Malfurion's Raiments of Triumph"
  [48207] = {4,258,"INVTYPE_SHOULDER"}, --"Malfurion's Shoulderpads of Triumph"
  [48208] = {4,245,"INVTYPE_SHOULDER"}, --"Malfurion's Shoulderpads of Triumph"
  [48209] = {4,245,"INVTYPE_ROBE"}, --"Malfurion's Raiments of Triumph"
  [48210] = {4,245,"INVTYPE_LEGS"}, --"Malfurion's Legguards of Triumph"
  [48211] = {4,245,"INVTYPE_HEAD"}, --"Malfurion's Headguard of Triumph"
  [48212] = {4,245,"INVTYPE_HAND"}, --"Malfurion's Handgrips of Triumph"
  [48213] = {4,232,"INVTYPE_HAND"}, --"Malfurion's Handgrips of Conquest"
  [48214] = {4,232,"INVTYPE_HEAD"}, --"Malfurion's Headguard of Conquest"
  [48215] = {4,232,"INVTYPE_LEGS"}, --"Malfurion's Legguards of Conquest"
  [48216] = {4,232,"INVTYPE_ROBE"}, --"Malfurion's Raiments of Conquest"
  [48217] = {4,232,"INVTYPE_SHOULDER"}, --"Malfurion's Shoulderpads of Conquest"
  [48218] = {4,232,"INVTYPE_HEAD"}, --"VanCleef's Helmet of Conquest"
  [48219] = {4,232,"INVTYPE_CHEST"}, --"VanCleef's Breastplate of Conquest"
  [48220] = {4,232,"INVTYPE_LEGS"}, --"VanCleef's Legplates of Conquest"
  [48221] = {4,232,"INVTYPE_SHOULDER"}, --"VanCleef's Pauldrons of Conquest"
  [48222] = {4,232,"INVTYPE_HAND"}, --"VanCleef's Gauntlets of Conquest"
  [48223] = {4,245,"INVTYPE_CHEST"}, --"VanCleef's Breastplate of Triumph"
  [48224] = {4,245,"INVTYPE_HAND"}, --"VanCleef's Gauntlets of Triumph"
  [48225] = {4,245,"INVTYPE_HEAD"}, --"VanCleef's Helmet of Triumph"
  [48226] = {4,245,"INVTYPE_LEGS"}, --"VanCleef's Legplates of Triumph"
  [48227] = {4,245,"INVTYPE_SHOULDER"}, --"VanCleef's Pauldrons of Triumph"
  [48228] = {4,258,"INVTYPE_SHOULDER"}, --"VanCleef's Pauldrons of Triumph"
  [48229] = {4,258,"INVTYPE_LEGS"}, --"VanCleef's Legplates of Triumph"
  [48230] = {4,258,"INVTYPE_HEAD"}, --"VanCleef's Helmet of Triumph"
  [48231] = {4,258,"INVTYPE_HAND"}, --"VanCleef's Gauntlets of Triumph"
  [48232] = {4,258,"INVTYPE_CHEST"}, --"VanCleef's Breastplate of Triumph"
  [48233] = {4,258,"INVTYPE_CHEST"}, --"Garona's Breastplate of Triumph"
  [48234] = {4,258,"INVTYPE_HAND"}, --"Garona's Gauntlets of Triumph"
  [48235] = {4,258,"INVTYPE_HEAD"}, --"Garona's Helmet of Triumph"
  [48236] = {4,258,"INVTYPE_LEGS"}, --"Garona's Legplates of Triumph"
  [48237] = {4,258,"INVTYPE_SHOULDER"}, --"Garona's Pauldrons of Triumph"
  [48238] = {4,245,"INVTYPE_SHOULDER"}, --"Garona's Pauldrons of Triumph"
  [48239] = {4,245,"INVTYPE_LEGS"}, --"Garona's Legplates of Triumph"
  [48240] = {4,245,"INVTYPE_HEAD"}, --"Garona's Helmet of Triumph"
  [48241] = {4,245,"INVTYPE_HAND"}, --"Garona's Gauntlets of Triumph"
  [48242] = {4,245,"INVTYPE_CHEST"}, --"Garona's Breastplate of Triumph"
  [48243] = {4,232,"INVTYPE_CHEST"}, --"Garona's Breastplate of Conquest"
  [48244] = {4,232,"INVTYPE_HAND"}, --"Garona's Gauntlets of Conquest"
  [48245] = {4,232,"INVTYPE_HEAD"}, --"Garona's Helmet of Conquest"
  [48246] = {4,232,"INVTYPE_LEGS"}, --"Garona's Legplates of Conquest"
  [48247] = {4,232,"INVTYPE_SHOULDER"}, --"Garona's Pauldrons of Conquest"
  [48250] = {4,232,"INVTYPE_HEAD"}, --"Windrunner's Headpiece of Conquest"
  [48251] = {4,232,"INVTYPE_CHEST"}, --"Windrunner's Tunic of Conquest"
  [48252] = {4,232,"INVTYPE_LEGS"}, --"Windrunner's Legguards of Conquest"
  [48253] = {4,232,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders of Conquest"
  [48254] = {4,232,"INVTYPE_HAND"}, --"Windrunner's Handguards of Conquest"
  [48255] = {4,245,"INVTYPE_CHEST"}, --"Windrunner's Tunic of Triumph"
  [48256] = {4,245,"INVTYPE_HAND"}, --"Windrunner's Handguards of Triumph"
  [48257] = {4,245,"INVTYPE_HEAD"}, --"Windrunner's Headpiece of Triumph"
  [48258] = {4,245,"INVTYPE_LEGS"}, --"Windrunner's Legguards of Triumph"
  [48259] = {4,245,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders of Triumph"
  [48260] = {4,258,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders of Triumph"
  [48261] = {4,258,"INVTYPE_LEGS"}, --"Windrunner's Legguards of Triumph"
  [48262] = {4,258,"INVTYPE_HEAD"}, --"Windrunner's Headpiece of Triumph"
  [48263] = {4,258,"INVTYPE_HAND"}, --"Windrunner's Handguards of Triumph"
  [48264] = {4,258,"INVTYPE_CHEST"}, --"Windrunner's Tunic of Triumph"
  [48265] = {4,258,"INVTYPE_CHEST"}, --"Windrunner's Tunic of Triumph"
  [48266] = {4,258,"INVTYPE_HAND"}, --"Windrunner's Handguards of Triumph"
  [48267] = {4,258,"INVTYPE_HEAD"}, --"Windrunner's Headpiece of Triumph"
  [48268] = {4,258,"INVTYPE_LEGS"}, --"Windrunner's Legguards of Triumph"
  [48269] = {4,258,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders of Triumph"
  [48270] = {4,245,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders of Triumph"
  [48271] = {4,245,"INVTYPE_LEGS"}, --"Windrunner's Legguards of Triumph"
  [48272] = {4,245,"INVTYPE_HEAD"}, --"Windrunner's Headpiece of Triumph"
  [48273] = {4,245,"INVTYPE_HAND"}, --"Windrunner's Handguards of Triumph"
  [48274] = {4,245,"INVTYPE_CHEST"}, --"Windrunner's Tunic of Triumph"
  [48275] = {4,232,"INVTYPE_CHEST"}, --"Windrunner's Tunic of Conquest"
  [48276] = {4,232,"INVTYPE_HAND"}, --"Windrunner's Handguards of Conquest"
  [48277] = {4,232,"INVTYPE_HEAD"}, --"Windrunner's Headpiece of Conquest"
  [48278] = {4,232,"INVTYPE_LEGS"}, --"Windrunner's Legguards of Conquest"
  [48279] = {4,232,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders of Conquest"
  [48280] = {4,232,"INVTYPE_HEAD"}, --"Nobundo's Headpiece of Conquest"
  [48281] = {4,232,"INVTYPE_CHEST"}, --"Nobundo's Tunic of Conquest"
  [48282] = {4,232,"INVTYPE_LEGS"}, --"Nobundo's Legguards of Conquest"
  [48283] = {4,232,"INVTYPE_SHOULDER"}, --"Nobundo's Spaulders of Conquest"
  [48284] = {4,232,"INVTYPE_HAND"}, --"Nobundo's Handguards of Conquest"
  [48285] = {4,245,"INVTYPE_CHEST"}, --"Nobundo's Tunic of Triumph"
  [48286] = {4,245,"INVTYPE_HAND"}, --"Nobundo's Handguards of Triumph"
  [48287] = {4,245,"INVTYPE_HEAD"}, --"Nobundo's Headpiece of Triumph"
  [48288] = {4,245,"INVTYPE_LEGS"}, --"Nobundo's Legguards of Triumph"
  [48289] = {4,245,"INVTYPE_SHOULDER"}, --"Nobundo's Spaulders of Triumph"
  [48290] = {4,258,"INVTYPE_SHOULDER"}, --"Nobundo's Spaulders of Triumph"
  [48291] = {4,258,"INVTYPE_LEGS"}, --"Nobundo's Legguards of Triumph"
  [48292] = {4,258,"INVTYPE_HEAD"}, --"Nobundo's Headpiece of Triumph"
  [48293] = {4,258,"INVTYPE_HAND"}, --"Nobundo's Handguards of Triumph"
  [48294] = {4,258,"INVTYPE_CHEST"}, --"Nobundo's Tunic of Triumph"
  [48295] = {4,232,"INVTYPE_CHEST"}, --"Thrall's Tunic of Conquest"
  [48296] = {4,232,"INVTYPE_HAND"}, --"Thrall's Handguards of Conquest"
  [48297] = {4,232,"INVTYPE_HEAD"}, --"Thrall's Headpiece of Conquest"
  [48298] = {4,232,"INVTYPE_LEGS"}, --"Thrall's Legguards of Conquest"
  [48299] = {4,232,"INVTYPE_SHOULDER"}, --"Thrall's Spaulders of Conquest"
  [48300] = {4,245,"INVTYPE_CHEST"}, --"Thrall's Tunic of Triumph"
  [48301] = {4,245,"INVTYPE_HAND"}, --"Thrall's Handguards of Triumph"
  [48302] = {4,245,"INVTYPE_HEAD"}, --"Thrall's Headpiece of Triumph"
  [48303] = {4,245,"INVTYPE_LEGS"}, --"Thrall's Legguards of Triumph"
  [48304] = {4,245,"INVTYPE_SHOULDER"}, --"Thrall's Spaulders of Triumph"
  [48305] = {4,258,"INVTYPE_CHEST"}, --"Thrall's Tunic of Triumph"
  [48306] = {4,258,"INVTYPE_HAND"}, --"Thrall's Handguards of Triumph"
  [48307] = {4,258,"INVTYPE_HEAD"}, --"Thrall's Headpiece of Triumph"
  [48308] = {4,258,"INVTYPE_LEGS"}, --"Thrall's Legguards of Triumph"
  [48309] = {4,258,"INVTYPE_SHOULDER"}, --"Thrall's Spaulders of Triumph"
  [48310] = {4,232,"INVTYPE_CHEST"}, --"Nobundo's Hauberk of Conquest"
  [48312] = {4,232,"INVTYPE_HAND"}, --"Nobundo's Gloves of Conquest"
  [48313] = {4,232,"INVTYPE_HEAD"}, --"Nobundo's Helm of Conquest"
  [48314] = {4,232,"INVTYPE_LEGS"}, --"Nobundo's Kilt of Conquest"
  [48315] = {4,232,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderpads of Conquest"
  [48316] = {4,245,"INVTYPE_CHEST"}, --"Nobundo's Hauberk of Triumph"
  [48317] = {4,245,"INVTYPE_HAND"}, --"Nobundo's Gloves of Triumph"
  [48318] = {4,245,"INVTYPE_HEAD"}, --"Nobundo's Helm of Triumph"
  [48319] = {4,245,"INVTYPE_LEGS"}, --"Nobundo's Kilt of Triumph"
  [48320] = {4,245,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderpads of Triumph"
  [48321] = {4,258,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderpads of Triumph"
  [48322] = {4,258,"INVTYPE_LEGS"}, --"Nobundo's Kilt of Triumph"
  [48323] = {4,258,"INVTYPE_HEAD"}, --"Nobundo's Helm of Triumph"
  [48324] = {4,258,"INVTYPE_HAND"}, --"Nobundo's Gloves of Triumph"
  [48325] = {4,258,"INVTYPE_CHEST"}, --"Nobundo's Hauberk of Triumph"
  [48326] = {4,258,"INVTYPE_CHEST"}, --"Thrall's Hauberk of Triumph"
  [48327] = {4,258,"INVTYPE_HAND"}, --"Thrall's Gloves of Triumph"
  [48328] = {4,258,"INVTYPE_HEAD"}, --"Thrall's Helm of Triumph"
  [48329] = {4,258,"INVTYPE_LEGS"}, --"Thrall's Kilt of Triumph"
  [48330] = {4,258,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderpads of Triumph"
  [48331] = {4,245,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderpads of Triumph"
  [48332] = {4,245,"INVTYPE_LEGS"}, --"Thrall's Kilt of Triumph"
  [48333] = {4,245,"INVTYPE_HEAD"}, --"Thrall's Helm of Triumph"
  [48334] = {4,245,"INVTYPE_HAND"}, --"Thrall's Gloves of Triumph"
  [48335] = {4,245,"INVTYPE_CHEST"}, --"Thrall's Hauberk of Triumph"
  [48336] = {4,232,"INVTYPE_CHEST"}, --"Thrall's Hauberk of Conquest"
  [48337] = {4,232,"INVTYPE_HAND"}, --"Thrall's Gloves of Conquest"
  [48338] = {4,232,"INVTYPE_HEAD"}, --"Thrall's Helm of Conquest"
  [48339] = {4,232,"INVTYPE_LEGS"}, --"Thrall's Kilt of Conquest"
  [48340] = {4,232,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderpads of Conquest"
  [48341] = {4,232,"INVTYPE_CHEST"}, --"Nobundo's Chestguard of Conquest"
  [48342] = {4,232,"INVTYPE_HAND"}, --"Nobundo's Grips of Conquest"
  [48343] = {4,232,"INVTYPE_HEAD"}, --"Nobundo's Faceguard of Conquest"
  [48344] = {4,232,"INVTYPE_LEGS"}, --"Nobundo's War-Kilt of Conquest"
  [48345] = {4,232,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderguards of Conquest"
  [48346] = {4,245,"INVTYPE_CHEST"}, --"Nobundo's Chestguard of Triumph"
  [48347] = {4,245,"INVTYPE_HAND"}, --"Nobundo's Grips of Triumph"
  [48348] = {4,245,"INVTYPE_HEAD"}, --"Nobundo's Faceguard of Triumph"
  [48349] = {4,245,"INVTYPE_LEGS"}, --"Nobundo's War-Kilt of Triumph"
  [48350] = {4,245,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderguards of Triumph"
  [48351] = {4,258,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderguards of Triumph"
  [48352] = {4,258,"INVTYPE_LEGS"}, --"Nobundo's War-Kilt of Triumph"
  [48353] = {4,258,"INVTYPE_HEAD"}, --"Nobundo's Faceguard of Triumph"
  [48354] = {4,258,"INVTYPE_HAND"}, --"Nobundo's Grips of Triumph"
  [48355] = {4,258,"INVTYPE_CHEST"}, --"Nobundo's Chestguard of Triumph"
  [48356] = {4,258,"INVTYPE_CHEST"}, --"Thrall's Chestguard of Triumph"
  [48357] = {4,258,"INVTYPE_HAND"}, --"Thrall's Grips of Triumph"
  [48358] = {4,258,"INVTYPE_HEAD"}, --"Thrall's Faceguard of Triumph"
  [48359] = {4,258,"INVTYPE_LEGS"}, --"Thrall's War-Kilt of Triumph"
  [48360] = {4,258,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderguards of Triumph"
  [48361] = {4,245,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderguards of Triumph"
  [48362] = {4,245,"INVTYPE_LEGS"}, --"Thrall's War-Kilt of Triumph"
  [48363] = {4,245,"INVTYPE_HEAD"}, --"Thrall's Faceguard of Triumph"
  [48364] = {4,245,"INVTYPE_HAND"}, --"Thrall's Grips of Triumph"
  [48365] = {4,245,"INVTYPE_CHEST"}, --"Thrall's Chestguard of Triumph"
  [48366] = {4,232,"INVTYPE_CHEST"}, --"Thrall's Chestguard of Conquest"
  [48367] = {4,232,"INVTYPE_HAND"}, --"Thrall's Grips of Conquest"
  [48368] = {4,232,"INVTYPE_HEAD"}, --"Thrall's Faceguard of Conquest"
  [48369] = {4,232,"INVTYPE_LEGS"}, --"Thrall's War-Kilt of Conquest"
  [48370] = {4,232,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderguards of Conquest"
  [48371] = {4,232,"INVTYPE_HEAD"}, --"Wrynn's Helmet of Conquest"
  [48372] = {4,232,"INVTYPE_CHEST"}, --"Wrynn's Battleplate of Conquest"
  [48373] = {4,232,"INVTYPE_LEGS"}, --"Wrynn's Legplates of Conquest"
  [48374] = {4,232,"INVTYPE_SHOULDER"}, --"Wrynn's Shoulderplates of Conquest"
  [48375] = {4,232,"INVTYPE_HAND"}, --"Wrynn's Gauntlets of Conquest"
  [48376] = {4,245,"INVTYPE_CHEST"}, --"Wrynn's Battleplate of Triumph"
  [48377] = {4,245,"INVTYPE_HAND"}, --"Wrynn's Gauntlets of Triumph"
  [48378] = {4,245,"INVTYPE_HEAD"}, --"Wrynn's Helmet of Triumph"
  [48379] = {4,245,"INVTYPE_LEGS"}, --"Wrynn's Legplates of Triumph"
  [48380] = {4,245,"INVTYPE_SHOULDER"}, --"Wrynn's Shoulderplates of Triumph"
  [48381] = {4,258,"INVTYPE_SHOULDER"}, --"Wrynn's Shoulderplates of Triumph"
  [48382] = {4,258,"INVTYPE_LEGS"}, --"Wrynn's Legplates of Triumph"
  [48383] = {4,258,"INVTYPE_HEAD"}, --"Wrynn's Helmet of Triumph"
  [48384] = {4,258,"INVTYPE_HAND"}, --"Wrynn's Gauntlets of Triumph"
  [48385] = {4,258,"INVTYPE_CHEST"}, --"Wrynn's Battleplate of Triumph"
  [48386] = {4,232,"INVTYPE_CHEST"}, --"Hellscream's Battleplate of Conquest"
  [48387] = {4,232,"INVTYPE_HAND"}, --"Hellscream's Gauntlets of Conquest"
  [48388] = {4,232,"INVTYPE_HEAD"}, --"Hellscream's Helmet of Conquest"
  [48389] = {4,232,"INVTYPE_LEGS"}, --"Hellscream's Legplates of Conquest"
  [48390] = {4,232,"INVTYPE_SHOULDER"}, --"Hellscream's Shoulderplates of Conquest"
  [48391] = {4,245,"INVTYPE_CHEST"}, --"Hellscream's Battleplate of Triumph"
  [48392] = {4,245,"INVTYPE_HAND"}, --"Hellscream's Gauntlets of Triumph"
  [48393] = {4,245,"INVTYPE_HEAD"}, --"Hellscream's Helmet of Triumph"
  [48394] = {4,245,"INVTYPE_LEGS"}, --"Hellscream's Legplates of Triumph"
  [48395] = {4,245,"INVTYPE_SHOULDER"}, --"Hellscream's Shoulderplates of Triumph"
  [48396] = {4,258,"INVTYPE_CHEST"}, --"Hellscream's Battleplate of Triumph"
  [48397] = {4,258,"INVTYPE_HAND"}, --"Hellscream's Gauntlets of Triumph"
  [48398] = {4,258,"INVTYPE_HEAD"}, --"Hellscream's Helmet of Triumph"
  [48399] = {4,258,"INVTYPE_LEGS"}, --"Hellscream's Legplates of Triumph"
  [48400] = {4,258,"INVTYPE_SHOULDER"}, --"Hellscream's Shoulderplates of Triumph"
  [48429] = {4,232,"INVTYPE_HEAD"}, --"Wrynn's Greathelm of Conquest"
  [48430] = {4,245,"INVTYPE_HEAD"}, --"Wrynn's Greathelm of Triumph"
  [48433] = {4,258,"INVTYPE_HEAD"}, --"Wrynn's Greathelm of Triumph"
  [48436] = {4,232,"INVTYPE_CHEST"}, --"Wrynn's Breastplate of Conquest"
  [48445] = {4,232,"INVTYPE_LEGS"}, --"Wrynn's Legguards of Conquest"
  [48446] = {4,245,"INVTYPE_LEGS"}, --"Wrynn's Legguards of Triumph"
  [48447] = {4,258,"INVTYPE_LEGS"}, --"Wrynn's Legguards of Triumph"
  [48448] = {4,232,"INVTYPE_SHOULDER"}, --"Wrynn's Pauldrons of Conquest"
  [48449] = {4,232,"INVTYPE_HAND"}, --"Wrynn's Handguards of Conquest"
  [48450] = {4,245,"INVTYPE_CHEST"}, --"Wrynn's Breastplate of Triumph"
  [48451] = {4,258,"INVTYPE_CHEST"}, --"Wrynn's Breastplate of Triumph"
  [48452] = {4,245,"INVTYPE_HAND"}, --"Wrynn's Handguards of Triumph"
  [48453] = {4,258,"INVTYPE_HAND"}, --"Wrynn's Handguards of Triumph"
  [48454] = {4,245,"INVTYPE_SHOULDER"}, --"Wrynn's Pauldrons of Triumph"
  [48455] = {4,258,"INVTYPE_SHOULDER"}, --"Wrynn's Pauldrons of Triumph"
  [48456] = {4,232,"INVTYPE_CHEST"}, --"Hellscream's Breastplate of Conquest"
  [48457] = {4,232,"INVTYPE_HAND"}, --"Hellscream's Handguards of Conquest"
  [48458] = {4,232,"INVTYPE_HEAD"}, --"Hellscream's Greathelm of Conquest"
  [48459] = {4,232,"INVTYPE_LEGS"}, --"Hellscream's Legguards of Conquest"
  [48460] = {4,232,"INVTYPE_SHOULDER"}, --"Hellscream's Pauldrons of Conquest"
  [48461] = {4,245,"INVTYPE_CHEST"}, --"Hellscream's Breastplate of Triumph"
  [48462] = {4,245,"INVTYPE_HAND"}, --"Hellscream's Handguards of Triumph"
  [48463] = {4,245,"INVTYPE_HEAD"}, --"Hellscream's Greathelm of Triumph"
  [48464] = {4,245,"INVTYPE_LEGS"}, --"Hellscream's Legguards of Triumph"
  [48465] = {4,245,"INVTYPE_SHOULDER"}, --"Hellscream's Pauldrons of Triumph"
  [48466] = {4,258,"INVTYPE_CHEST"}, --"Hellscream's Breastplate of Triumph"
  [48467] = {4,258,"INVTYPE_HAND"}, --"Hellscream's Handguards of Triumph"
  [48468] = {4,258,"INVTYPE_HEAD"}, --"Hellscream's Greathelm of Triumph"
  [48469] = {4,258,"INVTYPE_LEGS"}, --"Hellscream's Legguards of Triumph"
  [48470] = {4,258,"INVTYPE_SHOULDER"}, --"Hellscream's Pauldrons of Triumph"
  [48472] = {4,232,"INVTYPE_HEAD"}, --"Thassarian's Helmet of Conquest"
  [48474] = {4,232,"INVTYPE_CHEST"}, --"Thassarian's Battleplate of Conquest"
  [48476] = {4,232,"INVTYPE_LEGS"}, --"Thassarian's Legplates of Conquest"
  [48478] = {4,232,"INVTYPE_SHOULDER"}, --"Thassarian's Shoulderplates of Conquest"
  [48480] = {4,232,"INVTYPE_HAND"}, --"Thassarian's Gauntlets of Conquest"
  [48481] = {4,245,"INVTYPE_CHEST"}, --"Thassarian's Battleplate of Triumph"
  [48482] = {4,245,"INVTYPE_HAND"}, --"Thassarian's Gauntlets of Triumph"
  [48483] = {4,245,"INVTYPE_HEAD"}, --"Thassarian's Helmet of Triumph"
  [48484] = {4,245,"INVTYPE_LEGS"}, --"Thassarian's Legplates of Triumph"
  [48485] = {4,245,"INVTYPE_SHOULDER"}, --"Thassarian's Shoulderplates of Triumph"
  [48486] = {4,258,"INVTYPE_SHOULDER"}, --"Thassarian's Shoulderplates of Triumph"
  [48487] = {4,258,"INVTYPE_LEGS"}, --"Thassarian's Legplates of Triumph"
  [48488] = {4,258,"INVTYPE_HEAD"}, --"Thassarian's Helmet of Triumph"
  [48489] = {4,258,"INVTYPE_HAND"}, --"Thassarian's Gauntlets of Triumph"
  [48490] = {4,258,"INVTYPE_CHEST"}, --"Thassarian's Battleplate of Triumph"
  [48491] = {4,258,"INVTYPE_CHEST"}, --"Koltira's Battleplate of Triumph"
  [48492] = {4,258,"INVTYPE_HAND"}, --"Koltira's Gauntlets of Triumph"
  [48493] = {4,258,"INVTYPE_HEAD"}, --"Koltira's Helmet of Triumph"
  [48494] = {4,258,"INVTYPE_LEGS"}, --"Koltira's Legplates of Triumph"
  [48495] = {4,258,"INVTYPE_SHOULDER"}, --"Koltira's Shoulderplates of Triumph"
  [48496] = {4,245,"INVTYPE_SHOULDER"}, --"Koltira's Shoulderplates of Triumph"
  [48497] = {4,245,"INVTYPE_LEGS"}, --"Koltira's Legplates of Triumph"
  [48498] = {4,245,"INVTYPE_HEAD"}, --"Koltira's Helmet of Triumph"
  [48499] = {4,245,"INVTYPE_HAND"}, --"Koltira's Gauntlets of Triumph"
  [48500] = {4,245,"INVTYPE_CHEST"}, --"Koltira's Battleplate of Triumph"
  [48501] = {4,232,"INVTYPE_CHEST"}, --"Koltira's Battleplate of Conquest"
  [48502] = {4,232,"INVTYPE_HAND"}, --"Koltira's Gauntlets of Conquest"
  [48503] = {4,232,"INVTYPE_HEAD"}, --"Koltira's Helmet of Conquest"
  [48504] = {4,232,"INVTYPE_LEGS"}, --"Koltira's Legplates of Conquest"
  [48505] = {4,232,"INVTYPE_SHOULDER"}, --"Koltira's Shoulderplates of Conquest"
  [48529] = {4,232,"INVTYPE_HEAD"}, --"Thassarian's Faceguard of Conquest"
  [48531] = {4,232,"INVTYPE_CHEST"}, --"Thassarian's Chestguard of Conquest"
  [48533] = {4,232,"INVTYPE_LEGS"}, --"Thassarian's Legguards of Conquest"
  [48535] = {4,232,"INVTYPE_SHOULDER"}, --"Thassarian's Pauldrons of Conquest"
  [48537] = {4,232,"INVTYPE_HAND"}, --"Thassarian's Handguards of Conquest"
  [48538] = {4,245,"INVTYPE_CHEST"}, --"Thassarian's Chestguard of Triumph"
  [48539] = {4,245,"INVTYPE_HAND"}, --"Thassarian's Handguards of Triumph"
  [48540] = {4,245,"INVTYPE_HEAD"}, --"Thassarian's Faceguard of Triumph"
  [48541] = {4,245,"INVTYPE_LEGS"}, --"Thassarian's Legguards of Triumph"
  [48542] = {4,245,"INVTYPE_SHOULDER"}, --"Thassarian's Pauldrons of Triumph"
  [48543] = {4,258,"INVTYPE_SHOULDER"}, --"Thassarian's Pauldrons of Triumph"
  [48544] = {4,258,"INVTYPE_LEGS"}, --"Thassarian's Legguards of Triumph"
  [48545] = {4,258,"INVTYPE_HEAD"}, --"Thassarian's Faceguard of Triumph"
  [48546] = {4,258,"INVTYPE_HAND"}, --"Thassarian's Handguards of Triumph"
  [48547] = {4,258,"INVTYPE_CHEST"}, --"Thassarian's Chestguard of Triumph"
  [48548] = {4,258,"INVTYPE_CHEST"}, --"Koltira's Chestguard of Triumph"
  [48549] = {4,258,"INVTYPE_HAND"}, --"Koltira's Handguards of Triumph"
  [48550] = {4,258,"INVTYPE_HEAD"}, --"Koltira's Faceguard of Triumph"
  [48551] = {4,258,"INVTYPE_LEGS"}, --"Koltira's Legguards of Triumph"
  [48552] = {4,258,"INVTYPE_SHOULDER"}, --"Koltira's Pauldrons of Triumph"
  [48553] = {4,245,"INVTYPE_SHOULDER"}, --"Koltira's Pauldrons of Triumph"
  [48554] = {4,245,"INVTYPE_LEGS"}, --"Koltira's Legguards of Triumph"
  [48555] = {4,245,"INVTYPE_HEAD"}, --"Koltira's Faceguard of Triumph"
  [48556] = {4,245,"INVTYPE_HAND"}, --"Koltira's Handguards of Triumph"
  [48557] = {4,245,"INVTYPE_CHEST"}, --"Koltira's Chestguard of Triumph"
  [48558] = {4,232,"INVTYPE_CHEST"}, --"Koltira's Chestguard of Conquest"
  [48559] = {4,232,"INVTYPE_HAND"}, --"Koltira's Handguards of Conquest"
  [48560] = {4,232,"INVTYPE_HEAD"}, --"Koltira's Faceguard of Conquest"
  [48561] = {4,232,"INVTYPE_LEGS"}, --"Koltira's Legguards of Conquest"
  [48562] = {4,232,"INVTYPE_SHOULDER"}, --"Koltira's Pauldrons of Conquest"
  [48564] = {4,232,"INVTYPE_HEAD"}, --"Turalyon's Headpiece of Conquest"
  [48566] = {4,232,"INVTYPE_CHEST"}, --"Turalyon's Tunic of Conquest"
  [48568] = {4,232,"INVTYPE_LEGS"}, --"Turalyon's Greaves of Conquest"
  [48572] = {4,232,"INVTYPE_SHOULDER"}, --"Turalyon's Spaulders of Conquest"
  [48574] = {4,232,"INVTYPE_HAND"}, --"Turalyon's Gloves of Conquest"
  [48575] = {4,245,"INVTYPE_CHEST"}, --"Turalyon's Tunic of Triumph"
  [48576] = {4,245,"INVTYPE_HAND"}, --"Turalyon's Gloves of Triumph"
  [48577] = {4,245,"INVTYPE_HEAD"}, --"Turalyon's Headpiece of Triumph"
  [48578] = {4,245,"INVTYPE_LEGS"}, --"Turalyon's Greaves of Triumph"
  [48579] = {4,245,"INVTYPE_SHOULDER"}, --"Turalyon's Spaulders of Triumph"
  [48580] = {4,258,"INVTYPE_SHOULDER"}, --"Turalyon's Spaulders of Triumph"
  [48581] = {4,258,"INVTYPE_LEGS"}, --"Turalyon's Greaves of Triumph"
  [48582] = {4,258,"INVTYPE_HEAD"}, --"Turalyon's Headpiece of Triumph"
  [48583] = {4,258,"INVTYPE_HAND"}, --"Turalyon's Gloves of Triumph"
  [48584] = {4,258,"INVTYPE_CHEST"}, --"Turalyon's Tunic of Triumph"
  [48585] = {4,258,"INVTYPE_SHOULDER"}, --"Liadrin's Spaulders of Triumph"
  [48586] = {4,258,"INVTYPE_LEGS"}, --"Liadrin's Greaves of Triumph"
  [48587] = {4,258,"INVTYPE_HEAD"}, --"Liadrin's Headpiece of Triumph"
  [48588] = {4,258,"INVTYPE_HAND"}, --"Liadrin's Gloves of Triumph"
  [48589] = {4,258,"INVTYPE_CHEST"}, --"Liadrin's Tunic of Triumph"
  [48590] = {4,245,"INVTYPE_SHOULDER"}, --"Liadrin's Spaulders of Triumph"
  [48591] = {4,245,"INVTYPE_LEGS"}, --"Liadrin's Greaves of Triumph"
  [48592] = {4,245,"INVTYPE_HEAD"}, --"Liadrin's Headpiece of Triumph"
  [48593] = {4,245,"INVTYPE_HAND"}, --"Liadrin's Gloves of Triumph"
  [48594] = {4,245,"INVTYPE_CHEST"}, --"Liadrin's Tunic of Triumph"
  [48595] = {4,232,"INVTYPE_SHOULDER"}, --"Liadrin's Spaulders of Conquest"
  [48596] = {4,232,"INVTYPE_LEGS"}, --"Liadrin's Greaves of Conquest"
  [48597] = {4,232,"INVTYPE_HEAD"}, --"Liadrin's Headpiece of Conquest"
  [48598] = {4,232,"INVTYPE_HAND"}, --"Liadrin's Gloves of Conquest"
  [48599] = {4,232,"INVTYPE_CHEST"}, --"Liadrin's Tunic of Conquest"
  [48602] = {4,232,"INVTYPE_CHEST"}, --"Turalyon's Battleplate of Conquest"
  [48603] = {4,232,"INVTYPE_HAND"}, --"Turalyon's Gauntlets of Conquest"
  [48604] = {4,232,"INVTYPE_HEAD"}, --"Turalyon's Helm of Conquest"
  [48605] = {4,232,"INVTYPE_LEGS"}, --"Turalyon's Legplates of Conquest"
  [48606] = {4,232,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderplates of Conquest"
  [48607] = {4,245,"INVTYPE_CHEST"}, --"Turalyon's Battleplate of Triumph"
  [48608] = {4,245,"INVTYPE_HAND"}, --"Turalyon's Gauntlets of Triumph"
  [48609] = {4,245,"INVTYPE_HEAD"}, --"Turalyon's Helm of Triumph"
  [48610] = {4,245,"INVTYPE_LEGS"}, --"Turalyon's Legplates of Triumph"
  [48611] = {4,245,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderplates of Triumph"
  [48612] = {4,258,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderplates of Triumph"
  [48613] = {4,258,"INVTYPE_LEGS"}, --"Turalyon's Legplates of Triumph"
  [48614] = {4,258,"INVTYPE_HEAD"}, --"Turalyon's Helm of Triumph"
  [48615] = {4,258,"INVTYPE_HAND"}, --"Turalyon's Gauntlets of Triumph"
  [48616] = {4,258,"INVTYPE_CHEST"}, --"Turalyon's Battleplate of Triumph"
  [48617] = {4,258,"INVTYPE_CHEST"}, --"Liadrin's Battleplate of Triumph"
  [48618] = {4,258,"INVTYPE_HAND"}, --"Liadrin's Gauntlets of Triumph"
  [48619] = {4,258,"INVTYPE_HEAD"}, --"Liadrin's Helm of Triumph"
  [48620] = {4,258,"INVTYPE_LEGS"}, --"Liadrin's Legplates of Triumph"
  [48621] = {4,258,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderplates of Triumph"
  [48622] = {4,245,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderplates of Triumph"
  [48623] = {4,245,"INVTYPE_LEGS"}, --"Liadrin's Legplates of Triumph"
  [48624] = {4,245,"INVTYPE_HEAD"}, --"Liadrin's Helm of Triumph"
  [48625] = {4,245,"INVTYPE_HAND"}, --"Liadrin's Gauntlets of Triumph"
  [48626] = {4,245,"INVTYPE_CHEST"}, --"Liadrin's Battleplate of Triumph"
  [48627] = {4,232,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderplates of Conquest"
  [48628] = {4,232,"INVTYPE_LEGS"}, --"Liadrin's Legplates of Conquest"
  [48629] = {4,232,"INVTYPE_HEAD"}, --"Liadrin's Helm of Conquest"
  [48630] = {4,232,"INVTYPE_HAND"}, --"Liadrin's Gauntlets of Conquest"
  [48631] = {4,232,"INVTYPE_CHEST"}, --"Liadrin's Battleplate of Conquest"
  [48632] = {4,232,"INVTYPE_CHEST"}, --"Turalyon's Breastplate of Conquest"
  [48633] = {4,232,"INVTYPE_HAND"}, --"Turalyon's Handguards of Conquest"
  [48634] = {4,232,"INVTYPE_HEAD"}, --"Turalyon's Faceguard of Conquest"
  [48635] = {4,232,"INVTYPE_LEGS"}, --"Turalyon's Legguards of Conquest"
  [48636] = {4,232,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderguards of Conquest"
  [48637] = {4,245,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderguards of Triumph"
  [48638] = {4,245,"INVTYPE_LEGS"}, --"Turalyon's Legguards of Triumph"
  [48639] = {4,245,"INVTYPE_HEAD"}, --"Turalyon's Faceguard of Triumph"
  [48640] = {4,245,"INVTYPE_HAND"}, --"Turalyon's Handguards of Triumph"
  [48641] = {4,245,"INVTYPE_CHEST"}, --"Turalyon's Breastplate of Triumph"
  [48642] = {4,258,"INVTYPE_CHEST"}, --"Turalyon's Breastplate of Triumph"
  [48643] = {4,258,"INVTYPE_HAND"}, --"Turalyon's Handguards of Triumph"
  [48644] = {4,258,"INVTYPE_HEAD"}, --"Turalyon's Faceguard of Triumph"
  [48645] = {4,258,"INVTYPE_LEGS"}, --"Turalyon's Legguards of Triumph"
  [48646] = {4,258,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderguards of Triumph"
  [48647] = {4,258,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderguards of Triumph"
  [48648] = {4,258,"INVTYPE_LEGS"}, --"Liadrin's Legguards of Triumph"
  [48649] = {4,258,"INVTYPE_HEAD"}, --"Liadrin's Faceguard of Triumph"
  [48650] = {4,258,"INVTYPE_HAND"}, --"Liadrin's Handguards of Triumph"
  [48651] = {4,258,"INVTYPE_CHEST"}, --"Liadrin's Breastplate of Triumph"
  [48652] = {4,232,"INVTYPE_CHEST"}, --"Liadrin's Breastplate of Conquest"
  [48653] = {4,232,"INVTYPE_HAND"}, --"Liadrin's Handguards of Conquest"
  [48654] = {4,232,"INVTYPE_HEAD"}, --"Liadrin's Faceguard of Conquest"
  [48655] = {4,232,"INVTYPE_LEGS"}, --"Liadrin's Legguards of Conquest"
  [48656] = {4,232,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderguards of Conquest"
  [48657] = {4,245,"INVTYPE_CHEST"}, --"Liadrin's Breastplate of Triumph"
  [48658] = {4,245,"INVTYPE_HAND"}, --"Liadrin's Handguards of Triumph"
  [48659] = {4,245,"INVTYPE_HEAD"}, --"Liadrin's Faceguard of Triumph"
  [48660] = {4,245,"INVTYPE_LEGS"}, --"Liadrin's Legguards of Triumph"
  [48661] = {4,245,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderguards of Triumph"
  [48663] = {4,226,"INVTYPE_WEAPON"}, --"Tankard O' Terror"
  [48666] = {4,258,"INVTYPE_CLOAK"}, --"Drape of the Sunreavers"
  [48667] = {4,258,"INVTYPE_CLOAK"}, --"Shawl of the Devout Crusader"
  [48668] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of Serrated Blades"
  [48669] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of the Triumphant Combatant"
  [48670] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of the Unflinching Guardian"
  [48671] = {4,258,"INVTYPE_CLOAK"}, --"Drape of Bitter Incantation"
  [48672] = {4,258,"INVTYPE_CLOAK"}, --"Shawl of Fervent Crusader"
  [48673] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of the Silver Covenant"
  [48674] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of the Victorious Combatant"
  [48675] = {4,258,"INVTYPE_CLOAK"}, --"Cloak of the Unmoving Guardian"
  [48693] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Heartsmasher"
  [48695] = {4,245,"INVTYPE_2HWEAPON"}, --"Mor'kosh, the Bloodreaver"
  [48697] = {4,245,"INVTYPE_RANGED"}, --"Frenzystrike Longbow"
  [48699] = {4,245,"INVTYPE_WEAPON"}, --"Blood and Glory"
  [48701] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Spellharvest"
  [48703] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"The Facebreaker"
  [48705] = {4,245,"INVTYPE_2HWEAPON"}, --"Attrition"
  [48708] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Spellstorm Blade"
  [48709] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Heartcrusher"
  [48710] = {4,245,"INVTYPE_2HWEAPON"}, --"Paragon's Breadth"
  [48711] = {4,245,"INVTYPE_RANGED"}, --"Rhok'shalla, the Shadow's Bane"
  [48712] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"The Spinebreaker"
  [48713] = {4,245,"INVTYPE_2HWEAPON"}, --"Lothar's Edge"
  [48714] = {4,245,"INVTYPE_WEAPON"}, --"Honor of the Fallen"
  [48722] = {4,245,"INVTYPE_TRINKET"}, --"Shard of the Crystal Heart"
  [48724] = {4,245,"INVTYPE_TRINKET"}, --"Talisman of Resurgence"
  [48725] = {4,232,"INVTYPE_HAND"}, --"Khadgar's Gauntlets "
  [48726] = {4,232,"INVTYPE_HEAD"}, --"Khadgar's Hood "
  [48727] = {4,232,"INVTYPE_LEGS"}, --"Khadgar's Leggings "
  [48728] = {4,232,"INVTYPE_ROBE"}, --"Khadgar's Robe "
  [48729] = {4,232,"INVTYPE_SHOULDER"}, --"Khadgar's Shoulderpads "
  [48730] = {4,232,"INVTYPE_HAND"}, --"Sunstrider's Gauntlets "
  [48731] = {4,232,"INVTYPE_HEAD"}, --"Sunstrider's Hood "
  [48732] = {4,232,"INVTYPE_LEGS"}, --"Sunstrider's Leggings "
  [48733] = {4,232,"INVTYPE_ROBE"}, --"Sunstrider's Robe "
  [48734] = {4,232,"INVTYPE_SHOULDER"}, --"Sunstrider's Shoulderpads "
  [48735] = {4,232,"INVTYPE_HAND"}, --"Gul'dan's Gloves "
  [48736] = {4,232,"INVTYPE_HEAD"}, --"Gul'dan's Hood "
  [48737] = {4,232,"INVTYPE_LEGS"}, --"Gul'dan's Leggings "
  [48738] = {4,232,"INVTYPE_ROBE"}, --"Gul'dan's Robe "
  [48739] = {4,232,"INVTYPE_SHOULDER"}, --"Gul'dan's Shoulderpads "
  [48740] = {4,232,"INVTYPE_HAND"}, --"Kel'Thuzad's Gloves "
  [48741] = {4,232,"INVTYPE_HEAD"}, --"Kel'Thuzad's Hood "
  [48742] = {4,232,"INVTYPE_LEGS"}, --"Kel'Thuzad's Leggings "
  [48743] = {4,232,"INVTYPE_ROBE"}, --"Kel'Thuzad's Robe "
  [48744] = {4,232,"INVTYPE_SHOULDER"}, --"Kel'Thuzad's Shoulderpads "
  [48745] = {4,232,"INVTYPE_HEAD"}, --"Velen's Cowl "
  [48746] = {4,232,"INVTYPE_HAND"}, --"Velen's Gloves "
  [48747] = {4,232,"INVTYPE_LEGS"}, --"Velen's Leggings "
  [48748] = {4,232,"INVTYPE_ROBE"}, --"Velen's Robe "
  [48749] = {4,232,"INVTYPE_SHOULDER"}, --"Velen's Shoulderpads "
  [48750] = {4,232,"INVTYPE_HEAD"}, --"Zabra's Cowl "
  [48751] = {4,232,"INVTYPE_HAND"}, --"Zabra's Gloves "
  [48752] = {4,232,"INVTYPE_LEGS"}, --"Zabra's Leggings "
  [48753] = {4,232,"INVTYPE_ROBE"}, --"Zabra's Robe "
  [48754] = {4,232,"INVTYPE_SHOULDER"}, --"Zabra's Shoulderpads "
  [48755] = {4,232,"INVTYPE_HEAD"}, --"Velen's Circlet "
  [48756] = {4,232,"INVTYPE_HAND"}, --"Velen's Handwraps "
  [48757] = {4,232,"INVTYPE_SHOULDER"}, --"Velen's Mantle "
  [48758] = {4,232,"INVTYPE_LEGS"}, --"Velen's Pants "
  [48759] = {4,232,"INVTYPE_ROBE"}, --"Velen's Raiments "
  [48760] = {4,232,"INVTYPE_HEAD"}, --"Zabra's Circlet "
  [48761] = {4,232,"INVTYPE_HAND"}, --"Zabra's Handwraps "
  [48762] = {4,232,"INVTYPE_SHOULDER"}, --"Zabra's Mantle "
  [48763] = {4,232,"INVTYPE_LEGS"}, --"Zabra's Pants "
  [48764] = {4,232,"INVTYPE_ROBE"}, --"Zabra's Raiments "
  [48769] = {4,232,"INVTYPE_HAND"}, --"Runetotem's Handguards "
  [48770] = {4,232,"INVTYPE_HEAD"}, --"Runetotem's Headpiece "
  [48771] = {4,232,"INVTYPE_LEGS"}, --"Runetotem's Leggings "
  [48772] = {4,232,"INVTYPE_ROBE"}, --"Runetotem's Robe "
  [48773] = {4,232,"INVTYPE_SHOULDER"}, --"Runetotem's Spaulders "
  [48774] = {4,232,"INVTYPE_HAND"}, --"Malfurion's Handguards "
  [48775] = {4,232,"INVTYPE_HEAD"}, --"Malfurion's Headpiece "
  [48776] = {4,232,"INVTYPE_LEGS"}, --"Malfurion's Leggings "
  [48777] = {4,232,"INVTYPE_ROBE"}, --"Malfurion's Robe "
  [48778] = {4,232,"INVTYPE_SHOULDER"}, --"Malfurion's Spaulders "
  [48781] = {4,232,"INVTYPE_HEAD"}, --"Runetotem's Cover "
  [48782] = {4,232,"INVTYPE_HAND"}, --"Runetotem's Gloves "
  [48783] = {4,232,"INVTYPE_SHOULDER"}, --"Runetotem's Mantle "
  [48784] = {4,232,"INVTYPE_LEGS"}, --"Runetotem's Trousers "
  [48785] = {4,232,"INVTYPE_ROBE"}, --"Runetotem's Vestments "
  [48786] = {4,232,"INVTYPE_HEAD"}, --"Malfurion's Cover "
  [48787] = {4,232,"INVTYPE_HAND"}, --"Malfurion's Gloves "
  [48788] = {4,232,"INVTYPE_SHOULDER"}, --"Malfurion's Mantle "
  [48789] = {4,232,"INVTYPE_LEGS"}, --"Malfurion's Trousers "
  [48790] = {4,232,"INVTYPE_ROBE"}, --"Malfurion's Vestments "
  [48794] = {4,232,"INVTYPE_HAND"}, --"Runetotem's Handgrips "
  [48795] = {4,232,"INVTYPE_HEAD"}, --"Runetotem's Headguard "
  [48796] = {4,232,"INVTYPE_LEGS"}, --"Runetotem's Legguards "
  [48797] = {4,232,"INVTYPE_ROBE"}, --"Runetotem's Raiments "
  [48798] = {4,232,"INVTYPE_SHOULDER"}, --"Runetotem's Shoulderpads "
  [48799] = {4,232,"INVTYPE_HAND"}, --"Malfurion's Handgrips "
  [48800] = {4,232,"INVTYPE_HEAD"}, --"Malfurion's Headguard "
  [48801] = {4,232,"INVTYPE_LEGS"}, --"Malfurion's Legguards "
  [48802] = {4,232,"INVTYPE_ROBE"}, --"Malfurion's Raiments "
  [48803] = {4,232,"INVTYPE_SHOULDER"}, --"Malfurion's Shoulderpads "
  [48804] = {4,232,"INVTYPE_CHEST"}, --"Garona's Breastplate "
  [48805] = {4,232,"INVTYPE_HAND"}, --"Garona's Gauntlets "
  [48806] = {4,232,"INVTYPE_HEAD"}, --"Garona's Helmet "
  [48807] = {4,232,"INVTYPE_LEGS"}, --"Garona's Legplates "
  [48808] = {4,232,"INVTYPE_SHOULDER"}, --"Garona's Pauldrons "
  [48809] = {4,232,"INVTYPE_CHEST"}, --"VanCleef's Breastplate "
  [48810] = {4,232,"INVTYPE_HAND"}, --"VanCleef's Gauntlets "
  [48811] = {4,232,"INVTYPE_HEAD"}, --"VanCleef's Helmet "
  [48812] = {4,232,"INVTYPE_LEGS"}, --"VanCleef's Legplates "
  [48813] = {4,232,"INVTYPE_SHOULDER"}, --"VanCleef's Pauldrons "
  [48814] = {4,232,"INVTYPE_HAND"}, --"Windrunner's Handguards "
  [48815] = {4,232,"INVTYPE_HEAD"}, --"Windrunner's Headpiece "
  [48816] = {4,232,"INVTYPE_LEGS"}, --"Windrunner's Legguards "
  [48817] = {4,232,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders "
  [48818] = {4,232,"INVTYPE_CHEST"}, --"Windrunner's Tunic "
  [48819] = {4,232,"INVTYPE_HAND"}, --"Windrunner's Handguards "
  [48820] = {4,232,"INVTYPE_HEAD"}, --"Windrunner's Headpiece "
  [48821] = {4,232,"INVTYPE_LEGS"}, --"Windrunner's Legguards "
  [48822] = {4,232,"INVTYPE_SHOULDER"}, --"Windrunner's Spaulders "
  [48823] = {4,232,"INVTYPE_CHEST"}, --"Windrunner's Tunic "
  [48824] = {4,232,"INVTYPE_HAND"}, --"Nobundo's Handguards "
  [48825] = {4,232,"INVTYPE_HEAD"}, --"Nobundo's Headpiece "
  [48826] = {4,232,"INVTYPE_LEGS"}, --"Nobundo's Legguards "
  [48827] = {4,232,"INVTYPE_SHOULDER"}, --"Nobundo's Spaulders "
  [48828] = {4,232,"INVTYPE_CHEST"}, --"Nobundo's Tunic "
  [48829] = {4,232,"INVTYPE_HAND"}, --"Thrall's Handguards "
  [48830] = {4,232,"INVTYPE_HEAD"}, --"Thrall's Headpiece "
  [48831] = {4,232,"INVTYPE_LEGS"}, --"Thrall's Legguards "
  [48832] = {4,232,"INVTYPE_SHOULDER"}, --"Thrall's Spaulders "
  [48833] = {4,232,"INVTYPE_CHEST"}, --"Thrall's Tunic "
  [48836] = {4,232,"INVTYPE_HAND"}, --"Nobundo's Gloves "
  [48837] = {4,232,"INVTYPE_CHEST"}, --"Nobundo's Hauberk "
  [48838] = {4,232,"INVTYPE_HEAD"}, --"Nobundo's Helm "
  [48839] = {4,232,"INVTYPE_LEGS"}, --"Nobundo's Kilt "
  [48840] = {4,232,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderpads "
  [48841] = {4,232,"INVTYPE_HAND"}, --"Thrall's Gloves "
  [48842] = {4,232,"INVTYPE_CHEST"}, --"Thrall's Hauberk "
  [48843] = {4,232,"INVTYPE_HEAD"}, --"Thrall's Helm "
  [48844] = {4,232,"INVTYPE_LEGS"}, --"Thrall's Kilt "
  [48845] = {4,232,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderpads "
  [48846] = {4,232,"INVTYPE_CHEST"}, --"Nobundo's Chestguard "
  [48847] = {4,232,"INVTYPE_HEAD"}, --"Nobundo's Faceguard "
  [48848] = {4,232,"INVTYPE_HAND"}, --"Nobundo's Grips "
  [48849] = {4,232,"INVTYPE_SHOULDER"}, --"Nobundo's Shoulderguards "
  [48850] = {4,232,"INVTYPE_LEGS"}, --"Nobundo's War-Kilt "
  [48851] = {4,232,"INVTYPE_CHEST"}, --"Thrall's Chestguard "
  [48852] = {4,232,"INVTYPE_HEAD"}, --"Thrall's Faceguard "
  [48853] = {4,232,"INVTYPE_HAND"}, --"Thrall's Grips "
  [48854] = {4,232,"INVTYPE_SHOULDER"}, --"Thrall's Shoulderguards "
  [48855] = {4,232,"INVTYPE_LEGS"}, --"Thrall's War-Kilt "
  [48860] = {4,232,"INVTYPE_CHEST"}, --"Hellscream's Battleplate "
  [48861] = {4,232,"INVTYPE_HAND"}, --"Hellscream's Gauntlets "
  [48862] = {4,232,"INVTYPE_HEAD"}, --"Hellscream's Helmet "
  [48863] = {4,232,"INVTYPE_LEGS"}, --"Hellscream's Legplates "
  [48864] = {4,232,"INVTYPE_SHOULDER"}, --"Hellscream's Shoulderplates "
  [48865] = {4,232,"INVTYPE_CHEST"}, --"Wrynn's Battleplate "
  [48866] = {4,232,"INVTYPE_HAND"}, --"Wrynn's Gauntlets "
  [48867] = {4,232,"INVTYPE_HEAD"}, --"Wrynn's Helmet "
  [48868] = {4,232,"INVTYPE_LEGS"}, --"Wrynn's Legplates "
  [48869] = {4,232,"INVTYPE_SHOULDER"}, --"Wrynn's Shoulderplates "
  [48870] = {4,232,"INVTYPE_CHEST"}, --"Hellscream's Breastplate "
  [48871] = {4,232,"INVTYPE_HEAD"}, --"Hellscream's Greathelm "
  [48872] = {4,232,"INVTYPE_HAND"}, --"Hellscream's Handguards "
  [48873] = {4,232,"INVTYPE_LEGS"}, --"Hellscream's Legguards "
  [48874] = {4,232,"INVTYPE_SHOULDER"}, --"Hellscream's Pauldrons "
  [48875] = {4,232,"INVTYPE_CHEST"}, --"Wrynn's Breastplate "
  [48876] = {4,232,"INVTYPE_HEAD"}, --"Wrynn's Greathelm "
  [48877] = {4,232,"INVTYPE_HAND"}, --"Wrynn's Handguards "
  [48878] = {4,232,"INVTYPE_LEGS"}, --"Wrynn's Legguards "
  [48879] = {4,232,"INVTYPE_SHOULDER"}, --"Wrynn's Pauldrons "
  [48880] = {4,232,"INVTYPE_CHEST"}, --"Koltira's Battleplate "
  [48881] = {4,232,"INVTYPE_HAND"}, --"Koltira's Gauntlets "
  [48882] = {4,232,"INVTYPE_HEAD"}, --"Koltira's Helmet "
  [48883] = {4,232,"INVTYPE_LEGS"}, --"Koltira's Legplates "
  [48884] = {4,232,"INVTYPE_SHOULDER"}, --"Koltira's Shoulderplates "
  [48885] = {4,232,"INVTYPE_CHEST"}, --"Thassarian's Battleplate "
  [48886] = {4,232,"INVTYPE_HAND"}, --"Thassarian's Gauntlets "
  [48887] = {4,232,"INVTYPE_HEAD"}, --"Thassarian's Helmet "
  [48888] = {4,232,"INVTYPE_LEGS"}, --"Thassarian's Legplates "
  [48889] = {4,232,"INVTYPE_SHOULDER"}, --"Thassarian's Shoulderplates "
  [48890] = {4,232,"INVTYPE_CHEST"}, --"Koltira's Chestguard "
  [48891] = {4,232,"INVTYPE_HEAD"}, --"Koltira's Faceguard "
  [48892] = {4,232,"INVTYPE_HAND"}, --"Koltira's Handguards "
  [48893] = {4,232,"INVTYPE_LEGS"}, --"Koltira's Legguards "
  [48894] = {4,232,"INVTYPE_SHOULDER"}, --"Koltira's Pauldrons "
  [48895] = {4,232,"INVTYPE_CHEST"}, --"Thassarian's Chestguard "
  [48896] = {4,232,"INVTYPE_HEAD"}, --"Thassarian's Faceguard "
  [48897] = {4,232,"INVTYPE_HAND"}, --"Thassarian's Handguards "
  [48898] = {4,232,"INVTYPE_LEGS"}, --"Thassarian's Legguards "
  [48899] = {4,232,"INVTYPE_SHOULDER"}, --"Thassarian's Pauldrons "
  [48900] = {4,232,"INVTYPE_CHEST"}, --"Turalyon's Tunic "
  [48901] = {4,232,"INVTYPE_SHOULDER"}, --"Turalyon's Spaulders "
  [48902] = {4,232,"INVTYPE_HEAD"}, --"Turalyon's Headpiece "
  [48903] = {4,232,"INVTYPE_LEGS"}, --"Turalyon's Greaves "
  [48904] = {4,232,"INVTYPE_HAND"}, --"Turalyon's Gloves "
  [48905] = {4,232,"INVTYPE_CHEST"}, --"Liadrin's Tunic "
  [48906] = {4,232,"INVTYPE_SHOULDER"}, --"Liadrin's Spaulders "
  [48907] = {4,232,"INVTYPE_HEAD"}, --"Liadrin's Headpiece "
  [48908] = {4,232,"INVTYPE_LEGS"}, --"Liadrin's Greaves "
  [48909] = {4,232,"INVTYPE_HAND"}, --"Liadrin's Gloves "
  [48910] = {4,232,"INVTYPE_CHEST"}, --"Liadrin's Battleplate "
  [48911] = {4,232,"INVTYPE_HAND"}, --"Liadrin's Gauntlets "
  [48912] = {4,232,"INVTYPE_HEAD"}, --"Liadrin's Helm "
  [48913] = {4,232,"INVTYPE_LEGS"}, --"Liadrin's Legplates "
  [48914] = {4,232,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderplates "
  [48915] = {4,232,"INVTYPE_CHEST"}, --"Turalyon's Battleplate "
  [48916] = {4,232,"INVTYPE_HAND"}, --"Turalyon's Gauntlets "
  [48917] = {4,232,"INVTYPE_HEAD"}, --"Turalyon's Helm "
  [48918] = {4,232,"INVTYPE_LEGS"}, --"Turalyon's Legplates "
  [48919] = {4,232,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderplates "
  [48922] = {4,232,"INVTYPE_CHEST"}, --"Liadrin's Breastplate "
  [48923] = {4,232,"INVTYPE_HEAD"}, --"Liadrin's Faceguard "
  [48924] = {4,232,"INVTYPE_HAND"}, --"Liadrin's Handguards "
  [48925] = {4,232,"INVTYPE_LEGS"}, --"Liadrin's Legguards "
  [48926] = {4,232,"INVTYPE_SHOULDER"}, --"Liadrin's Shoulderguards "
  [48927] = {4,232,"INVTYPE_CHEST"}, --"Turalyon's Breastplate "
  [48928] = {4,232,"INVTYPE_HEAD"}, --"Turalyon's Faceguard "
  [48929] = {4,232,"INVTYPE_HAND"}, --"Turalyon's Handguards "
  [48930] = {4,232,"INVTYPE_LEGS"}, --"Turalyon's Legguards "
  [48931] = {4,232,"INVTYPE_SHOULDER"}, --"Turalyon's Shoulderguards "
  [48954] = {4,232,"INVTYPE_FINGER"}, --"Etched Band of the Kirin Tor"
  [48955] = {4,232,"INVTYPE_FINGER"}, --"Etched Loop of the Kirin Tor"
  [48956] = {4,232,"INVTYPE_FINGER"}, --"Etched Ring of the Kirin Tor"
  [48957] = {4,232,"INVTYPE_FINGER"}, --"Etched Signet of the Kirin Tor"
  [49024] = {4,200,"INVTYPE_WEAPON"}, --"Monster - Ironforge Smasher (Light)"
  [49074] = {4,200,"INVTYPE_TRINKET"}, --"Coren's Chromium Coaster"
  [49076] = {4,200,"INVTYPE_TRINKET"}, --"Mithril Pocketwatch"
  [49078] = {4,200,"INVTYPE_TRINKET"}, --"Ancient Pickled Egg"
  [49080] = {4,200,"INVTYPE_TRINKET"}, --"Brawler's Souvenir"
  [49116] = {4,200,"INVTYPE_TRINKET"}, --"Bitter Balebrew Charm"
  [49118] = {4,200,"INVTYPE_TRINKET"}, --"Bubbling Brightbrew Charm"
  [49120] = {4,200,"INVTYPE_WEAPON"}, --"Direbrew's Bloody Shanker"
  [49121] = {4,200,"INVTYPE_FINGER"}, --"Ring of Ghoulish Glee"
  [49123] = {4,200,"INVTYPE_FINGER"}, --"The Horseman's Seal"
  [49124] = {4,200,"INVTYPE_FINGER"}, --"Wicked Witch's Band"
  [49126] = {4,200,"INVTYPE_HEAD"}, --"The Horseman's Horrific Helm"
  [49128] = {4,200,"INVTYPE_WEAPONMAINHAND"}, --"The Horseman's Baleful Blade"
  [49231] = {4,232,"INVTYPE_FEET"}, --"Boots of the Grieving Soul"
  [49232] = {4,232,"INVTYPE_FEET"}, --"Sandals of the Grieving Soul"
  [49233] = {4,245,"INVTYPE_FEET"}, --"Sandals of the Grieving Soul"
  [49234] = {4,245,"INVTYPE_FEET"}, --"Boots of the Grieving Soul"
  [49235] = {4,232,"INVTYPE_FEET"}, --"Boots of Tortured Space"
  [49236] = {4,232,"INVTYPE_FEET"}, --"Sabatons of Tortured Space"
  [49237] = {4,245,"INVTYPE_FEET"}, --"Sabatons of Tortured Space"
  [49238] = {4,245,"INVTYPE_FEET"}, --"Boots of Tortured Space"
  [49292] = {4,213,"INVTYPE_WEAPON"}, --"Monster - Sword - Forgemaster 2h "
  [49293] = {4,200,"INVTYPE_2HWEAPON"}, --"Monster - Demise w/ Frost Enchant"
  [49296] = {4,232,"INVTYPE_WEAPON"}, --"Singed Vis'kag the Bloodletter"
  [49297] = {4,232,"INVTYPE_WEAPON"}, --"Empowered Deathbringer"
  [49298] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Glinting Azuresong Mageblade"
  [49299] = {4,232,"INVTYPE_2HWEAPON"}, --"Keen Obsidian Edged Blade"
  [49301] = {4,232,"INVTYPE_2HWEAPON"}, --"Reclaimed Thunderstrike"
  [49302] = {4,232,"INVTYPE_2HWEAPON"}, --"Reclaimed Shadowstrike"
  [49303] = {4,232,"INVTYPE_WEAPON"}, --"Gleaming Quel'Serrar"
  [49304] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Sharpened Fang of the Mystics"
  [49305] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Snub-Nose Blastershot Launcher"
  [49306] = {4,232,"INVTYPE_NECK"}, --"Eskhandar's Choker"
  [49307] = {4,232,"INVTYPE_CLOAK"}, --"Fluttering Sapphiron Drape"
  [49308] = {4,232,"INVTYPE_HOLDABLE"}, --"Antique Cornerstone Grimoire"
  [49309] = {4,232,"INVTYPE_FINGER"}, --"Runed Ring of Binding"
  [49310] = {4,232,"INVTYPE_TRINKET"}, --"Purified Shard of the Scale"
  [49312] = {4,232,"INVTYPE_TRINKET"}, --"Purified Onyxia Blood Talisman"
  [49313] = {4,232,"INVTYPE_FINGER"}, --"Polished Dragonslayer's Signet"
  [49314] = {4,232,"INVTYPE_NECK"}, --"Sparkling Onyxia Tooth Pendant"
  [49315] = {4,232,"INVTYPE_HEAD"}, --"Nemesis Skullcover"
  [49316] = {4,232,"INVTYPE_HEAD"}, --"Circlet of Transcendence"
  [49317] = {4,232,"INVTYPE_HEAD"}, --"Coronet of Transcendence"
  [49318] = {4,232,"INVTYPE_HEAD"}, --"Netherwind Hood"
  [49319] = {4,232,"INVTYPE_HEAD"}, --"Dragonstalker's Helmet"
  [49320] = {4,232,"INVTYPE_HEAD"}, --"Faceguard of Wrath"
  [49321] = {4,232,"INVTYPE_HEAD"}, --"Greathelm of Wrath"
  [49322] = {4,232,"INVTYPE_HEAD"}, --"Bloodfang Mask"
  [49323] = {4,232,"INVTYPE_HEAD"}, --"Judgement Cover"
  [49324] = {4,232,"INVTYPE_HEAD"}, --"Judgement Helmet"
  [49325] = {4,232,"INVTYPE_HEAD"}, --"Judgement Helm"
  [49326] = {4,232,"INVTYPE_HEAD"}, --"Stormrage Hood"
  [49327] = {4,232,"INVTYPE_HEAD"}, --"Stormrage Antlers"
  [49328] = {4,232,"INVTYPE_HEAD"}, --"Stormrage Helm"
  [49329] = {4,232,"INVTYPE_HEAD"}, --"Gaze of Ten Storms"
  [49330] = {4,232,"INVTYPE_HEAD"}, --"Cowl of Ten Storms"
  [49331] = {4,232,"INVTYPE_HEAD"}, --"Coif of Ten Storms"
  [49332] = {4,232,"INVTYPE_HEAD"}, --"Frostforged Ringhelm"
  [49333] = {4,232,"INVTYPE_HEAD"}, --"Frostforged Helmet"
  [49357] = {4,200,"INVTYPE_WEAPON"}, --"Monster - Mace, 1H Tauren (Red, Fire)"
  [49437] = {4,232,"INVTYPE_WEAPON"}, --"Rusted Gutgore Ripper"
  [49463] = {4,232,"INVTYPE_TRINKET"}, --"Purified Shard of the Flame"
  [49464] = {4,245,"INVTYPE_TRINKET"}, --"Shiny Shard of the Flame"
  [49465] = {4,245,"INVTYPE_WEAPON"}, --"Tarnished Gutgore Ripper"
  [49466] = {4,245,"INVTYPE_HEAD"}, --"Frostforged Helm"
  [49467] = {4,245,"INVTYPE_HEAD"}, --"Frostforged Greathelm"
  [49468] = {4,245,"INVTYPE_HEAD"}, --"Helm of Ten Storms"
  [49469] = {4,245,"INVTYPE_HEAD"}, --"Crown of Ten Storms"
  [49470] = {4,245,"INVTYPE_HEAD"}, --"Helmet of Ten Storms"
  [49471] = {4,245,"INVTYPE_HEAD"}, --"Stormrage Coverlet"
  [49472] = {4,245,"INVTYPE_HEAD"}, --"Stormrage Crown"
  [49473] = {4,245,"INVTYPE_HEAD"}, --"Stormrage Cover"
  [49474] = {4,245,"INVTYPE_HEAD"}, --"Judgement Hood"
  [49475] = {4,245,"INVTYPE_HEAD"}, --"Judgement Heaume"
  [49476] = {4,245,"INVTYPE_HEAD"}, --"Judgement Crown"
  [49477] = {4,245,"INVTYPE_HEAD"}, --"Bloodfang Hood"
  [49478] = {4,245,"INVTYPE_HEAD"}, --"Helmet of Wrath"
  [49479] = {4,245,"INVTYPE_HEAD"}, --"Helm of Wrath"
  [49480] = {4,245,"INVTYPE_HEAD"}, --"Dragonstalker's Helm"
  [49481] = {4,245,"INVTYPE_HEAD"}, --"Netherwind Crown"
  [49482] = {4,245,"INVTYPE_HEAD"}, --"Aurora of Transcendence"
  [49483] = {4,245,"INVTYPE_HEAD"}, --"Halo of Transcendence"
  [49484] = {4,245,"INVTYPE_HEAD"}, --"Nemesis Skullcap"
  [49485] = {4,245,"INVTYPE_NECK"}, --"Sparkling Onyxia Tooth Pendant"
  [49486] = {4,245,"INVTYPE_FINGER"}, --"Polished Dragonslayer's Signet"
  [49487] = {4,245,"INVTYPE_TRINKET"}, --"Purified Onyxia Blood Talisman"
  [49488] = {4,245,"INVTYPE_TRINKET"}, --"Shiny Shard of the Scale"
  [49489] = {4,245,"INVTYPE_FINGER"}, --"Signified Ring of Binding"
  [49490] = {4,245,"INVTYPE_HOLDABLE"}, --"Antediluvian Cornerstone Grimoire"
  [49491] = {4,245,"INVTYPE_CLOAK"}, --"Flowing Sapphiron Drape"
  [49492] = {4,245,"INVTYPE_NECK"}, --"Eskhandar's Links"
  [49493] = {4,245,"INVTYPE_RANGEDRIGHT"}, --"Rifled Blastershot Launcher"
  [49494] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Honed Fang of the Mystics"
  [49495] = {4,245,"INVTYPE_WEAPON"}, --"Burnished Quel'Serrar"
  [49496] = {4,245,"INVTYPE_2HWEAPON"}, --"Reinforced Shadowstrike"
  [49497] = {4,245,"INVTYPE_2HWEAPON"}, --"Reinforced Thunderstrike"
  [49498] = {4,245,"INVTYPE_2HWEAPON"}, --"Sharpened Obsidian Edged Blade"
  [49499] = {4,245,"INVTYPE_WEAPONMAINHAND"}, --"Polished Azuresong Mageblade"
  [49500] = {4,245,"INVTYPE_WEAPON"}, --"Raging Deathbringer"
  [49501] = {4,245,"INVTYPE_WEAPON"}, --"Tempered Vis'kag the Bloodletter"
  [49682] = {4,219,"INVTYPE_WEAPON"}, --"Black Knight's Rondel"
  [49686] = {4,277,"INVTYPE_TRINKET"}, --"Maghia's Misguided Quill"
  [49783] = {4,219,"INVTYPE_WEAPON"}, --"Lucky Old Sun"
  [49784] = {4,219,"INVTYPE_LEGS"}, --"Minister's Number One Legplates"
  [49785] = {4,219,"INVTYPE_SHOULDER"}, --"Bewildering Shoulderpads"
  [49786] = {4,219,"INVTYPE_ROBE"}, --"Robes of the Cheating Heart"
  [49787] = {4,219,"INVTYPE_WRIST"}, --"Seven Stormy Mornings"
  [49788] = {4,219,"INVTYPE_HAND"}, --"Cold Sweat Grips"
  [49789] = {4,219,"INVTYPE_WEAPON"}, --"Heartshiver"
  [49790] = {4,219,"INVTYPE_2HWEAPON"}, --"Blood Boil Lancet"
  [49791] = {4,219,"INVTYPE_CHEST"}, --"Lost Reliquary Chestguard"
  [49792] = {4,219,"INVTYPE_CLOAK"}, --"Accursed Crawling Cape"
  [49793] = {4,219,"INVTYPE_2HWEAPON"}, --"Tower of the Mouldering Corpse"
  [49794] = {4,219,"INVTYPE_LEGS"}, --"Legplates of Frozen Granite"
  [49795] = {4,219,"INVTYPE_FEET"}, --"Sollerets of Suffering"
  [49796] = {4,219,"INVTYPE_WAIST"}, --"Essence of Anger"
  [49797] = {4,219,"INVTYPE_WRIST"}, --"Brace Guards of the Starless Night"
  [49798] = {4,219,"INVTYPE_FEET"}, --"Soul Screaming Boots"
  [49799] = {4,219,"INVTYPE_NECK"}, --"Coil of Missing Gems"
  [49800] = {4,219,"INVTYPE_FINGER"}, --"Spiteful Signet"
  [49801] = {4,219,"INVTYPE_2HWEAPON"}, --"Unspeakable Secret"
  [49802] = {4,219,"INVTYPE_2HWEAPON"}, --"Garfrost's Two-Ton Hammer"
  [49803] = {4,219,"INVTYPE_FINGER"}, --"Ring of Carnelian and Bone"
  [49804] = {4,219,"INVTYPE_HEAD"}, --"Polished Mirror Helm"
  [49805] = {4,219,"INVTYPE_FEET"}, --"Ice-Steeped Sandals"
  [49806] = {4,219,"INVTYPE_WAIST"}, --"Flayer's Black Belt"
  [49807] = {4,219,"INVTYPE_WEAPON"}, --"Krick's Beetle Stabber"
  [49808] = {4,219,"INVTYPE_WAIST"}, --"Bent Gold Belt"
  [49809] = {4,219,"INVTYPE_WRIST"}, --"Wristguards of Subterranean Moss"
  [49810] = {4,219,"INVTYPE_WAIST"}, --"Scabrous Zombie Leather Belt"
  [49811] = {4,219,"INVTYPE_LEGS"}, --"Black Dragonskin Breeches"
  [49812] = {4,219,"INVTYPE_FINGER"}, --"Purloined Wedding Ring"
  [49813] = {4,219,"INVTYPE_RANGEDRIGHT"}, --"Rimebane Rifle"
  [49816] = {4,219,"INVTYPE_CHEST"}, --"Scourgelord's Frigid Chestplate"
  [49817] = {4,219,"INVTYPE_LEGS"}, --"Shaggy Wyrmleather Leggings"
  [49818] = {4,219,"INVTYPE_NECK"}, --"Painfully Sharp Choker"
  [49819] = {4,219,"INVTYPE_HEAD"}, --"Skeleton Lord's Cranium"
  [49820] = {4,219,"INVTYPE_WRIST"}, --"Gondria's Spectral Bracer"
  [49821] = {4,219,"INVTYPE_SHIELD"}, --"Protector of Frigid Souls"
  [49822] = {4,219,"INVTYPE_LEGS"}, --"Rimewoven Silks"
  [49823] = {4,219,"INVTYPE_CLOAK"}, --"Cloak of the Fallen Cardinal"
  [49824] = {4,219,"INVTYPE_HEAD"}, --"Horns of the Spurned Val'kyr"
  [49825] = {4,219,"INVTYPE_ROBE"}, --"Palebone Robes"
  [49826] = {4,219,"INVTYPE_CHEST"}, --"Shroud of Rime"
  [49827] = {4,219,"INVTYPE_WEAPON"}, --"Ghoulslicer"
  [49828] = {4,219,"INVTYPE_HAND"}, --"Marwyn's Macabre Fingertips"
  [49829] = {4,219,"INVTYPE_SHOULDER"}, --"Valonforth's Tarnished Pauldrons"
  [49830] = {4,219,"INVTYPE_HEAD"}, --"Fallen Sentry's Hood"
  [49831] = {4,219,"INVTYPE_FEET"}, --"Muddied Boots of Brill"
  [49832] = {4,219,"INVTYPE_CLOAK"}, --"Eerie Runeblade Polisher"
  [49833] = {4,219,"INVTYPE_WEAPONMAINHAND"}, --"Splintered Icecrown Parapet"
  [49834] = {4,219,"INVTYPE_SHOULDER"}, --"Frayed Abomination Stitching Shoulders"
  [49835] = {4,219,"INVTYPE_SHIELD"}, --"Splintered Door of the Citadel"
  [49836] = {4,219,"INVTYPE_LEGS"}, --"Frostsworn Bone Leggings"
  [49837] = {4,219,"INVTYPE_HAND"}, --"Mitts of Burning Hail"
  [49838] = {4,219,"INVTYPE_HAND"}, --"Carpal Tunnelers"
  [49839] = {4,219,"INVTYPE_2HWEAPON"}, --"Mourning Malice"
  [49840] = {4,219,"INVTYPE_WEAPON"}, --"Hate-Forged Cleaver"
  [49841] = {4,219,"INVTYPE_CHEST"}, --"Blackened Geist Ribs"
  [49842] = {4,219,"INVTYPE_CLOAK"}, --"Tapestry of the Frozen Throne"
  [49843] = {4,219,"INVTYPE_HAND"}, --"Crystalline Citadel Gauntlets"
  [49844] = {4,219,"INVTYPE_RANGED"}, --"Crypt Fiend Slayer"
  [49845] = {4,219,"INVTYPE_WEAPONMAINHAND"}, --"Bone Golem Scapula"
  [49846] = {4,219,"INVTYPE_WEAPONMAINHAND"}, --"Chilled Heart of the Glacier"
  [49847] = {4,219,"INVTYPE_LEGS"}, --"Legguards of Untimely Demise"
  [49848] = {4,219,"INVTYPE_SHOULDER"}, --"Grim Lasher Shoulderguards"
  [49849] = {4,219,"INVTYPE_HEAD"}, --"Tattered Glacial-Woven Hood"
  [49851] = {4,219,"INVTYPE_HEAD"}, --"Greathelm of the Silver Hand"
  [49852] = {4,219,"INVTYPE_RANGEDRIGHT"}, --"Coffin Nail"
  [49853] = {4,219,"INVTYPE_WAIST"}, --"Titanium Links of Lore"
  [49854] = {4,219,"INVTYPE_SHOULDER"}, --"Mantle of Tattered Feathers"
  [49855] = {4,219,"INVTYPE_HAND"}, --"Plated Grips of Korth'azz"
  [49888] = {4,264,"INVTYPE_2HWEAPON"}, --"Shadow's Edge"
  [49890] = {4,264,"INVTYPE_FEET"}, --"Deathfrost Boots"
  [49891] = {4,264,"INVTYPE_LEGS"}, --"Leggings of Woven Death"
  [49892] = {4,264,"INVTYPE_LEGS"}, --"Lightweave Leggings"
  [49893] = {4,264,"INVTYPE_FEET"}, --"Sandals of Consecration"
  [49894] = {4,264,"INVTYPE_FEET"}, --"Blessed Cenarion Boots"
  [49895] = {4,264,"INVTYPE_FEET"}, --"Footpads of Impending Death"
  [49896] = {4,264,"INVTYPE_FEET"}, --"Earthsoul Boots"
  [49897] = {4,264,"INVTYPE_FEET"}, --"Rock-Steady Treads"
  [49898] = {4,264,"INVTYPE_LEGS"}, --"Legwraps of Unleashed Nature"
  [49899] = {4,264,"INVTYPE_LEGS"}, --"Bladeborn Leggings"
  [49900] = {4,264,"INVTYPE_LEGS"}, --"Lightning-Infused Leggings"
  [49901] = {4,264,"INVTYPE_LEGS"}, --"Draconic Bonesplinter Legguards"
  [49902] = {4,264,"INVTYPE_LEGS"}, --"Puresteel Legplates"
  [49903] = {4,264,"INVTYPE_LEGS"}, --"Legplates of Painful Death"
  [49904] = {4,264,"INVTYPE_LEGS"}, --"Pillars of Might"
  [49905] = {4,264,"INVTYPE_FEET"}, --"Protectors of Life"
  [49906] = {4,264,"INVTYPE_FEET"}, --"Hellfrozen Bonegrinders"
  [49907] = {4,264,"INVTYPE_FEET"}, --"Boots of Kingly Upheaval"
  [49919] = {4,264,"INVTYPE_2HWEAPON"}, --"Cryptmaker"
  [49949] = {4,264,"INVTYPE_FINGER"}, --"Band of the Bone Colossus"
  [49950] = {4,264,"INVTYPE_FEET"}, --"Frostbitten Fur Boots"
  [49951] = {4,264,"INVTYPE_CHEST"}, --"Gendarme's Cuirass"
  [49952] = {4,264,"INVTYPE_HEAD"}, --"Snowserpent Mail Helm"
  [49960] = {4,264,"INVTYPE_WRIST"}, --"Bracers of Dark Reckoning"
  [49964] = {4,264,"INVTYPE_LEGS"}, --"Legguards of Lost Hope"
  [49967] = {4,264,"INVTYPE_FINGER"}, --"Marrowgar's Frigid Eye"
  [49968] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Frozen Bonespike"
  [49975] = {4,264,"INVTYPE_NECK"}, --"Bone Sentinel's Amulet"
  [49976] = {4,264,"INVTYPE_SHIELD"}, --"Bulwark of Smouldering Steel"
  [49977] = {4,264,"INVTYPE_FINGER"}, --"Loop of the Endless Labyrinth"
  [49978] = {4,264,"INVTYPE_WAIST"}, --"Crushing Coldwraith Belt"
  [49979] = {4,264,"INVTYPE_HAND"}, --"Handguards of Winter's Respite"
  [49980] = {4,264,"INVTYPE_SHOULDER"}, --"Rusted Bonespike Pauldrons"
  [49981] = {4,271,"INVTYPE_RANGEDRIGHT"}, --"Fal'inrush, Defender of Quel'thalas"
  [49982] = {4,264,"INVTYPE_WEAPON"}, --"Heartpierce"
  [49983] = {4,264,"INVTYPE_FEET"}, --"Blood-Soaked Saronite Stompers"
  [49985] = {4,264,"INVTYPE_FINGER"}, --"Juggernaut Band"
  [49986] = {4,264,"INVTYPE_HEAD"}, --"Broken Ram Skull Helm"
  [49987] = {4,264,"INVTYPE_SHOULDER"}, --"Cultist's Bloodsoaked Spaulders"
  [49988] = {4,264,"INVTYPE_LEGS"}, --"Leggings of Northern Lights"
  [49989] = {4,264,"INVTYPE_NECK"}, --"Ahn'kahar Onyx Neckguard"
  [49990] = {4,264,"INVTYPE_FINGER"}, --"Ring of Maddening Whispers"
  [49991] = {4,264,"INVTYPE_SHOULDER"}, --"Shoulders of Mercy Killing"
  [49992] = {4,264,"INVTYPE_2HWEAPON"}, --"Nibelung"
  [49993] = {4,264,"INVTYPE_FEET"}, --"Necrophotic Greaves"
  [49994] = {4,264,"INVTYPE_WRIST"}, --"The Lady's Brittle Bracers"
  [49995] = {4,264,"INVTYPE_HAND"}, --"Fallen Lord's Handguards"
  [49996] = {4,264,"INVTYPE_ROBE"}, --"Deathwhisper Raiment"
  [49997] = {4,271,"INVTYPE_WEAPON"}, --"Mithrios, Bronzebeard's Legacy"
  [49998] = {4,264,"INVTYPE_CLOAK"}, --"Shadowvault Slayer's Cloak"
  [49999] = {4,264,"INVTYPE_FINGER"}, --"Skeleton Lord's Circle"
  [50000] = {4,264,"INVTYPE_WRIST"}, --"Scourge Hunter's Vambraces"
  [50001] = {4,264,"INVTYPE_CHEST"}, --"Ikfirus's Sack of Wonder"
  [50002] = {4,264,"INVTYPE_WRIST"}, --"Polar Bear Claw Bracers"
  [50003] = {4,264,"INVTYPE_SHOULDER"}, --"Boneguard Commander's Pauldrons"
  [50005] = {4,264,"INVTYPE_NECK"}, --"Amulet of the Silent Eulogy"
  [50006] = {4,264,"INVTYPE_HEAD"}, --"Corp'rethar Ceremonial Crown"
  [50008] = {4,264,"INVTYPE_FINGER"}, --"Ring of Rapid Ascent"
  [50009] = {4,264,"INVTYPE_FEET"}, --"Boots of Unnatural Growth"
  [50010] = {4,264,"INVTYPE_WAIST"}, --"Waistband of Righteous Fury"
  [50011] = {4,264,"INVTYPE_HAND"}, --"Gunship Captain's Mittens"
  [50012] = {4,271,"INVTYPE_WEAPON"}, --"Havoc's Call, Blade of Lordaeron Kings"
  [50014] = {4,264,"INVTYPE_CLOAK"}, --"Greatcloak of the Turned Champion"
  [50015] = {4,264,"INVTYPE_WAIST"}, --"Belt of the Blood Nova"
  [50016] = {4,264,"INVTYPE_WEAPON"}, --"Rib Spreader"
  [50019] = {4,264,"INVTYPE_CLOAK"}, --"Winding Sheet"
  [50020] = {4,264,"INVTYPE_SHOULDER"}, --"Raging Behemoth's Shoulderplates"
  [50021] = {4,264,"INVTYPE_HAND"}, --"Aldriana's Gloves of Secrecy"
  [50022] = {4,264,"INVTYPE_SHOULDER"}, --"Dual-Bladed Pauldrons"
  [50023] = {4,264,"INVTYPE_NECK"}, --"Bile-Encrusted Medallion"
  [50024] = {4,264,"INVTYPE_CHEST"}, --"Blightborne Warplate"
  [50025] = {4,264,"INVTYPE_FINGER"}, --"Seal of Many Mouths"
  [50026] = {4,264,"INVTYPE_HEAD"}, --"Helm of the Elder Moon"
  [50027] = {4,264,"INVTYPE_CHEST"}, --"Rot-Resistant Breastplate"
  [50028] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Trauma"
  [50030] = {4,264,"INVTYPE_WRIST"}, --"Bloodsunder's Bracers"
  [50032] = {4,264,"INVTYPE_WRIST"}, --"Death Surgeon's Sleeves"
  [50033] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Corpse-Impaling Spike"
  [50034] = {4,264,"INVTYPE_RANGED"}, --"Zod's Repeating Longbow"
  [50035] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Black Bruise"
  [50036] = {4,264,"INVTYPE_WAIST"}, --"Belt of Broken Bones"
  [50037] = {4,264,"INVTYPE_HAND"}, --"Fleshrending Gauntlets"
  [50038] = {4,264,"INVTYPE_CHEST"}, --"Carapace of Forgotten Kings"
  [50040] = {4,264,"INVTYPE_2HWEAPON"}, --"Distant Land"
  [50041] = {4,264,"INVTYPE_LEGS"}, --"Leather of Stitched Scourge Parts"
  [50042] = {4,264,"INVTYPE_LEGS"}, --"Gangrenous Leggings"
  [50046] = {4,251,"INVTYPE_WEAPON"}, --"Quel'Delar, Cunning of the Shadows"
  [50047] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Quel'Delar, Lens of the Mind"
  [50048] = {4,251,"INVTYPE_2HWEAPON"}, --"Quel'Delar, Might of the Faithful"
  [50049] = {4,251,"INVTYPE_2HWEAPON"}, --"Quel'Delar, Ferocity of the Scorned"
  [50050] = {4,251,"INVTYPE_WEAPON"}, --"Cudgel of Furious Justice"
  [50051] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Hammer of Purified Flame"
  [50052] = {4,251,"INVTYPE_2HWEAPON"}, --"Lightborn Spire"
  [50056] = {4,264,"INVTYPE_LEGS"}, --"Plaguebringer's Stained Pants"
  [50059] = {4,264,"INVTYPE_SHOULDER"}, --"Horrific Flesh Epaulets"
  [50060] = {4,264,"INVTYPE_HEAD"}, --"Faceplate of the Forgotten"
  [50061] = {4,264,"INVTYPE_NECK"}, --"Holiday's Grace"
  [50062] = {4,264,"INVTYPE_FEET"}, --"Plague Scientist's Boots"
  [50063] = {4,264,"INVTYPE_WAIST"}, --"Lingering Illness"
  [50064] = {4,264,"INVTYPE_HAND"}, --"Unclean Surgical Gloves"
  [50065] = {4,264,"INVTYPE_SHIELD"}, --"Icecrown Glacial Wall"
  [50067] = {4,264,"INVTYPE_WAIST"}, --"Astrylian's Sutured Cinch"
  [50068] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Rigormortis"
  [50069] = {4,264,"INVTYPE_WAIST"}, --"Professor's Bloodied Smock"
  [50070] = {4,271,"INVTYPE_2HWEAPON"}, --"Glorenzelg, High-Blade of the Silver Hand"
  [50071] = {4,264,"INVTYPE_FEET"}, --"Treads of the Wasteland"
  [50072] = {4,264,"INVTYPE_HEAD"}, --"Landsoul's Horned Greathelm"
  [50073] = {4,264,"INVTYPE_HEAD"}, --"Geistlord's Punishment Sack"
  [50074] = {4,264,"INVTYPE_CLOAK"}, --"Royal Crimson Cloak"
  [50075] = {4,264,"INVTYPE_HAND"}, --"Taldaram's Plated Fists"
  [50078] = {4,251,"INVTYPE_CHEST"}, --"Ymirjar Lord's Battleplate"
  [50079] = {4,251,"INVTYPE_HAND"}, --"Ymirjar Lord's Gauntlets"
  [50080] = {4,251,"INVTYPE_HEAD"}, --"Ymirjar Lord's Helmet"
  [50081] = {4,251,"INVTYPE_LEGS"}, --"Ymirjar Lord's Legplates"
  [50082] = {4,251,"INVTYPE_SHOULDER"}, --"Ymirjar Lord's Shoulderplates"
  [50087] = {4,251,"INVTYPE_CHEST"}, --"Shadowblade Breastplate"
  [50088] = {4,251,"INVTYPE_HAND"}, --"Shadowblade Gauntlets"
  [50089] = {4,251,"INVTYPE_HEAD"}, --"Shadowblade Helmet"
  [50090] = {4,251,"INVTYPE_LEGS"}, --"Shadowblade Legplates"
  [50094] = {4,251,"INVTYPE_CHEST"}, --"Scourgelord Battleplate"
  [50095] = {4,251,"INVTYPE_HAND"}, --"Scourgelord Gauntlets"
  [50096] = {4,251,"INVTYPE_HEAD"}, --"Scourgelord Helmet"
  [50097] = {4,251,"INVTYPE_LEGS"}, --"Scourgelord Legplates"
  [50098] = {4,251,"INVTYPE_SHOULDER"}, --"Scourgelord Shoulderplates"
  [50105] = {4,251,"INVTYPE_SHOULDER"}, --"Shadowblade Pauldrons"
  [50106] = {4,251,"INVTYPE_ROBE"}, --"Lasherweave Robes"
  [50107] = {4,251,"INVTYPE_HAND"}, --"Lasherweave Gauntlets"
  [50108] = {4,251,"INVTYPE_HEAD"}, --"Lasherweave Helmet"
  [50109] = {4,251,"INVTYPE_LEGS"}, --"Lasherweave Legplates"
  [50113] = {4,251,"INVTYPE_SHOULDER"}, --"Lasherweave Pauldrons"
  [50114] = {4,251,"INVTYPE_HAND"}, --"Ahn'Kahar Blood Hunter's Handguards"
  [50115] = {4,251,"INVTYPE_HEAD"}, --"Ahn'Kahar Blood Hunter's Headpiece"
  [50116] = {4,251,"INVTYPE_LEGS"}, --"Ahn'Kahar Blood Hunter's Legguards"
  [50117] = {4,251,"INVTYPE_SHOULDER"}, --"Ahn'Kahar Blood Hunter's Spaulders"
  [50118] = {4,251,"INVTYPE_CHEST"}, --"Ahn'Kahar Blood Hunter's Tunic"
  [50169] = {4,232,"INVTYPE_THROWN"}, --"Papa's Brand New Knife"
  [50170] = {4,264,"INVTYPE_FINGER"}, --"Valanar's Other Signet Ring"
  [50171] = {4,264,"INVTYPE_SHOULDER"}, --"Shoulders of Frost-Tipped Thorns"
  [50172] = {4,264,"INVTYPE_ROBE"}, --"Sanguine Silk Robes"
  [50173] = {4,264,"INVTYPE_HOLDABLE"}, --"Shadow Silk Spindle"
  [50174] = {4,264,"INVTYPE_FINGER"}, --"Incarnadine Band of Mending"
  [50175] = {4,264,"INVTYPE_WRIST"}, --"Crypt Keeper's Bracers"
  [50176] = {4,264,"INVTYPE_HAND"}, --"San'layn Ritualist Gloves"
  [50177] = {4,264,"INVTYPE_CHEST"}, --"Mail of Crimson Coins"
  [50178] = {4,264,"INVTYPE_2HWEAPON"}, --"Bloodfall"
  [50179] = {4,264,"INVTYPE_WEAPON"}, --"Last Word"
  [50180] = {4,264,"INVTYPE_NECK"}, --"Lana'thel's Chain of Flagellation"
  [50181] = {4,264,"INVTYPE_2HWEAPON"}, --"Dying Light"
  [50182] = {4,264,"INVTYPE_NECK"}, --"Blood Queen's Crimson Choker"
  [50183] = {4,264,"INVTYPE_WEAPON"}, --"Lungbreaker"
  [50184] = {4,264,"INVTYPE_WEAPONOFFHAND"}, --"Keleseth's Seducer"
  [50185] = {4,264,"INVTYPE_FINGER"}, --"Devium's Eternally Cold Ring"
  [50186] = {4,264,"INVTYPE_FINGER"}, --"Frostbrood Sapphire Ring"
  [50187] = {4,264,"INVTYPE_WAIST"}, --"Coldwraith Links"
  [50188] = {4,264,"INVTYPE_HAND"}, --"Anub'ar Stalker's Gloves"
  [50190] = {4,264,"INVTYPE_FEET"}, --"Grinning Skull Greatboots"
  [50191] = {4,232,"INVTYPE_WEAPON"}, --"Nighttime"
  [50192] = {4,264,"INVTYPE_LEGS"}, --"Scourge Reaver's Legplates"
  [50193] = {4,232,"INVTYPE_SHOULDER"}, --"Very Fashionable Shoulders"
  [50194] = {4,232,"INVTYPE_HAND"}, --"Weeping Gauntlets"
  [50195] = {4,264,"INVTYPE_NECK"}, --"Noose of Malachite"
  [50196] = {4,232,"INVTYPE_NECK"}, --"Love's Prisoner"
  [50197] = {4,232,"INVTYPE_HEAD"}, --"Eyes of Bewilderment"
  [50198] = {4,232,"INVTYPE_TRINKET"}, --"Needle-Encrusted Scorpion"
  [50199] = {4,264,"INVTYPE_LEGS"}, --"Leggings of Dying Candles"
  [50202] = {4,264,"INVTYPE_HEAD"}, --"Snowstorm Helm"
  [50203] = {4,232,"INVTYPE_WEAPON"}, --"Blood Weeper"
  [50204] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Wand of the Drowned Contessa"
  [50205] = {4,264,"INVTYPE_CLOAK"}, --"Frostbinder's Shredded Cape"
  [50206] = {4,232,"INVTYPE_HEAD"}, --"Frayed Scoundrel's Cap"
  [50207] = {4,232,"INVTYPE_FEET"}, --"Black Spire Sabatons"
  [50208] = {4,232,"INVTYPE_SHOULDER"}, --"Pauldrons of the Souleater"
  [50209] = {4,232,"INVTYPE_WRIST"}, --"Essence of Suffering"
  [50210] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Seethe"
  [50211] = {4,232,"INVTYPE_NECK"}, --"Arcane Loops of Anger"
  [50212] = {4,232,"INVTYPE_HAND"}, --"Essence of Desire"
  [50213] = {4,232,"INVTYPE_ROBE"}, --"Mord'rethar Robes"
  [50214] = {4,232,"INVTYPE_HEAD"}, --"Helm of the Spirit Shock"
  [50215] = {4,232,"INVTYPE_FEET"}, --"Recovered Reliquary Boots"
  [50227] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Surgeon's Needle"
  [50228] = {4,232,"INVTYPE_NECK"}, --"Barbed Ymirheim Choker"
  [50229] = {4,232,"INVTYPE_LEGS"}, --"Legguards of the Frosty Depths"
  [50230] = {4,232,"INVTYPE_WRIST"}, --"Malykriss Vambraces"
  [50233] = {4,232,"INVTYPE_SHOULDER"}, --"Spurned Val'kyr Shoulderguards"
  [50234] = {4,232,"INVTYPE_SHOULDER"}, --"Shoulderplates of Frozen Blood"
  [50235] = {4,232,"INVTYPE_TRINKET"}, --"Ick's Rotting Thumb"
  [50240] = {4,251,"INVTYPE_HAND"}, --"Dark Coven Gloves"
  [50241] = {4,251,"INVTYPE_HEAD"}, --"Dark Coven Hood"
  [50242] = {4,251,"INVTYPE_LEGS"}, --"Dark Coven Leggings"
  [50243] = {4,251,"INVTYPE_ROBE"}, --"Dark Coven Robe"
  [50244] = {4,251,"INVTYPE_SHOULDER"}, --"Dark Coven Shoulderpads"
  [50251] = {4,263,"INVTYPE_WEAPONOFFHAND"}, --"Shadow's Edge One-Hander"
  [50256] = {4,263,"INVTYPE_WEAPON"}, --"Shadow's Edge One-Hander (NEW)"
  [50259] = {4,232,"INVTYPE_TRINKET"}, --"Nevermelting Ice Crystal"
  [50260] = {4,232,"INVTYPE_TRINKET"}, --"Ephemeral Snowflake"
  [50262] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Felglacier Bolter"
  [50263] = {4,232,"INVTYPE_WAIST"}, --"Braid of Salt and Fire"
  [50264] = {4,232,"INVTYPE_WRIST"}, --"Chewed Leather Wristguards"
  [50265] = {4,232,"INVTYPE_LEGS"}, --"Blackened Ghoul Skin Leggings"
  [50266] = {4,232,"INVTYPE_ROBE"}, --"Ancient Polar Bear Hide"
  [50267] = {4,232,"INVTYPE_2HWEAPON"}, --"Tyrannical Beheader"
  [50268] = {4,232,"INVTYPE_WEAPON"}, --"Rimefang's Claw"
  [50269] = {4,232,"INVTYPE_LEGS"}, --"Fleshwerk Leggings"
  [50270] = {4,232,"INVTYPE_WAIST"}, --"Belt of Rotted Fingernails"
  [50271] = {4,232,"INVTYPE_FINGER"}, --"Band of Stained Souls"
  [50272] = {4,232,"INVTYPE_CHEST"}, --"Frost Wyrm Ribcage"
  [50273] = {4,232,"INVTYPE_2HWEAPON"}, --"Engraved Gargoyle Femur"
  [50275] = {4,251,"INVTYPE_HAND"}, --"Bloodmage Gloves"
  [50276] = {4,251,"INVTYPE_HEAD"}, --"Bloodmage Hood"
  [50277] = {4,251,"INVTYPE_LEGS"}, --"Bloodmage Leggings"
  [50278] = {4,251,"INVTYPE_ROBE"}, --"Bloodmage Robe"
  [50279] = {4,251,"INVTYPE_SHOULDER"}, --"Bloodmage Shoulderpads"
  [50283] = {4,232,"INVTYPE_FEET"}, --"Mudslide Boots"
  [50284] = {4,232,"INVTYPE_HAND"}, --"Rusty Frozen Fingerguards"
  [50285] = {4,232,"INVTYPE_CHEST"}, --"Icebound Bronze Cuirass"
  [50286] = {4,232,"INVTYPE_FEET"}, --"Prelate's Snowshoes"
  [50290] = {4,232,"INVTYPE_WEAPON"}, --"Falric's Wrist-Chopper"
  [50291] = {4,232,"INVTYPE_RANGEDRIGHT"}, --"Soulsplinter"
  [50292] = {4,232,"INVTYPE_WRIST"}, --"Bracer of Worn Molars"
  [50293] = {4,232,"INVTYPE_SHOULDER"}, --"Spaulders of Black Betrayal"
  [50294] = {4,232,"INVTYPE_CHEST"}, --"Chestpiece of High Treason"
  [50295] = {4,232,"INVTYPE_FEET"}, --"Spiked Toestompers"
  [50296] = {4,232,"INVTYPE_2HWEAPON"}, --"Orca-Hunter's Harpoon"
  [50297] = {4,232,"INVTYPE_CHEST"}, --"Frostsworn Bone Chestpiece"
  [50298] = {4,232,"INVTYPE_HEAD"}, --"Sightless Crown of Ulmaas"
  [50299] = {4,232,"INVTYPE_HAND"}, --"Suspiciously Soft Gloves"
  [50300] = {4,232,"INVTYPE_CHEST"}, --"Choking Hauberk"
  [50302] = {4,232,"INVTYPE_WEAPON"}, --"Liar's Tongue"
  [50303] = {4,232,"INVTYPE_WEAPON"}, --"Black Icicle"
  [50304] = {4,232,"INVTYPE_HAND"}, --"Hoarfrost Gauntlets"
  [50305] = {4,232,"INVTYPE_FEET"}, --"Grinning Skull Boots"
  [50306] = {4,232,"INVTYPE_FINGER"}, --"The Lady's Promise"
  [50308] = {4,232,"INVTYPE_FEET"}, --"Blighted Leather Footpads"
  [50309] = {4,232,"INVTYPE_HOLDABLE"}, --"Shriveled Heart"
  [50310] = {4,232,"INVTYPE_NECK"}, --"Fossilized Ammonite Choker"
  [50311] = {4,232,"INVTYPE_HEAD"}, --"Second Helm of the Executioner"
  [50312] = {4,232,"INVTYPE_CHEST"}, --"Chestguard of Broken Branches"
  [50313] = {4,232,"INVTYPE_FINGER"}, --"Oath of Empress Zoe"
  [50314] = {4,232,"INVTYPE_WAIST"}, --"Strip of Remorse"
  [50315] = {4,232,"INVTYPE_WEAPONMAINHAND"}, --"Seven-Fingered Claws"
  [50318] = {4,232,"INVTYPE_WRIST"}, --"Ghostly Wristwraps"
  [50319] = {4,232,"INVTYPE_WEAPON"}, --"Unsharpened Ice Razor"
  [50324] = {4,251,"INVTYPE_SHOULDER"}, --"Lightsworn Shoulderplates"
  [50325] = {4,251,"INVTYPE_LEGS"}, --"Lightsworn Legplates"
  [50326] = {4,251,"INVTYPE_HEAD"}, --"Lightsworn Helmet"
  [50327] = {4,251,"INVTYPE_HAND"}, --"Lightsworn Gauntlets"
  [50328] = {4,251,"INVTYPE_CHEST"}, --"Lightsworn Battleplate"
  [50329] = {4,251,"INVTYPE_WRIST"}, --"Icecrown-10 Normal Loot Token"
  [50330] = {4,251,"INVTYPE_WRIST"}, --"Icecrown-10 Heroic Loot Token"
  [50331] = {4,251,"INVTYPE_WRIST"}, --"Icecrown-25 Heroic Loot Token"
  [50332] = {4,251,"INVTYPE_WRIST"}, --"Icecrown-25 Normal Loot Token"
  [50333] = {4,264,"INVTYPE_WRIST"}, --"Toskk's Maximized Wristguards"
  [50339] = {4,251,"INVTYPE_TRINKET"}, --"Sliver of Pure Ice"
  [50340] = {4,251,"INVTYPE_TRINKET"}, --"Muradin's Spyglass"
  [50341] = {4,251,"INVTYPE_TRINKET"}, --"Unidentifiable Organ"
  [50342] = {4,251,"INVTYPE_TRINKET"}, --"Whispering Fanged Skull"
  [50343] = {4,264,"INVTYPE_TRINKET"}, --"Whispering Fanged Skull"
  [50344] = {4,264,"INVTYPE_TRINKET"}, --"Unidentifiable Organ"
  [50345] = {4,264,"INVTYPE_TRINKET"}, --"Muradin's Spyglass"
  [50346] = {4,264,"INVTYPE_TRINKET"}, --"Sliver of Pure Ice"
  [50348] = {4,277,"INVTYPE_TRINKET"}, --"Dislodged Foreign Object"
  [50349] = {4,277,"INVTYPE_TRINKET"}, --"Corpse Tongue Coin"
  [50351] = {4,264,"INVTYPE_TRINKET"}, --"Tiny Abomination in a Jar"
  [50352] = {4,264,"INVTYPE_TRINKET"}, --"Corpse Tongue Coin"
  [50353] = {4,264,"INVTYPE_TRINKET"}, --"Dislodged Foreign Object"
  [50354] = {4,264,"INVTYPE_TRINKET"}, --"Bauble of True Blood"
  [50355] = {4,264,"INVTYPE_TRINKET"}, --"Herkuml War Token"
  [50356] = {4,264,"INVTYPE_TRINKET"}, --"Corroded Skeleton Key"
  [50357] = {4,264,"INVTYPE_TRINKET"}, --"Maghia's Misguided Quill"
  [50358] = {4,264,"INVTYPE_TRINKET"}, --"Purified Lunar Dust"
  [50359] = {4,264,"INVTYPE_TRINKET"}, --"Althor's Abacus"
  [50360] = {4,264,"INVTYPE_TRINKET"}, --"Phylactery of the Nameless Lich"
  [50361] = {4,264,"INVTYPE_TRINKET"}, --"Sindragosa's Flawless Fang"
  [50362] = {4,264,"INVTYPE_TRINKET"}, --"Deathbringer's Will"
  [50363] = {4,277,"INVTYPE_TRINKET"}, --"Deathbringer's Will"
  [50364] = {4,277,"INVTYPE_TRINKET"}, --"Sindragosa's Flawless Fang"
  [50365] = {4,277,"INVTYPE_TRINKET"}, --"Phylactery of the Nameless Lich"
  [50366] = {4,277,"INVTYPE_TRINKET"}, --"Althor's Abacus"
  [50375] = {4,251,"INVTYPE_FINGER"}, --"Ashen Band of Courage"
  [50376] = {4,251,"INVTYPE_FINGER"}, --"Ashen Band of Vengeance"
  [50377] = {4,251,"INVTYPE_FINGER"}, --"Ashen Band of Destruction"
  [50378] = {4,251,"INVTYPE_FINGER"}, --"Ashen Band of Wisdom"
  [50384] = {4,259,"INVTYPE_FINGER"}, --"Ashen Band of Greater Destruction"
  [50386] = {4,259,"INVTYPE_FINGER"}, --"Ashen Band of Greater Wisdom"
  [50387] = {4,259,"INVTYPE_FINGER"}, --"Ashen Band of Greater Vengeance"
  [50388] = {4,259,"INVTYPE_FINGER"}, --"Ashen Band of Greater Courage"
  [50391] = {4,251,"INVTYPE_HAND"}, --"Crimson Acolyte Handwraps"
  [50392] = {4,251,"INVTYPE_HEAD"}, --"Crimson Acolyte Cowl"
  [50393] = {4,251,"INVTYPE_LEGS"}, --"Crimson Acolyte Pants"
  [50394] = {4,251,"INVTYPE_ROBE"}, --"Crimson Acolyte Raiments"
  [50396] = {4,251,"INVTYPE_SHOULDER"}, --"Crimson Acolyte Mantle"
  [50397] = {4,268,"INVTYPE_FINGER"}, --"Ashen Band of Unmatched Destruction"
  [50398] = {4,277,"INVTYPE_FINGER"}, --"Ashen Band of Endless Destruction"
  [50399] = {4,268,"INVTYPE_FINGER"}, --"Ashen Band of Unmatched Wisdom"
  [50400] = {4,277,"INVTYPE_FINGER"}, --"Ashen Band of Endless Wisdom"
  [50401] = {4,268,"INVTYPE_FINGER"}, --"Ashen Band of Unmatched Vengeance"
  [50402] = {4,277,"INVTYPE_FINGER"}, --"Ashen Band of Endless Vengeance"
  [50403] = {4,268,"INVTYPE_FINGER"}, --"Ashen Band of Unmatched Courage"
  [50404] = {4,277,"INVTYPE_FINGER"}, --"Ashen Band of Endless Courage"
  [50411] = {4,264,"INVTYPE_WEAPON"}, --"Scourgeborne Waraxe"
  [50412] = {4,264,"INVTYPE_WEAPON"}, --"Bloodvenom Blade"
  [50413] = {4,264,"INVTYPE_WAIST"}, --"Nerub'ar Stalker's Cord"
  [50414] = {4,264,"INVTYPE_FINGER"}, --"Might of Blight"
  [50415] = {4,264,"INVTYPE_2HWEAPON"}, --"Bryntroll, the Bone Arbiter"
  [50416] = {4,264,"INVTYPE_FEET"}, --"Boots of the Funeral March"
  [50417] = {4,264,"INVTYPE_WRIST"}, --"Bracers of Eternal Dreaming"
  [50418] = {4,264,"INVTYPE_ROBE"}, --"Robe of the Waking Nightmare"
  [50421] = {4,264,"INVTYPE_NECK"}, --"Sindragosa's Cruel Claw"
  [50423] = {4,264,"INVTYPE_HOLDABLE"}, --"Sundial of Eternal Dusk"
  [50424] = {4,264,"INVTYPE_FINGER"}, --"Memory of Malygos"
  [50425] = {4,271,"INVTYPE_2HWEAPON"}, --"Oathbinder, Charge of the Ranger-General"
  [50426] = {4,271,"INVTYPE_WEAPON"}, --"Heaven's Fall, Kryss of a Thousand Lies"
  [50427] = {4,271,"INVTYPE_WEAPONMAINHAND"}, --"Bloodsurge, Kel'Thuzad's Blade of Agony"
  [50428] = {4,271,"INVTYPE_WEAPONMAINHAND"}, --"Royal Scepter of Terenas II"
  [50429] = {4,271,"INVTYPE_2HWEAPON"}, --"Archus, Greatstaff of Antonidas"
  [50444] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Rowan's Rifle of Silver Bullets"
  [50447] = {4,264,"INVTYPE_FINGER"}, --"Harbinger's Bone Band"
  [50449] = {4,264,"INVTYPE_SHOULDER"}, --"Stiffened Corpse Shoulderpads"
  [50450] = {4,264,"INVTYPE_LEGS"}, --"Leggings of Dubious Charms"
  [50451] = {4,264,"INVTYPE_WAIST"}, --"Belt of the Lonely Noble"
  [50452] = {4,264,"INVTYPE_NECK"}, --"Wodin's Lucky Necklace"
  [50453] = {4,264,"INVTYPE_FINGER"}, --"Ring of Rotting Sinew"
  [50454] = {4,264,"INVTYPE_RELIC"}, --"Idol of the Black Willow"
  [50455] = {4,264,"INVTYPE_RELIC"}, --"Libram of Three Truths"
  [50456] = {4,264,"INVTYPE_RELIC"}, --"Idol of the Crying Moon"
  [50457] = {4,264,"INVTYPE_RELIC"}, --"Idol of the Lunar Eclipse"
  [50458] = {4,264,"INVTYPE_RELIC"}, --"Bizuri's Totem of Shattered Ice"
  [50459] = {4,264,"INVTYPE_RELIC"}, --"Sigil of the Hanged Man"
  [50460] = {4,264,"INVTYPE_RELIC"}, --"Libram of Blinding Light"
  [50461] = {4,264,"INVTYPE_RELIC"}, --"Libram of the Eternal Tower"
  [50462] = {4,264,"INVTYPE_RELIC"}, --"Sigil of the Bone Gryphon"
  [50463] = {4,264,"INVTYPE_RELIC"}, --"Totem of the Avalanche"
  [50464] = {4,264,"INVTYPE_RELIC"}, --"Totem of the Surging Sea"
  [50466] = {4,264,"INVTYPE_CLOAK"}, --"Sentinel's Winter Cloak"
  [50467] = {4,264,"INVTYPE_CLOAK"}, --"Might of the Ocean Serpent"
  [50468] = {4,264,"INVTYPE_CLOAK"}, --"Drape of the Violet Tower"
  [50469] = {4,264,"INVTYPE_CLOAK"}, --"Volde's Cloak of the Night Sky"
  [50470] = {4,264,"INVTYPE_CLOAK"}, --"Recovered Scarlet Onslaught Cape"
  [50472] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Nightmare Ender"
  [50474] = {4,264,"INVTYPE_THROWN"}, --"Shrapnel Star"
  [50603] = {4,277,"INVTYPE_2HWEAPON"}, --"Cryptmaker"
  [50604] = {4,277,"INVTYPE_FINGER"}, --"Band of the Bone Colossus"
  [50605] = {4,277,"INVTYPE_HEAD"}, --"Snowserpent Mail Helm"
  [50606] = {4,277,"INVTYPE_CHEST"}, --"Gendarme's Cuirass"
  [50607] = {4,277,"INVTYPE_FEET"}, --"Frostbitten Fur Boots"
  [50608] = {4,277,"INVTYPE_WEAPONMAINHAND"}, --"Frozen Bonespike"
  [50609] = {4,277,"INVTYPE_NECK"}, --"Bone Sentinel's Amulet"
  [50610] = {4,277,"INVTYPE_FINGER"}, --"Marrowgar's Frigid Eye"
  [50611] = {4,277,"INVTYPE_WRIST"}, --"Bracers of Dark Reckoning"
  [50612] = {4,277,"INVTYPE_LEGS"}, --"Legguards of Lost Hope"
  [50613] = {4,277,"INVTYPE_WAIST"}, --"Crushing Coldwraith Belt"
  [50614] = {4,277,"INVTYPE_FINGER"}, --"Loop of the Endless Labyrinth"
  [50615] = {4,277,"INVTYPE_HAND"}, --"Handguards of Winter's Respite"
  [50616] = {4,277,"INVTYPE_SHIELD"}, --"Bulwark of Smouldering Steel"
  [50617] = {4,277,"INVTYPE_SHOULDER"}, --"Rusted Bonespike Pauldrons"
  [50618] = {4,277,"INVTYPE_FINGER"}, --"Frostbrood Sapphire Ring"
  [50619] = {4,277,"INVTYPE_HAND"}, --"Anub'ar Stalker's Gloves"
  [50620] = {4,277,"INVTYPE_WAIST"}, --"Coldwraith Links"
  [50621] = {4,277,"INVTYPE_WEAPON"}, --"Lungbreaker"
  [50622] = {4,277,"INVTYPE_FINGER"}, --"Devium's Eternally Cold Ring"
  [50623] = {4,277,"INVTYPE_LEGS"}, --"Leggings of Dying Candles"
  [50624] = {4,277,"INVTYPE_LEGS"}, --"Scourge Reaver's Legplates"
  [50625] = {4,277,"INVTYPE_FEET"}, --"Grinning Skull Greatboots"
  [50626] = {4,277,"INVTYPE_HEAD"}, --"Snowstorm Helm"
  [50627] = {4,277,"INVTYPE_NECK"}, --"Noose of Malachite"
  [50628] = {4,277,"INVTYPE_CLOAK"}, --"Frostbinder's Shredded Cape"
  [50629] = {4,277,"INVTYPE_ROBE"}, --"Robe of the Waking Nightmare"
  [50630] = {4,277,"INVTYPE_WRIST"}, --"Bracers of Eternal Dreaming"
  [50631] = {4,277,"INVTYPE_RANGEDRIGHT"}, --"Nightmare Ender"
  [50632] = {4,277,"INVTYPE_FEET"}, --"Boots of the Funeral March"
  [50633] = {4,277,"INVTYPE_NECK"}, --"Sindragosa's Cruel Claw"
  [50635] = {4,277,"INVTYPE_HOLDABLE"}, --"Sundial of Eternal Dusk"
  [50636] = {4,277,"INVTYPE_FINGER"}, --"Memory of Malygos"
  [50638] = {4,277,"INVTYPE_RANGED"}, --"Zod's Repeating Longbow"
  [50639] = {4,277,"INVTYPE_FEET"}, --"Blood-Soaked Saronite Stompers"
  [50640] = {4,277,"INVTYPE_HEAD"}, --"Broken Ram Skull Helm"
  [50641] = {4,277,"INVTYPE_WEAPON"}, --"Heartpierce"
  [50642] = {4,277,"INVTYPE_FINGER"}, --"Juggernaut Band"
  [50643] = {4,277,"INVTYPE_SHOULDER"}, --"Shoulders of Mercy Killing"
  [50644] = {4,277,"INVTYPE_FINGER"}, --"Ring of Maddening Whispers"
  [50645] = {4,277,"INVTYPE_LEGS"}, --"Leggings of Northern Lights"
  [50646] = {4,277,"INVTYPE_SHOULDER"}, --"Cultist's Bloodsoaked Spaulders"
  [50647] = {4,277,"INVTYPE_NECK"}, --"Ahn'kahar Onyx Neckguard"
  [50648] = {4,277,"INVTYPE_2HWEAPON"}, --"Nibelung"
  [50649] = {4,277,"INVTYPE_ROBE"}, --"Deathwhisper Raiment"
  [50650] = {4,277,"INVTYPE_HAND"}, --"Fallen Lord's Handguards"
  [50651] = {4,277,"INVTYPE_WRIST"}, --"The Lady's Brittle Bracers"
  [50652] = {4,277,"INVTYPE_FEET"}, --"Necrophotic Greaves"
  [50653] = {4,277,"INVTYPE_CLOAK"}, --"Shadowvault Slayer's Cloak"
  [50654] = {4,277,"INVTYPE_WEAPON"}, --"Scourgeborne Waraxe"
  [50655] = {4,277,"INVTYPE_WRIST"}, --"Scourge Hunter's Vambraces"
  [50656] = {4,277,"INVTYPE_CHEST"}, --"Ikfirus's Sack of Wonder"
  [50657] = {4,277,"INVTYPE_FINGER"}, --"Skeleton Lord's Circle"
  [50658] = {4,277,"INVTYPE_NECK"}, --"Amulet of the Silent Eulogy"
  [50659] = {4,277,"INVTYPE_WRIST"}, --"Polar Bear Claw Bracers"
  [50660] = {4,277,"INVTYPE_SHOULDER"}, --"Boneguard Commander's Pauldrons"
  [50661] = {4,277,"INVTYPE_HEAD"}, --"Corp'rethar Ceremonial Crown"
  [50663] = {4,277,"INVTYPE_HAND"}, --"Gunship Captain's Mittens"
  [50664] = {4,277,"INVTYPE_FINGER"}, --"Ring of Rapid Ascent"
  [50665] = {4,277,"INVTYPE_FEET"}, --"Boots of Unnatural Growth"
  [50667] = {4,277,"INVTYPE_WAIST"}, --"Waistband of Righteous Fury"
  [50668] = {4,277,"INVTYPE_CLOAK"}, --"Greatcloak of the Turned Champion"
  [50670] = {4,277,"INVTYPE_WRIST"}, --"Toskk's Maximized Wristguards"
  [50671] = {4,277,"INVTYPE_WAIST"}, --"Belt of the Blood Nova"
  [50672] = {4,277,"INVTYPE_WEAPON"}, --"Bloodvenom Blade"
  [50673] = {4,277,"INVTYPE_SHOULDER"}, --"Dual-Bladed Pauldrons"
  [50674] = {4,277,"INVTYPE_SHOULDER"}, --"Raging Behemoth's Shoulderplates"
  [50675] = {4,277,"INVTYPE_HAND"}, --"Aldriana's Gloves of Secrecy"
  [50676] = {4,277,"INVTYPE_WEAPON"}, --"Rib Spreader"
  [50677] = {4,277,"INVTYPE_CLOAK"}, --"Winding Sheet"
  [50678] = {4,277,"INVTYPE_FINGER"}, --"Seal of Many Mouths"
  [50679] = {4,277,"INVTYPE_HEAD"}, --"Helm of the Elder Moon"
  [50680] = {4,277,"INVTYPE_CHEST"}, --"Rot-Resistant Breastplate"
  [50681] = {4,277,"INVTYPE_CHEST"}, --"Blightborne Warplate"
  [50682] = {4,277,"INVTYPE_NECK"}, --"Bile-Encrusted Medallion"
  [50684] = {4,277,"INVTYPE_RANGEDRIGHT"}, --"Corpse-Impaling Spike"
  [50685] = {4,277,"INVTYPE_WEAPONMAINHAND"}, --"Trauma"
  [50686] = {4,277,"INVTYPE_WRIST"}, --"Death Surgeon's Sleeves"
  [50687] = {4,277,"INVTYPE_WRIST"}, --"Bloodsunder's Bracers"
  [50688] = {4,277,"INVTYPE_WAIST"}, --"Nerub'ar Stalker's Cord"
  [50689] = {4,277,"INVTYPE_CHEST"}, --"Carapace of Forgotten Kings"
  [50690] = {4,277,"INVTYPE_HAND"}, --"Fleshrending Gauntlets"
  [50691] = {4,277,"INVTYPE_WAIST"}, --"Belt of Broken Bones"
  [50692] = {4,277,"INVTYPE_WEAPONMAINHAND"}, --"Black Bruise"
  [50693] = {4,277,"INVTYPE_FINGER"}, --"Might of Blight"
  [50694] = {4,277,"INVTYPE_LEGS"}, --"Plaguebringer's Stained Pants"
  [50695] = {4,277,"INVTYPE_2HWEAPON"}, --"Distant Land"
  [50696] = {4,277,"INVTYPE_LEGS"}, --"Leather of Stitched Scourge Parts"
  [50697] = {4,277,"INVTYPE_LEGS"}, --"Gangrenous Leggings"
  [50698] = {4,277,"INVTYPE_SHOULDER"}, --"Horrific Flesh Epaulets"
  [50699] = {4,277,"INVTYPE_FEET"}, --"Plague Scientist's Boots"
  [50700] = {4,277,"INVTYPE_NECK"}, --"Holiday's Grace"
  [50701] = {4,277,"INVTYPE_HEAD"}, --"Faceplate of the Forgotten"
  [50702] = {4,277,"INVTYPE_WAIST"}, --"Lingering Illness"
  [50703] = {4,277,"INVTYPE_HAND"}, --"Unclean Surgical Gloves"
  [50704] = {4,277,"INVTYPE_WEAPONMAINHAND"}, --"Rigormortis"
  [50705] = {4,277,"INVTYPE_WAIST"}, --"Professor's Bloodied Smock"
  [50706] = {4,277,"INVTYPE_TRINKET"}, --"Tiny Abomination in a Jar"
  [50707] = {4,277,"INVTYPE_WAIST"}, --"Astrylian's Sutured Cinch"
  [50708] = {4,277,"INVTYPE_WEAPON"}, --"Last Word"
  [50709] = {4,277,"INVTYPE_2HWEAPON"}, --"Bryntroll, the Bone Arbiter"
  [50710] = {4,277,"INVTYPE_WEAPONOFFHAND"}, --"Keleseth's Seducer"
  [50711] = {4,277,"INVTYPE_FEET"}, --"Treads of the Wasteland"
  [50712] = {4,277,"INVTYPE_HEAD"}, --"Landsoul's Horned Greathelm"
  [50713] = {4,277,"INVTYPE_HEAD"}, --"Geistlord's Punishment Sack"
  [50714] = {4,277,"INVTYPE_FINGER"}, --"Valanar's Other Signet Ring"
  [50715] = {4,277,"INVTYPE_SHOULDER"}, --"Shoulders of Frost-Tipped Thorns"
  [50716] = {4,277,"INVTYPE_HAND"}, --"Taldaram's Plated Fists"
  [50717] = {4,277,"INVTYPE_ROBE"}, --"Sanguine Silk Robes"
  [50718] = {4,277,"INVTYPE_CLOAK"}, --"Royal Crimson Cloak"
  [50719] = {4,277,"INVTYPE_HOLDABLE"}, --"Shadow Silk Spindle"
  [50720] = {4,277,"INVTYPE_FINGER"}, --"Incarnadine Band of Mending"
  [50721] = {4,277,"INVTYPE_WRIST"}, --"Crypt Keeper's Bracers"
  [50722] = {4,277,"INVTYPE_HAND"}, --"San'layn Ritualist Gloves"
  [50723] = {4,277,"INVTYPE_CHEST"}, --"Mail of Crimson Coins"
  [50724] = {4,277,"INVTYPE_NECK"}, --"Blood Queen's Crimson Choker"
  [50725] = {4,277,"INVTYPE_2HWEAPON"}, --"Dying Light"
  [50726] = {4,277,"INVTYPE_TRINKET"}, --"Bauble of True Blood"
  [50727] = {4,277,"INVTYPE_2HWEAPON"}, --"Bloodfall"
  [50728] = {4,277,"INVTYPE_NECK"}, --"Lana'thel's Chain of Flagellation"
  [50729] = {4,277,"INVTYPE_SHIELD"}, --"Icecrown Glacial Wall"
  [50730] = {4,284,"INVTYPE_2HWEAPON"}, --"Glorenzelg, High-Blade of the Silver Hand"
  [50731] = {4,284,"INVTYPE_2HWEAPON"}, --"Archus, Greatstaff of Antonidas"
  [50732] = {4,284,"INVTYPE_WEAPONMAINHAND"}, --"Bloodsurge, Kel'Thuzad's Blade of Agony"
  [50733] = {4,284,"INVTYPE_RANGEDRIGHT"}, --"Fal'inrush, Defender of Quel'thalas"
  [50734] = {4,284,"INVTYPE_WEAPONMAINHAND"}, --"Royal Scepter of Terenas II"
  [50735] = {4,284,"INVTYPE_2HWEAPON"}, --"Oathbinder, Charge of the Ranger-General"
  [50736] = {4,284,"INVTYPE_WEAPON"}, --"Heaven's Fall, Kryss of a Thousand Lies"
  [50737] = {4,284,"INVTYPE_WEAPON"}, --"Havoc's Call, Blade of Lordaeron Kings"
  [50738] = {4,284,"INVTYPE_WEAPON"}, --"Mithrios, Bronzebeard's Legacy"
  [50759] = {4,251,"INVTYPE_WEAPON"}, --"Bone Warden's Splitter"
  [50760] = {4,251,"INVTYPE_WEAPON"}, --"Bonebreaker Scepter"
  [50761] = {4,251,"INVTYPE_2HWEAPON"}, --"Citadel Enforcer's Claymore"
  [50762] = {4,251,"INVTYPE_WAIST"}, --"Linked Scourge Vertebrae"
  [50763] = {4,251,"INVTYPE_NECK"}, --"Marrowgar's Scratching Choker"
  [50764] = {4,251,"INVTYPE_CLOAK"}, --"Shawl of Nerubian Silk"
  [50765] = {4,251,"INVTYPE_HEAD"}, --"Crimson Acolyte Hood"
  [50766] = {4,251,"INVTYPE_HAND"}, --"Crimson Acolyte Gloves"
  [50767] = {4,251,"INVTYPE_SHOULDER"}, --"Crimson Acolyte Shoulderpads"
  [50768] = {4,251,"INVTYPE_ROBE"}, --"Crimson Acolyte Robe"
  [50769] = {4,251,"INVTYPE_LEGS"}, --"Crimson Acolyte Leggings"
  [50771] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Frost Needle"
  [50772] = {4,251,"INVTYPE_FEET"}, --"Ancient Skeletal Boots"
  [50773] = {4,251,"INVTYPE_WAIST"}, --"Cord of the Patronizing Practitioner"
  [50774] = {4,251,"INVTYPE_WRIST"}, --"Coldwraith Bracers"
  [50775] = {4,251,"INVTYPE_LEGS"}, --"Corrupted Silverplate Leggings"
  [50776] = {4,251,"INVTYPE_RANGED"}, --"Njorndar Bone Bow"
  [50777] = {4,251,"INVTYPE_HAND"}, --"Handgrips of Frost and Sleet"
  [50778] = {4,251,"INVTYPE_WAIST"}, --"Soulthief's Braided Belt"
  [50779] = {4,251,"INVTYPE_HEAD"}, --"Deathspeaker Zealot's Helm"
  [50780] = {4,251,"INVTYPE_CHEST"}, --"Chestguard of the Frigid Noose"
  [50781] = {4,251,"INVTYPE_HOLDABLE"}, --"Scourgelord's Baton"
  [50782] = {4,251,"INVTYPE_HAND"}, --"Sister's Handshrouds"
  [50783] = {4,251,"INVTYPE_FEET"}, --"Boots of the Frozen Seed"
  [50784] = {4,251,"INVTYPE_WAIST"}, --"Deathspeaker Disciple's Belt"
  [50785] = {4,251,"INVTYPE_WRIST"}, --"Bracers of Dark Blessings"
  [50786] = {4,251,"INVTYPE_CHEST"}, --"Ghoul Commander's Cuirass"
  [50787] = {4,251,"INVTYPE_WEAPON"}, --"Frost Giant's Cleaver"
  [50788] = {4,251,"INVTYPE_FEET"}, --"Bone Drake's Enameled Boots"
  [50789] = {4,251,"INVTYPE_WRIST"}, --"Icecrown Rampart Bracers"
  [50790] = {4,251,"INVTYPE_FINGER"}, --"Abomination's Bloody Ring"
  [50791] = {4,251,"INVTYPE_CLOAK"}, --"Saronite Gargoyle Cloak"
  [50792] = {4,251,"INVTYPE_SHOULDER"}, --"Pauldrons of Lost Hope"
  [50793] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Midnight Sun"
  [50794] = {4,251,"INVTYPE_SHIELD"}, --"Neverending Winter"
  [50795] = {4,251,"INVTYPE_WAIST"}, --"Cord of Dark Suffering"
  [50796] = {4,251,"INVTYPE_WRIST"}, --"Bracers of Pale Illumination"
  [50797] = {4,251,"INVTYPE_HEAD"}, --"Ice-Reinforced Vrykul Helm"
  [50798] = {4,251,"INVTYPE_2HWEAPON"}, --"Ramaladni's Blade of Culling"
  [50799] = {4,251,"INVTYPE_HAND"}, --"Scourge Stranglers"
  [50800] = {4,251,"INVTYPE_CHEST"}, --"Hauberk of a Thousand Cuts"
  [50801] = {4,251,"INVTYPE_CHEST"}, --"Blade-Scored Carapace"
  [50802] = {4,251,"INVTYPE_WRIST"}, --"Gargoyle Spit Bracers"
  [50803] = {4,251,"INVTYPE_FINGER"}, --"Saurfang's Cold-Forged Band"
  [50804] = {4,251,"INVTYPE_FEET"}, --"Icecrown Spire Sandals"
  [50805] = {4,251,"INVTYPE_2HWEAPON"}, --"Mag'hari Chieftain's Staff"
  [50806] = {4,251,"INVTYPE_LEGS"}, --"Leggings of Unrelenting Blood"
  [50807] = {4,251,"INVTYPE_HEAD"}, --"Thaumaturge's Crackling Cowl"
  [50808] = {4,251,"INVTYPE_LEGS"}, --"Deathforged Legplates"
  [50809] = {4,251,"INVTYPE_NECK"}, --"Soulcleave Pendant"
  [50810] = {4,251,"INVTYPE_WEAPON"}, --"Gutbuster"
  [50811] = {4,251,"INVTYPE_HAND"}, --"Festering Fingerguards"
  [50812] = {4,251,"INVTYPE_FEET"}, --"Taldron's Long Neglected Boots"
  [50819] = {4,251,"INVTYPE_SHOULDER"}, --"Lasherweave Mantle"
  [50820] = {4,251,"INVTYPE_LEGS"}, --"Lasherweave Trousers"
  [50821] = {4,251,"INVTYPE_HEAD"}, --"Lasherweave Cover"
  [50822] = {4,251,"INVTYPE_HAND"}, --"Lasherweave Gloves"
  [50823] = {4,251,"INVTYPE_ROBE"}, --"Lasherweave Vestment"
  [50824] = {4,251,"INVTYPE_SHOULDER"}, --"Lasherweave Shoulderpads"
  [50825] = {4,251,"INVTYPE_LEGS"}, --"Lasherweave Legguards"
  [50826] = {4,251,"INVTYPE_HEAD"}, --"Lasherweave Headguard"
  [50827] = {4,251,"INVTYPE_HAND"}, --"Lasherweave Handgrips"
  [50828] = {4,251,"INVTYPE_ROBE"}, --"Lasherweave Raiment"
  [50830] = {4,251,"INVTYPE_CHEST"}, --"Frost Witch's Chestguard"
  [50831] = {4,251,"INVTYPE_HAND"}, --"Frost Witch's Grips"
  [50832] = {4,251,"INVTYPE_HEAD"}, --"Frost Witch's Faceguard"
  [50833] = {4,251,"INVTYPE_LEGS"}, --"Frost Witch's War-Kilt"
  [50834] = {4,251,"INVTYPE_SHOULDER"}, --"Frost Witch's Shoulderguards"
  [50835] = {4,251,"INVTYPE_CHEST"}, --"Frost Witch's Tunic"
  [50836] = {4,251,"INVTYPE_HAND"}, --"Frost Witch's Handguards"
  [50837] = {4,251,"INVTYPE_HEAD"}, --"Frost Witch's Headpiece"
  [50838] = {4,251,"INVTYPE_LEGS"}, --"Frost Witch's Legguards"
  [50839] = {4,251,"INVTYPE_SHOULDER"}, --"Frost Witch's Spaulders"
  [50841] = {4,251,"INVTYPE_CHEST"}, --"Frost Witch's Hauberk"
  [50842] = {4,251,"INVTYPE_HAND"}, --"Frost Witch's Gloves"
  [50843] = {4,251,"INVTYPE_HEAD"}, --"Frost Witch's Helm"
  [50844] = {4,251,"INVTYPE_LEGS"}, --"Frost Witch's Kilt"
  [50845] = {4,251,"INVTYPE_SHOULDER"}, --"Frost Witch's Shoulderpads"
  [50846] = {4,251,"INVTYPE_SHOULDER"}, --"Ymirjar Lord's Pauldrons"
  [50847] = {4,251,"INVTYPE_LEGS"}, --"Ymirjar Lord's Legguards"
  [50848] = {4,251,"INVTYPE_HEAD"}, --"Ymirjar Lord's Greathelm"
  [50849] = {4,251,"INVTYPE_HAND"}, --"Ymirjar Lord's Handguards"
  [50850] = {4,251,"INVTYPE_CHEST"}, --"Ymirjar Lord's Breastplate"
  [50852] = {4,251,"INVTYPE_NECK"}, --"Precious's Putrid Collar"
  [50853] = {4,251,"INVTYPE_SHOULDER"}, --"Scourgelord Pauldrons"
  [50854] = {4,251,"INVTYPE_LEGS"}, --"Scourgelord Legguards"
  [50855] = {4,251,"INVTYPE_HEAD"}, --"Scourgelord Faceguard"
  [50856] = {4,251,"INVTYPE_HAND"}, --"Scourgelord Handguards"
  [50857] = {4,251,"INVTYPE_CHEST"}, --"Scourgelord Chestguard"
  [50858] = {4,251,"INVTYPE_LEGS"}, --"Plague-Soaked Leather Leggings"
  [50859] = {4,251,"INVTYPE_CLOAK"}, --"Cloak of Many Skins"
  [50860] = {4,251,"INVTYPE_SHOULDER"}, --"Lightsworn Shoulderguards"
  [50861] = {4,251,"INVTYPE_LEGS"}, --"Lightsworn Legguards"
  [50862] = {4,251,"INVTYPE_HEAD"}, --"Lightsworn Faceguard"
  [50863] = {4,251,"INVTYPE_HAND"}, --"Lightsworn Handguards"
  [50864] = {4,251,"INVTYPE_CHEST"}, --"Lightsworn Chestguard"
  [50865] = {4,251,"INVTYPE_SHOULDER"}, --"Lightsworn Spaulders"
  [50866] = {4,251,"INVTYPE_LEGS"}, --"Lightsworn Greaves"
  [50867] = {4,251,"INVTYPE_HEAD"}, --"Lightsworn Headpiece"
  [50868] = {4,251,"INVTYPE_HAND"}, --"Lightsworn Gloves"
  [50869] = {4,251,"INVTYPE_CHEST"}, --"Lightsworn Tunic"
  [50965] = {4,264,"INVTYPE_CHEST"}, --"Castle Breaker's Battleplate"
  [50966] = {4,251,"INVTYPE_2HWEAPON"}, --"Abracadaver"
  [50967] = {4,251,"INVTYPE_HAND"}, --"Festergut's Gaseous Gloves"
  [50968] = {4,264,"INVTYPE_CHEST"}, --"Cataclysmic Chestguard"
  [50969] = {4,264,"INVTYPE_CHEST"}, --"Chestplate of Unspoken Truths"
  [50970] = {4,264,"INVTYPE_CHEST"}, --"Longstrider's Vest"
  [50971] = {4,264,"INVTYPE_CHEST"}, --"Mail of the Geyser"
  [50972] = {4,264,"INVTYPE_CHEST"}, --"Shadow Seeker's Tunic"
  [50973] = {4,264,"INVTYPE_ROBE"}, --"Vestments of Spruce and Fir"
  [50974] = {4,264,"INVTYPE_ROBE"}, --"Meteor Chaser's Raiment"
  [50975] = {4,264,"INVTYPE_ROBE"}, --"Ermine Coronation Robes"
  [50976] = {4,264,"INVTYPE_HAND"}, --"Gauntlets of Overexposure"
  [50977] = {4,264,"INVTYPE_HAND"}, --"Gatecrasher's Gauntlets"
  [50978] = {4,264,"INVTYPE_HAND"}, --"Gauntlets of the Kraken"
  [50979] = {4,264,"INVTYPE_HAND"}, --"Logsplitters"
  [50980] = {4,264,"INVTYPE_HAND"}, --"Blizzard Keeper's Mitts"
  [50981] = {4,264,"INVTYPE_HAND"}, --"Gloves of the Great Horned Owl"
  [50982] = {4,264,"INVTYPE_HAND"}, --"Cat Burglar's Grips"
  [50983] = {4,264,"INVTYPE_HAND"}, --"Gloves of False Gestures"
  [50984] = {4,264,"INVTYPE_HAND"}, --"Gloves of Ambivalence"
  [50985] = {4,251,"INVTYPE_WRIST"}, --"Wrists of Septic Shock"
  [50986] = {4,251,"INVTYPE_FINGER"}, --"Signet of Putrefaction"
  [50987] = {4,264,"INVTYPE_WAIST"}, --"Malevolent Girdle"
  [50988] = {4,251,"INVTYPE_SHOULDER"}, --"Bloodstained Surgeon's Shoulderguards"
  [50989] = {4,264,"INVTYPE_WAIST"}, --"Lich Killer's Lanyard"
  [50990] = {4,251,"INVTYPE_LEGS"}, --"Kilt of Untreated Wounds"
  [50991] = {4,264,"INVTYPE_WAIST"}, --"Verdigris Chain Belt"
  [50992] = {4,264,"INVTYPE_WAIST"}, --"Waistband of Despair"
  [50993] = {4,264,"INVTYPE_WAIST"}, --"Band of the Night Raven"
  [50994] = {4,264,"INVTYPE_WAIST"}, --"Belt of Petrified Ivy"
  [50995] = {4,264,"INVTYPE_WAIST"}, --"Vengeful Noose"
  [50996] = {4,264,"INVTYPE_WAIST"}, --"Belt of Omission"
  [50997] = {4,264,"INVTYPE_WAIST"}, --"Circle of Ossus"
  [50998] = {4,251,"INVTYPE_2HWEAPON"}, --"Shaft of Glacial Ice"
  [50999] = {4,251,"INVTYPE_THROWN"}, --"Gluth's Fetching Knife"
  [51000] = {4,251,"INVTYPE_WAIST"}, --"Flesh-Shaper's Gurney Strap"
  [51001] = {4,251,"INVTYPE_FINGER"}, --"Rotface's Rupturing Ring"
  [51002] = {4,251,"INVTYPE_HEAD"}, --"Taldron's Short-Sighted Helm"
  [51003] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Abomination Knuckles"
  [51004] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Lockjaw"
  [51005] = {4,251,"INVTYPE_HAND"}, --"Gloves of Broken Fingers"
  [51006] = {4,251,"INVTYPE_FEET"}, --"Shuffling Shoes"
  [51007] = {4,251,"INVTYPE_WRIST"}, --"Ether-Soaked Bracers"
  [51008] = {4,251,"INVTYPE_NECK"}, --"Choker of Filthy Diamonds"
  [51009] = {4,251,"INVTYPE_ROBE"}, --"Chestguard of the Failed Experiment"
  [51010] = {4,251,"INVTYPE_WEAPON"}, --"The Facelifter"
  [51011] = {4,251,"INVTYPE_WEAPON"}, --"Flesh-Carving Scalpel"
  [51012] = {4,251,"INVTYPE_NECK"}, --"Infected Choker"
  [51013] = {4,251,"INVTYPE_HEAD"}, --"Discarded Bag of Entrails"
  [51014] = {4,251,"INVTYPE_SHOULDER"}, --"Scalpel-Sharpening Shoulderguards"
  [51015] = {4,251,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Morbid Ritual"
  [51016] = {4,251,"INVTYPE_NECK"}, --"Pendant of Split Veins"
  [51017] = {4,251,"INVTYPE_WAIST"}, --"Cauterized Cord"
  [51018] = {4,251,"INVTYPE_CHEST"}, --"Chestplate of Septic Stitches"
  [51019] = {4,251,"INVTYPE_LEGS"}, --"Rippling Flesh Kilt"
  [51020] = {4,251,"INVTYPE_SHOULDER"}, --"Shoulders of Ruinous Senility"
  [51021] = {4,251,"INVTYPE_WEAPON"}, --"Soulbreaker"
  [51022] = {4,251,"INVTYPE_2HWEAPON"}, --"Hersir's Greatspear"
  [51023] = {4,251,"INVTYPE_FEET"}, --"Taldaram's Soft Slippers"
  [51024] = {4,251,"INVTYPE_FINGER"}, --"Thrice Fanged Signet"
  [51025] = {4,251,"INVTYPE_LEGS"}, --"Battle-Maiden's Legguards"
  [51125] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Scourgelord Shoulderplates"
  [51126] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Scourgelord Legplates"
  [51127] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Scourgelord Helmet"
  [51128] = {4,264,"INVTYPE_HAND"}, --"Sanctified Scourgelord Gauntlets"
  [51129] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Scourgelord Battleplate"
  [51130] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Scourgelord Pauldrons"
  [51131] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Scourgelord Legguards"
  [51132] = {4,264,"INVTYPE_HAND"}, --"Sanctified Scourgelord Handguards"
  [51133] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Scourgelord Faceguard"
  [51134] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Scourgelord Chestguard"
  [51135] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Lasherweave Pauldrons"
  [51136] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Lasherweave Legplates"
  [51137] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Lasherweave Helmet"
  [51138] = {4,264,"INVTYPE_HAND"}, --"Sanctified Lasherweave Gauntlets"
  [51139] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Lasherweave Robes"
  [51140] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Lasherweave Shoulderpads"
  [51141] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Lasherweave Raiment"
  [51142] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Lasherweave Legguards"
  [51143] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Lasherweave Headguard"
  [51144] = {4,264,"INVTYPE_HAND"}, --"Sanctified Lasherweave Handgrips"
  [51145] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Lasherweave Vestment"
  [51146] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Lasherweave Trousers"
  [51147] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Lasherweave Mantle"
  [51148] = {4,264,"INVTYPE_HAND"}, --"Sanctified Lasherweave Gloves"
  [51149] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Lasherweave Cover"
  [51150] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Ahn'Kahar Blood Hunter's Tunic"
  [51151] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Ahn'Kahar Blood Hunter's Spaulders"
  [51152] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Ahn'Kahar Blood Hunter's Legguards"
  [51153] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Ahn'Kahar Blood Hunter's Headpiece"
  [51154] = {4,264,"INVTYPE_HAND"}, --"Sanctified Ahn'Kahar Blood Hunter's Handguards"
  [51155] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Bloodmage Shoulderpads"
  [51156] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Bloodmage Robe"
  [51157] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Bloodmage Leggings"
  [51158] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Bloodmage Hood"
  [51159] = {4,264,"INVTYPE_HAND"}, --"Sanctified Bloodmage Gloves"
  [51160] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Lightsworn Shoulderplates"
  [51161] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Lightsworn Legplates"
  [51162] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Lightsworn Helmet"
  [51163] = {4,264,"INVTYPE_HAND"}, --"Sanctified Lightsworn Gauntlets"
  [51164] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Lightsworn Battleplate"
  [51165] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Lightsworn Tunic"
  [51166] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Lightsworn Spaulders"
  [51167] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Lightsworn Headpiece"
  [51168] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Lightsworn Greaves"
  [51169] = {4,264,"INVTYPE_HAND"}, --"Sanctified Lightsworn Gloves"
  [51170] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Lightsworn Shoulderguards"
  [51171] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Lightsworn Legguards"
  [51172] = {4,264,"INVTYPE_HAND"}, --"Sanctified Lightsworn Handguards"
  [51173] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Lightsworn Faceguard"
  [51174] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Lightsworn Chestguard"
  [51175] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Crimson Acolyte Shoulderpads"
  [51176] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Crimson Acolyte Robe"
  [51177] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Crimson Acolyte Leggings"
  [51178] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Crimson Acolyte Hood"
  [51179] = {4,264,"INVTYPE_HAND"}, --"Sanctified Crimson Acolyte Gloves"
  [51180] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Crimson Acolyte Raiments"
  [51181] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Crimson Acolyte Pants"
  [51182] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Crimson Acolyte Mantle"
  [51183] = {4,264,"INVTYPE_HAND"}, --"Sanctified Crimson Acolyte Handwraps"
  [51184] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Crimson Acolyte Cowl"
  [51185] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Shadowblade Pauldrons"
  [51186] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Shadowblade Legplates"
  [51187] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Shadowblade Helmet"
  [51188] = {4,264,"INVTYPE_HAND"}, --"Sanctified Shadowblade Gauntlets"
  [51189] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Shadowblade Breastplate"
  [51190] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Frost Witch's Tunic"
  [51191] = {4,264,"INVTYPE_HAND"}, --"Sanctified Frost Witch's Handguards"
  [51192] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Frost Witch's Headpiece"
  [51193] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Frost Witch's Legguards"
  [51194] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Frost Witch's Spaulders"
  [51195] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Frost Witch's Chestguard"
  [51196] = {4,264,"INVTYPE_HAND"}, --"Sanctified Frost Witch's Grips"
  [51197] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Frost Witch's Faceguard"
  [51198] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Frost Witch's War-Kilt"
  [51199] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Frost Witch's Shoulderguards"
  [51200] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Frost Witch's Hauberk"
  [51201] = {4,264,"INVTYPE_HAND"}, --"Sanctified Frost Witch's Gloves"
  [51202] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Frost Witch's Helm"
  [51203] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Frost Witch's Kilt"
  [51204] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Frost Witch's Shoulderpads"
  [51205] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Dark Coven Shoulderpads"
  [51206] = {4,264,"INVTYPE_ROBE"}, --"Sanctified Dark Coven Robe"
  [51207] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Dark Coven Leggings"
  [51208] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Dark Coven Hood"
  [51209] = {4,264,"INVTYPE_HAND"}, --"Sanctified Dark Coven Gloves"
  [51210] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Ymirjar Lord's Shoulderplates"
  [51211] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Ymirjar Lord's Legplates"
  [51212] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Ymirjar Lord's Helmet"
  [51213] = {4,264,"INVTYPE_HAND"}, --"Sanctified Ymirjar Lord's Gauntlets"
  [51214] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Ymirjar Lord's Battleplate"
  [51215] = {4,264,"INVTYPE_SHOULDER"}, --"Sanctified Ymirjar Lord's Pauldrons"
  [51216] = {4,264,"INVTYPE_LEGS"}, --"Sanctified Ymirjar Lord's Legguards"
  [51217] = {4,264,"INVTYPE_HAND"}, --"Sanctified Ymirjar Lord's Handguards"
  [51218] = {4,264,"INVTYPE_HEAD"}, --"Sanctified Ymirjar Lord's Greathelm"
  [51219] = {4,264,"INVTYPE_CHEST"}, --"Sanctified Ymirjar Lord's Breastplate"
  [51220] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Ymirjar Lord's Breastplate"
  [51221] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Ymirjar Lord's Greathelm"
  [51222] = {4,277,"INVTYPE_HAND"}, --"Sanctified Ymirjar Lord's Handguards"
  [51223] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Ymirjar Lord's Legguards"
  [51224] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Ymirjar Lord's Pauldrons"
  [51225] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Ymirjar Lord's Battleplate"
  [51226] = {4,277,"INVTYPE_HAND"}, --"Sanctified Ymirjar Lord's Gauntlets"
  [51227] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Ymirjar Lord's Helmet"
  [51228] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Ymirjar Lord's Legplates"
  [51229] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Ymirjar Lord's Shoulderplates"
  [51230] = {4,277,"INVTYPE_HAND"}, --"Sanctified Dark Coven Gloves"
  [51231] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Dark Coven Hood"
  [51232] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Dark Coven Leggings"
  [51233] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Dark Coven Robe"
  [51234] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Dark Coven Shoulderpads"
  [51235] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Frost Witch's Shoulderpads"
  [51236] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Frost Witch's Kilt"
  [51237] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Frost Witch's Helm"
  [51238] = {4,277,"INVTYPE_HAND"}, --"Sanctified Frost Witch's Gloves"
  [51239] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Frost Witch's Hauberk"
  [51240] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Frost Witch's Shoulderguards"
  [51241] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Frost Witch's War-Kilt"
  [51242] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Frost Witch's Faceguard"
  [51243] = {4,277,"INVTYPE_HAND"}, --"Sanctified Frost Witch's Grips"
  [51244] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Frost Witch's Chestguard"
  [51245] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Frost Witch's Spaulders"
  [51246] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Frost Witch's Legguards"
  [51247] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Frost Witch's Headpiece"
  [51248] = {4,277,"INVTYPE_HAND"}, --"Sanctified Frost Witch's Handguards"
  [51249] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Frost Witch's Tunic"
  [51250] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Shadowblade Breastplate"
  [51251] = {4,277,"INVTYPE_HAND"}, --"Sanctified Shadowblade Gauntlets"
  [51252] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Shadowblade Helmet"
  [51253] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Shadowblade Legplates"
  [51254] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Shadowblade Pauldrons"
  [51255] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Crimson Acolyte Cowl"
  [51256] = {4,277,"INVTYPE_HAND"}, --"Sanctified Crimson Acolyte Handwraps"
  [51257] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Crimson Acolyte Mantle"
  [51258] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Crimson Acolyte Pants"
  [51259] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Crimson Acolyte Raiments"
  [51260] = {4,277,"INVTYPE_HAND"}, --"Sanctified Crimson Acolyte Gloves"
  [51261] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Crimson Acolyte Hood"
  [51262] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Crimson Acolyte Leggings"
  [51263] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Crimson Acolyte Robe"
  [51264] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Crimson Acolyte Shoulderpads"
  [51265] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Lightsworn Chestguard"
  [51266] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Lightsworn Faceguard"
  [51267] = {4,277,"INVTYPE_HAND"}, --"Sanctified Lightsworn Handguards"
  [51268] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Lightsworn Legguards"
  [51269] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Lightsworn Shoulderguards"
  [51270] = {4,277,"INVTYPE_HAND"}, --"Sanctified Lightsworn Gloves"
  [51271] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Lightsworn Greaves"
  [51272] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Lightsworn Headpiece"
  [51273] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Lightsworn Spaulders"
  [51274] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Lightsworn Tunic"
  [51275] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Lightsworn Battleplate"
  [51276] = {4,277,"INVTYPE_HAND"}, --"Sanctified Lightsworn Gauntlets"
  [51277] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Lightsworn Helmet"
  [51278] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Lightsworn Legplates"
  [51279] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Lightsworn Shoulderplates"
  [51280] = {4,277,"INVTYPE_HAND"}, --"Sanctified Bloodmage Gloves"
  [51281] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Bloodmage Hood"
  [51282] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Bloodmage Leggings"
  [51283] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Bloodmage Robe"
  [51284] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Bloodmage Shoulderpads"
  [51285] = {4,277,"INVTYPE_HAND"}, --"Sanctified Ahn'Kahar Blood Hunter's Handguards"
  [51286] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Ahn'Kahar Blood Hunter's Headpiece"
  [51287] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Ahn'Kahar Blood Hunter's Legguards"
  [51288] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Ahn'Kahar Blood Hunter's Spaulders"
  [51289] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Ahn'Kahar Blood Hunter's Tunic"
  [51290] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Lasherweave Cover"
  [51291] = {4,277,"INVTYPE_HAND"}, --"Sanctified Lasherweave Gloves"
  [51292] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Lasherweave Mantle"
  [51293] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Lasherweave Trousers"
  [51294] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Lasherweave Vestment"
  [51295] = {4,277,"INVTYPE_HAND"}, --"Sanctified Lasherweave Handgrips"
  [51296] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Lasherweave Headguard"
  [51297] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Lasherweave Legguards"
  [51298] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Lasherweave Raiment"
  [51299] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Lasherweave Shoulderpads"
  [51300] = {4,277,"INVTYPE_ROBE"}, --"Sanctified Lasherweave Robes"
  [51301] = {4,277,"INVTYPE_HAND"}, --"Sanctified Lasherweave Gauntlets"
  [51302] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Lasherweave Helmet"
  [51303] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Lasherweave Legplates"
  [51304] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Lasherweave Pauldrons"
  [51305] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Scourgelord Chestguard"
  [51306] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Scourgelord Faceguard"
  [51307] = {4,277,"INVTYPE_HAND"}, --"Sanctified Scourgelord Handguards"
  [51308] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Scourgelord Legguards"
  [51309] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Scourgelord Pauldrons"
  [51310] = {4,277,"INVTYPE_CHEST"}, --"Sanctified Scourgelord Battleplate"
  [51311] = {4,277,"INVTYPE_HAND"}, --"Sanctified Scourgelord Gauntlets"
  [51312] = {4,277,"INVTYPE_HEAD"}, --"Sanctified Scourgelord Helmet"
  [51313] = {4,277,"INVTYPE_LEGS"}, --"Sanctified Scourgelord Legplates"
  [51314] = {4,277,"INVTYPE_SHOULDER"}, --"Sanctified Scourgelord Shoulderplates"
  [51325] = {4,251,"INVTYPE_WAIST"}, --"Blood-Drinker's Girdle"
  [51326] = {4,251,"INVTYPE_RANGEDRIGHT"}, --"Wand of Ruby Claret"
  [51379] = {4,251,"INVTYPE_ROBE"}, --"Bloodsoul Raiment"
  [51380] = {4,251,"INVTYPE_FEET"}, --"Pale Corpse Boots"
  [51381] = {4,251,"INVTYPE_FINGER"}, --"Cerise Coiled Ring"
  [51382] = {4,251,"INVTYPE_CLOAK"}, --"Heartsick Mender's Cape"
  [51383] = {4,251,"INVTYPE_SHOULDER"}, --"Spaulders of the Blood Princes"
  [51384] = {4,251,"INVTYPE_WEAPON"}, --"Bloodsipper"
  [51385] = {4,251,"INVTYPE_RANGEDRIGHT"}, --"Stakethrower"
  [51386] = {4,251,"INVTYPE_HAND"}, --"Throatrender Handguards"
  [51387] = {4,251,"INVTYPE_FINGER"}, --"Seal of the Twilight Queen"
  [51548] = {4,251,"INVTYPE_NECK"}, --"Collar of Haughty Disdain"
  [51550] = {4,251,"INVTYPE_LEGS"}, --"Ivory-Inlaid Leggings"
  [51551] = {4,251,"INVTYPE_CHEST"}, --"Chestguard of Siphoned Elements"
  [51552] = {4,251,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Searing Kiss"
  [51553] = {4,251,"INVTYPE_RANGEDRIGHT"}, --"Lana'thel's Bloody Nail"
  [51554] = {4,251,"INVTYPE_HEAD"}, --"Cowl of Malefic Repose"
  [51555] = {4,251,"INVTYPE_WAIST"}, --"Tightening Waistband"
  [51556] = {4,251,"INVTYPE_HAND"}, --"Veincrusher Gauntlets"
  [51557] = {4,251,"INVTYPE_FINGER"}, --"Runed Signet of the Kirin Tor"
  [51558] = {4,251,"INVTYPE_FINGER"}, --"Runed Loop of the Kirin Tor"
  [51559] = {4,251,"INVTYPE_FINGER"}, --"Runed Ring of the Kirin Tor"
  [51560] = {4,251,"INVTYPE_FINGER"}, --"Runed Band of the Kirin Tor"
  [51561] = {4,251,"INVTYPE_RANGEDRIGHT"}, --"Dreamhunter's Carbine"
  [51562] = {4,251,"INVTYPE_2HWEAPON"}, --"Oxheart"
  [51563] = {4,251,"INVTYPE_WRIST"}, --"Taiga Bindings"
  [51564] = {4,251,"INVTYPE_WAIST"}, --"Ironrope Belt of Ymirjar"
  [51565] = {4,251,"INVTYPE_SHOULDER"}, --"Skinned Whelp Shoulders"
  [51566] = {4,251,"INVTYPE_LEGS"}, --"Legguards of the Twisted Dream"
  [51582] = {4,251,"INVTYPE_2HWEAPON"}, --"Sister Svalna's Aether Staff"
  [51583] = {4,251,"INVTYPE_HAND"}, --"Stormbringer Gloves"
  [51584] = {4,251,"INVTYPE_CLOAK"}, --"Lich Wrappings"
  [51585] = {4,251,"INVTYPE_HEAD"}, --"Sister Svalna's Spangenhelm"
  [51586] = {4,251,"INVTYPE_SHOULDER"}, --"Emerald Saint's Spaulders"
  [51682] = {4,251,"INVTYPE_SHOULDER"}, --"Scourgelord Shoulderplates"
  [51683] = {4,251,"INVTYPE_LEGS"}, --"Scourgelord Legplates"
  [51684] = {4,251,"INVTYPE_HEAD"}, --"Scourgelord Helmet"
  [51685] = {4,251,"INVTYPE_HAND"}, --"Scourgelord Gauntlets"
  [51686] = {4,251,"INVTYPE_CHEST"}, --"Scourgelord Battleplate"
  [51687] = {4,251,"INVTYPE_CHEST"}, --"Scourgelord Chestguard"
  [51688] = {4,251,"INVTYPE_HAND"}, --"Scourgelord Handguards"
  [51689] = {4,251,"INVTYPE_HEAD"}, --"Scourgelord Faceguard"
  [51690] = {4,251,"INVTYPE_LEGS"}, --"Scourgelord Legguards"
  [51691] = {4,251,"INVTYPE_SHOULDER"}, --"Scourgelord Pauldrons"
  [51692] = {4,251,"INVTYPE_SHOULDER"}, --"Lasherweave Pauldrons"
  [51693] = {4,251,"INVTYPE_LEGS"}, --"Lasherweave Legplates"
  [51694] = {4,251,"INVTYPE_HEAD"}, --"Lasherweave Helmet"
  [51695] = {4,251,"INVTYPE_HAND"}, --"Lasherweave Gauntlets"
  [51696] = {4,251,"INVTYPE_ROBE"}, --"Lasherweave Robes"
  [51697] = {4,251,"INVTYPE_ROBE"}, --"Lasherweave Raiment"
  [51698] = {4,251,"INVTYPE_HAND"}, --"Lasherweave Handgrips"
  [51699] = {4,251,"INVTYPE_HEAD"}, --"Lasherweave Headguard"
  [51700] = {4,251,"INVTYPE_LEGS"}, --"Lasherweave Legguards"
  [51701] = {4,251,"INVTYPE_SHOULDER"}, --"Lasherweave Shoulderpads"
  [51702] = {4,251,"INVTYPE_ROBE"}, --"Lasherweave Vestment"
  [51703] = {4,251,"INVTYPE_HAND"}, --"Lasherweave Gloves"
  [51704] = {4,251,"INVTYPE_HEAD"}, --"Lasherweave Cover"
  [51705] = {4,251,"INVTYPE_LEGS"}, --"Lasherweave Trousers"
  [51706] = {4,251,"INVTYPE_SHOULDER"}, --"Lasherweave Mantle"
  [51707] = {4,251,"INVTYPE_CHEST"}, --"Ahn'Kahar Blood Hunter's Tunic"
  [51708] = {4,251,"INVTYPE_SHOULDER"}, --"Ahn'Kahar Blood Hunter's Spaulders"
  [51709] = {4,251,"INVTYPE_LEGS"}, --"Ahn'Kahar Blood Hunter's Legguards"
  [51710] = {4,251,"INVTYPE_HEAD"}, --"Ahn'Kahar Blood Hunter's Headpiece"
  [51711] = {4,251,"INVTYPE_HAND"}, --"Ahn'Kahar Blood Hunter's Handguards"
  [51712] = {4,251,"INVTYPE_SHOULDER"}, --"Bloodmage Shoulderpads"
  [51713] = {4,251,"INVTYPE_ROBE"}, --"Bloodmage Robe"
  [51714] = {4,251,"INVTYPE_LEGS"}, --"Bloodmage Leggings"
  [51715] = {4,251,"INVTYPE_HEAD"}, --"Bloodmage Hood"
  [51716] = {4,251,"INVTYPE_HAND"}, --"Bloodmage Gloves"
  [51717] = {4,251,"INVTYPE_CHEST"}, --"Lightsworn Battleplate"
  [51718] = {4,251,"INVTYPE_HAND"}, --"Lightsworn Gauntlets"
  [51719] = {4,251,"INVTYPE_HEAD"}, --"Lightsworn Helmet"
  [51720] = {4,251,"INVTYPE_LEGS"}, --"Lightsworn Legplates"
  [51721] = {4,251,"INVTYPE_SHOULDER"}, --"Lightsworn Shoulderplates"
  [51722] = {4,251,"INVTYPE_CHEST"}, --"Lightsworn Tunic"
  [51723] = {4,251,"INVTYPE_HAND"}, --"Lightsworn Gloves"
  [51724] = {4,251,"INVTYPE_HEAD"}, --"Lightsworn Headpiece"
  [51725] = {4,251,"INVTYPE_LEGS"}, --"Lightsworn Greaves"
  [51726] = {4,251,"INVTYPE_SHOULDER"}, --"Lightsworn Spaulders"
  [51727] = {4,251,"INVTYPE_CHEST"}, --"Lightsworn Chestguard"
  [51728] = {4,251,"INVTYPE_HAND"}, --"Lightsworn Handguards"
  [51729] = {4,251,"INVTYPE_HEAD"}, --"Lightsworn Faceguard"
  [51730] = {4,251,"INVTYPE_LEGS"}, --"Lightsworn Legguards"
  [51731] = {4,251,"INVTYPE_SHOULDER"}, --"Lightsworn Shoulderguards"
  [51732] = {4,251,"INVTYPE_LEGS"}, --"Crimson Acolyte Leggings"
  [51733] = {4,251,"INVTYPE_ROBE"}, --"Crimson Acolyte Robe"
  [51734] = {4,251,"INVTYPE_SHOULDER"}, --"Crimson Acolyte Shoulderpads"
  [51735] = {4,251,"INVTYPE_HAND"}, --"Crimson Acolyte Gloves"
  [51736] = {4,251,"INVTYPE_HEAD"}, --"Crimson Acolyte Hood"
  [51737] = {4,251,"INVTYPE_HEAD"}, --"Crimson Acolyte Cowl"
  [51738] = {4,251,"INVTYPE_HAND"}, --"Crimson Acolyte Handwraps"
  [51739] = {4,251,"INVTYPE_SHOULDER"}, --"Crimson Acolyte Mantle"
  [51740] = {4,251,"INVTYPE_ROBE"}, --"Crimson Acolyte Raiments"
  [51741] = {4,251,"INVTYPE_LEGS"}, --"Crimson Acolyte Pants"
  [51742] = {4,251,"INVTYPE_HAND"}, --"Shadowblade Gauntlets"
  [51743] = {4,251,"INVTYPE_CHEST"}, --"Shadowblade Breastplate"
  [51744] = {4,251,"INVTYPE_LEGS"}, --"Shadowblade Legplates"
  [51745] = {4,251,"INVTYPE_HEAD"}, --"Shadowblade Helmet"
  [51746] = {4,251,"INVTYPE_SHOULDER"}, --"Shadowblade Pauldrons"
  [51747] = {4,251,"INVTYPE_CHEST"}, --"Frost Witch's Tunic"
  [51748] = {4,251,"INVTYPE_HAND"}, --"Frost Witch's Handguards"
  [51749] = {4,251,"INVTYPE_HEAD"}, --"Frost Witch's Headpiece"
  [51750] = {4,251,"INVTYPE_LEGS"}, --"Frost Witch's Legguards"
  [51751] = {4,251,"INVTYPE_SHOULDER"}, --"Frost Witch's Spaulders"
  [51752] = {4,251,"INVTYPE_CHEST"}, --"Frost Witch's Chestguard"
  [51753] = {4,251,"INVTYPE_HAND"}, --"Frost Witch's Grips"
  [51754] = {4,251,"INVTYPE_HEAD"}, --"Frost Witch's Faceguard"
  [51755] = {4,251,"INVTYPE_LEGS"}, --"Frost Witch's War-Kilt"
  [51756] = {4,251,"INVTYPE_SHOULDER"}, --"Frost Witch's Shoulderguards"
  [51757] = {4,251,"INVTYPE_CHEST"}, --"Frost Witch's Hauberk"
  [51758] = {4,251,"INVTYPE_HAND"}, --"Frost Witch's Gloves"
  [51759] = {4,251,"INVTYPE_HEAD"}, --"Frost Witch's Helm"
  [51760] = {4,251,"INVTYPE_LEGS"}, --"Frost Witch's Kilt"
  [51761] = {4,251,"INVTYPE_SHOULDER"}, --"Frost Witch's Shoulderpads"
  [51762] = {4,251,"INVTYPE_SHOULDER"}, --"Dark Coven Shoulderpads"
  [51763] = {4,251,"INVTYPE_ROBE"}, --"Dark Coven Robe"
  [51764] = {4,251,"INVTYPE_LEGS"}, --"Dark Coven Leggings"
  [51765] = {4,251,"INVTYPE_HEAD"}, --"Dark Coven Hood"
  [51766] = {4,251,"INVTYPE_HAND"}, --"Dark Coven Gloves"
  [51767] = {4,251,"INVTYPE_SHOULDER"}, --"Ymirjar Lord's Shoulderplates"
  [51768] = {4,251,"INVTYPE_LEGS"}, --"Ymirjar Lord's Legplates"
  [51769] = {4,251,"INVTYPE_HEAD"}, --"Ymirjar Lord's Helmet"
  [51770] = {4,251,"INVTYPE_HAND"}, --"Ymirjar Lord's Gauntlets"
  [51771] = {4,251,"INVTYPE_CHEST"}, --"Ymirjar Lord's Battleplate"
  [51772] = {4,251,"INVTYPE_CHEST"}, --"Ymirjar Lord's Breastplate"
  [51773] = {4,251,"INVTYPE_HAND"}, --"Ymirjar Lord's Handguards"
  [51774] = {4,251,"INVTYPE_HEAD"}, --"Ymirjar Lord's Greathelm"
  [51775] = {4,251,"INVTYPE_LEGS"}, --"Ymirjar Lord's Legguards"
  [51776] = {4,251,"INVTYPE_SHOULDER"}, --"Ymirjar Lord's Pauldrons"
  [51777] = {4,251,"INVTYPE_LEGS"}, --"Leggings of the Refracted Mind"
  [51779] = {4,251,"INVTYPE_NECK"}, --"Rimetooth Pendant"
  [51782] = {4,251,"INVTYPE_WAIST"}, --"Etched Dragonbone Girdle"
  [51783] = {4,251,"INVTYPE_WRIST"}, --"Vambraces of the Frost Wyrm Queen"
  [51784] = {4,251,"INVTYPE_WEAPONOFFHAND"}, --"Splintershard"
  [51785] = {4,251,"INVTYPE_FEET"}, --"Wyrmwing Treads"
  [51786] = {4,251,"INVTYPE_LEGS"}, --"Legplates of Aetheric Strife"
  [51787] = {4,251,"INVTYPE_FEET"}, --"Scourge Fanged Stompers"
  [51788] = {4,251,"INVTYPE_WEAPONMAINHAND"}, --"Bleak Coldarra Carver"
  [51789] = {4,251,"INVTYPE_HAND"}, --"Icicle Shapers"
  [51790] = {4,251,"INVTYPE_ROBE"}, --"Robes of Azure Downfall"
  [51791] = {4,251,"INVTYPE_SHIELD"}, --"Lost Pavise of the Blue Flight"
  [51792] = {4,251,"INVTYPE_SHOULDER"}, --"Shoulderguards of Crystalline Bone"
  [51795] = {4,258,"INVTYPE_WEAPON"}, --"Troggbane, Axe of the Frostborne King"
  [51796] = {4,258,"INVTYPE_2HWEAPON"}, --"Warmace of Menethil"
  [51797] = {4,258,"INVTYPE_2HWEAPON"}, --"Tainted Twig of Nordrassil"
  [51798] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Valius, Gavel of the Lightbringer"
  [51799] = {4,258,"INVTYPE_2HWEAPON"}, --"Halion, Staff of Forgotten Love"
  [51800] = {4,258,"INVTYPE_WEAPON"}, --"Stormfury, Black Blade of the Betrayer"
  [51801] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Pugius, Fist of Defiance"
  [51802] = {4,258,"INVTYPE_RANGEDRIGHT"}, --"Windrunner's Heartseeker"
  [51803] = {4,258,"INVTYPE_WEAPONMAINHAND"}, --"Tel'thas, Dagger of the Blood King"
  [51804] = {4,226,"INVTYPE_NECK"}, --"Winking Eye of Love"
  [51805] = {4,226,"INVTYPE_NECK"}, --"Heartbreak Charm"
  [51806] = {4,226,"INVTYPE_NECK"}, --"Shard of Pirouetting Happiness"
  [51807] = {4,226,"INVTYPE_NECK"}, --"Sweet Perfume Broach"
  [51808] = {4,226,"INVTYPE_NECK"}, --"Choker of the Pure Heart"
  [51811] = {4,264,"INVTYPE_SHOULDER"}, --"Shoulderguards of Crystalline Bone"
  [51812] = {4,264,"INVTYPE_SHIELD"}, --"Lost Pavise of the Blue Flight"
  [51813] = {4,264,"INVTYPE_ROBE"}, --"Robes of Azure Downfall"
  [51814] = {4,264,"INVTYPE_HAND"}, --"Icicle Shapers"
  [51815] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Bleak Coldarra Carver"
  [51816] = {4,264,"INVTYPE_FEET"}, --"Scourge Fanged Stompers"
  [51817] = {4,264,"INVTYPE_LEGS"}, --"Legplates of Aetheric Strife"
  [51818] = {4,264,"INVTYPE_FEET"}, --"Wyrmwing Treads"
  [51819] = {4,264,"INVTYPE_WEAPONOFFHAND"}, --"Splintershard"
  [51820] = {4,264,"INVTYPE_WRIST"}, --"Vambraces of the Frost Wyrm Queen"
  [51821] = {4,264,"INVTYPE_WAIST"}, --"Etched Dragonbone Girdle"
  [51822] = {4,264,"INVTYPE_NECK"}, --"Rimetooth Pendant"
  [51823] = {4,264,"INVTYPE_LEGS"}, --"Leggings of the Refracted Mind"
  [51824] = {4,264,"INVTYPE_SHOULDER"}, --"Emerald Saint's Spaulders"
  [51825] = {4,264,"INVTYPE_HEAD"}, --"Sister Svalna's Spangenhelm"
  [51826] = {4,264,"INVTYPE_CLOAK"}, --"Lich Wrappings"
  [51827] = {4,264,"INVTYPE_HAND"}, --"Stormbringer Gloves"
  [51828] = {4,264,"INVTYPE_2HWEAPON"}, --"Sister Svalna's Aether Staff"
  [51829] = {4,264,"INVTYPE_LEGS"}, --"Legguards of the Twisted Dream"
  [51830] = {4,264,"INVTYPE_SHOULDER"}, --"Skinned Whelp Shoulders"
  [51831] = {4,264,"INVTYPE_WAIST"}, --"Ironrope Belt of Ymirjar"
  [51832] = {4,264,"INVTYPE_WRIST"}, --"Taiga Bindings"
  [51833] = {4,264,"INVTYPE_2HWEAPON"}, --"Oxheart"
  [51834] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Dreamhunter's Carbine"
  [51835] = {4,264,"INVTYPE_HAND"}, --"Veincrusher Gauntlets"
  [51836] = {4,264,"INVTYPE_WAIST"}, --"Tightening Waistband"
  [51837] = {4,264,"INVTYPE_HEAD"}, --"Cowl of Malefic Repose"
  [51838] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Lana'thel's Bloody Nail"
  [51839] = {4,264,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Searing Kiss"
  [51840] = {4,264,"INVTYPE_CHEST"}, --"Chestguard of Siphoned Elements"
  [51841] = {4,264,"INVTYPE_LEGS"}, --"Ivory-Inlaid Leggings"
  [51842] = {4,264,"INVTYPE_NECK"}, --"Collar of Haughty Disdain"
  [51843] = {4,264,"INVTYPE_FINGER"}, --"Seal of the Twilight Queen"
  [51844] = {4,264,"INVTYPE_HAND"}, --"Throatrender Handguards"
  [51845] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Stakethrower"
  [51846] = {4,264,"INVTYPE_WEAPON"}, --"Bloodsipper"
  [51847] = {4,264,"INVTYPE_SHOULDER"}, --"Spaulders of the Blood Princes"
  [51848] = {4,264,"INVTYPE_CLOAK"}, --"Heartsick Mender's Cape"
  [51849] = {4,264,"INVTYPE_FINGER"}, --"Cerise Coiled Ring"
  [51850] = {4,264,"INVTYPE_FEET"}, --"Pale Corpse Boots"
  [51851] = {4,264,"INVTYPE_ROBE"}, --"Bloodsoul Raiment"
  [51852] = {4,264,"INVTYPE_RANGEDRIGHT"}, --"Wand of Ruby Claret"
  [51853] = {4,264,"INVTYPE_WAIST"}, --"Blood-Drinker's Girdle"
  [51854] = {4,264,"INVTYPE_LEGS"}, --"Battle-Maiden's Legguards"
  [51855] = {4,264,"INVTYPE_FINGER"}, --"Thrice Fanged Signet"
  [51856] = {4,264,"INVTYPE_FEET"}, --"Taldaram's Soft Slippers"
  [51857] = {4,264,"INVTYPE_2HWEAPON"}, --"Hersir's Greatspear"
  [51858] = {4,264,"INVTYPE_WEAPON"}, --"Soulbreaker"
  [51859] = {4,264,"INVTYPE_SHOULDER"}, --"Shoulders of Ruinous Senility"
  [51860] = {4,264,"INVTYPE_LEGS"}, --"Rippling Flesh Kilt"
  [51861] = {4,264,"INVTYPE_CHEST"}, --"Chestplate of Septic Stitches"
  [51862] = {4,264,"INVTYPE_WAIST"}, --"Cauterized Cord"
  [51863] = {4,264,"INVTYPE_NECK"}, --"Pendant of Split Veins"
  [51864] = {4,264,"INVTYPE_SHOULDER"}, --"Shoulderpads of the Morbid Ritual"
  [51865] = {4,264,"INVTYPE_SHOULDER"}, --"Scalpel-Sharpening Shoulderguards"
  [51866] = {4,264,"INVTYPE_HEAD"}, --"Discarded Bag of Entrails"
  [51867] = {4,264,"INVTYPE_NECK"}, --"Infected Choker"
  [51868] = {4,264,"INVTYPE_WEAPON"}, --"Flesh-Carving Scalpel"
  [51869] = {4,264,"INVTYPE_WEAPON"}, --"The Facelifter"
  [51870] = {4,264,"INVTYPE_ROBE"}, --"Chestguard of the Failed Experiment"
  [51871] = {4,264,"INVTYPE_NECK"}, --"Choker of Filthy Diamonds"
  [51872] = {4,264,"INVTYPE_WRIST"}, --"Ether-Soaked Bracers"
  [51873] = {4,264,"INVTYPE_FEET"}, --"Shuffling Shoes"
  [51874] = {4,264,"INVTYPE_HAND"}, --"Gloves of Broken Fingers"
  [51875] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Lockjaw"
  [51876] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Abomination Knuckles"
  [51877] = {4,264,"INVTYPE_HEAD"}, --"Taldron's Short-Sighted Helm"
  [51878] = {4,264,"INVTYPE_FINGER"}, --"Rotface's Rupturing Ring"
  [51879] = {4,264,"INVTYPE_WAIST"}, --"Flesh-Shaper's Gurney Strap"
  [51880] = {4,264,"INVTYPE_THROWN"}, --"Gluth's Fetching Knife"
  [51881] = {4,264,"INVTYPE_2HWEAPON"}, --"Shaft of Glacial Ice"
  [51882] = {4,264,"INVTYPE_LEGS"}, --"Kilt of Untreated Wounds"
  [51883] = {4,264,"INVTYPE_SHOULDER"}, --"Bloodstained Surgeon's Shoulderguards"
  [51884] = {4,264,"INVTYPE_FINGER"}, --"Signet of Putrefaction"
  [51885] = {4,264,"INVTYPE_WRIST"}, --"Wrists of Septic Shock"
  [51886] = {4,264,"INVTYPE_HAND"}, --"Festergut's Gaseous Gloves"
  [51887] = {4,264,"INVTYPE_2HWEAPON"}, --"Abracadaver"
  [51888] = {4,264,"INVTYPE_CLOAK"}, --"Cloak of Many Skins"
  [51889] = {4,264,"INVTYPE_LEGS"}, --"Plague-Soaked Leather Leggings"
  [51890] = {4,264,"INVTYPE_NECK"}, --"Precious's Putrid Collar"
  [51891] = {4,264,"INVTYPE_FEET"}, --"Taldron's Long Neglected Boots"
  [51892] = {4,264,"INVTYPE_HAND"}, --"Festering Fingerguards"
  [51893] = {4,264,"INVTYPE_WEAPON"}, --"Gutbuster"
  [51894] = {4,264,"INVTYPE_NECK"}, --"Soulcleave Pendant"
  [51895] = {4,264,"INVTYPE_LEGS"}, --"Deathforged Legplates"
  [51896] = {4,264,"INVTYPE_HEAD"}, --"Thaumaturge's Crackling Cowl"
  [51897] = {4,264,"INVTYPE_LEGS"}, --"Leggings of Unrelenting Blood"
  [51898] = {4,264,"INVTYPE_2HWEAPON"}, --"Mag'hari Chieftain's Staff"
  [51899] = {4,264,"INVTYPE_FEET"}, --"Icecrown Spire Sandals"
  [51900] = {4,264,"INVTYPE_FINGER"}, --"Saurfang's Cold-Forged Band"
  [51901] = {4,264,"INVTYPE_WRIST"}, --"Gargoyle Spit Bracers"
  [51902] = {4,264,"INVTYPE_CHEST"}, --"Blade-Scored Carapace"
  [51903] = {4,264,"INVTYPE_CHEST"}, --"Hauberk of a Thousand Cuts"
  [51904] = {4,264,"INVTYPE_HAND"}, --"Scourge Stranglers"
  [51905] = {4,264,"INVTYPE_2HWEAPON"}, --"Ramaladni's Blade of Culling"
  [51906] = {4,264,"INVTYPE_HEAD"}, --"Ice-Reinforced Vrykul Helm"
  [51907] = {4,264,"INVTYPE_WRIST"}, --"Bracers of Pale Illumination"
  [51908] = {4,264,"INVTYPE_WAIST"}, --"Cord of Dark Suffering"
  [51909] = {4,264,"INVTYPE_SHIELD"}, --"Neverending Winter"
  [51910] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Midnight Sun"
  [51911] = {4,264,"INVTYPE_SHOULDER"}, --"Pauldrons of Lost Hope"
  [51912] = {4,264,"INVTYPE_CLOAK"}, --"Saronite Gargoyle Cloak"
  [51913] = {4,264,"INVTYPE_FINGER"}, --"Abomination's Bloody Ring"
  [51914] = {4,264,"INVTYPE_WRIST"}, --"Icecrown Rampart Bracers"
  [51915] = {4,264,"INVTYPE_FEET"}, --"Bone Drake's Enameled Boots"
  [51916] = {4,264,"INVTYPE_WEAPON"}, --"Frost Giant's Cleaver"
  [51917] = {4,264,"INVTYPE_CHEST"}, --"Ghoul Commander's Cuirass"
  [51918] = {4,264,"INVTYPE_WRIST"}, --"Bracers of Dark Blessings"
  [51919] = {4,264,"INVTYPE_WAIST"}, --"Deathspeaker Disciple's Belt"
  [51920] = {4,264,"INVTYPE_FEET"}, --"Boots of the Frozen Seed"
  [51921] = {4,264,"INVTYPE_HAND"}, --"Sister's Handshrouds"
  [51922] = {4,264,"INVTYPE_HOLDABLE"}, --"Scourgelord's Baton"
  [51923] = {4,264,"INVTYPE_CHEST"}, --"Chestguard of the Frigid Noose"
  [51924] = {4,264,"INVTYPE_HEAD"}, --"Deathspeaker Zealot's Helm"
  [51925] = {4,264,"INVTYPE_WAIST"}, --"Soulthief's Braided Belt"
  [51926] = {4,264,"INVTYPE_HAND"}, --"Handgrips of Frost and Sleet"
  [51927] = {4,264,"INVTYPE_RANGED"}, --"Njorndar Bone Bow"
  [51928] = {4,264,"INVTYPE_LEGS"}, --"Corrupted Silverplate Leggings"
  [51929] = {4,264,"INVTYPE_WRIST"}, --"Coldwraith Bracers"
  [51930] = {4,264,"INVTYPE_WAIST"}, --"Cord of the Patronizing Practitioner"
  [51931] = {4,264,"INVTYPE_FEET"}, --"Ancient Skeletal Boots"
  [51932] = {4,264,"INVTYPE_WEAPONMAINHAND"}, --"Frost Needle"
  [51933] = {4,264,"INVTYPE_CLOAK"}, --"Shawl of Nerubian Silk"
  [51934] = {4,264,"INVTYPE_NECK"}, --"Marrowgar's Scratching Choker"
  [51935] = {4,264,"INVTYPE_WAIST"}, --"Linked Scourge Vertebrae"
  [51936] = {4,264,"INVTYPE_2HWEAPON"}, --"Citadel Enforcer's Claymore"
  [51937] = {4,264,"INVTYPE_WEAPON"}, --"Bonebreaker Scepter"
  [51938] = {4,264,"INVTYPE_WEAPON"}, --"Bone Warden's Splitter"
  [51939] = {4,271,"INVTYPE_WEAPONMAINHAND"}, --"Tel'thas, Dagger of the Blood King"
  [51940] = {4,271,"INVTYPE_RANGEDRIGHT"}, --"Windrunner's Heartseeker"
  [51941] = {4,271,"INVTYPE_WEAPONMAINHAND"}, --"Pugius, Fist of Defiance"
  [51942] = {4,271,"INVTYPE_WEAPON"}, --"Stormfury, Black Blade of the Betrayer"
  [51943] = {4,271,"INVTYPE_2HWEAPON"}, --"Halion, Staff of Forgotten Love"
  [51944] = {4,271,"INVTYPE_WEAPONMAINHAND"}, --"Valius, Gavel of the Lightbringer"
  [51945] = {4,271,"INVTYPE_2HWEAPON"}, --"Tainted Twig of Nordrassil"
  [51946] = {4,271,"INVTYPE_2HWEAPON"}, --"Warmace of Menethil"
  [51947] = {4,271,"INVTYPE_WEAPON"}, --"Troggbane, Axe of the Frostborne King"
  [52569] = {4,251,"INVTYPE_FINGER"}, --"Ashen Band of Might"
  [52570] = {4,259,"INVTYPE_FINGER"}, --"Ashen Band of Greater Might"
  [52571] = {4,268,"INVTYPE_FINGER"}, --"Ashen Band of Unmatched Might"
  [52572] = {4,277,"INVTYPE_FINGER"}, --"Ashen Band of Endless Might"
  [53103] = {4,258,"INVTYPE_NECK"}, --"Baltharus' Gift"
  [53110] = {4,258,"INVTYPE_FINGER"}, --"Zarithrian's Offering"
  [53111] = {4,258,"INVTYPE_FEET"}, --"Scion's Treads"
  [53112] = {4,258,"INVTYPE_WRIST"}, --"Bracers of the Heir"
  [53113] = {4,258,"INVTYPE_SHOULDER"}, --"Twilight Scale Shoulders"
  [53114] = {4,258,"INVTYPE_CHEST"}, --"Gloaming Sark"
  [53115] = {4,258,"INVTYPE_CLOAK"}, --"Abduction's Cover"
  [53116] = {4,258,"INVTYPE_FINGER"}, --"Saviana's Tribute"
  [53117] = {4,258,"INVTYPE_HAND"}, --"Changeling Gloves"
  [53118] = {4,258,"INVTYPE_WAIST"}, --"Misbegotten Belt"
  [53119] = {4,258,"INVTYPE_FEET"}, --"Boots of Divided Being"
  [53121] = {4,258,"INVTYPE_WAIST"}, --"Surrogate Belt"
  [53125] = {4,271,"INVTYPE_FEET"}, --"Apocalypse's Advance"
  [53126] = {4,271,"INVTYPE_WRIST"}, --"Umbrage Armbands"
  [53127] = {4,271,"INVTYPE_FEET"}, --"Returning Footfalls"
  [53129] = {4,271,"INVTYPE_FEET"}, --"Treads of Impending Resurrection"
  [53132] = {4,271,"INVTYPE_NECK"}, --"Penumbra Pendant"
  [53133] = {4,271,"INVTYPE_FINGER"}, --"Signet of Twilight"
  [53134] = {4,271,"INVTYPE_WRIST"}, --"Phaseshifter's Bracers"
  [53486] = {4,271,"INVTYPE_WRIST"}, --"Bracers of Fiery Night"
  [53487] = {4,271,"INVTYPE_FEET"}, --"Foreshadow Steps"
  [53488] = {4,271,"INVTYPE_WAIST"}, --"Split Shape Belt"
  [53489] = {4,271,"INVTYPE_CLOAK"}, --"Cloak of Burning Dusk"
  [53490] = {4,271,"INVTYPE_FINGER"}, --"Ring of Phased Regeneration"
  [53491] = {4,232,"INVTYPE_WRIST"}, --"Twilight Offering Bands"
  [53492] = {4,232,"INVTYPE_FINGER"}, --"Ring of the Three Headed Beast"
  [53493] = {4,232,"INVTYPE_LEGS"}, --"Sacrificial Mail"
  [53494] = {4,232,"INVTYPE_WAIST"}, --"Girdle of Oblation"
  [53495] = {4,232,"INVTYPE_FINGER"}, --"Old Gods' Blessing"
  [53496] = {4,232,"INVTYPE_SHIELD"}, --"Barrier of the Earth Princess"
  [53497] = {4,232,"INVTYPE_CLOAK"}, --"Zaetar's Deathshroud"
  [53498] = {4,232,"INVTYPE_ROBE"}, --"Earth Bride's Gown"
  [53499] = {4,232,"INVTYPE_NECK"}, --"Amulet of the Centauri"
  [53500] = {4,232,"INVTYPE_CHEST"}, --"Tectonic Plate"
  [53501] = {4,232,"INVTYPE_FINGER"}, --"Sulfuron's Favor"
  [53502] = {4,232,"INVTYPE_NECK"}, --"Flamelash Amulet"
  [53503] = {4,232,"INVTYPE_NECK"}, --"Pendant of Burning Spirits"
  [53504] = {4,232,"INVTYPE_FEET"}, --"Flamewaker's Treads"
  [53505] = {4,232,"INVTYPE_CHEST"}, --"Salamander Skin"
  [53506] = {4,232,"INVTYPE_CLOAK"}, --"Cloak of Mocking Winds"
  [53507] = {4,232,"INVTYPE_FEET"}, --"Sandfury Sandals"
  [53508] = {4,232,"INVTYPE_CHEST"}, --"Pulmonary Casing"
  [53509] = {4,232,"INVTYPE_NECK"}, --"Amulet of Evil Winds"
  [54556] = {4,271,"INVTYPE_CLOAK"}, --"Abduction's Cover"
  [54557] = {4,271,"INVTYPE_NECK"}, --"Baltharus' Gift"
  [54558] = {4,271,"INVTYPE_FEET"}, --"Boots of Divided Being"
  [54559] = {4,271,"INVTYPE_WRIST"}, --"Bracers of the Heir"
  [54560] = {4,271,"INVTYPE_HAND"}, --"Changeling Gloves"
  [54561] = {4,271,"INVTYPE_CHEST"}, --"Gloaming Sark"
  [54562] = {4,271,"INVTYPE_WAIST"}, --"Misbegotten Belt"
  [54563] = {4,271,"INVTYPE_FINGER"}, --"Saviana's Tribute"
  [54564] = {4,271,"INVTYPE_FEET"}, --"Scion's Treads"
  [54565] = {4,271,"INVTYPE_WAIST"}, --"Surrogate Belt"
  [54566] = {4,271,"INVTYPE_SHOULDER"}, --"Twilight Scale Shoulders"
  [54567] = {4,271,"INVTYPE_FINGER"}, --"Zarithrian's Offering"
  [54569] = {4,271,"INVTYPE_TRINKET"}, --"Sharpened Twilight Scale"
  [54571] = {4,271,"INVTYPE_TRINKET"}, --"Petrified Twilight Scale"
  [54572] = {4,271,"INVTYPE_TRINKET"}, --"Charred Twilight Scale"
  [54573] = {4,271,"INVTYPE_TRINKET"}, --"Glowing Twilight Scale"
  [54576] = {4,284,"INVTYPE_FINGER"}, --"Signet of Twilight"
  [54577] = {4,284,"INVTYPE_FEET"}, --"Returning Footfalls"
  [54578] = {4,284,"INVTYPE_FEET"}, --"Apocalypse's Advance"
  [54579] = {4,284,"INVTYPE_FEET"}, --"Treads of Impending Resurrection"
  [54580] = {4,284,"INVTYPE_WRIST"}, --"Umbrage Armbands"
  [54581] = {4,284,"INVTYPE_NECK"}, --"Penumbra Pendant"
  [54582] = {4,284,"INVTYPE_WRIST"}, --"Bracers of Fiery Night"
  [54583] = {4,284,"INVTYPE_CLOAK"}, --"Cloak of Burning Dusk"
  [54584] = {4,284,"INVTYPE_WRIST"}, --"Phaseshifter's Bracers"
  [54585] = {4,284,"INVTYPE_FINGER"}, --"Ring of Phased Regeneration"
  [54586] = {4,284,"INVTYPE_FEET"}, --"Foreshadow Steps"
  [54587] = {4,284,"INVTYPE_WAIST"}, --"Split Shape Belt"
  [54588] = {4,284,"INVTYPE_TRINKET"}, --"Charred Twilight Scale"
  [54589] = {4,284,"INVTYPE_TRINKET"}, --"Glowing Twilight Scale"
  [54590] = {4,284,"INVTYPE_TRINKET"}, --"Sharpened Twilight Scale"
  [54591] = {4,284,"INVTYPE_TRINKET"}, --"Petrified Twilight Scale"
  [54592] = {4,232,"INVTYPE_WRIST"}, --"Sul'Iithuz Scale Bracers"
  [54801] = {4,232,"INVTYPE_CLOAK"}, --"Icebound Cloak"
  [54802] = {4,232,"INVTYPE_CLOAK"}, --"The Frost Lord's War Cloak"
  [54803] = {4,232,"INVTYPE_CLOAK"}, --"The Frost Lord's Battle Shroud"
  [54804] = {4,232,"INVTYPE_CLOAK"}, --"Shroud of Winter's Chill"
  [54805] = {4,232,"INVTYPE_CLOAK"}, --"Cloak of the Frigid Winds"
  [54806] = {4,232,"INVTYPE_2HWEAPON"}, --"Frostscythe of Lord Ahune"
}

for k,v in pairs(CACHED_ITEM_DATA) do
  if not prices[k] then
    prices[k] = v
  end
end
for k,v in pairs(CUSTOM_ITEM_DATA) do
  if not prices[k] and v[2]>=200 then -- exclude pre-wrath
    prices[k] = v
  end
end

-- The default quality threshold:
-- 0 - Poor
-- 1 - Uncommon
-- 2 - Common
-- 3 - Rare
-- 4 - Epic
-- 5 - Legendary
-- 6 - Artifact
local quality_threshold = 4

local function getStaticValues(itemID, itemQuality, itemLevel, itemEquipLoc)
  -- Check our item database
  if CACHED_ITEM_DATA[itemID] then
    itemQuality, itemLevel, itemEquipLoc = unpack(CACHED_ITEM_DATA[itemID])
  end

  -- Check to see if there is custom data for this item ID
  if CUSTOM_ITEM_DATA[itemID] then
    itemQuality, itemLevel, itemEquipLoc = unpack(CUSTOM_ITEM_DATA[itemID])
  end

  -- Is the item above our minimum threshold?
  if not itemQuality or itemQuality < quality_threshold then
    return nil, nil, itemLevel, itemQuality, itemEquipLoc
  end

  local slot_multiplier1 = EQUIPSLOT_MULTIPLIER_1[itemEquipLoc]
  local slot_multiplier2 = EQUIPSLOT_MULTIPLIER_2[itemEquipLoc]

  if not slot_multiplier1 then
    return nil, nil, itemLevel, itemQuality, itemEquipLoc
  end
  local gp_base = 4.83 * 2 ^ (itemLevel/50 + (itemQuality - 4)) -- ~20% increase per tier (13ilvl) 
  local high = math.floor(gp_base * slot_multiplier1)
  local low = slot_multiplier2 and math.floor(gp_base * slot_multiplier2) or nil
  return high, low
end
--/run for _,i in ipairs({200,213,226,239,251,264,277})do print(4.83 * 2 ^ (i/50))end
-- 213,219,226,232,245,251,258,264,277,
--[[
updated in P2: -- some ulduar/hardmode/weapons ilevels are speculative
T7-10   :  200-213 (base, end-bosses/sarth2D+)
T7-25   :  213-226 (base, end-bosses/sarth2D+)

T8-10   :  225-232-239-245 (base, weapons, hardmode/algalon, hardmode/algalon weapons)
T8-25   :  232-238-252-258 (base, weapons, hardmode/algalon, hardmode/algalon weapons)

T9-10   :  232-245-258 (base, heroic, tribute)
T9-25   :  245-258-272 (base, heroic, tribute)

T10-10  :  251-258-264-271 (base, end-boss, heroic, heroic end-boss)
T10-25  :  264-271-277-284 (base, end-boss, heroic, heroic end-boss)

T10.5-10:  258-271 (base, heroic)
T10.5-25:  271-284 (base, heroic)
]]

local function calcTier(ilevel)
  if not ilevel then return end
  local tier = "T10.5"
  if ilevel <=209 then
    tier = "T7"
  elseif ilevel <=219 then
    tier = "T7.5"
  elseif ilevel <=229 then
    tier = "T8"
  elseif ilevel <=239 then
    tier = "T8.5"
  elseif ilevel <=249 then
    tier = "T9"
  elseif ilevel <=259 then
    tier = "T9.5"
  elseif ilevel <=269 then
    tier = "T10"
  elseif ilevel >=270 then
    tier = "T10.5"
  end
  return tier
end

local function GetDiscountDetail(invType, classID, subclassID)
  --[[Bit of documentation here
  Some discounts are baked-in for historical reasons of how the epgp price calculation worked off item equip location. Equip location lumps together some items (eg wands + some ranged weapon types) that have conditional discounts (based on class and role which is dynamic) so a human was needed to apply this manually. The formula just returned "this equiplocation has 2 possible valuations, you pick the correct one".

  We can only decide discount status deterministically for certain combinations.
  Two-Handed melee weapon to Hunter
  Main-hand or One-hand melee weapon to Hunter (Off-hand melee weapon has discount baked-in)
  Shield to Shaman (as the only non-tank shield bearer)
  Any ranged weapon to melee (ie Warrior or Rogue)
  All Wands (epgp formula is done based on inventory type and they share IndexRangedRight with some ranged weapons)

  Other cases still need a human deciding (One-hand melee weapon to Tank for tanking, One-hand melee weapon to tank or melee for Dual Wield Offhand use, Shield to Paladin, Two-hand melee weapon to Titan Grip warrior for Offhand use)
  ]]
  local wand_discount = subclassID == Enum.ItemWeaponSubclass.Wand
  local ranged_discount = ((invType == Enum.InventoryType.IndexRangedType) or (invType == Enum.InventoryType.IndexRangedrightType)) and "WARRIOR:ROGUE"
  local shield_discount = (subclassID == Enum.ItemArmorSubclass.Shield) and "SHAMAN"
  local onehand_discount = ((invType == Enum.InventoryType.IndexWeaponType) or (invType == Enum.InventoryType.IndexWeaponmainhandType)) and "HUNTER"
  local twohand_discount = (invType == Enum.InventoryType.Index2HweaponType) and "HUNTER"
  return wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount
end

function bepgp_prices_wrath:GetPrice(item,progress)
  if not (type(item)=="number" or type(item)=="string") then return end
  if not progress then progress = "T10" end
  local price1,price2,itemID,data,tier,useful
  local itemType, itemSubType, itemEquipLoc, icon, classID, subclassID
  local wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount, item_level
  itemID, itemType, itemSubType, itemEquipLoc, icon, classID, subclassID = GetItemInfoInstant(item)
  if (itemID) then
    local invType = GetItemInventoryTypeByID(itemID)
    data = prices[itemID]
    if (data) then
      local quality, ilevel, equip = unpack(data)
      item_level = tonumber(ilevel)
      tier = calcTier(ilevel)
      price1, price2 = getStaticValues(itemID, quality, ilevel, equip)
      wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount = GetDiscountDetail(invType, classID, subclassID)
    else
      return
    end
  end
  return price1, tier, price2, wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount, item_level
end

function bepgp_prices_wrath:OnEnable()
  local system = {func=bepgp_prices_wrath.GetPrice,flavor="_wrath"}
  bepgp:RegisterPriceSystem(name_version,system)
  local mzt,_,_,_,reason = GetAddOnInfo("MizusRaidTracker")
  if not (reason == "ADDON_MISSING" or reason == "ADDON_DISABLED") then
    local loading, finished = IsAddOnLoaded("MizusRaidTracker")
    if loading and finished then
      self:ADDON_LOADED("ADDON_LOADED","MizusRaidTracker")
    else
      self:RegisterEvent("ADDON_LOADED")
    end
  end
end

function bepgp_prices_wrath:ADDON_LOADED(event,...)
  if ... == "MizusRaidTracker" then
    self:UnregisterEvent("ADDON_LOADED")
    local MRT_ItemCost = function(mrt_data)
      local itemstring = mrt_data.ItemString
      local dkpValue = self:GetPrice(itemstring, bepgp.db.profile.progress)
      local itemNote
      if not dkpValue then
        dkpValue = 0
        itemNote = ""
      else
        local dkpValue2 = math.floor(dkpValue*bepgp.db.profile.discount)
        itemNote = string.format("%d or %d", dkpValue, dkpValue2)
      end
      return dkpValue, mrt_data.Looter, itemNote, "", true
    end
    if MRT_RegisterItemCostHandlerCore then
      MRT_RegisterItemCostHandlerCore(MRT_ItemCost, addonName)
    end
  end
end

function bepgp_prices_wrath:Recalculate()
  BastionLootDB._CACHE_ITEM_DATA = BastionLootDB._CACHE_ITEM_DATA or {}
  local stats = {}
  for i=29000,60000 do
    local itemID, itemType, itemSubType, itemEquipLoc, icon, classID, subclassID = GetItemInfoInstant(i)
    if itemID and EQUIPSLOT_MULTIPLIER_1[itemEquipLoc] then
      if not BastionLootDB._CACHE_ITEM_DATA[itemID] then
        BastionLootDB._CACHE_ITEM_DATA[itemID] = {-1,-1,itemEquipLoc}
      elseif BastionLootDB._CACHE_ITEM_DATA[itemID][1]==-1 then
        local itemAsync = Item:CreateFromItemID(itemID)
        itemAsync:ContinueOnItemLoad(function()
          local quality = itemAsync:GetItemQuality()
          local iLevel = itemAsync:GetCurrentItemLevel()
          if quality == 4 and iLevel >= 200 then
            local iLink = itemAsync:GetItemLink()
            stats.ITEM_MOD_RESILIENCE_RATING = nil
            GetItemStats(iLink,stats)
            if not stats.ITEM_MOD_RESILIENCE_RATING then
              local iName = itemAsync:GetItemName()
              BastionLootDB._CACHE_ITEM_DATA[itemID][1] = quality
              BastionLootDB._CACHE_ITEM_DATA[itemID][2] = iLevel
              BastionLootDB._CACHE_ITEM_DATA[itemID][4] = iName
            end
          end
        end)
      end
    end
  end
end

function bepgp_prices_wrath:Clean(wipe)
  if not BastionLootDB._CACHE_ITEM_DATA then return end
  if wipe then
    BastionLootDB._CACHE_ITEM_DATA = nil
    return
  end
  for itemID, data in pairs(BastionLootDB._CACHE_ITEM_DATA) do
    if data[1]==-1 then
      BastionLootDB._CACHE_ITEM_DATA[itemID] = nil
    end
  end
end

function bepgp_prices_wrath:Distribution(ilvlMin,ilvlMax)
  local count = 0
  local atLevel = {}
  for k,v in pairs(prices) do
    atLevel[v[2]] = atLevel[v[2]] and atLevel[v[2]]+1 or 1
    if ilvlMax then
      if v[2]>=ilvlMin and v[2]<=ilvlMax then
        count = count + 1
      end
    else
      if ilvlMin then
        if v[2]==ilvlMin then
          count = count + 1
        end
      end
    end
  end
  if ilvlMax then
    bepgp:debugPrint(format("Items between %d-%d iLvl: %d",ilvlMin,ilvlMax,count))
  elseif ilvlMin then
    bepgp:debugPrint(format("Items at %d iLvl: %d",ilvlMin, count))
  end
  local keys = GetKeysArray(atLevel)
  table.sort(keys)
  for _,iLvl in ipairs(keys) do
    bepgp:debugPrint(format("Items at %d: %d",iLvl,atLevel[iLvl]))
  end
end

bepgp_prices_wrath._prices = prices

--[[
Enum.ItemClass[Armor|Weapon|Miscellaneous]
Enum.ItemArmorSubclass[Cloth|Leather|Mail|Plate|Shield|Libram|Idol|Totem|Sigil|Relic]
Enum.ItemWeaponSubclass[Wand]
Enum.ItemMiscellaneousSubclass[Junk]
Enum.InventoryType[IndexNonEquipType|IndexHeadType|IndexNeckType|IndexShoulderType|IndexChestType|IndexWaistType|IndexLegsType|IndexFeetType|IndexWristType|IndexHandType|IndexFingerType|IndexTrinketType|IndexWeaponType|IndexShieldType|IndexRangedType|IndexCloakType|Index2HweaponType|IndexRobeType|IndexWeaponmainhandType|IndexWeaponoffhandType|IndexHoldableType|IndexRangedrightType|IndexRelicType]
]]
